(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2904403,     102395]*)
(*NotebookOutlinePosition[   2905179,     102421]*)
(*  CellTagsIndexPosition[   2905135,     102417]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
MDA-Chapter 3: Design of Mechanisms - 3.4 Paths of Crank-Rocker \
Mechanisms\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell["crank-rocker mechanismus: Basic functions", "Subsection"],

Cell["\<\
Clear[par,\[CurlyPhi],\[Psi],\[Psi]1,\[Psi]2,\[CurlyPhi]0,\[Psi]0,a,\
b,c,d];\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
\[Sigma] = ArcTan[a Sin[\[CurlyPhi]]/(d-a Cos[\[CurlyPhi]])]
\[CapitalDelta] = Simplify[Sqrt[(a Sin[\[CurlyPhi]])^2 + (d-a \
Cos[\[CurlyPhi]])^2]]
\[Lambda] = Simplify[ArcCos[(\[CapitalDelta]^2 + b^2 - c^2) / (2 b \
\[CapitalDelta])] ]
f\[Psi] = \[Pi] - (\[Sigma] + \[Lambda])
f\[Psi]2 = \[Pi] - (\[Sigma] - \[Lambda])\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(ArcTan[\(a\ Sin[\[CurlyPhi]]\)\/\(d - a\ Cos[\[CurlyPhi]]\)]\)], \
"Output"],

Cell[BoxData[
    \(\@\(a\^2 + d\^2 - 2\ a\ d\ Cos[\[CurlyPhi]]\)\)], "Output"],

Cell[BoxData[
    \(ArcCos[\(a\^2 + b\^2 - c\^2 + d\^2 - 2\ a\ d\ Cos[\[CurlyPhi]]\)\/\(2\ \
b\ \@\(a\^2 + d\^2 - 2\ a\ d\ Cos[\[CurlyPhi]]\)\)]\)], "Output"],

Cell[BoxData[
    \(\[Pi] - 
      ArcCos[\(a\^2 + b\^2 - c\^2 + d\^2 - 2\ a\ d\ Cos[\[CurlyPhi]]\)\/\(2\ \
b\ \@\(a\^2 + d\^2 - 2\ a\ d\ Cos[\[CurlyPhi]]\)\)] - 
      ArcTan[\(a\ Sin[\[CurlyPhi]]\)\/\(d - a\ Cos[\[CurlyPhi]]\)]\)], \
"Output"],

Cell[BoxData[
    \(\[Pi] + 
      ArcCos[\(a\^2 + b\^2 - c\^2 + d\^2 - 2\ a\ d\ Cos[\[CurlyPhi]]\)\/\(2\ \
b\ \@\(a\^2 + d\^2 - 2\ a\ d\ Cos[\[CurlyPhi]]\)\)] - 
      ArcTan[\(a\ Sin[\[CurlyPhi]]\)\/\(d - a\ Cos[\[CurlyPhi]]\)]\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[CurlyPhi]i = 
      Pi + ArcCos[\((d^2 + \((c - a)\)^2 - 
                b^2)\)\ /\ \((2\ \((c - 
                    a)\)\ d)\)]; \), "\[IndentingNewLine]", 
    \(\[CurlyPhi]a = 
      ArcCos[\((d^2 + \((c + a)\)^2 - 
              b^2)\)\ /\ \((2\ \((c + 
                  a)\)\ d)\)]; \), "\[IndentingNewLine]", 
    \(f\[CurlyPhi]0 = \[CurlyPhi]i - \[CurlyPhi]a\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(\[Pi] + 
      ArcCos[\(\(-b\^2\) + \((\(-a\) + c)\)\^2 + d\^2\)\/\(2\ \((\(-a\) + \
c)\)\ d\)] - 
      ArcCos[\(\(-b\^2\) + \((a + c)\)\^2 + d\^2\)\/\(2\ \((a + c)\)\ \
d\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[Psi]i = 
      Pi - ArcCos[\((d^2 + 
                b^2 - \((c - 
                      a)\)^2)\)\ /\ \((2\ b\ d)\)]; \), \
"\[IndentingNewLine]", 
    \(\[Psi]a = 
      Pi - ArcCos[\((d^2 + 
                b^2 - \((c + 
                      a)\)^2)\)\ /\ \((2\ b\ d)\)]; \), \
"\[IndentingNewLine]", 
    \(f\[Psi]0 = \[Psi]i - \[Psi]a\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(\(-ArcCos[\(b\^2 - \((\(-a\) + c)\)\^2 + d\^2\)\/\(2\ b\ d\)]\) + 
      ArcCos[\(b\^2 - \((a + c)\)\^2 + d\^2\)\/\(2\ b\ d\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Mu]min1 = 
      ArcCos[\((c^2 + b^2 - \((d - a)\)^2)\)/\((2\ b\ c)\)]\)], "Input"],

Cell[BoxData[
    \(ArcCos[\(b\^2 + c\^2 - \((\(-a\) + d)\)\^2\)\/\(2\ b\ c\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Mu]min2 = 
      Pi - ArcCos[\((c^2 + b^2 - \((d + a)\)^2)\)/\((2\ b\ c)\)]\)], "Input"],

Cell[BoxData[
    \(\[Pi] - 
      ArcCos[\(b\^2 + c\^2 - \((a + d)\)\^2\)\/\(2\ b\ c\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Grashof = Min[a, b, c, d] + Max[a, b, c, d]\)], "Input"],

Cell[BoxData[
    \(Max[a, b, c, d] + Min[a, b, c, d]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\[Delta] = 
      ArcTan[\((d + b\ Cos[\[Psi]] - 
            a\ Cos[\[CurlyPhi]])\), \((b\ Sin[\[Psi]] - 
            a\ Sin[\[CurlyPhi]]\ )\)]\)], "Input"],

Cell[BoxData[
    \(ArcTan[
      d - a\ Cos[\[CurlyPhi]] + b\ Cos[\[Psi]], \(-a\)\ Sin[\[CurlyPhi]] + 
        b\ Sin[\[Psi]]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(xK\  = \ 
      A0x\  + \ a\ Cos[\[CurlyPhi] + \[Gamma]0] + 
        k\ Cos[\[Kappa] + \[Delta] + \[Gamma]0]\), "\[IndentingNewLine]", 
    \(yK\  = \ 
      A0y\  + \ a\ Sin[\[CurlyPhi] + \[Gamma]0] + 
        k\ Sin[\[Kappa] + \[Delta] + \[Gamma]0]\)}], "Input"],

Cell[BoxData[
    \(A0x + k\ Cos[\[Gamma]0 + \[Delta] + \[Kappa]] + 
      a\ Cos[\[Gamma]0 + \[CurlyPhi]]\)], "Output"],

Cell[BoxData[
    \(A0y + k\ Sin[\[Gamma]0 + \[Delta] + \[Kappa]] + 
      a\ Sin[\[Gamma]0 + \[CurlyPhi]]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3.1\tCalculate the path of a coupler point K", "Section",
  CellChangeTimes -> {{3.4198523331725683`*^9, 3.419852336349229*^9}}],

Cell[CellGroupData[{

Cell["par set 1  (\[Psi]->f\[Psi]", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(par = {A0x \[Rule] 22, 
        A0y \[Rule] 59, \[Gamma]0 \[Rule] \(-57\)\ \[Degree], a \[Rule] 47, 
        b \[Rule] 52, c \[Rule] 17, d \[Rule] 35.5, \[Kappa] -> 0, 
        k \[Rule] 58.5}\)], "Input",
  CellChangeTimes -> {{3.419852365989037*^9, 3.4198524491248837`*^9}}],

Cell[BoxData[
    \({A0x \[Rule] 22, A0y \[Rule] 59, \[Gamma]0 \[Rule] \(-57\)\ \[Degree], 
      a \[Rule] 47, b \[Rule] 52, c \[Rule] 17, 
      d \[Rule] 35.5`, \[Kappa] \[Rule] 0, k \[Rule] 58.5`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xKpar = \(\(xK /. \[Delta] -> f\[Delta]\) /. \[Psi] -> f\[Psi]\) /. 
          par;\)\), "\n", 
    \(\(yKpar = \(\(yK /. \[Delta] -> f\[Delta]\) /. \[Psi] -> f\[Psi]\) /. 
          par;\)\), "\n", 
    \(\(plo1\  = \ 
        ParametricPlot[{xKpar, yKpar}, {\[CurlyPhi], 47.8\ Degree, 
            112.7\ Degree}, PlotRange \[Rule] {{0, 130}, {0, 120}}, 
          GridLines \[Rule] Automatic, 
          PlotLabel \[Rule] "\<Path of K - par set 1\>"];\)\)}], "Input",
  CellChangeTimes -> {{3.4198524708446827`*^9, 3.4198524779235077`*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.00769231 0 0.00515028 [
[.15385 -0.0125 -6 -9 ]
[.15385 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.46154 -0.0125 -6 -9 ]
[.46154 -0.0125 6 0 ]
[.61538 -0.0125 -6 -9 ]
[.61538 -0.0125 6 0 ]
[.76923 -0.0125 -9 -9 ]
[.76923 -0.0125 9 0 ]
[.92308 -0.0125 -9 -9 ]
[.92308 -0.0125 9 0 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.15385 0 m
.15385 .61803 L
s
.30769 0 m
.30769 .61803 L
s
.46154 0 m
.46154 .61803 L
s
.61538 0 m
.61538 .61803 L
s
.76923 0 m
.76923 .61803 L
s
.92308 0 m
.92308 .61803 L
s
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.15385 0 m
.15385 .00625 L
s
[(20)] .15385 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(40)] .30769 -0.0125 0 1 Mshowa
.46154 0 m
.46154 .00625 L
s
[(60)] .46154 -0.0125 0 1 Mshowa
.61538 0 m
.61538 .00625 L
s
[(80)] .61538 -0.0125 0 1 Mshowa
.76923 0 m
.76923 .00625 L
s
[(100)] .76923 -0.0125 0 1 Mshowa
.92308 0 m
.92308 .00625 L
s
[(120)] .92308 -0.0125 0 1 Mshowa
.125 Mabswid
.03846 0 m
.03846 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.5 0 m
.5 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(20)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(40)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(60)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(80)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(100)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(120)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
123.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(par) show
159.000 13.000 moveto
(set) show
183.000 13.000 moveto
(1) show
189.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.896 .43677 m
.93601 .39293 L
.95327 .3677 L
.96388 .34812 L
.97012 .33369 L
.97472 .32009 L
.97639 .31388 L
.97777 .30764 L
.97872 .30225 L
.97935 .29757 L
.97976 .29335 L
.97991 .2913 L
.97997 .29015 L
.98002 .2891 L
.98005 .28813 L
.98008 .28711 L
.98009 .28653 L
.98009 .28599 L
.9801 .28499 L
.98009 .28405 L
.98008 .28319 L
.98006 .28226 L
.98003 .28128 L
.98 .28048 L
.97995 .27963 L
.97986 .27812 L
.97971 .27636 L
.97956 .27479 L
.97913 .27143 L
.97854 .26796 L
.97717 .26208 L
.97561 .25708 L
.9736 .25201 L
.96876 .24298 L
.96355 .23591 L
.95728 .2294 L
.95072 .22406 L
.94331 .21927 L
.92883 .21241 L
.92088 .20962 L
.91205 .20711 L
.90335 .20512 L
.89359 .20335 L
.88387 .20197 L
.87463 .20094 L
.86534 .20015 L
.85989 .19978 L
.85483 .19948 L
.84465 .19903 L
.83892 .19885 L
Mistroke
.8334 .19871 L
.82811 .19861 L
.82512 .19857 L
.8224 .19854 L
.81983 .19851 L
.81848 .1985 L
.81704 .1985 L
.81578 .19849 L
.81439 .19848 L
.81378 .19848 L
.81312 .19848 L
.81251 .19848 L
.81193 .19848 L
.81123 .19848 L
.81085 .19848 L
.81045 .19848 L
.81005 .19848 L
.80963 .19848 L
.80887 .19848 L
.80816 .19848 L
.80751 .19848 L
.80679 .19848 L
.80602 .19848 L
.80426 .19849 L
.80261 .1985 L
.79949 .19851 L
.79371 .19856 L
.78736 .19863 L
.77502 .19881 L
.76156 .19905 L
.7362 .19958 L
.7074 .20018 L
.67763 .20072 L
.66157 .20095 L
.65281 .20106 L
.64326 .20116 L
.6346 .20124 L
.62477 .20131 L
.62038 .20134 L
.61558 .20136 L
.61132 .20138 L
.60671 .2014 L
.60418 .2014 L
.60187 .20141 L
.5995 .20141 L
.59729 .20142 L
.5947 .20142 L
.59333 .20142 L
.59263 .20142 L
.59187 .20142 L
Mistroke
.59059 .20142 L
.5894 .20142 L
.58866 .20142 L
.58796 .20142 L
.58665 .20142 L
.58594 .20142 L
.58527 .20142 L
.58401 .20142 L
.58266 .20142 L
.58118 .20142 L
.5785 .20141 L
.57601 .20141 L
.5702 .2014 L
.56393 .20138 L
.55306 .20133 L
.54087 .20127 L
.51716 .20113 L
.50277 .20104 L
.49474 .20099 L
.4858 .20094 L
.47762 .20091 L
.47311 .20089 L
.4681 .20087 L
.46581 .20087 L
.46336 .20086 L
.46124 .20086 L
.45889 .20086 L
.45664 .20086 L
.45419 .20086 L
.45184 .20086 L
.44967 .20086 L
.44784 .20086 L
.44611 .20086 L
.44417 .20087 L
.44207 .20087 L
.43766 .20089 L
.43348 .20091 L
.42948 .20093 L
.42496 .20097 L
.41617 .20105 L
.40474 .20121 L
.39761 .20134 L
.39049 .20149 L
.38305 .20168 L
.37377 .20195 L
.349 .20297 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{405.312, 250.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006E0000nR000`400?l00000o`00003ooooooonF
ooooo`00E?ooool5o`0000?ooooo0_l0000_ooooo`?o00000oooool2o`0002gooooo0ol00004oooo
o`;o0000;_ooool3o`0000Cooooo0_l0000[ooooo`?o00001?ooool2o`0000Cooooo0_l0000Woooo
o`?o00000_ooool5o`0000?ooooo0_l0000Sooooo`00EOooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002co
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Oooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
02;ooooo001Fooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000;?ooool5o`00
00;ooooo00Co0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo0000;?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00009oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00008_ooool005Oooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo02[ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000[oooo
o`Co00000oooool01?l0003oooooooooool0000]ooooo`?o00000oooool01?l0003oooooooooool0
000[ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Wooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo023ooooo001Dooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000]ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000:ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002cooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Oooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08?ooool005Cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002kooooo0_l00003oooo
o`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
000/ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Zooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Kooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Rooooo`00EOoo
ool3o`0000Cooooo0_l0000`ooooo`03o`000?oooooooooo00;ooooo0_l0000^ooooo`;o00001?oo
ool2o`0002kooooo0ol00004ooooo`;o0000;?ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0002Sooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000Sooooo`00oooooonF
ooooo`00oooooonFooooo`00oooooonFooooo`00oooooonFooooo`00oooooonFooooo`008ooooooo
o`0006Ko00003Oooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ioooo
o`008oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo000Sooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oo
oooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000S
ooooo`?o0000=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000oooooooo
ool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09ooo
ool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?o
oooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo0ol0
000dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0doooo
o`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Woooo
o`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008ooo
ool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0
003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool3o`0003Cooooo
00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo
00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo
000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001o
ooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Soooo
o`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`00
0?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Cooooo`Go00000oooool2
o`0000Kooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool09oooool001Cooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Eooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00001Oooool3o`000?oo001oHol007l=ooooo`005_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0Wooooo`004oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0Wooooo`004oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`005?ooool3o`0000Cooooo
0_l00006ooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000S
ooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03
o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo02Oooooo000Sooooo`?o0000=?ooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09ooo
ool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?o
oooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o
0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000oooo
ooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool09oooool002?ooooo0ol0000dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008ooo
ool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0
003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003ooooo
ooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0d
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0W
ooooo`008oooool3o`0003Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`00
0?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oo
oooo000Eooooo`?o00000oooool2o`0000Kooooo00?o0000ooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0Soooooc?o00005?ooool00ol007ooooooooooo`0Wooooo`005_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool04?oooon0o`00017ooooo00?o001oooooooooool0
7oooool9o`0000_ooooo00?o001oooooooooool09oooool001?ooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo00_ooooo1Ol0000Sooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
=?ooool00ol007ooooooooooo`0Xooooo`Oo00001?ooool00ol007ooooooooooo`0Wooooo`004ooo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo0ol0003oo`00Od;o
001o0ol0000No`00O`gooooo000Dooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<_ooool3o`0002Sooooo000Eooooo`;o00000oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`04
o`00Oooooooo0000o`0002Kooooo000Fooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03
o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`04
o`00Ooooooooooooooooo`?o00008oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007oo
ooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oo
ooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool01?ooool2o`00027o
oooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo00Kooooo00?o0000ooooooooool07_ooool002?ooooo00?o
0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool01oooool00ol0003oooooooooo`0Mooooo`008oooool00ol0003oooooooooo`0d
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`08
ooooo`03o`000?oooooooooo01cooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00Wooooo0_l0000Loooo
o`008oooool3o`0003Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo00_ooooo00?o0000ooooooooool06Oooool002?ooooo00?o0000ooooooooool0
=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
3?ooool00ol0003oooooooooo`0Hooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooo
oooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooo
oooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0<ooooo`03o`000?oo
oooooooo01Sooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool0
0ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool0
0ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00gooooo00?o0000ooooooooool05oooool0
02?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo
03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo
03?ooooo00?o001oooooooooool03Oooool00ol0003oooooooooo`0Gooooo`008oooool00ol0003o
ooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo000Sooooo`03o`000?oooooooooo03Cooooo
00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo
00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00kooooo
00?o0000ooooooooool05_ooool002?ooooo00?o0000ooooooooool0=?ooool00ol007oooooooooo
o`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oooooooooo
o`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool03oooool00ol0003ooooooooo
o`0Eooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo000Soooo
o`?o0000=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool04?ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0dooooo`03
o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03
o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0@ooooo`03
o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0
=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo013ooooo00?o0000ooooooooool0
5?ooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool04?ooool00ol0003oooooooooo`0Dooooo`008oooool0
0ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool0
0ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool0
0ol007ooooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo
03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo
03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo
017ooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007oo
ooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oo
ooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo
000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo017ooooo00?o0000ooooooooool04oooool002?ooooo0ol0000d
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0A
ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo017ooooo00?o0000oooo
ooooool04oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool04Oooool00ol0003oooooooooo`0Cooooo`00
8oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oo
oooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo017ooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool0=?ooool0
0ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool0
0ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool04Oooool0
0ol0003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo
03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo
03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Aooooo`03o`000?oooooooooo
01?ooooo000Dooooo`?o00001?ooool2o`0000Kooooo00?o0000ooooooooool0=?ooool00ol007oo
ooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oo
ooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`004oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo000Cooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`?o0000ool007mJ
o`00O`03o`000?l007oo001o00Ko001o3Oooool001?ooooo1?l00003ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool04Oooool00ol0003oooooooooo`0Cooooo`004oooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0=?ooool0
0ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool0
0ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool04?ooool0
0ol0003oooooooooo`0Dooooo`005?ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool04?ooool00ol0003oooooooooo`0Dooooo`005Oooool2o`00
00Cooooo0_l00006ooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo013ooooo00?o0000ooooooooool05?ooool002?o
oooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool04?ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003ooooo
ooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0?ooooo`03o`000?oooooooooo01Gooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00oooooo00?o
0000ooooooooool05Oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool03oooool00ol0003oooooooooo`0E
ooooo`008oooool3o`0003Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo00kooooo00?o0000ooooooooool05_ooool002?ooooo00?o0000oooooooo
ool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool03_ooool00ol0003oooooooooo`0Fooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0=ooooo`03o`00
0?oooooooooo01Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00gooooo00?o0000ooooooooool05ooo
ool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool03Oooool00ol0003oooooooooo`0Gooooo`008oooool00ol0
003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo000Sooooo`03o`000?oooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00co
oooo00?o0000ooooooooool06?ooool002?ooooo00?o0000ooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool02oooool00ol0003ooooo
ooooo`0Iooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo000S
ooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo00[ooooo00?o0000ooooooooool06_ooool002?ooooo0ol0000doooo
o`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`09oooo
o`03o`000?oooooooooo01_ooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00Wooooo00?o0000oooooooo
ool06oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool02?ooool00ol0003oooooooooo`0Looooo`008ooo
ool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`08ooooo`03o`000?oooooooooo01cooooo000Sooooo`03o`000?oooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo00Oooooo00?o0000ooooooooool07Oooool002?ooooo00?o0000ooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool01_ooool00ol0
003oooooooooo`0Nooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`06ooooo`03o`000?oooooooooo01ko
oooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo00Gooooo00?o0000ooooooooool07oooool002?ooooo00?o
0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool01?ooool00ol0003oooooooooo`0Pooooo`008oooool3o`0003Cooooo00?o001o
ooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00Cooooo00?o0000
ooooooooool08?ooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool00oooool00ol0003oooooooooo`0Qoooo
o`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`02ooooo`03o`000?oooooooooo02;ooooo000Sooooo`03o`00
0?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo00;ooooo00?o0000ooooooooool08_ooool002?ooooo00?o0000ooooooooool0=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00Go001ooooooooooooooooo
o`00000Uooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool01?l007ooooooooooool0000Vooooo`005?ooool3o`0000Cooooo0_l0
0006ooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooo000002Oooooo000Cooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0
=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
=?ooool00ol007ooooooooooo`0cooooo`03o`00Ool0003ooooo02Oooooo000Cooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`000?oooooooooo02Oo
oooo000Dooooo`?o00000oooool01?l0003oooooooooool00005ooooo`?o0000ool007m5o`00O`03
o`000?l007oo001o01_o001o3Oooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo037ooooo00?o0000ooooool007l0:Oooool001?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0=?ooool0
0ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool0
0ol007ooooooooooo`0dooooo`03o`00Oooooooooooo037ooooo00?o0000ooooool007l0:Oooool0
01Cooooo0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo
03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo
03Cooooo00?o001oooooooooool0<?ooool01?l0003oooooooooool007lYooooo`008oooool00ol0
003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0;oooool01Ol0
003ooooooooooooooooo001o02Wooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0^ooooo`03o`000?oooooooooo00;ooooo00?o001ooooo
ooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03
o`00Oooooooooooo02gooooo00?o0000ooooooooool00oooool00ol007ooooooooooo`0Wooooo`00
8oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
;?ooool00ol0003oooooooooo`04ooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oo
oooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0[ooooo`03o`000?oo
oooooooo00Gooooo00?o001oooooooooool09oooool002?ooooo0ol0000dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0:_ooool00ol0003oooooooooo`06ooooo`03o`00Oooooooo
oooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oo
oooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000S
ooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03
o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0
=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0
=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`?o0000=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09ooo
ool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?o
oooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o
0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000oooo
ooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo0ol0000dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008ooo
ool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0
003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003ooooo
ooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`003_ooool3o`0000Cooooo0_l00004
ooooo`;o00001_ooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0Wooooo`003oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0Wooooo`003oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001Oooool3o`000?oo001oHol007l=ooooo`003oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0Wooooo`003oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo
03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo
03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`003_ooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo02Oooooo000?ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001_ooool00ol0
003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003ooooo
ooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0d
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0d
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0W
ooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool3o`0003Cooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`00
0?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Co
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oo
oooo000Sooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03Cooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000S
ooooo`03o`000?oooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo02Oooooo000Sooooo`?o0000=?ooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000oooooooo
ool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?oo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09ooo
ool002?ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?o
oooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0=?ooool00ol007oooooo
ooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o
0000ooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0=?ooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool09oooool002?ooooo0ol0000dooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0doooo
o`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0doooo
o`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Woooo
o`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00
Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008ooo
ool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooo
oooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0
003oooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0Wooooo`003_ooool3o`0000;ooooo1Ol00003ooooo`;o00001_ooool00ol0003o
ooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0dooooo`03o`00Oooooooooooo03Cooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0Wooooo`003oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo
03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0dooooo`03o`00Oooooooooooo
03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`003oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool3o`00
0?oo001oHol007l=ooooo`003oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`3oooooogKooooo000?ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0?ooooooM_ooool0
00kooooo0_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
003oooooogSooooo000?ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o0000oooooomi
ooooo`00oooooonFooooo`00g_ooool3o`000;Cooooo003Oooooo`03o`000?oooooooooo0;?ooooo
002Fooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000;ooooo1Ol0
0007ooooo`?o000000?oooooo`000?l000004oooool3o`0000?ooooo1?l000001?oooooo0000o`00
0?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00009ooooo`?o0000Poooool009Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0000Dooooo`06o`000?ooooooooooo`000?oooooo
00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooool000001_ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo08;ooooo002Gooooo`03o`000?oooooooooo
00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00
0009ooooo`Co00002?ooool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003ooooo
ooooo`09ooooo`?o00000_ooool5o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`22ooooo`00Uoooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Sooooo0_l0000Fooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`22ooooo`00
Uoooool01?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`?o
00000oooool4o`0000Sooooo00?o0000ooooool000005?ooool4o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000002?ooool4o`0000;ooooo0ol00002ooooo`Co00002_ooool00ol0003o
ooooooooo`22ooooo`00Uoooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00
03Sooooo00?o0000ooooooooool02Oooool2o`0008Cooooo002Fooooo`Co00002Oooool00ol0003o
ooooooooo`02ooooo`;o00004oooool2o`0000Oooooo0ol000000ooooooo0000o`00000gooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0P_ooool00?ooooooU_ooool00?ooooooU_oo
ool00001\
\>"],
  ImageRangeCache->{{{0, 404.312}, {249.5, 0}} -> {-13.0622, -7.34537, \
0.365841, 0.54641}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Animation of double-rocker mecha par 1 (\[Psi]\[Rule]f\[Psi])\
\>", \
"Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pa = par\)], "Input"],

Cell[BoxData[
    \({A0x \[Rule] 22, A0y \[Rule] 59, \[Gamma]0 \[Rule] \(-57\)\ \[Degree], 
      a \[Rule] 47, b \[Rule] 52, c \[Rule] 17, 
      d \[Rule] 35.5`, \[Kappa] \[Rule] 0, k \[Rule] 58.5`}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(f\[Psi]i = f\[Psi];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rA0x = A0x /. pa;\)\), "\n", 
    \(\(rA0y = A0y /. pa;\)\), "\n", 
    \(\(rB0x = d\ Cos[\[Gamma]0] /. pa;\)\), "\n", 
    \(\(rB0y = d\ Sin[\[Gamma]0] /. pa;\)\), "\n", 
    \(\(rax\  = \ 
        A0x\  + \ a\ Cos[\[CurlyPhi] + \[Gamma]0] /. pa;\)\), "\n", 
    \(\(ray\  = \ 
        A0y\  + \ a\ Sin[\[CurlyPhi] + \[Gamma]0] /. pa;\)\), "\n", 
    \(\(rbx\  = \ \(A0x\  + \ b\ Cos[\[Psi] + \[Gamma]0]\  + 
              d\ Cos[\[Gamma]0] /. \[Psi] \[Rule] f\[Psi]i\) /. 
          pa;\)\), "\n", 
    \(\(rby\  = \ \(A0y\  + \ b\ Sin[\[Psi] + \[Gamma]0]\  + 
              d\ Sin[\[Gamma]0] /. \[Psi] \[Rule] f\[Psi]i\) /. 
          pa;\)\), "\n", 
    \(\(rkx\  = \ \(\(xK /. \[Delta] \[Rule] f\[Delta]\) /. \[Psi] \[Rule] 
              f\[Psi]i\) /. pa;\)\), "\n", 
    \(\(rky\  = \ \(\(yK /. \[Delta] \[Rule] f\[Delta]\) /. \[Psi] \[Rule] 
              f\[Psi]i\) /. pa;\)\), "\n", 
    \(\(lmax\  = \ Max[a, b, c, d] /. pa;\)\), "\n", 
    \(\(Plo0 = 
        Plot[0, {i, 0, 1}, 
          PlotRange \[Rule] {{\(-100\), 300}, {\(-150\), 200}}, 
          Frame \[Rule] True, AspectRatio \[Rule] Automatic, 
          PlotLabel \[Rule] "\<Coupling Path par set 2)\>"];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{108, 94.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001/0000GR000`400?l00000o`00003oK?ooool0
06cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?oo
ool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00
K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/oooo
o`00K?ooool006cooooo000/oooooaCo000000?oooooo`000?l000000_l0000Wooooo`00:oooool0
0ol0003oooooo`00000Co`000005ooooool0003o0000ooooool000009_ooool002Gooooo1Ol00004
oooooa?o000000Goooooo`000?l0003oooooo`00000Vooooo`00;_oooolCo`000005ooooool0003o
0000ooooool000009_ooool002_ooooo1_l000000ooooooo0000o`000004o`000003ooooool0003o
000000Ko000000Goooooo`000?l0003oooooo`00000Vooooo`00:oooool00ol0003oooooo`000003
o`000003ooooool0003o000000Co000000?oooooo`000?l000001_l000001Ooooooo0000o`000?oo
oooo000002Kooooo000[oooooaGo000000?oooooo`000?l000000_l0000Wooooo`00K?ooool001_o
oooo0ol00004ooooo`;o00001?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo01?o0000;Oooool001Co
oooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`Co000000?oooooo`000?oo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo000Looooo`04o`00
0?ooooooooooooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`006_ooool5o`0000;o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`006oooool2o`0000Cooooo00Co0000
oooooooooooo00000_ooool4o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0[ooooo`007?ooool01?l0003oooooooooooooool4o`0000?ooooo1?l0
00000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:ooo
ool0023ooooo1?l00003ooooo`Co000000?oooooo`000?l000004Ol0000]ooooo`008?ooool5o`00
00;ooooo1?l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:oooool001_ooooo0ol00004ooooo`?o00000_ooool4o`000003ooooool0003ooooo00?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`007?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00004
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool001_ooooo0ol00002oooo
o`Go00000_ooool4o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0[ooooo`007?ooool01?l0003oooooooooooooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0:oooool001[ooooo1Ol000000ooooooo0000o`000003o`0000;ooooo1?l000000ooo
oooo0000ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool001_o
oooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool0
01cooooo00Co0000oooooooooooooooo1Ol00002ooooo`Co000000?oooooo`000?ooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo000Kooooo`?o00000_ooool2o`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000Bo`0002gooooo000Joooo
o`06o`000?oooooo0000ooooool0003ooooo1Ol00002ooooo`Co0000@Oooool000;o00005_ooool3
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo01Cooooo0ol0000Xooooo`0000?o0000ooooooooool06?ooool3o`0000Cooooo0_l0
0004ooooo`;o00006?ooool00ol0003oooooooooo`0Wooooo`000ol00002ooooo`Go000000?ooooo
o`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l0
0007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l0
00001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00003ooooo`0000Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00000_oo
ool00004o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003oooooooooo`09
ooooo`?o00000_ooool5o`0000;ooooo00?o0000ooooooooool00oooool00004o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?o
oooo0003o`0000Cooooo00Co0000oooooooooooooooo0ol00003ooooo`Co00000oooool5o`0000Oo
oooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002?ooool4o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo0ol00002oooo
o`Co00000oooool000Oooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`03oooo
o`001Oooool3o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000oooooooo
ool00_ooool2o`0002oooooo00?o0000ooooooooool00oooool006cooooo001/ooooo`00K?ooool0
06cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?oo
ool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00
K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/oooo
o`00K?ooool00001\
\>"],
  ImageRangeCache->{{{0, 107}, {93.5, 0}} -> {-1118.62, -1005.7, 22.778, \
22.778}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Do[
  PloMecha1 = Graphics[{
        Circle  [{rA0x,rA0y},a/.pa],

        Circle  [{rA0x,rA0y},lmax/100],
        Circle  [{rax,ray},lmax/100],
        Circle  [{rbx,rby},lmax/100],
        Circle  [{rkx,rky},lmax/100],
        Circle  [{rB0x,rB0y},lmax/100],
        
\t\tLine  [{{rA0x,rA0y}, {rB0x,rB0y}}],
\t\tLine  [{{rA0x,rA0y}, {rax,ray}}],
\t\tLine  [{{rB0x,rB0y}, {rbx,rby}}],
\t\tLine  [{{rax,ray}, {rbx,rby}, {rkx,rky}, {rax,ray}}],

        Text  [A0,{rA0x+lmax/30, rA0y-lmax/30}], 
        Text  [A ,{rax+lmax/30, ray+lmax/30}], 
        Text  [B ,{rbx+lmax/30, rby+lmax/30}], 
        Text  [K ,{rkx+lmax/30, rky+lmax/30}], 
        Text  [B0,{rB0x+lmax/30,rB0y-lmax/30}]}]; 
   Show[Plo0, plo3, PloMecha1];
 ,{\[CurlyPhi], 48 Degree, 112 Degree, 6 Degree}];  \
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.42105 .50412 .0013 0 365.73 arc
s
newpath
.45787 .52536 .0013 0 365.73 arc
s
newpath
.54774 .5772 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.42105 .50412 L
s
.29834 .30057 m
.45787 .52536 L
s
.42105 .50412 m
.45787 .52536 L
.54774 .5772 L
.42105 .50412 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.42539 .50845 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.4622 .52969 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.55207 .58153 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool5o`000003ooooool0003ooooo00;o0000Zoooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
[Oooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Wooooo00Co0000oooooooooooo0000[Oooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo00000:_ooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Z?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Wooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0:Cooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool01oooool001Cooooo
0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool01oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Oooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0XOooool00ol0003ooooo
ooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooooco00002Oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Oooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Woooool00ol0003ooooo
ooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Woooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Kooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`Oo0000
2oooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool01?ooool5o`000003ooooool0003ooooo00Cooooo1_l0
0006ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool01?l0003oooooooooooooool3o`0000Kooooo00?o0000ooooooooool02Ooo
ool2o`0000Gooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`Co00002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0jooooo`;o00003?ooool00ol0003oooooooooo`0<ooooo`;o00000oooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000>_ooool00ol0003o
ooooo`00000<ooooo`03o`000?oooooooooo00kooooo0_l00002ooooo`03o`000?oooooooooo09Oo
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`0000co
oooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0002Iooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000<oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooool00000VOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo000009Sooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooo`00002Gooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooool00000U_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`;o0000U_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo0_l0002Dooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05oooool2o`0009Cooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool05oooool2o`0009Cooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06?ooool2o`0009?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooo`00002Booooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo0000TOooool00ol0003oooooooooo`07
ooooo`006oooool2o`00033ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Oooooo<ol0001aooooo`;o00002Oooool001_ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooo
oooooooo1_l0000Aooooo`04o`000?ooooooooooo`0001kooooo0ol0001_ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`04o`000?oooooo0000o`0001Sooooo00Co0000oooooooooooo00007ooo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`;o00006_ooool0
1?l0003oooooooooool0000Pooooo`;o0000KOooool00ol0003oooooooooo`07ooooo`003Oooool3
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`;o00006oooool01Ol0003ooooooooooooooooo0000023ooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool3o`000003ooooool0003ooooo01_ooooo
00Go0000ooooooooooooooooo`00000Oooooo`;o0000K?ooool00ol0003oooooooooo`07ooooo`00
4?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000^ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01Sooooo1_l000000ooooooo0000ooooo`0Nooooo`03o`000?oooooooooo06So
oooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`Ko00000_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool000cooooo
1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Aooooo`Ko000000?oooooo`000?l000001?l00002ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooool0003o0000ooooo`03o`00
00;ooooo0_l00009ooooo`Ko00002?ooool3o`0000;ooooo00Co0000oooooooooooo00007Oooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`00
00Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00000oooool2o`000005ooooool0003oooooooooool000000ooo
ool5o`0000kooooo0ol00003ooooo`?o00007Oooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Ko000000?oooooo`000?l000001Ol0
000Dooooo`;o00001Oooool2o`0001cooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0002gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003ooooo0ol00002ooooo`03o`000?oo
oooooooo01Cooooo0ol00006ooooo`Co00006Oooool00ol0003oooooooooo`1Yooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`04o`000?oooooo
ooooo`0001Sooooo00?o0000ooooooooool01Oooool4o`0001Sooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00005oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o0000
5oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00006ooooo`;o0000
1Oooool2o`0001Sooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000Wooooo`03o`00
0?oooooooooo00Kooooo00Co0000oooooooooooo00000_ooool2o`0001?ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00cooooo00Co0000oooooooooooo00009oooool00ol0003oooooooooo`06ooooo`04
o`000?ooooooooooo`0000Cooooo0_l0000Aooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04
o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool01Oooool4o`0000Oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o
0000;_ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000oooo
ooooool04Oooool2o`0000gooooo00?o0000ooooooooool0Joooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000Voooo
o`03o`000?oooooooooo01Cooooo0_l0000;ooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04
o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0002Kooooo00?o0000oooo
ooooool05oooool2o`0000Oooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooo
oooo00009Oooool00ol0003oooooooooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo01cooooo00Go0000oooo
ooooooooooooo`00001`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000<?ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool07_ooool3
o`000003ooooool0003o000006gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`0O
ooooo`;o000000?oooooo`000?ooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00009?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooo0000073ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`05o`000?oooooooooo
ooooool000008_ooool00ol0003oooooooooo`0Pooooo`;o0000LOooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`00000Rooooo`03o`000?oooooooooo01oooooo0_l000000ooooooo0000ooooo`1_
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool07oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000dooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooool0
00000_l000000ooooooo0000o`00001]ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool01oooool0
00Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0=oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool05_ooool2o`00027ooooo0_l0001h
ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Sooooo0_l0
00000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03[ooooo0_l00008ooooo`03o`000?oooooooooo017ooooo0_l0000Qooooo`;o0000
Noooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0003cooooo0_l00008ooooo`;o
00003oooool2o`0002;ooooo00?o0000ooooooooool0NOooool3o`0000Wooooo0008ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooool000000_l00007ooooo`03o`000?oooooooooo
00Wooooo0ol0000Sooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool01oooool000Oo
oooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooo
oooo00Gooooo0ol0000Tooooo`;o0000Ooooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`05ooooo`go00009Oooool2o`00087ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00gooooo0_l0000Uooooo`;o0000Q?ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool03oooool2o`00027ooooo0_l0
0025ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0A
ooooo`?o00006oooool3o`0008Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Dooooo`?o00005?ooool4o`0008_ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`Ko
00002_ooool4o`0008oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Mooooo`[o0000Toooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2ioooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007oooo
o`?o00000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
00Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool01?l0
003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00003
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co0000
oooooooooooooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003co
oooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000
ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`0000Wo
oooo0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo0?oooooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0003oooooo`[ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo
001Rooooo`?o00005_ooool3o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo001S
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l000000ooo
oooo0000ooooo`03o`0000;ooooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000oooool2
o`0000;ooooo1_l00007ooooo`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo1?l0
0003ooooo`?o00001?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo043ooooo001A
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo043ooooo001@oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`03o`000?oo
oooooooo00Wooooo0ol00002ooooo`Go00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`;o00002Oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000
ooooooooool01?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo00Co
0000oooooooooooooooo0ol00003ooooo`Co00000oooool5o`0000Oooooo00Co0000oooooooooooo
00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002?ooool4o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000002?ooool4o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0@Oooool0057ooooo00Co0000oooooooo
oooo00005Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Booooo`?o00004oooool3
o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2
o`0002oooooo00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.42234 .51635 .0013 0 365.73 arc
s
newpath
.46482 .51494 .0013 0 365.73 arc
s
newpath
.56851 .51151 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.42234 .51635 L
s
.29834 .30057 m
.46482 .51494 L
s
.42234 .51635 m
.46482 .51494 L
.56851 .51151 L
.42234 .51635 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.42667 .52068 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.46915 .51928 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.57284 .51584 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool5o`000003ooooool0003ooooo00;o0000Zoooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
[Oooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`00002/ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
Zoooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`2Wooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Oo
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Y_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Xoooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:?ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`07ooooo`00
5?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`07ooooo`004ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0
1oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Coooooo?l00009ooooo`004ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
1oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Nooooo`03o`00
0?oooooooooo00Oooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Mooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09[o
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo
1ol0000=ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`Go000000?oooooo`000?ooool01?oo
ool6o`0000Sooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`04o`000?ooooooooooooooo`?o00001_ooool00ol0003ooooooooo
o`09ooooo`;o00001_ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo1?l00009ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03[ooooo0_l0000<ooooo`03o`000?oooooooooo00cooooo0_l00005oooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000jooooo`03
o`000?oooooo000000cooooo00?o0000ooooooooool03_ooool2o`0000Cooooo00?o0000oooooooo
ool0UOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo
00003?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0UOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0gooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooooooo`0Aooooo`05o`000?oooooooooooooo
ool00000Uoooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`05
o`000?ooooooooooooooool00000U_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Cooooo`05o`000?ooooooooooooooool00000UOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool00000U?ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00
09Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000cooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`00
09;ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`00
09;ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool01Ol0003o
oooooooooooooooo0000097ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo0000093ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo0000093ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000`ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07oooooc?o0000
LOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`Ko00004Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Wooooo0ol0001_ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`04o`000?oooooo0000o`0001Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l0
000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool2o`0006gooooo00?o
0000ooooooooool01oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2o`0001_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Oooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06_ooool2o`0006cooooo00?o0000ooooooooool01oooool0013ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000;_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`1Xooooo`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`07ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Gooooo`?o000000?oooooo`000?l00000JOooool00ol0003oooooooooo`07ooooo`003?ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooool0003o0000
ooooo`03o`0000;ooooo0_l0000Gooooo`;o000000Coooooo`000?l0003o00001?ooool4o`0000Ko
oooo5Ol0001Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000oooool2o`000005ooooool0003oooooooooool000004OoooolNo`00
00cooooo0ol0001[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`Ko000000Goooooo`000?ooooooooooo`000002ooooo`oo00001Oooool5o`0000Kooooo00Co0000
oooooooooooo00005_ooool2o`0006cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000]
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`04o`000?oooooo0000ooooo`So00005Oooool3o`0000Oooooo0ol0000Gooooo`?o0000J_oo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000oooool0
1?l0003oooooooooool0000Gooooo`?o00001oooool01?l0003oooooooooool0000Fooooo`;o0000
00?oooooo`000?ooool0JOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00005oooool2o`0000Sooooo00Co0000oooooooo
oooo00005Oooool3o`000003ooooool0003o000006Wooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`00
00Kooooo0_l00005ooooo`;o00006?ooool2o`0000Oooooo1?l0000Hooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00009oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000^ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00009oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo06_ooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00009_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`00
02Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool01?l0003o
ooooooooool0000Vooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_o
oooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
06kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0:ooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000<?ooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1^ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000Roooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`00000Rooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0LOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`1booooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07?ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07Gooooo00?o0000oooo
ooooool01oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0=oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool05_ooool2o`00
027ooooo0_l0001hooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03Sooooo0_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Oooooo0008oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03[ooooo0_l00008ooooo`03o`000?oooooooooo017ooooo0_l0
000Qooooo`;o0000Noooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0003cooooo
0_l00008ooooo`;o00003oooool2o`0002;ooooo00?o0000ooooooooool0NOooool3o`0000Wooooo
0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000000_l00007ooooo`03
o`000?oooooooooo00Wooooo0ol0000Sooooo`03o`000?oooooooooo07cooooo00?o0000oooooooo
ool01oooool000Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo0ol00005oooo
o`03o`000?oooooooooo00Gooooo0ol0000Tooooo`;o0000Ooooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`05ooooo`go00009Oooool2o`00087ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00gooooo0_l0000Uooooo`;o0000Q?oo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool03oooool2
o`00027ooooo0_l00025ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Aooooo`?o00006oooool3o`0008Sooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Dooooo`?o00005?ooool4o`0008_o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Gooooo`Ko00002_ooool4o`0008oooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Mooooo`[o0000Toooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo0007ooooo`?o00000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009oooo
o`002?ooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
00Oooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
00Sooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oo
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooooolo`0000Wooooo0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo0?oooooo2?ooool000Kooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0003oooooo`[ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0
003oooooo`_ooooo001Rooooo`?o00005_ooool3o`0002Kooooo0ol0000dooooo`03o`000?oooooo
oooo04;ooooo001Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo047ooooo001Booooo`;o00000oooool3o`0000Co
oooo0_l000000ooooooo0000ooooo`03o`0000;ooooo1Ol000000ooooooo0000o`000003o`000005
ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000002o`0000Oooooo0ol00004oooo
o`Co00000oooool2o`0000;ooooo1_l00007ooooo`?o00000oooool4o`000004ooooool0003o0000
o`0000Wooooo1?l00003ooooo`?o00001?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooo
oooo043ooooo001Aooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
043ooooo001@ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003
ooooo`03o`000?oooooooooo00Wooooo0ol00002ooooo`Go00000_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool3o`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oooooooooooooo
o`;o00002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool0
053ooooo00?o0000ooooooooool01?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool4
o`0000Cooooo00Co0000oooooooooooooooo0ol00003ooooo`Co00000oooool5o`0000Oooooo00Co
0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002?ooool4o`0000?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo0ol00002ooooo`Co0000
2?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0@Oooool0057ooooo
00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Boooo
o`?o00004oooool3o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000oooo
ooooool00_ooool2o`0002oooooo00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.42234 .52865 .0013 0 365.73 arc
s
newpath
.46332 .51738 .0013 0 365.73 arc
s
newpath
.56335 .48987 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.42234 .52865 L
s
.29834 .30057 m
.46332 .51738 L
s
.42234 .52865 m
.46332 .51738 L
.56335 .48987 L
.42234 .52865 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.42667 .53298 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.46765 .52171 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.56769 .4942 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool5o`000003ooooool0003ooooo00;o0000Zoooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
[Oooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Wooooo00Co0000oooooooooooo0000[Oooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo00000:_ooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Z?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Wooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0:?ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool01oooool001Cooooo
0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool01oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Oooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0XOooool00ol0003ooooo
ooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooooco00002Oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Oooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0W_ooool00ol0003ooooo
ooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0W_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo09cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Jooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`Oo0000
3?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool01?ooool5o`000003ooooool0003ooooo00Cooooo1_l0
0007ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool01?l0003oooooooooooooool3o`0000Kooooo00?o0000ooooooooool02Ooo
ool2o`0000Kooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`Co00002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0jooooo`;o00003?ooool00ol0003oooooooooo`0<ooooo`;o00001Oooool00ol0
003oooooooooo`2Gooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000>_ooool00ol0003o
ooooo`00000<ooooo`03o`000?oooooooooo00kooooo0_l00003ooooo`03o`000?oooooooooo09Ko
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`0000co
oooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000009Sooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo0000
00cooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000009Oooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo
000009Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool01?l0
003oooooooooool0002Fooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Cooooo00Co0000oooooooooooo0000UOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Eooooo`04o`000?ooooooooooo`0009Cooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Fooooo`04o`000?ooooooooooo`0009;ooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooo000009?ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05oooool01?l0003oooooooooool0002Booooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo0000TOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooo
ool00000T?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`05
o`000?ooooooooooooooool00000T?ooool00ol0003oooooooooo`07ooooo`006oooool2o`00033o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oo
oooo<ol0001aooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo1_l0000Aooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool3o`0006oooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00Co0000ooooool0003o00006?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2oooool2o`0001[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`?o0000
00?oooooo`000?l00000J_ooool00ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`;o00006oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo0ol0
00000ooooooo0000ooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`?o000000?oooooo`000?ooool0
6oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo1?l000001?oooooo0000
o`000?l0001/ooooo`03o`000?oooooooooo00Oooooo000@ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool2o`0002kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo013ooooo1Ol00004ooooo`?o0000J_ooool3o`0000Wo
oooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`Go00002?ooool00ol0003oooooo`00001/ooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo1Ol0000<ooooo`04o`000?oooooo0000o`0006_ooooo00?o0000ooooooooool01oooool000co
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo0000
o`000?ooool00ol00002ooooo`;o00006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo1Ol0000>ooooo`Ko0000J_ooool00ol0003oooooooooo`07ooooo`003?ooool5o`00
00?ooooo0_l00005ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo0_l000001Ooooooo0000oooooooo
oooo000001Oooooo00?o0000ooooooooool01_ooool7o`0001Gooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool6o`000005ooooool0
003oooooooooool000006?ooool00ol0003oooooooooo`03ooooo`Oo00005oooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`00
0?ooool@o`0000cooooo2_l000001Ooooooo0000oooooooooooo000001Oooooo00?o0000oooooooo
ool0JOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool0000:oooooa7o00001_ooool3o`0001Sooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00005_ooool5o`0000Kooooo00Co0000oooooooooooo00005oooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00006ooooo`;o00001Oooool2
o`0001Sooooo00?o0000ooooool000001oooool01?l0003oooooooooool0000Gooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooool000001_oo
ool4o`0001Oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00009ooo
ool2o`0002;ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00009ooo
ool2o`0002;ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool2
o`0002kooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000Wooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000Vooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00009_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooo`0002Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool0
1?l0003oooooooooool0000Uooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000`ooooo`03o`000?oooooo
oooo00Wooooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo06kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Wooooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000002;ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000002;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000=?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo07;ooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0M?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0MOooool00ol0003ooooooooo
o`07ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0g
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Fooooo`;o00008Ooo
ool2o`0007Sooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
>?ooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0>_ooool2o`0000Sooooo00?o0000ooooooooool04Oooool2o`00027o
oooo0_l0001kooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000??ooool2o`00
00Sooooo0_l0000?ooooo`;o00008_ooool00ol0003oooooooooo`1iooooo`?o00002Oooool000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000002o`0000Oooooo00?o0000
ooooooooool02Oooool3o`0002?ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`07
ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o
0000ooooooooool01Oooool3o`0002Cooooo0_l0001oooooo`03o`000?oooooooooo00Oooooo0008
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00Gooooo3Ol0000Uooooo`;o0000POooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool2o`0002Gooooo0_l00024ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0?ooooo`;o0000
8Oooool2o`0008Gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo017ooooo0ol0000Kooooo`?o0000R?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Cooooo0ol0000Dooooo`Co0000Roooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01Oooooo1_l0000:ooooo`Co0000Soooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo01gooooo2_l0002Cooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooo
oooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool000Oooooo0ol00003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`002?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`0000Wooooo0008
ooooo`04o`000?ooooooooooooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001ooo
ool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool01?l0003oooooooooooooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??oo
ool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
ooco00002Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool0ooooool8ooooo`001_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooo`[ooooo
0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`000?oooooo2_ooool000Oooooo0ol00004ooooo`;o00001?ooool2o`000?oo
oooo2oooool006;ooooo0ol0000Fooooo`?o00009_ooool3o`0003Cooooo00?o0000ooooooooool0
@_ooool006?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0@Oooool005;ooooo0_l00003ooooo`?o00001?ooool2
o`000003ooooool0003ooooo00?o00000_ooool5o`000003ooooool0003o000000?o000000Gooooo
o`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o00001oooool3o`0000Cooooo1?l0
0003ooooo`;o00000_ooool6o`0000Oooooo0ol00003ooooo`Co000000Coooooo`000?l0003o0000
2Oooool4o`0000?ooooo0ol00004ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0
@?ooool0057ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooool000001_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0@?oo
ool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo
00?o0000ooooooooool02Oooool3o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l0
0009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`00D?oo
ool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co0000
1?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l00003ooooo`Go00001oooool01?l0003o
ooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00008ooooo`Co00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l00008oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`11ooooo`00DOooool01?l0
003oooooooooool0000Eooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0@_ooool005;ooooo0ol0
000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`Co00002Oooool00ol0003ooooooooo
o`02ooooo`;o0000;oooool00ol0003oooooooooo`09ooooo`?o0000B?ooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.42105 .54088 .0013 0 365.73 arc
s
newpath
.45959 .52297 .0013 0 365.73 arc
s
newpath
.55367 .47923 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.42105 .54088 L
s
.29834 .30057 m
.45959 .52297 L
s
.42105 .54088 m
.45959 .52297 L
.55367 .47923 L
.42105 .54088 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.42539 .54521 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.46393 .5273 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.55801 .48356 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool5o`000003ooooool0003ooooo00;o0000Zoooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
[Oooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Wooooo00Co0000oooooooooooo0000[Oooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo00000:_ooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Z?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Wooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0:Cooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool01oooool001Cooooo
0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool01oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Oooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0XOooool00ol0003ooooo
ooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooooco00002Oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Oooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Woooool00ol0003ooooo
ooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0W_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Kooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`Oo0000
3?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool01?ooool5o`000003ooooool0003ooooo00Cooooo1_l0
0006ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool01?l0003oooooooooooooool3o`0000Kooooo00?o0000ooooooooool02Ooo
ool2o`0000Gooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`Co00002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0jooooo`;o00003?ooool00ol0003oooooooooo`0<ooooo`;o00001?ooool00ol0
003oooooooooo`2Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000>_ooool00ol0003o
ooooo`00000<ooooo`03o`000?oooooooooo00kooooo0_l00002ooooo`03o`000?oooooooooo09Oo
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`0000co
oooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0002Iooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000<oooo
o`03o`000?oooooooooo017ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0009Oooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003oooooo`00002Goooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooool0
0000U_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooo000009Gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`;o0000U?oo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo0_l0002Dooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool00000Toooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000009;o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
o`00002Booooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00Co
0000oooooooooooo0000TOooool00ol0003oooooooooo`07ooooo`006oooool2o`00033ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo=_l0
00000ooooooo0000o`00001[ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo1_l0
000Aooooo`05o`000?ooooooooooooooool000007Oooool3o`000003ooooool0003ooooo06cooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00Co0000ooooool0003o00006?ooool01?l0003ooooo
ooooool0000Looooo`Go0000K_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0001[ooooo
00Go0000ooooooooooooooooo`00000Hooooo`?o00000_ooool4o`0006gooooo00?o0000oooooooo
ool01oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2o`0001_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Cooooo`?o00001?ooool01?l0003oooooo`000?l0001]ooooo`03
o`000?oooooooooo00Oooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`?o000000?oooooo`000?ooool06oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo013ooooo0_l00007ooooo`03o`000?oooooooooo00;o0000K?ooool00ol0
003oooooooooo`07ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo0_l0000^ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`;o00002?ooool3o`000003ooooool0003o000006[ooooo0ol00009oooo
o`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool3o`0000oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07oooo
o`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`?o00004Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool01Ol0003oooooo`000?l0003o
oooo00?o00000_ooool2o`0001Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`?o00004oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<oooo
o`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool2o`000005ooooool0003o
ooooooooool000005oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`?o0000
5_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooooooo`Ko000000Goooooo`000?ooooooooooo`00000Hooooo`03o`000?oooooooooo00Co
oooo1Ol0000Hooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?oooooo0000ooooo`Ko00006?ooool00ol0003oooooooooo`04ooooo`?o
000000?oooooo`000?ooool05oooool00ol0003oooooooooo`1Yooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Oo0000
4_ooool00ol0003oooooooooo`02ooooo`Co00000_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo1ol0000:ooooo`03o`000?oooooooooo00?o
00000oooool3o`0001Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo
00001_ooool2o`0000Gooooo0_l0000>ooooo`Oo00000oooool4o`0000Gooooo00Co0000oooooooo
oooo00006?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000Toooo
o`Oo00001Oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<oooo
o`04o`000?ooooooooooo`0002Gooooo00Go0000ooooool0003oooooo`000005ooooo`Co00006?oo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000Uooooo`Go00008Ooo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;_ooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0002Kooooo0ol0000Qooooo`03o`000?oo
oooooooo06_ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00_ooooo00Co0000oooooooooooo00009_ooool00ol0003oooooo`00000Qooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0002Kooooo0_l0000Qooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0002Kooooo0_l0000Qooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000Uooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool2
o`00033ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000Tooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0K_ooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000Tooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00009?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool000008_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000008_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0L_ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo01Kooooo0_l0000Qooooo`;o0000N?ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?ooool01_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0jooooo`;o00002?ooool00ol0003o
ooooooooo`0Aooooo`;o00008Oooool2o`0007_ooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo0_l0000looooo`;o00002?ooool2o`0000oooooo0_l0000Rooooo`03o`000?oooooooooo
07Wooooo0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
000000;o00001oooool00ol0003oooooooooo`09ooooo`?o00008oooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`?o00009?ooool2o`0007oooooo00?o
0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool=o`0002Gooooo0_l00021
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`;o
00009Oooool2o`0008Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo00oooooo0_l0000Qooooo`;o0000QOooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool04Oooool3o`0001_ooooo0ol00028ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05?ooool3
o`0001Cooooo1?l0002;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool05oooool6o`0000[ooooo1?l0002?ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool:o`0009?o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooooooo
o`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
00Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003ooooooooo
o`2hooooo`?o00002Oooool000Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0007ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Gooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2i
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Kooooo1Ol00003ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`000?oooooo2_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001oooool3o`0000Co
oooo0_l00004ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000
=?ooool00ol0003oooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2
o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go000000?ooooo
o`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l0
0007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l0
00001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00008ooooo`Go0000
1?ooool00ol0003oooooooooo`10ooooo`00DOooool01_l0003oooooooooool0003oooooo`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0
003oooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`?o00000_ooool5o`0000;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo
001@ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool0
1?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o000000Co
ooooo`000?l0003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o00000oooool4o`0000?o
oooo1Ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`00
00Sooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo1?l00002oooo
o`?o00000_ooool4o`0000Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo047ooooo001Aooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool06_ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`12ooooo`00D_ooool3o`0001?ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo1?l0
0009ooooo`03o`000?oooooooooo00;ooooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo0ol0
0018ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.4185 .55291 .0013 0 365.73 arc
s
newpath
.45428 .52998 .0013 0 365.73 arc
s
newpath
.54164 .47401 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.4185 .55291 L
s
.29834 .30057 m
.45428 .52998 L
s
.4185 .55291 m
.45428 .52998 L
.54164 .47401 L
.4185 .55291 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.42283 .55724 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.45861 .53432 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.54597 .47835 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool5o`000003ooooool0003ooooo00;o0000Zoooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000[_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Wooooo00Co0000oooooooooooo0000[Oooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo00000:_ooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`00002/ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0:Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z?ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Y_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Cooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0:Cooooo00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0:?ooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`07ooooo`004ooo
ool01?l0003oooooooooool00004ooooooco00002Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`07ooooo`005?oo
ool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Looooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`Oo00002oooool00ol0003ooooo
ooooo`2Looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01?ooool5o`000003ooooool0003ooooo00Cooooo1_l00005ooooo`03o`000?oo
oooooooo09cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooooooool3o`0000Kooooo00?o0000ooooooooool02Oooool2o`0000Cooooo00?o
0000ooooooooool0Voooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`Co00002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0V_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0joooo
o`;o00003?ooool00ol0003oooooooooo`0<ooooo`;o00000_ooool00ol0003oooooooooo`2Joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000>_ooool00ol0003oooooo`00000<ooooo`03
o`000?oooooooooo00kooooo0_l000000ooooooo0000ooooo`2Iooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooool00000V_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0gooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0Aooooo`;o
0000V_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`;o0000
VOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`;o0000V?oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo09Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`2Eooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000<oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`2Cooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`2Cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0Toooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06?ooool2o`0009?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05oooool2o`0001kooooo0ol000000ooooooo0000o`00001_ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01ooooolco`000003ooooool0003ooooo06kooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool01?l0003oooooooooooooool6o`00017ooooo00?o0000ooooool000007?ooool2o`000004oooo
ool0003o0000o`0006oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Co0000ooooool0003o
00006?ooool2o`0001[ooooo0_l000000ooooooo0000o`000002ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l0000Jooooo`03o`000?oooooo000001Oooooo
0_l00003ooooo`03o`000?oooooo000000;ooooo0_l0001]ooooo`03o`000?oooooooooo00Oooooo
000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo0_l0000Kooooo`04o`000?ooooooooooo`0001Gooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Oooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooo0000
01?ooooo0_l00005ooooo`?o000000Coooooo`000?l0003ooooo0_l0001/ooooo`03o`000?oooooo
oooo00Oooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2
o`0002kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000@ooooo`;o00003ooo
ool00ol0003oooooooooo`1Xooooo`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_oo
ool01Ol0003ooooooooooooooooo000000kooooo0_l0000@ooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02Oooool2o`0001;ooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooool0003o0000ooooo`03o`0000;ooooo0_l0000Hooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool3o`0001?ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`07ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?o
oooo0_l000001Ooooooo0000oooooooooooo000001Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`;o00005Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`Ko000000Goooooo`000?ooooooooooo`00000H
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0001Oooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
ool0003ooooo0ol00002ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooooooool2o`0001Sooooo00?o0000ooooooooool0JOooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000oooool5o`0001Oooooo00?o0000
ooooooooool00oooool4o`0001[ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo0000oooo
o`04o`0001;ooooo00?o0000ooooooooool01?ooool3o`000003ooooool0003ooooo01Sooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00001_ooool2o`0000Gooooo0_l0
0006ooooo`Go00003Oooool00ol0003oooooooooo`03ooooo`?o00000_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0001[ooooo1?l0
0009ooooo`04o`000?ooooooooooooooo`;o00000_ooool3o`0001Wooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00cooooo00Co0000oooooooooooo00007_ooool4o`0000Gooooo00Co0000ooooool0003o
00001?ooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04
o`000?ooooooooooo`0002;ooooo1?l000001?oooooo0000o`000?l00005ooooo`04o`000?oooooo
ooooo`0001Sooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool2
o`0002kooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000Uooooo`Ko00000ooo
ool4o`0001Sooooo00?o0000ooooooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000Uooooo`?o000000?o
ooooo`000?ooool07oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0
000Uooooo`Go00007oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0
000Vooooo`03o`000?oooooo0000023ooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000
oooooooooooo00009Oooool2o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00009Oooool00ol0003oooooo`00000Pooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000`ooooo`03o`000?oooooo
oooo00Wooooo00Co0000oooooooooooo00009?ooool01?l0003oooooo`000?l0000Oooooo`03o`00
0?oooooooooo06kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo00Wooooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000002;ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooo
oooooooo000002;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000=?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07;ooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0MOooool00ol0003ooooo
ooooo`07ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003ooooooooo
o`0gooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Fooooo`;o0000
8Oooool2o`0007Sooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>?ooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0>_ooool2o`0000Sooooo00?o0000ooooooooool04Oooool2o`00
027ooooo0_l0001kooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000??ooool2
o`0000Sooooo0_l0000?ooooo`;o00008_ooool00ol0003oooooooooo`1iooooo`?o00002Oooool0
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000002o`0000Oooooo00?o
0000ooooooooool02Oooool3o`0002?ooooo00?o0000ooooooooool0O?ooool00ol0003ooooooooo
o`07ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool3o`0000Gooooo
00?o0000ooooooooool01Oooool3o`0002Cooooo0_l0001oooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00Gooooo3Ol0000Uooooo`;o0000POooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool2o`0002Gooooo0_l00024oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0?ooooo`;o
00008Oooool2o`0008Gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo017ooooo0ol0000Kooooo`?o0000R?ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Cooooo0ol0000Dooooo`Co0000Rooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01Oooooo1_l0000:ooooo`Co0000Soooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo2_l0002Cooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oo
oooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool000Oooooo0ol00003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`002?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`0000Wooooo
0008ooooo`04o`000?ooooooooooooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
1oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
2?ooool01?l0003oooooooooooooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0006ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooooco00002Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool0ooooool8ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooo`[o
oooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`000?oooooo2_ooool000Oooooo0ol00004ooooo`;o00001?ooool2o`00
0?oooooo2oooool006;ooooo0ol0000Fooooo`?o00009_ooool3o`0003Cooooo00?o0000oooooooo
ool0@_ooool006?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0@Oooool005;ooooo0_l00003ooooo`?o00001?oo
ool2o`000003ooooool0003ooooo00?o00000_ooool5o`000003ooooool0003o000000?o000000Go
ooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o00001oooool3o`0000Cooooo
1?l00003ooooo`;o00000_ooool6o`0000Oooooo0ol00003ooooo`Co000000Coooooo`000?l0003o
00002Oooool4o`0000?ooooo0ol00004ooooo`;o00002?ooool5o`0000Cooooo00?o0000oooooooo
ool0@?ooool0057ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooool000001_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000?o
oooo00?o0000ooooooooool02Oooool3o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o0000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo
0_l00009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`00
D?ooool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co
00001?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l00003ooooo`Go00001oooool01?l0
003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00008ooooo`Co00000oooool2
o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l00008
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`11ooooo`00DOooool0
1?l0003oooooooooool0000Eooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0@_ooool005;ooooo
0ol0000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`Co00002Oooool00ol0003ooooo
ooooo`02ooooo`;o0000;oooool00ol0003oooooooooo`09ooooo`?o0000B?ooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.4147 .56461 .0013 0 365.73 arc
s
newpath
.44755 .53765 .0013 0 365.73 arc
s
newpath
.52775 .47183 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.4147 .56461 L
s
.29834 .30057 m
.44755 .53765 L
s
.4147 .56461 m
.44755 .53765 L
.52775 .47183 L
.4147 .56461 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.41903 .56894 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.45188 .54198 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.53208 .47616 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool5o`000003ooooool0003ooooo00;o0000Zoooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000[_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Wooooo00Co0000oooooooooooo0000[Oooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0002/ooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool00000[?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Wooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0:Oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Uooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2Uooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o00001Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2Tooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`07ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool01oooool001?ooooo00Co
0000oooooooooooo00001?ooooolo`0000Wooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0X_ooool00ol0003oooooooooo`07ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01oooool001Cooooo0_l0
0005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0X?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Ooooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0WOooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool02Oooool7o`0000Wooooo00?o0000ooooooooool0
W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Cooooo1Ol000000ooooooo0000ooooo`04ooooo`Ko00001?ooool00ol0003ooooooooo
o`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000
oooooooooooooooo0ol00006ooooo`03o`000?oooooooooo00Wooooo0_l00002ooooo`03o`000?oo
oooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool4
o`0000Wooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0002Nooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03[ooooo0_l0000<ooooo`03o`000?oooooo
oooo00cooooo0_l000000ooooooo0000ooooo`2Looooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000>_ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00kooooo0_l0002Loooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000<oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000003?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool04Oooool2o`0009[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04_ooool2o`0009Wooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04_ooool00ol0003oooooo`00002Hooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000Uoooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooool00000UOooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Cooooo00Co0000oooooooooooo0000UOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo000009Gooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00002Dooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000006ooo
ool3o`000003ooooool0003o000007?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05_ooool2o`0001cooooo0_l000000ooooooo0000ooooo`1cooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01ooooolco`00077ooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool01?l0003o
ooooooooooooool6o`00013ooooo0_l0000Iooooo`04o`000?oooooo0000o`0000Cooooo0ol0001_
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo0000o`0001Oooooo0_l0000G
ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`;o00006Oooool2o`0001Kooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00?ooooo0_l0001]ooooo`03o`000?oooooooooo00Oooooo
000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo0_l0000Kooooo`03o`000?oooooooooo01;ooooo0_l0
0003ooooo`?o000000?oooooo`000?l000001Oooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo00Oooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`?o000000?oooooo`000?ooool06oooool00ol0003oooooooooo`0@ooooo`;o0000
3oooool2o`0006cooooo00?o0000ooooooooool01oooool0013ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`;o0000;_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Xooooo`?o0000
2Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool06_ooool2o`0000oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooo`00000<ooooo`;o00005?ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1?ooool01Ol0003oooooo`000?l0003ooooo00?o00000_ooool2o`0001Sooooo00?o0000ooooool0
00002oooool2o`0001Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`00
3?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo0_l000001Ooooooo
0000oooooooooooo000001Oooooo00Co0000oooooooooooo00002Oooool2o`0001Kooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool6
o`000005ooooool0003oooooooooool000006?ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0002gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Co0000ooooool0003ooooo0ol00002ooooo`03o`000?oooooooooo01Kooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Wo
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo
1?l0000Hooooo`05o`000?ooooooooooooooool000000oooool2o`0001[ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00ol0000Eooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_l0000Kooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000Ko
oooo0_l00005ooooo`;o00000oooool3o`0001;ooooo00?o0000ooooooooool00_ooool4o`0001co
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00005Oooool3o`0000oo
oooo00?o0000ooooooooool00oooool2o`000003ooooool0003ooooo01Wooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00cooooo00Co0000oooooooooooo00006?ooool2o`0000gooooo00Co0000oooooooo
oooooooo0ol00002ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_o
oooo00Co0000oooooooooooo00006_ooool3o`0000[ooooo00?o0000ooooooooool00_l000001?oo
oooo0000o`000?l0000Kooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000^ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00007Oooool3
o`0000Oooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0000Iooooo`03o`00
0?oooooooooo06_ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00_ooooo00Co0000oooooooooooo00008?ooool3o`0000?ooooo00?o0000ooooool00000
1?ooool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo06cooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04o`00
0?ooooooooooo`0002?ooooo1ol00002ooooo`Co00006Oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2oooool01?l0003oooooooooool0000Tooooo`?o000000?oooooo`000?ooool07oooool00ol0003o
ooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool02oooool01?l0003oooooooooool0000Tooooo`Go00007oooool00ol0003o
ooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool02_ooool01?l0003oooooooooool0000Uooooo`03o`000?oooooo0000023o
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00033ooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool0000Tooooo`;o000000?oooooo`000?oo
ool07_ooool00ol0003oooooooooo`1^ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooool0
00008?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000Tooooo`?o
00007oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000002;o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01Ol0003ooooo
oooooooooooo000002;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000=?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07;ooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Loooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0MOooool00ol0003o
ooooooooo`07ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`0gooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Fooooo`;o
00008Oooool2o`0007Sooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0>?ooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool01oooool000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>_ooool2o`0000Sooooo00?o0000ooooooooool04Oooool2
o`00027ooooo0_l0001kooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000??oo
ool2o`0000Sooooo0_l0000?ooooo`;o00008_ooool00ol0003oooooooooo`1iooooo`?o00002Ooo
ool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000002o`0000Oooooo
00?o0000ooooooooool02Oooool3o`0002?ooooo00?o0000ooooooooool0O?ooool00ol0003ooooo
ooooo`07ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool3o`0000Go
oooo00?o0000ooooooooool01Oooool3o`0002Cooooo0_l0001oooooo`03o`000?oooooooooo00Oo
oooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00Gooooo3Ol0000Uooooo`;o0000POooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool2o`0002Gooooo0_l00024
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0?oooo
o`;o00008Oooool2o`0008Gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo017ooooo0ol0000Kooooo`?o0000R?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Cooooo0ol0000Dooooo`Co0000
Roooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01Oooooo1_l0000:ooooo`Co0000Soooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo2_l0002Cooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Oooooo0ol00003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`002?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`0000Wo
oooo0008ooooo`04o`000?ooooooooooooooo`Co00000oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`001oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`002?ooool01?l0003oooooooooooooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o
0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo0006ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
1oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooooco00002Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool0ooooool8ooooo`001_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003ooooo
o`[ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`000?oooooo2_ooool000Oooooo0ol00004ooooo`;o00001?ooool2
o`000?oooooo2oooool006;ooooo0ol0000Fooooo`?o00009_ooool3o`0003Cooooo00?o0000oooo
ooooool0@_ooool006?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0@Oooool005;ooooo0_l00003ooooo`?o0000
1?ooool2o`000003ooooool0003ooooo00?o00000_ooool5o`000003ooooool0003o000000?o0000
00Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o00001oooool3o`0000Co
oooo1?l00003ooooo`;o00000_ooool6o`0000Oooooo0ol00003ooooo`Co000000Coooooo`000?l0
003o00002Oooool4o`0000?ooooo0ol00004ooooo`;o00002?ooool5o`0000Cooooo00?o0000oooo
ooooool0@?ooool0057ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooool000001_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`00
00?ooooo00?o0000ooooooooool02Oooool3o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo
oooo0_l00009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10oooo
o`00D?ooool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`000004ooooool0003o0000oooo
o`Co00001?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l00003ooooo`Go00001oooool0
1?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00008ooooo`Co00000ooo
ool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l0
0008ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`11ooooo`00DOoo
ool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0@_ooool005;o
oooo0ol0000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`Co00002Oooool00ol0003o
ooooooooo`02ooooo`;o0000;oooool00ol0003oooooooooo`09ooooo`?o0000B?ooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.40969 .57584 .0013 0 365.73 arc
s
newpath
.43943 .54548 .0013 0 365.73 arc
s
newpath
.51201 .47135 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.40969 .57584 L
s
.29834 .30057 m
.43943 .54548 L
s
.40969 .57584 m
.43943 .54548 L
.51201 .47135 L
.40969 .57584 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.41403 .58018 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.44376 .54981 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.51635 .47568 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo0_l0002[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00002^ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool0002]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`000:cooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
002/ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool02Oooool01Ol0003ooooooooooooooooo00000:cooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2Xooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:So
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Yoooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0:Kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2V
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Gooooo00?o0000oooooooo
ool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Tooooo`03
o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Y?ooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooooco
00002Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Sooooo`03
o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0X_ooool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
X_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Qooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`2Oooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`09ooooo`Oo00002?ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01?ooool5o`000003oooo
ool0003ooooo00Cooooo1_l00002ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooooooool3o`0000Kooooo
00?o0000ooooooooool02Oooool2o`000003ooooool0003ooooo09oooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool4o`0000Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooo`00002Oooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03[ooooo0_l0000<ooooo`03o`000?oooooooooo00cooooo0_l0002Oooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000>_ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo
00kooooo0_l0002Looooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>?ooool01?l0003o
ooooooooool0000<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooool00000W?ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0gooooo`05o`000?oooooooooooooo
ool000003?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000009_ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool0002Joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00Co0000oooooooo
oooo0000VOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`04
o`000?ooooooooooo`0009Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool04Oooool01Ol0003ooooooooooooooooo000009Oooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Booooo`05o`000?ooooooooooooooool00000UOooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Cooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooo
ooooo`00002Eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo
00Go0000ooooooooooooooooo`00002Dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000Gooooo`?o000000?oooooo`000?l0
0000Moooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`04o`00
0?ooooooooooo`0001Sooooo0_l000000ooooooo0000ooooo`1gooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01ooooolco`00077ooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool01?l0003ooooooooo
ooooool6o`0000kooooo00Co0000oooooooooooo00005_ooool3o`0000Sooooo0ol0001_ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo0000o`0001Cooooo00Go0000oooooooo
ooooooooo`00000Dooooo`?o000000?oooooo`000?ooool02?ooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`;o00005oooool01?l0003oooooooooool0000Coooo
o`;o000000Goooooo`000?ooooooooooo`000009ooooo`;o0000KOooool00ol0003oooooooooo`07
ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`;o00006Oooool00ol0003oooooo`00000Boooo
o`;o000000Goooooo`000?l0003o0000ooooo`02o`0000Wooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01oooool3o`000003ooooool0003ooooo01Sooooo00Co0000oooooooooooo0000
4?ooool2o`00017ooooo0_l0001/ooooo`03o`000?oooooooooo00Oooooo000@ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0002kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooo`00000?ooooo`;o00004oooool00ol0003oooooooooo`1Xooooo`?o0000
2Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00000>ooooo`;o0000
5?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6Oooool2o`0000gooooo0_l0000Eooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
1oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`05o`00
0?oooooo0000o`000?ooool00ol00002ooooo`;o00005oooool2o`0000cooooo0_l0000Fooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o0000
1Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00003ooooo`;o000000Goooooo`000?ooooooooooo`00000Goooo
o`03o`000?oooooooooo00Wooooo0_l0000Gooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo1_l000001Ooooooo0000oooooooooooo
000001Sooooo00?o0000ooooooooool01oooool2o`0001Sooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0002gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003ooooo0ol00002
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool2o`0001Wooooo00?o0000
ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ool000000oooool2o`000003ooooool0003ooooo01Oooooo0_l00006ooooo`;o00006_ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool01?l0003oooooo`000?l0000Gooooo`03o`000?oooooo000000Gooooo0_l0000K
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000Kooooo0_l00005
ooooo`;o000000?oooooo`000?l000005Oooool01?l0003oooooooooool00003ooooo`;o00007?oo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000Booooo`;o00004ooo
ool01_l0003ooooooooooooooooo0000ooooo`;o00007?ooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
3?ooool01?l0003oooooooooool0000Dooooo`;o00004Oooool00ol0003oooooooooo`04o`0001go
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00005_ooool2o`0000oo
oooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000^ooooo`03o`000?oooooooooo00_o
oooo00Co0000oooooooooooo00006?ooool2o`0000gooooo00?o0000ooooooooool00_l00002oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Joooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000Joooo
o`;o00002_ooool01Ol0003oooooooooool0003ooooo00?o00007?ooool00ol0003oooooooooo`1/
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool02oooool01?l0003oooooooooool0000Looooo`;o00002?ooool00ol0003oooooo`000002
ooooo`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000
oooooooooooo00007_ooool2o`0000Kooooo0_l00003ooooo`04o`000?ooooooooooo`0001[ooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00008?ooool2o`0000?ooooo
0_l00003ooooo`Co00006_ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool01?l0003ooooooooo
ool0000Rooooo`;o000000Coooooo`000?l0003o00008?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0002;ooooo00?o0000ooooool000000_l0000Pooooo`03o`000?oooooooooo06ko
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo
00Co0000oooooooooooo00008_ooool5o`00023ooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo
00Co0000oooooooooooo00008oooool3o`00023ooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooo0000023ooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Rooooo`;o00008?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo
0ol0000Oooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0L_ooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1c
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Ko
oooo0_l0000Qooooo`;o0000N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0hooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0jooooo`;o00002?ooool00ol0003oooooooooo`0A
ooooo`;o00008Oooool2o`0007_ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0_l0
000looooo`;o00002?ooool2o`0000oooooo0_l0000Rooooo`03o`000?oooooooooo07Wooooo0ol0
0009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000;o0000
1oooool00ol0003oooooooooo`09ooooo`?o00008oooool00ol0003oooooooooo`1looooo`03o`00
0?oooooooooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`05ooooo`?o00009?ooool2o`0007oooooo00?o0000oooooooo
ool01oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool01Oooool=o`0002Gooooo0_l00021ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`;o00009Oooool2
o`0008Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
00oooooo0_l0000Qooooo`;o0000QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool04Oooool3o`0001_ooooo0ol00028ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05?ooool3o`0001Cooooo
1?l0002;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool05oooool6o`0000[ooooo1?l0002?ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool:o`0009?ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo
00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`2hooooo`?o
00002Oooool000Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo0007ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Gooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2i
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool000Kooooo1Ol00003ooooo`;o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
0?oooooo2_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001oooool3o`0000Cooooo0_l00004
ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000=?ooool00ol0
003oooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2o`0000?ooooo
0ol00004ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go000000?oooooo`000?l00000
0ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`?o
00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l000001?oooooo
0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00008ooooo`Go00001?ooool00ol0
003oooooooooo`10ooooo`00DOooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooo`00
0006ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002oooo
o`?o00000oooool00ol0003oooooooooo`09ooooo`?o00000_ooool5o`0000;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo001@ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Ko
oooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003ooooo
ooooooooool2o`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o000000Coooooo`000?l0
003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o00000oooool4o`0000?ooooo1Ol00007
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Sooooo1?l0
0003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`?o00000_oo
ool4o`0000Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo047ooooo
001Aooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool06_ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`12oooo
o`00D_ooool3o`0001?ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo1?l00009ooooo`03
o`000?oooooooooo00;ooooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo0ol00018ooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.40354 .5865 .0013 0 365.73 arc
s
newpath
.42988 .55314 .0013 0 365.73 arc
s
newpath
.49419 .47172 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.40354 .5865 L
s
.29834 .30057 m
.42988 .55314 L
s
.40354 .5865 m
.42988 .55314 L
.49419 .47172 L
.40354 .5865 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.40788 .59083 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.43422 .55748 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.49852 .47605 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo0_l0002[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00002^ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooo`00002^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`000:cooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000[Oooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`00002/ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
00000:cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ZOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2Wooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o
00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`07ooooo`00
4oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Gooooo00?o0000oooooooo
ool01oooool001?ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`07ooooo`00
4oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0X?ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool7o`0000Ko
oooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00Cooooo1Ol000000ooooooo0000ooooo`04ooooo`Ko0000
00?oooooo`000?ooool0XOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`04o`000?ooooooooooooooo`?o00001_ooool00ol0003oooooooooo`09ooooo`;o0000
X_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`Co00002Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>_ooool2o`0000cooooo00?o0000ooooooooool02oooool3
o`0009oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000jooooo`03o`000?oooooo0000
00cooooo00?o0000ooooooooool03?ooool01?l0003oooooo`000?l0002Looooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo
oooo00cooooo00Go0000ooooooooooooooooo`00002Looooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oo
oooooooo00gooooo00Go0000ooooooooooooooooo`00002Kooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Foooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
<oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09?ooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Tooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0T_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04Oooool3o`000003ooooool0003o000007_ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01;ooooo0_l000000ooooooo0000ooooo`1kooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01ooooolco`00077ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool01?l0003ooooooooooooo
ool6o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`;o00003?oo
ool3o`0006oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00Co0000ooooool0003o00004Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo0_l000000ooooooo0000oooo
o`0<ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l0000D
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooooooo00_ooooo0_l0001]ooooo`03o`000?oooooooooo00Oooooo000=oooo
o`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo0_l0000Eooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooo`000002o`000003ooooool0003o000000gooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool3o`000003ooooool0003ooooo01Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo0_l0001/
ooooo`03o`000?oooooooooo00Oooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool2o`0002kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1X
ooooo`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool01Ol0003oooooo`000?l0003ooooo00?o00000_ooool2o`0001Cooooo00Go0000oooooooooooo
ooooo`00000:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`07ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?o
oooo0_l000001Ooooooo0000oooooooooooo000001Cooooo00Co0000oooooooooooo00002Oooool2
o`0001Wooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool6o`000005ooooool0003oooooooooool000005?ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`;o0000;Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool3o`0000;ooooo
00?o0000ooooooooool04oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000000oooool01?l0003oooooooooool0000Eooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool4o`0001Kooooo0_l00006oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooo
oooo00001_ooool2o`0000Gooooo0ol0000Fooooo`;o00001Oooool2o`0001gooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00cooooo00Co0000oooooooooooo00004?ooool2o`0001Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`04
o`000?ooooooooooo`0001;ooooo0_l0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000Doooo
o`03o`000?oooooooooo013ooooo0_l00002ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool2o`0002kooooo00?o0000oooooooo
ool02oooool01?l0003oooooooooool0000Eooooo`;o00004?ooool5o`0001kooooo00?o0000oooo
ooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool02oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_l000000ooooooo0000ooooo`0Looooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04
o`000?ooooooooooo`0001Sooooo0_l0000<ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000J
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000000ol0000Mooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`0001_ooooo0_l00008ooooo`05o`000?oooooo
0000ooooool000000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0001gooooo0_l00006ooooo`?o000000Goooooo`000?oooooooooo
o`00000Kooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000`ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00007oooool00ol0003ooooo
ooooo`02ooooo`04o`000?oooooo0000ooooo`Co00006oooool00ol0003oooooooooo`1^ooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`00023ooooo0_l00002ooooo`;o00008Oooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooool0000Qooooo`;o000000Coooooo`000?l0003o00007oooool00ol0
003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000023ooooo00Go0000oooo
ool0003oooooo`00000Pooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000008?ooool5o`0001oooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000001oooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo0_l000000ooooooo
0000ooooo`0Mooooo`03o`000?oooooooooo07;ooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Looooo`04o`000?ooooooooooo`0001oooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o0000
7_ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1eooooo`03o`000?oo
oooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo03Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Kooooo0_l0
000Qooooo`;o0000N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0hooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0jooooo`;o00002?ooool00ol0003oooooooooo`0Aooooo`;o
00008Oooool2o`0007_ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0_l0000loooo
o`;o00002?ooool2o`0000oooooo0_l0000Rooooo`03o`000?oooooooooo07Wooooo0ol00009oooo
o`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000;o00001oooool0
0ol0003oooooooooo`09ooooo`?o00008oooool00ol0003oooooooooo`1looooo`03o`000?oooooo
oooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`?o00001Ooo
ool00ol0003oooooooooo`05ooooo`?o00009?ooool2o`0007oooooo00?o0000ooooooooool01ooo
ool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool01Oooool=o`0002Gooooo0_l00021ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`;o00009Oooool2o`0008Co
oooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00oooooo
0_l0000Qooooo`;o0000QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool04Oooool3o`0001_ooooo0ol00028ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05?ooool3o`0001Cooooo1?l0002;
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool05oooool6o`0000[ooooo1?l0002?ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool:o`0009?ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000
ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`2hooooo`?o00002Ooo
ool000Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0007ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool000Kooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo
2_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo0000ooooool:ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o
0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000=?ooool00ol0003ooooo
ooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2o`0000?ooooo0ol00004
ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go000000?oooooo`000?l000000ol00000
1Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`?o00001?oo
ool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l000001?oooooo0000o`00
0?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00008ooooo`Go00001?ooool00ol0003ooooo
ooooo`10ooooo`00DOooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooo`000006oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o0000
0oooool00ol0003oooooooooo`09ooooo`?o00000_ooool5o`0000;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo0ol0
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003ooooooooooooo
ool2o`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo
001@ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo
1?l00004ooooo`04o`000?ooooooooooooooo`?o00000oooool4o`0000?ooooo1Ol00007ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Sooooo1?l00003oooo
o`;o00000oooool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`?o00000_ooool4o`00
00Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo047ooooo001Aoooo
o`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`12ooooo`00D_oo
ool3o`0001?ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo1?l00009ooooo`03o`000?oo
oooooooo00;ooooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo0ol00018ooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.39631 .59645 .0013 0 365.73 arc
s
newpath
.4188 .56038 .0013 0 365.73 arc
s
newpath
.4737 .47234 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.39631 .59645 L
s
.29834 .30057 m
.4188 .56038 L
s
.39631 .59645 m
.4188 .56038 L
.4737 .47234 L
.39631 .59645 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.40065 .60078 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.42314 .56471 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.47803 .47668 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo0_l0002[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00002^ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooo`00002^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`000:cooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000[Oooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`00002/ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
00000:cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ZOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2Wooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o
00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`07ooooo`00
4oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Kooooo00?o0000oooooooo
ool01oooool001?ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`07ooooo`00
4oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Cooooo00?o0000oooooooo
ool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0XOooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool7o`0000Go
oooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00Cooooo1Ol000000ooooooo0000ooooo`04ooooo`Oo0000
Xoooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oo
ooooooooooooo`?o00001_ooool00ol0003oooooooooo`09ooooo`;o0000X_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`Co00002Oooool00ol0003ooooooooo
o`0:ooooo`;o0000XOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0j
ooooo`;o00003?ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000o`0009oooooo00?o
0000ooooooooool01oooool001_ooooo0_l0000jooooo`03o`000?oooooo000000cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`02o`0009cooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0hooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09Wooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo09Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09Oooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Toooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2Booooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`?o000000?oooooo`000?l00000P?oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03Oooool2o`000003ooooool0003ooooo083ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000`ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`07oooooc?o0000LOooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`04
o`000?ooooooooooooooo`Ko00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo0ol0000Aooooo`?o0000Koooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool01?l0003o
ooooo`000?l0000@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool3o`00
0003ooooool0003ooooo017ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool2o`0001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool04?ooool2o`0006gooooo00?o0000oooooooo
ool01oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2o`0001Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000;o000000?oooooo`000?l00000
4_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`?o000000?oooooo`000?oo
ool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05oooool2o`0006cooooo00?o0000ooooooooool01oooool0013ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`;o0000;_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06Sooooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool2o`0001_ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooool0003o0000ooooo`03o`0000;ooooo0_l0000Boooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o
00001Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00003ooooo`;o000000Goooooo`000?ooooooooooo`00000B
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo1_l000001Ooooooo0000oooooooooooo000001;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0002gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003ooooo0ol0
0002ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ooooool2o`0001kooooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000Cooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`;o
000000?oooooo`000?ooool04_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00006oooo
o`;o00001Oooool2o`0001Gooooo00Co0000oooooooooooo00000_ooool2o`00023ooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00003oooool2o`0001?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<
ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool04Oooool01?l0003oooooo`00
0?ooool2o`00023ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000
4_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooo0000ooooool000008Oooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;_ooool00ol0003ooooo
ooooo`0;ooooo`04o`000?ooooooooooo`0001?ooooo0_l0000Aooooo`?o00008Oooool00ol0003o
ooooooooo`1[ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0;ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool03Oooool4o`00027o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00005_ooool00ol0003o
ooooooooo`0=ooooo`;o000000?oooooo`000?ooool07_ooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo
0000ooooo`0Nooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0001So
oooo0_l0000;ooooo`Co00007oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool01?l0003ooooo
ooooool0000Jooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00033ooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo00Ko
oooo0ol00002ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0K_ooool2o`0000Wo
oooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool01?l0003ooooo
ooooool0000Looooo`;o00001_ooool5o`0001kooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo
00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`;o00008Oooool00ol0003o
ooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000001kooooo00Go0000oooooooo
ooooooooo`00000Rooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooooooo
ool000007_ooool2o`000004ooooool0003o0000o`00023ooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo0000
00;o00008?ooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Oooooo000Kooooo`;o
0000=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool06oooool5o`0001oooooo00?o0000ooooooooool0L_ooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooool000008?ooool00ol0003oooooooooo`1cooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo0_l000000ooooooo0000oooo
o`0Nooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06Oooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo07Gooooo00?o
0000ooooooooool01oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000
ooooooooool0=oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool05_oo
ool2o`0000;ooooo0_l0000Mooooo`;o0000N?ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?ooool01_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0jooooo`;o00002?ooool00ol0003o
ooooooooo`0Aooooo`;o00008Oooool2o`0007_ooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo0_l0000looooo`;o00002?ooool2o`0000oooooo0_l0000Rooooo`03o`000?oooooooooo
07Wooooo0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
000000;o00001oooool00ol0003oooooooooo`09ooooo`?o00008oooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`?o00009?ooool2o`0007oooooo00?o
0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool=o`0002Gooooo0_l00021
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo087ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`;o
00009Oooool2o`0008Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo00oooooo0_l0000Qooooo`;o0000QOooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool04Oooool3o`0001_ooooo0ol00028ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05?ooool3
o`0001Cooooo1?l0002;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool05oooool6o`0000[ooooo1?l0002?ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool:o`0009?o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooooooo
o`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
00Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003ooooooooo
o`2hooooo`?o00002Oooool000Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0007ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Gooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2i
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Kooooo1Ol00003ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`000?oooooo2_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001oooool3o`0000Co
oooo0_l00004ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000
=?ooool00ol0003oooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2
o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go000000?ooooo
o`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l0
0007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l0
00001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00008ooooo`Go0000
1?ooool00ol0003oooooooooo`10ooooo`00DOooool01_l0003oooooooooool0003oooooo`0000?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0
003oooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00002ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`?o00000_ooool5o`0000;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo
001@ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool0
1?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o000000Co
ooooo`000?l0003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o00000oooool4o`0000?o
oooo1Ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`00
00Sooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo1?l00002oooo
o`?o00000_ooool4o`0000Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo047ooooo001Aooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool06_ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`12ooooo`00D_ooool3o`0001?ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo1?l0
0009ooooo`03o`000?oooooooooo00;ooooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo0ol0
0018ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.38809 .60559 .0013 0 365.73 arc
s
newpath
.40587 .56698 .0013 0 365.73 arc
s
newpath
.44927 .47275 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.38809 .60559 L
s
.29834 .30057 m
.40587 .56698 L
s
.38809 .60559 m
.40587 .56698 L
.44927 .47275 L
.38809 .60559 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.39242 .60992 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.4102 .57132 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.4536 .47708 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo0_l0002[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02Oooool2o`000:oooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
00000:kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
00Wooooo00?o0000ooooool00000[Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0002]ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool01?l0003o
ooooooooool0002]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0002]ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool01Ol0003o
oooooooooooooooo00000:cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000[?ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000??ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Z?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Wooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`07
ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`07oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:Oooooo00?o0000oooo
ooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Woooo
o`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Coooooo?l00009oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Voooo
o`03o`000?oooooooooo00Oooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Uooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0:?ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Wooooo1ol00003ooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`Go000000?oooooo`000?oo
ool01?ooool6o`000:Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool01?l0003oooooooooooooool3o`0000Kooooo00?o0000ooooooooool01oooool01?l0003o
ooooo`000?l0002Rooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo1?l00009ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00002Qoooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03[ooooo0_l0000<ooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooooooo0_l0002Oooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000>_ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool2o`0009cooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0hooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Wooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo09Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo09Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Toooool2o`0000Wo
oooo000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`2Cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2B
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`?o000000?oooooo`000?l00000Qoooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01_ooool4o`0008Sooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07oooooc?o0000LOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`Ko0000
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo0_l0000Hooooo`?o0000
Koooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool01?l0003oooooo`000?l0000<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000Iooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l0000?ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool05ooo
ool2o`0006gooooo00?o0000ooooooooool01oooool000gooooo0ol00004ooooo`;o00001Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool2
o`00013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`?o000000?ooooo
o`000?l000006Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000<oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`?o000000?o
ooooo`000?ooool04?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooooooo`;o0000
7_ooool2o`0006cooooo00?o0000ooooooooool01oooool0013ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`;o0000;_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo06So
oooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool01oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00008Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool01Ol0003oooooo`000?l0
003ooooo00?o00000_ooool2o`0000kooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool0000Qooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool000cooooo1Ol0
0003ooooo`;o00001Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`;o000000Goooooo`000?oooooo
ooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000008_ooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`Ko
000000Goooooo`000?ooooooooooo`00000>ooooo`03o`000?oooooooooo00Oooooo0_l0000Roooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000]ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`07
o`000?oooooo0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo0_l00002oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool01Oooool2
o`0002?ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00001_ooool2
o`0000Gooooo0_l0000Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00oooool2o`0002?ooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00cooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00?ooooo0_l0000Sooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooo
o`00013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`;o00008oooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;_ooool00ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool03Oooool0
1ol0003ooooooooooooooooo0000ooooool000008_ooool00ol0003oooooooooo`1[ooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04o`000?oo
ooooooooo`0001;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02o`0002?ooooo
00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooo000000;o00008_ooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02ooo
ool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00_ooooo1Ol0000Rooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool0
2oooool4o`00027ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo0000
5_ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000o`00027ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00033ooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00Sooooo1?l0000Qooooo`03
o`000?oooooooooo06kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo00Wooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`07ooooo`?o
000000?oooooo`000?ooool07oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool0000Iooooo`03o`000?oooooooooo00Kooooo0ol000000ooooooo0000ooooo`0Nooooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003o
ooooooooo`04ooooo`Go00008?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01Ol0003ooooo
oooooooooooo000001[ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000Qooooo`03
o`000?oooooooooo077ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6?ooool01?l0003oooooooooooooool3o`00027ooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_l0000Qooooo`03o`00
0?oooooooooo07;ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`Ko00008?oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Sooooo00Go0000ooooool0003oooooo`00000Pooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool5o`0001oooooo00?o0000
ooooooooool0MOooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo0_l00004oooo
o`;o00001Oooool00ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Fooooo`?o000000?oooooo`000?ooool07Oooool2o`0007Sooooo00?o0000
ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>?ooool2o`000003ooooool0
003ooooo00Kooooo00?o0000ooooooooool05?ooool01_l0003oooooooooool0003oooooo`0001go
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0jooooo`;o00002?ooool00ol0003oooooooooo`0Aooooo`;o00001?ooool00ol0
003oooooooooo`0Jooooo`;o0000Noooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2
o`0003cooooo0_l00008ooooo`;o00003oooool2o`0000Gooooo0_l0000Kooooo`03o`000?oooooo
oooo07Wooooo0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooo000000;o00001oooool00ol0003oooooooooo`09ooooo`?o00008oooool00ol0003ooooooooo
o`1looooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`?o00009?ooool2o`0007oooooo
00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool=o`0002Gooooo0_l0
0021ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo087ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=oooo
o`;o00009Oooool2o`0008Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo00oooooo0_l0000Qooooo`;o0000QOooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool04Oooool3o`0001_ooooo0ol00028ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05?oo
ool3o`0001Cooooo1?l0002;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool05oooool6o`0000[ooooo1?l0002?ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool:o`00
09?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooo
ooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2ioooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o00001Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool000Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003ooooo
ooooo`2hooooo`?o00002Oooool000Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Go
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooooooo
o`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Kooooo1Ol00003ooooo`;o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`000?oooooo2_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001oooool3o`00
00Cooooo0_l00004ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o
0000=?ooool00ol0003oooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_oo
ool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go000000?o
ooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
0_l00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo
1?l000001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00008ooooo`Go
00001?ooool00ol0003oooooooooo`10ooooo`00DOooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0
0003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`?o00000_ooool5o`0000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043o
oooo001@ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o0000
00Coooooo`000?l0003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o00000oooool4o`00
00?ooooo1Ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3
o`0000Sooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo1?l00002
ooooo`?o00000_ooool4o`0000Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo047ooooo001Aooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool06_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`12ooooo`00D_ooool3o`0001?ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo
1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo
0ol00018ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .1175 0 365.73 arc
s
newpath
.305 .5225 .0013 0 365.73 arc
s
newpath
.37895 .61381 .0013 0 365.73 arc
s
newpath
.39002 .57278 .0013 0 365.73 arc
s
newpath
.41707 .47262 .0013 0 365.73 arc
s
newpath
.29834 .30057 .0013 0 365.73 arc
s
.305 .5225 m
.29834 .30057 L
s
.305 .5225 m
.37895 .61381 L
s
.29834 .30057 m
.39002 .57278 L
s
.37895 .61381 m
.39002 .57278 L
.41707 .47262 L
.37895 .61381 L
s
gsave
.30933 .51817 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.38328 .61815 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.39436 .57712 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.4214 .47695 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.30267 .29623 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool4o`0000Cooooo0_l0002[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Z_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool5o`000005ooooool0
003oooooooooool00000ZOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000:[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;o000000Goooooo`000?ooooooooooo`00002Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
1Oooool6o`0000;ooooo0_l0002[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02Oooool2o`000:oooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
00000:kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
00Wooooo00?o0000ooooool00000[Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooo`00002^ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool01?l0003ooooo
ooooool0002]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool0002]ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool01?l0003ooooo
ooooool0002]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo00000:cooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool00000[?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo
00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo00000:_ooooo0_l00009ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo00000:_ooooo
00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo00000:_ooooo00?o0000ooooooooool0
1oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xooooo`03o`00
0?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Z?ooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooooco0000
2Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Wooooo`03o`00
0?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Yoooool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Yooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`2Uooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`09ooooo`Oo00000_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01?ooool5o`000003ooooool0
003ooooo00Cooooo1_l0002Tooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00Co0000oooooooooooooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooooooo0_l0002Rooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo1?l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03[ooooo0_l0000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool2
o`0009oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000jooooo`03o`000?oooooo0000
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`;o0000W?ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0V_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0gooooo`05o`000?oooooooooooooo
ool000003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0VOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
Uoooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0UOooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`2Cooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09?ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`?o000000?oooooo`000?l00000Soooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00_ooooo1Ol0002@ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000<?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooooolco`00077o
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02oooool01?l0003oooooooooooooool6o`0000?ooooo00?o0000oooooooo
ool02oooool2o`00023ooooo0ol0001_ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`04o`00
0?oooooo0000o`0000Wooooo00?o0000ooooooooool02oooool3o`00027ooooo00?o0000oooooooo
ool0KOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool2o`0000cooooo00?o0000ooooooooool0
2_ooool2o`000003ooooool0003ooooo023ooooo0_l0001]ooooo`03o`000?oooooooooo00Oooooo
000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`03o`000?oooooooooo00Wooooo0ol0
00000ooooooo0000o`00000Qooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01ooo
ool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo
0ol000000ooooooo0000ooooo`0<ooooo`03o`000?oooooooooo00Wooooo0_l000000ooooooo0000
ooooo`0Rooooo`;o0000K?ooool00ol0003oooooooooo`07ooooo`004?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000^ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02?ooool01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo06So
oooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooo00009?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
o`0002Cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooool0003o0000oooo
o`03o`0000;ooooo0_l0000;ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool5
o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo0_l000001Ooooooo0000oooo
oooooooo000000[ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000002Co
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooooooool6o`000005ooooool0003oooooooooool000002_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Zoooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01ol0003oooooo`000?oooooo0000
ooooool000000_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo0_l00004
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Koooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool03?ooool01?l0003oooooooooool00006ooooo`;o00001?ooool3o`0000gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00003Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00003_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00003oooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000^ooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
06_ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_o
oooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00;o00001?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`04
o`000?ooooooooooo`00017ooooo00?o0000ooooooooool02_ooool01?l0003oooooo`000?l00004
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00Co0000oooo
oooooooo00004_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000C
ooooo`03o`000?oooooooooo00Sooooo0ol00004ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`07
ooooo`Co00000oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000`ooooo`03o`000?oooooooooo00Wooooo00Co0000oooo
oooooooo00005?ooool00ol0003oooooooooo`08ooooo`;o000000Coooooo`000?oooooo00008_oo
ool00ol0003oooooooooo`1^ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool01ooo
ool01_l0003oooooooooool0003oooooo`0002;ooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo
00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`06ooooo`?o00000_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool0
00005_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool2o`0002;ooooo00?o0000oooooooo
ool0L?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00?o
oooo0_l00002ooooo`;o00008Oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool5o`00027ooooo
00?o0000ooooooooool0L_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Qooooo`03o`000?oooooooooo07;ooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`07o`000?ooooooooooooooool0003o
ooooo`00000Rooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooo`000002o`0002;ooooo00?o0000ooooooooool0
M?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`Ko00008?oo
ool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo01Gooooo0ol000000ooooooo0000ooooo`0Nooooo`;o0000N?oo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0hooooo`;o0000
00?oooooo`000?ooool01_ooool00ol0003oooooooooo`0Dooooo`Go00007_ooool00ol0003ooooo
ooooo`1hooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03[o
oooo0_l00008ooooo`03o`000?oooooooooo017ooooo0_l000001?oooooo0000ooooool0000Moooo
o`;o0000Noooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0003cooooo0_l00008
ooooo`;o00003oooool2o`0000?ooooo00?o0000ooooool000007?ooool00ol0003oooooooooo`1i
ooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooo`00
0002o`0000Oooooo00?o0000ooooooooool02Oooool3o`0000Kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00001?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`?o0000
2?ooool2o`0001[ooooo0_l0001oooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oo
oooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Gooooo3Ol0000Uooooo`;o0000POooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool03Oooool2o`0002Gooooo0_l00024ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0?ooooo`;o00008Oooool2o`0008Go
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo017ooooo
0ol0000Kooooo`?o0000R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Cooooo0ol0000Dooooo`Co0000Roooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Oooooo1_l0000:
ooooo`Co0000Soooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01gooooo2_l0002Cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0ol0
0003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`0000Wooooo0008ooooo`04o`000?oo
ooooooooooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001oooool2o`0000?ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool01?l0003ooooo
ooooooooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooo
ooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo0006ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooooco00002Oooool0
00Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool0ooooool8ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooo`[ooooo0006ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`000?oooooo2_ooool000Oooooo0ol00004ooooo`;o00001?ooool2o`000?oooooo2oooool006;o
oooo0ol0000Fooooo`?o00009_ooool3o`0003Cooooo00?o0000ooooooooool0@_ooool006?ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0@Oooool005;ooooo0_l00003ooooo`?o00001?ooool2o`000003ooooool0
003ooooo00?o00000_ooool5o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000
ooooo`02o`000003ooooool0003o000000;o00001oooool3o`0000Cooooo1?l00003ooooo`;o0000
0_ooool6o`0000Oooooo0ol00003ooooo`Co000000Coooooo`000?l0003o00002Oooool4o`0000?o
oooo0ol00004ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0@?ooool0057ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0
003ooooooooooooooooo000000kooooo00?o0000ooooool000001_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00?o0000oooooooo
ool02Oooool3o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003ooooo
ooooo`04ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co00001?ooool01?l0003o
ooooooooooooool3o`0000?ooooo1?l00003ooooo`Go00001oooool01?l0003oooooooooool00002
ooooo`;o00000oooool4o`0000?ooooo0ol00008ooooo`Co00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l00008ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`11ooooo`00DOooool01?l0003oooooooooool0
000Eooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool0@_ooool005;ooooo0ol0000Cooooo`?o0000
1Oooool00ol0003oooooooooo`0Cooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o0000
;oooool00ol0003oooooooooo`09ooooo`?o0000B?ooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["par set 2 (\[Psi]->f\[Psi]2)", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(par2 = {A0x \[Rule] 42, 
        A0y \[Rule] 29, \[Gamma]0 \[Rule] \(-57\)\ \[Degree], a \[Rule] 41.5, 
        b \[Rule] 117, c \[Rule] 129, 
        d \[Rule] 85, \[Kappa] \[Rule] 180\ Degree, k \[Rule] 52}\)], "Input",\

  CellChangeTimes -> {{3.419852365989037*^9, 3.4198524491248837`*^9}}],

Cell[BoxData[
    \({A0x \[Rule] 42, A0y \[Rule] 29, \[Gamma]0 \[Rule] \(-57\)\ \[Degree], 
      a \[Rule] 41.5`, b \[Rule] 117, c \[Rule] 129, 
      d \[Rule] 85, \[Kappa] \[Rule] 180\ \[Degree], 
      k \[Rule] 52}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xKpar = \(\(xK /. \[Delta] -> f\[Delta]\) /. \[Psi] -> f\[Psi]2\) /. 
          par2;\)\), "\n", 
    \(\(yKpar = \(\(yK /. \[Delta] -> f\[Delta]\) /. \[Psi] -> f\[Psi]2\) /. 
          par2;\)\), "\n", 
    \(\(plo2\  = \ 
        ParametricPlot[{xKpar, yKpar}, {\[CurlyPhi], 0\ Degree, 360\ Degree}, 
          PlotRange \[Rule] {{0, 130}, {0, 120}}, 
          GridLines \[Rule] Automatic, 
          PlotLabel \[Rule] "\<Path of K - par set 2\>"];\)\)}], "Input",
  CellChangeTimes -> {{3.4198524708446827`*^9, 3.4198524779235077`*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.00769231 0 0.00515028 [
[.15385 -0.0125 -6 -9 ]
[.15385 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.46154 -0.0125 -6 -9 ]
[.46154 -0.0125 6 0 ]
[.61538 -0.0125 -6 -9 ]
[.61538 -0.0125 6 0 ]
[.76923 -0.0125 -9 -9 ]
[.76923 -0.0125 9 0 ]
[.92308 -0.0125 -9 -9 ]
[.92308 -0.0125 9 0 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.15385 0 m
.15385 .61803 L
s
.30769 0 m
.30769 .61803 L
s
.46154 0 m
.46154 .61803 L
s
.61538 0 m
.61538 .61803 L
s
.76923 0 m
.76923 .61803 L
s
.92308 0 m
.92308 .61803 L
s
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.15385 0 m
.15385 .00625 L
s
[(20)] .15385 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(40)] .30769 -0.0125 0 1 Mshowa
.46154 0 m
.46154 .00625 L
s
[(60)] .46154 -0.0125 0 1 Mshowa
.61538 0 m
.61538 .00625 L
s
[(80)] .61538 -0.0125 0 1 Mshowa
.76923 0 m
.76923 .00625 L
s
[(100)] .76923 -0.0125 0 1 Mshowa
.92308 0 m
.92308 .00625 L
s
[(120)] .92308 -0.0125 0 1 Mshowa
.125 Mabswid
.03846 0 m
.03846 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.5 0 m
.5 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(20)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(40)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(60)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(80)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(100)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(120)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
123.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(par) show
159.000 13.000 moveto
(set) show
183.000 13.000 moveto
(2) show
189.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.70552 .19863 m
.74005 .19756 L
.77608 .19636 L
.79337 .19584 L
.8026 .1956 L
.81112 .1954 L
.81888 .19525 L
.8229 .19519 L
.82711 .19514 L
.8306 .19511 L
.8344 .19509 L
.83782 .19508 L
.84098 .19508 L
.84291 .19509 L
.84496 .1951 L
.8486 .19513 L
.8508 .19516 L
.85286 .19519 L
.85666 .19526 L
.8635 .19545 L
.86727 .19559 L
.87067 .19574 L
.8827 .19646 L
.88848 .19694 L
.89461 .19755 L
.90673 .19915 L
.91866 .20136 L
.92896 .20394 L
.93755 .20671 L
.94507 .20973 L
.95234 .21334 L
.96363 .22083 L
.96895 .22553 L
.97336 .23028 L
.97751 .2358 L
.98133 .24224 L
.98411 .24834 L
.98618 .25428 L
.98782 .26081 L
.9885 .26458 L
.98898 .26807 L
.98915 .26967 L
.9893 .27138 L
.9894 .27285 L
.98949 .27447 L
.98955 .27623 L
.98958 .27723 L
.98959 .27814 L
.98959 .27992 L
.98956 .28161 L
Mistroke
.9895 .2832 L
.98942 .28489 L
.98932 .2865 L
.98921 .28797 L
.98884 .2916 L
.9884 .29504 L
.98716 .30223 L
.98531 .31025 L
.98004 .32681 L
.97338 .34248 L
.96565 .35727 L
.9427 .39128 L
.91574 .4218 L
.8793 .45455 L
.84024 .48287 L
.74884 .53182 L
.69923 .55108 L
.64179 .56835 L
.58597 .58055 L
.55416 .58564 L
.54001 .58748 L
.5249 .58916 L
.50978 .59055 L
.49607 .59156 L
.48947 .59196 L
.48232 .59233 L
.47563 .59262 L
.46938 .59283 L
.46211 .59303 L
.45826 .5931 L
.45414 .59316 L
.45207 .59318 L
.44982 .59319 L
.4477 .5932 L
.44574 .59321 L
.44203 .5932 L
.44016 .59319 L
.4381 .59317 L
.43439 .59313 L
.431 .59307 L
.42728 .593 L
.42337 .59289 L
.4168 .59268 L
.40963 .59237 L
.39468 .59152 L
.38068 .59045 L
.35485 .58775 L
.32768 .58385 L
.29905 .57849 L
.24957 .56589 L
Mistroke
.20159 .54882 L
.16171 .52991 L
.12897 .50994 L
.09835 .4857 L
.07583 .46202 L
.05843 .43667 L
.05121 .42203 L
.04621 .40835 L
.04431 .40136 L
.04348 .39768 L
.04273 .3938 L
.04219 .39041 L
.04171 .38668 L
.04154 .38505 L
.04138 .3833 L
.04126 .38177 L
.04116 .38015 L
.04108 .37845 L
.04103 .37688 L
.041 .37519 L
.041 .37423 L
.041 .37333 L
.04102 .37172 L
.04107 .37024 L
.04113 .36862 L
.04123 .36691 L
.04147 .36395 L
.04176 .36119 L
.04267 .35499 L
.04407 .34827 L
.04607 .34107 L
.05095 .32824 L
.05724 .31609 L
.06437 .30524 L
.08349 .28366 L
.09678 .27227 L
.11076 .26225 L
.14378 .24397 L
.17915 .22994 L
.20001 .22356 L
.22059 .21836 L
.24614 .21316 L
.27168 .20912 L
.29828 .20594 L
.31285 .20456 L
.32867 .20334 L
.34239 .20247 L
.35782 .20168 L
.37221 .20111 L
.38593 .20069 L
Mistroke
.40235 .20033 L
.4118 .20019 L
.42064 .20009 L
.42846 .20002 L
.43295 .19999 L
.43718 .19997 L
.44165 .19996 L
.44577 .19995 L
.44805 .19994 L
.45055 .19994 L
.45512 .19994 L
.45961 .19994 L
.46386 .19995 L
.4677 .19996 L
.47187 .19997 L
.48131 .20001 L
.49009 .20005 L
.52379 .20025 L
.54191 .20035 L
.55218 .20039 L
.55707 .2004 L
.56161 .20042 L
.56588 .20042 L
.57043 .20043 L
.57501 .20043 L
.58008 .20043 L
.58445 .20043 L
.58917 .20042 L
.59363 .2004 L
.59773 .20039 L
.60772 .20034 L
.61703 .20027 L
.62727 .20018 L
.63822 .20005 L
.66055 .19969 L
.68073 .19927 L
.70552 .19863 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249.875, 154.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i0000VR000`400?l00000o`00003onOooool0
03Wooooo1Ol00003ooooo`;o00006?ooool3o`0000?ooooo0_l0000Fooooo`?o00001?ooool2o`00
01Oooooo0ol00004ooooo`;o00005?ooool3o`0000Cooooo0_l00004ooooo`;o00004?ooool3o`00
00;ooooo1Ol00003ooooo`;o00005Oooool003[ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Booooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Eooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Doooo
o`00>oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Gooooo1Ol00002oooo
o`04o`000?ooooooooooo`0001Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
01Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001Cooooo000looooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`0Cooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00005?ooool4o`00
00?ooooo00Co0000oooooooooooo00005_ooool3o`0000?ooooo00Co0000oooooooooooo00005?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`0Booooo`00>Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00005_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001Cooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000Eooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01;ooooo000iooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Gooooo`;o00000oooool01?l0
003oooooooooool0000Eooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00005Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00004oooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000?ooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00005?ooool003[ooooo0ol0
0004ooooo`;o00006Oooool00ol0003oooooooooo`02ooooo`;o00005oooool2o`0000Cooooo0_l0
000Gooooo`?o00001?ooool2o`0001Gooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0
000Aooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o00005Oooool00?Wooooo003ioooo
o`00nOooool00?Wooooo000Ooooooloo00002oooool001oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool0
01oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo
00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo
00?o001oooooooooool06Oooool001oooooo0_l0000Nooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0M
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0M
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0I
ooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0Mooooo`03
o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`00
7oooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7?ooool00ol007ooooooooooo`0Iooooo`007oooool2o`0001kooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooo
oooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooo
oooo01Wooooo000Oooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01go
oooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wo
oooo000Oooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01gooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000O
ooooo`;o00007_ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool0017ooooo1Ol00003ooooo`;o
00001?ooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`0Iooooo`004_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01gooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Dooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool3o`000<co001o2oooool0
017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool06Oooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00?o001oooooooooool06Oooool001;ooooo0ol00004ooooo`;o00001?oo
ool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?oo
ool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?oo
ool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool2o`00
01kooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo
01Wooooo000Oooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01gooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo
000Oooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01gooooo00?o001o
ooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001o
ooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Ooooo
o`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo01Wooooo000Oooooo`;o00007_ooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool0
7Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool0
6Oooool001oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool0
01oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool06Oooool001oooooo0_l0000Nooooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003ooooo
ooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooo
ooooo`0Iooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`004oooool3o`0000?ooooo0_l00004
ooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool05?oooolUo`0000?ooooo00?o001o
ooooooooool06Oooool001Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000007oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo00?oooooD?l0
0009ooooo`03o`00Oooooooooooo01Wooooo1Ol0000Jooooo`004Oooool5o`0000;ooooo00Co0000
oooooooooooo00000oooool3o`0003So001o2ol0001jo`00O`?o00003?l007l;ooooo`004Oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`0Cooooo`Go00001Oooool00ol007ooooooooooo`0Looooo`03o`00
Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00
Oooooooooooo00;ooooo00?o0000ooooooooool05?ooool001;ooooo00?o0000ooooool000000ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool0
3_ooool5o`0000[ooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`03ooooo`?o0000
4oooool001?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`09ooooo`Go00003oooool00ol007ooooooooooo`0Looooo`03o`00
Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00
Oooooooooooo00Kooooo00?o0000ooooooooool04?ooool001Cooooo00?o0000ooooooooool00_oo
ool2o`0000Cooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`04ooooo`Go00005?oo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00Oooooo00?o0000ooooooooool03ooo
ool001oooooo0_l0000Nooooo`04o`00Ooooooooooooooooo`?o00006Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo00Sooooo00?o0000ooooooooool03_ooool001oooooo00?o0000
ooooooooool07Oooool01?l007oo0000o`000?l0000Looooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool02Oooool00ol0003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`0L
ooooo`;o00007oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001o
ooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00Wooooo00?o0000
ooooooooool03Oooool001oooooo00?o0000ooooooooool06_ooool2o`000003ooooool007oooooo
01kooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`09ooooo`03o`000?oooooooooo
00gooooo000Oooooo`03o`000?oooooooooo01Sooooo0_l00003ooooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo000Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool02_ooool00ol0003ooooo
ooooo`0<ooooo`007oooool2o`0001Kooooo0_l00006ooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo000O
ooooo`03o`000?oooooooooo01?ooooo0_l00008ooooo`03o`00Oooooooooooo01gooooo00?o001o
ooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001o
ooooooooool07?ooool00ol007ooooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo000Ooooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool02oooool00ol0003oooooooooo`0;oooo
o`007oooool00ol0003oooooooooo`0@ooooo`;o00002oooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool02oooool00ol0003oooooooooo`0;ooooo`00
7oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o001oooooooooool0
7Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00_ooooo00?o0000ooooooooool0
2oooool001oooooo0_l0000?ooooo`03o`000?oooooooooo00cooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00_ooooo00?o0000ooooooooool02ooo
ool001oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo000Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool02oooool00ol0
003oooooooooo`0;ooooo`004_ooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03_ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01co
oooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01co
oooo00?o001oooooooooool02oooool00ol0003oooooooooo`0;ooooo`004Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00kooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo00_ooooo00?o0000ooooooooool02oooool0017ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo0ol0000;o`00O`03o`000?l007oo
001o0;_o001o00?o0000o`00Ool007l02oooool0017ooooo1?l00003ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0:ooooo`03o`000?oooooo
oooo00cooooo000Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00[ooooo00?o0000ooooooooool03?ooool0
01;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01cooooo00?o001oooooooooool02Oooool00ol0003oooooooooo`0=ooooo`004oooool2o`00
00Cooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool02Oooool00ol0
003oooooooooo`0=ooooo`007oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;o
oooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00Wo
oooo00?o0000ooooooooool03Oooool001oooooo0_l00008ooooo`03o`000?oooooooooo01?ooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00Sooooo
00?o0000ooooooooool03_ooool001oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooooooo
o`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooooooo
o`08ooooo`03o`000?oooooooooo00kooooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo00Oooooo00?o0000ooooooooool03oooool001oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`06ooooo`03o`000?oooooooooo013ooooo000Oooooo`;o0000
1oooool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7?ooool00ol007ooooooooooo`06ooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01cooooo00?o001oooooooooool01Oooool00ol0003oooooooooo`0Aooooo`007oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00Cooooo00?o0000ooooooooool04_ooool0
01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`03ooooo`03o`000?oooooooooo
01?ooooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool00oooool00ol0003o
ooooooooo`0Cooooo`007oooool2o`0000Oooooo00?o0000ooooooooool05?ooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool00_ooool00ol0003ooooo
ooooo`0Dooooo`007oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`05o`00Ooooooooooooooooool00000
5oooool001oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`00Oooo
oooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01gooooo00?o001oooooooooool07?ooool01Ol007oooooooooooooooooo000001Oooooo
000Booooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Dooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooooooo
o`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool01?l007oooooooooo
ool0000Hooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o001ooooooooo
ool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooo000001Wooooo000Aooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oo`000?ooool06Oooool001;ooooo0ol00003ooooo`04o`000?ooooooooooo`00
00?ooooo0ol00007o`00O`03o`000?l007oo001o0;;o001o00?o0000o`00Ool007l03Ol007l;oooo
o`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Looooo`03o`000?oooooooooo01Wooooo000Aooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04_ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01[ooooo0_l0
00000ol007ooooooooooo`0Iooooo`004_ooool3o`0000Cooooo0_l00004ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04_ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01Wooooo00Co0000oooooooooooo001o6oooool001oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Aooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool06?ooool0
1Ol0003ooooooooooooooooo001o01_ooooo000Oooooo`;o00002_ooool00ol0003oooooooooo`0A
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0M
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool05_ooool2o`0000Cooooo00?o001o
ooooooooool06Oooool001oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aoooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool05Oooool00ol0003oooooooooo`04oooo
o`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool04?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001ooooooooo
ool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01Cooooo00?o0000oooooooo
ool01Oooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00
Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Booooo`;o0000
2?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00kooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooo
oooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Aooooo`03o`000?oo
oooooooo00Sooooo00?o001oooooooooool06Oooool001oooooo0_l0000>ooooo`03o`000?oooooo
oooo00gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0@ooooo`03o`000?oooooo
oooo00Wooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0<ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool03_ooool2o`00
00cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0;ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02_ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Wooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0:ooooo`;o00004?ooool00ol007ooooooooooo`0Iooooo`007oooool2o`0001?ooooo0_l00009
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0M
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool02?ooool2o`0001;ooooo00?o001o
ooooooooool06Oooool001oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06oooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool01_ooool2o`0001Cooooo00?o001ooooo
ooooool06Oooool001oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03
o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01gooooo00?o001oooooooooool01?ooool2o`0001Kooooo00?o001ooooooooo
ool06Oooool000cooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
0_ooool2o`0001Sooooo00?o001oooooooooool06Oooool000gooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`03ooooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00Go001ooooooooo
ooooooooo`00000Jooooo`03o`00Oooooooooooo01Wooooo000=ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo01Sooooo0_l00003ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00Co001oooooool0003o00006ooo
ool00ol007ooooooooooo`0Iooooo`003Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000oooool3o`0001[o001o0_l00020o`00O`;o0000
;_l007l;ooooo`003Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Looooo`03o`000?l007oooooo01ko
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01_o
oooo0_l000000ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000<ooooo`;o0000
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool07Oooool2o`0001kooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01Wooooo0_l00002ooooo`03o`00Oooooooooooo01cooooo00?o001ooooo
ooooool06Oooool000gooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`03
o`000?oooooooooo01gooooo00Co001oooooool0003o00007?ooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool05oooool2o`0000Cooooo00?o001ooooo
ooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0Mooooo`04
o`00Ooooooooooooooooo`;o00006_ooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool05?ooool3o`0000Kooooo00?o001oooooooooool07?ooool00ol0
07ooooooooooo`0Iooooo`007oooool2o`0001kooooo00?o001oooooooooool00oooool2o`0001So
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01;o
oooo0_l00009ooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo
00?o0000ooooooooool07Oooool00ol007ooooooooooo`05ooooo`;o00005_ooool00ol007oooooo
ooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool03oooool3o`0000_ooooo
00?o001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003ooooooooo
o`0Mooooo`03o`00Oooooooooooo00Oooooo0ol0000Cooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0=ooooo`;o00003_ooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01gooooo00?o001o
ooooooooool02_ooool3o`00013ooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0M
ooooo`03o`00Oooooooooooo00[ooooo0ol0000@ooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0=oooo
o`?o00003Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool01oooool3o`0001?ooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Ioooo
o`007oooool2o`0001kooooo00?o001oooooooooool04?ooool4o`0000Wooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo00Cooooo0ol0000Fooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`0Dooooo`?o00001_ooool00ol007ooooooooooo`0Looooo`03o`00
Oooooooooooo01gooooo00?o001oooooool000001?l0000Iooooo`03o`00Oooooooooooo01cooooo
00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool00ol007oooooooooo
o`0Gooooo`?o00000oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01[ooooo1Ol0
000Nooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000
ooooooooool07Oooool00ol007ooooooooooo`0Jooooo`Go00007Oooool00ol007ooooooooooo`0D
ooooo`Ko00000oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooo000000Go00005oooool00ol007ooooooooooo`0?ooooo`Go00002Oooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oo
oooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo00Go
oooo3Ol0000:ooooo`03o`00Oooooooooooo00Cooooo2ol0000>ooooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool2o`0001kooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Boooooa7o00006Oooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o
0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool06Oooool000cooooo0ol00002ooooo`Go00000oooool2o`0000Cooooo00?o0000
ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool06Oooool000gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07Oooool00ol007oooooooooo
o`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool000gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool06Oooool000gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooooooo0ol0003<o`00O`_ooooo000=ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0=_o
oooo000<ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo0000gOooool000gooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0003Nooooo`00
Soooool3o`0006Oooooo002@ooooo`03o`000?oooooooooo06Kooooo0017ooooo`?o00001?ooool4
o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000;ooooo1Ol00007ooooo`?o000000?ooooo
o`000?l000004oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00009ooooo`Co00000ooo
ool3o`0000Cooooo0_l00008ooooo`Go0000=Oooool004Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooool0000Dooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooool000001_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0003Gooooo0018ooooo`03o`000?oooooooooo00?ooooo0ol00003oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000009ooooo`Co00002?oo
ool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`?o0000
0_ooool5o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0eooooo`00B?oo
ool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00Sooooo0_l0000Fooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003ooooooooo
ooooool2o`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0dooooo`00B?ooool01?l0003ooooo
ooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00009ooooo`?o00000oooool4o`0000So
oooo00?o0000ooooool000005?ooool4o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00002?ooool4o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo0000
03Gooooo0018ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000>?ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000=Oooool004Oooooo1?l00009
ooooo`03o`000?oooooooooo00;ooooo0_l0000Cooooo`;o00001oooool3o`000003ooooool0003o
000003Oooooo00?o0000ooooooooool02Oooool3o`0003Kooooo003iooooo`00nOooool00001\
\>"],
  ImageRangeCache->{{{0, 248.875}, {153.375, 0}} -> {-20.0782, -10.9164, \
0.631499, 0.943189}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[plo1, plo2, 
        PlotLabel \[Rule] "\<Path of K - par set 1+2\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.00769231 0 0.00515028 [
[.15385 -0.0125 -6 -9 ]
[.15385 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.46154 -0.0125 -6 -9 ]
[.46154 -0.0125 6 0 ]
[.61538 -0.0125 -6 -9 ]
[.61538 -0.0125 6 0 ]
[.76923 -0.0125 -9 -9 ]
[.76923 -0.0125 9 0 ]
[.92308 -0.0125 -9 -9 ]
[.92308 -0.0125 9 0 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.15385 0 m
.15385 .61803 L
s
.30769 0 m
.30769 .61803 L
s
.46154 0 m
.46154 .61803 L
s
.61538 0 m
.61538 .61803 L
s
.76923 0 m
.76923 .61803 L
s
.92308 0 m
.92308 .61803 L
s
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.15385 0 m
.15385 .00625 L
s
[(20)] .15385 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(40)] .30769 -0.0125 0 1 Mshowa
.46154 0 m
.46154 .00625 L
s
[(60)] .46154 -0.0125 0 1 Mshowa
.61538 0 m
.61538 .00625 L
s
[(80)] .61538 -0.0125 0 1 Mshowa
.76923 0 m
.76923 .00625 L
s
[(100)] .76923 -0.0125 0 1 Mshowa
.92308 0 m
.92308 .00625 L
s
[(120)] .92308 -0.0125 0 1 Mshowa
.125 Mabswid
.03846 0 m
.03846 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.5 0 m
.5 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(20)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(40)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(60)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(80)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(100)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(120)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
123.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(par) show
159.000 13.000 moveto
(set) show
183.000 13.000 moveto
(1) show
189.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
195.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.896 .43677 m
.93601 .39293 L
.95327 .3677 L
.96388 .34812 L
.97012 .33369 L
.97472 .32009 L
.97639 .31388 L
.97777 .30764 L
.97872 .30225 L
.97935 .29757 L
.97976 .29335 L
.97991 .2913 L
.97997 .29015 L
.98002 .2891 L
.98005 .28813 L
.98008 .28711 L
.98009 .28653 L
.98009 .28599 L
.9801 .28499 L
.98009 .28405 L
.98008 .28319 L
.98006 .28226 L
.98003 .28128 L
.98 .28048 L
.97995 .27963 L
.97986 .27812 L
.97971 .27636 L
.97956 .27479 L
.97913 .27143 L
.97854 .26796 L
.97717 .26208 L
.97561 .25708 L
.9736 .25201 L
.96876 .24298 L
.96355 .23591 L
.95728 .2294 L
.95072 .22406 L
.94331 .21927 L
.92883 .21241 L
.92088 .20962 L
.91205 .20711 L
.90335 .20512 L
.89359 .20335 L
.88387 .20197 L
.87463 .20094 L
.86534 .20015 L
.85989 .19978 L
.85483 .19948 L
.84465 .19903 L
.83892 .19885 L
Mistroke
.8334 .19871 L
.82811 .19861 L
.82512 .19857 L
.8224 .19854 L
.81983 .19851 L
.81848 .1985 L
.81704 .1985 L
.81578 .19849 L
.81439 .19848 L
.81378 .19848 L
.81312 .19848 L
.81251 .19848 L
.81193 .19848 L
.81123 .19848 L
.81085 .19848 L
.81045 .19848 L
.81005 .19848 L
.80963 .19848 L
.80887 .19848 L
.80816 .19848 L
.80751 .19848 L
.80679 .19848 L
.80602 .19848 L
.80426 .19849 L
.80261 .1985 L
.79949 .19851 L
.79371 .19856 L
.78736 .19863 L
.77502 .19881 L
.76156 .19905 L
.7362 .19958 L
.7074 .20018 L
.67763 .20072 L
.66157 .20095 L
.65281 .20106 L
.64326 .20116 L
.6346 .20124 L
.62477 .20131 L
.62038 .20134 L
.61558 .20136 L
.61132 .20138 L
.60671 .2014 L
.60418 .2014 L
.60187 .20141 L
.5995 .20141 L
.59729 .20142 L
.5947 .20142 L
.59333 .20142 L
.59263 .20142 L
.59187 .20142 L
Mistroke
.59059 .20142 L
.5894 .20142 L
.58866 .20142 L
.58796 .20142 L
.58665 .20142 L
.58594 .20142 L
.58527 .20142 L
.58401 .20142 L
.58266 .20142 L
.58118 .20142 L
.5785 .20141 L
.57601 .20141 L
.5702 .2014 L
.56393 .20138 L
.55306 .20133 L
.54087 .20127 L
.51716 .20113 L
.50277 .20104 L
.49474 .20099 L
.4858 .20094 L
.47762 .20091 L
.47311 .20089 L
.4681 .20087 L
.46581 .20087 L
.46336 .20086 L
.46124 .20086 L
.45889 .20086 L
.45664 .20086 L
.45419 .20086 L
.45184 .20086 L
.44967 .20086 L
.44784 .20086 L
.44611 .20086 L
.44417 .20087 L
.44207 .20087 L
.43766 .20089 L
.43348 .20091 L
.42948 .20093 L
.42496 .20097 L
.41617 .20105 L
.40474 .20121 L
.39761 .20134 L
.39049 .20149 L
.38305 .20168 L
.37377 .20195 L
.349 .20297 L
Mfstroke
.70552 .19863 m
.74005 .19756 L
.77608 .19636 L
.79337 .19584 L
.8026 .1956 L
.81112 .1954 L
.81888 .19525 L
.8229 .19519 L
.82711 .19514 L
.8306 .19511 L
.8344 .19509 L
.83782 .19508 L
.84098 .19508 L
.84291 .19509 L
.84496 .1951 L
.8486 .19513 L
.8508 .19516 L
.85286 .19519 L
.85666 .19526 L
.8635 .19545 L
.86727 .19559 L
.87067 .19574 L
.8827 .19646 L
.88848 .19694 L
.89461 .19755 L
.90673 .19915 L
.91866 .20136 L
.92896 .20394 L
.93755 .20671 L
.94507 .20973 L
.95234 .21334 L
.96363 .22083 L
.96895 .22553 L
.97336 .23028 L
.97751 .2358 L
.98133 .24224 L
.98411 .24834 L
.98618 .25428 L
.98782 .26081 L
.9885 .26458 L
.98898 .26807 L
.98915 .26967 L
.9893 .27138 L
.9894 .27285 L
.98949 .27447 L
.98955 .27623 L
.98958 .27723 L
.98959 .27814 L
.98959 .27992 L
.98956 .28161 L
Mistroke
.9895 .2832 L
.98942 .28489 L
.98932 .2865 L
.98921 .28797 L
.98884 .2916 L
.9884 .29504 L
.98716 .30223 L
.98531 .31025 L
.98004 .32681 L
.97338 .34248 L
.96565 .35727 L
.9427 .39128 L
.91574 .4218 L
.8793 .45455 L
.84024 .48287 L
.74884 .53182 L
.69923 .55108 L
.64179 .56835 L
.58597 .58055 L
.55416 .58564 L
.54001 .58748 L
.5249 .58916 L
.50978 .59055 L
.49607 .59156 L
.48947 .59196 L
.48232 .59233 L
.47563 .59262 L
.46938 .59283 L
.46211 .59303 L
.45826 .5931 L
.45414 .59316 L
.45207 .59318 L
.44982 .59319 L
.4477 .5932 L
.44574 .59321 L
.44203 .5932 L
.44016 .59319 L
.4381 .59317 L
.43439 .59313 L
.431 .59307 L
.42728 .593 L
.42337 .59289 L
.4168 .59268 L
.40963 .59237 L
.39468 .59152 L
.38068 .59045 L
.35485 .58775 L
.32768 .58385 L
.29905 .57849 L
.24957 .56589 L
Mistroke
.20159 .54882 L
.16171 .52991 L
.12897 .50994 L
.09835 .4857 L
.07583 .46202 L
.05843 .43667 L
.05121 .42203 L
.04621 .40835 L
.04431 .40136 L
.04348 .39768 L
.04273 .3938 L
.04219 .39041 L
.04171 .38668 L
.04154 .38505 L
.04138 .3833 L
.04126 .38177 L
.04116 .38015 L
.04108 .37845 L
.04103 .37688 L
.041 .37519 L
.041 .37423 L
.041 .37333 L
.04102 .37172 L
.04107 .37024 L
.04113 .36862 L
.04123 .36691 L
.04147 .36395 L
.04176 .36119 L
.04267 .35499 L
.04407 .34827 L
.04607 .34107 L
.05095 .32824 L
.05724 .31609 L
.06437 .30524 L
.08349 .28366 L
.09678 .27227 L
.11076 .26225 L
.14378 .24397 L
.17915 .22994 L
.20001 .22356 L
.22059 .21836 L
.24614 .21316 L
.27168 .20912 L
.29828 .20594 L
.31285 .20456 L
.32867 .20334 L
.34239 .20247 L
.35782 .20168 L
.37221 .20111 L
.38593 .20069 L
Mistroke
.40235 .20033 L
.4118 .20019 L
.42064 .20009 L
.42846 .20002 L
.43295 .19999 L
.43718 .19997 L
.44165 .19996 L
.44577 .19995 L
.44805 .19994 L
.45055 .19994 L
.45512 .19994 L
.45961 .19994 L
.46386 .19995 L
.4677 .19996 L
.47187 .19997 L
.48131 .20001 L
.49009 .20005 L
.52379 .20025 L
.54191 .20035 L
.55218 .20039 L
.55707 .2004 L
.56161 .20042 L
.56588 .20042 L
.57043 .20043 L
.57501 .20043 L
.58008 .20043 L
.58445 .20043 L
.58917 .20042 L
.59363 .2004 L
.59773 .20039 L
.60772 .20034 L
.61703 .20027 L
.62727 .20018 L
.63822 .20005 L
.66055 .19969 L
.68073 .19927 L
.70552 .19863 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00@?ooool5o`0000?ooooo0_l0000Mooooo`?o00000oooool2o`0001cooooo0ol00004oooo
o`;o00007?ooool3o`0000Cooooo0_l0000Jooooo`?o00001?ooool2o`0000Cooooo0_l0000Foooo
o`?o00000_ooool5o`0000?ooooo0_l0000Iooooo`00@Oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0001gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001[ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
01Sooooo0012ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006_ooool5o`00
00;ooooo00Co0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00006_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00006_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00005_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00006?ooool004?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo01Sooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000Joooo
o`Co00000oooool01?l0003oooooooooool0000Kooooo`?o00000oooool01?l0003oooooooooool0
000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Fooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo01Kooooo0010ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Kooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00006_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Kooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool05_ooool0043ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001cooooo0_l00003oooo
o`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
000Jooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Iooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0001Gooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Hooooo`00@Ooo
ool3o`0000Cooooo0_l0000Nooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`;o00001?oo
ool2o`0001cooooo0ol00004ooooo`;o00006oooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0001Oooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000Iooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`008?ooooodo`0000cooooo000P
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool0023ooooo00?o0000oooo
ooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool07Oooool0023ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool0
8oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool0
8_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool0
7Oooool0023ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool07Oooool0023ooooo0_l0000Tooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0
003oooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol0
07ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol0
07ooooooooooo`0Mooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003ooooo
ooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oooooo
ooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007oooooo
ooooo`0Mooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o
001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o
001oooooooooool08_ooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003oooooooooo`0S
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0M
ooooo`008?ooool2o`0002Cooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Roooo
o`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Roooo
o`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o001ooooooooo
ool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001ooooooooo
ool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`00
0?oooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00
Oooooooooooo01gooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool08_oo
ool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08ooo
ool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooo
oooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo01gooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool08_ooool00ol0
07ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol0
07ooooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000Pooooo`;o00009?ooool00ol007oo
ooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oo
ooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023ooooo
00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool08oooool00ol007oooooooooo
o`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oooooooooo
o`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000
ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001o
ooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001o
ooooooooool07Oooool0017ooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0Soooo
o`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Roooo
o`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Moooo
o`004_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001o
ooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001o
ooooooooool07Oooool001?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo01gooooo000Dooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`02ooooo`?o0000lOl007l<ooooo`004Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Sooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Mooooo`004Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oooooo
ooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007oooooo
ooooo`0Mooooo`004_ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o
001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o
001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000Pooooo`;o
00009?ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001ooooooooo
ool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001ooooooooo
ool07Oooool0023ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool08ooo
ool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_oo
ool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Ooo
ool0023ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool08oooool00ol0
07ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol0
07ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023o
oooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool07Oooool0023ooooo0_l0000Tooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003ooooooooo
o`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oooooooooo
o`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007oooooooooo
o`0Mooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001o
ooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001o
ooooooooool08_ooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003oooooooooo`0Soooo
o`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Roooo
o`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Moooo
o`008?ooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001ooooooooo
ool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001ooooooooo
ool08_ooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00
Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Mooooo`008?oo
ool2o`0002Cooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo01gooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool08_ooool0
0ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool0
0ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooooooo
02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
01gooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007oo
ooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007oo
ooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000Cooooo`?o00000oooool2o`0000Gooooo
00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`0PooooobCo00001?ooool00ol007oooooo
ooooo`0Mooooo`005?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool0
2ooooomno`0000Gooooo1_l0000Nooooo`004Oooool5o`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo4ol0000Booooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Iooooo`Ko0000
0oooool01?l007ooooooo`000?l0000Looooo`004Oooool01?l0003oooooooooool00003ooooo`04
o`000?ooooooooooo`0000Cooooo0ol0000lo`00O`co0000T_l007l5o`0000;o001o0ol0000=o`00
O`cooooo000Booooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0Sooooo`03o`00Oooooooooooo01;ooooo1?l0000<ooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo
02;ooooo00Co001oooooool0003o00000oooool2o`0001Oooooo000Cooooo`;o00000oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool03oooool3
o`00013ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo02?ooooo00?o001oooooooooool08_ooool01Ol007oooooooooooooooooo000000Cooooo00?o
0000ooooooooool05?ooool001Cooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000
ooooooooool08oooool00ol007ooooooooooo`0;ooooo`Co00004oooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo00;ooooo0_l00003ooooo`03o`000?oooooooooo01?ooooo000Poooo
o`03o`000?oooooooooo02?ooooo00?o001oooooooooool01_ooool5o`0001Oooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`04ooooo`05o`000?ooooooooooooooool000005?ooool0
023ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`02ooooo`Co00007?ooool00ol0
07ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol0
07ooooooooooo`0Rooooo`03o`00Oooooooooooo00Gooooo00Go0000ooooooooooooooooo`00000C
ooooo`008?ooool2o`0002Cooooo00?o001oooooooooool00_l0000Pooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool01_ooool01?l0003oooooooooool0000Cooooo`008?ooool00ol0
003oooooooooo`0Sooooo`?o00008_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
00Oooooo00Co0000oooooooooooo00004_ooool0023ooooo00?o0000ooooooooool08Oooool2o`00
0003o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Roooo
o`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`07oooo
o`05o`000?ooooooooooooooool000004Oooool0023ooooo00?o0000ooooooooool07oooool2o`00
00;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
00Sooooo00Co0000oooooooooooo00004Oooool0023ooooo00?o0000ooooooooool07Oooool2o`00
00Cooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
00Sooooo00Go0000ooooooooooooooooo`00000@ooooo`008?ooool00ol0003oooooooooo`0Koooo
o`;o00001_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool02Oooool01?l0003oooooooooool0000@ooooo`008?ooool2o`0001[ooooo0_l00008oooo
o`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Roooo
o`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0:oooo
o`03o`000?oooooo0000013ooooo000Pooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02?ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001ooooooooo
ool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001ooooooooo
ool02_ooool01?l0003oooooooooool0000?ooooo`008?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00Wooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03
o`00Oooooooooooo00[ooooo00Co0000oooooooooooo00003oooool0023ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0:ooooo`03o`00Oooooooooooo02;ooooo00?o001ooooooooo
ool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001ooooooooo
ool08_ooool00ol007ooooooooooo`0;ooooo`03o`000?oooooo000000oooooo000Pooooo`03o`00
0?oooooooooo01Cooooo0_l0000=ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool0
8_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool0
8_ooool00ol007ooooooooooo`0;ooooo`03o`000?oooooo000000oooooo000Pooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool03Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool02oooool00ol0003oooooo`00000?ooooo`008?ooool2
o`0001?ooooo00?o0000ooooooooool03_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool02oooool00ol0003oooooo`00000?ooooo`008?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o001oooooooooool08_ooool00ol0
07ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol0
07ooooooooooo`0Rooooo`03o`00Oooooooooooo00_ooooo00?o0000ooooool000003oooool0023o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0;ooooo`03o`000?oooooo000000oo
oooo000Pooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol007oooooo
ooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oooooo
ooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool02oooool00ol0003ooooo
o`00000?ooooo`004_ooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o
001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o
001oooooooooool02oooool00ol0003oooooo`00000?ooooo`004Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00
Oooooooooooo00_ooooo00?o0000ooooool000003oooool0017ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Cooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oo
ooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007oo
ooooooooo`0:ooooo`04o`000?ooooooooooo`0000oooooo000Aooooo`Co00000oooool01?l0003o
ooooooooool00004ooooo`?o00003?l007l00ol0003o001oo`00O`3Ko`00O`03o`000?l007oo0000
00Co001o3?ooool0017ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05Oooool00ol007ooooooooooo`0Roooo
o`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Soooo
o`03o`00Oooooooooooo02;ooooo00?o001oooooooooool02_ooool00ol0003oooooo`00000@oooo
o`004_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Eooooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`0:ooooo`03o`000?oooooo0000013ooooo000Cooooo`;o
00001?ooool2o`0000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03
o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0:ooooo`;o
00004Oooool0023ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00
Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0:ooooo`;o0000
4Oooool0023ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`09ooooo`03o`000?oo
oooo0000017ooooo000Pooooo`;o00002_ooool00ol0003oooooooooo`0Gooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`09ooooo`;o00004_ooool0
023ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
02?ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`09ooooo`;o00004_ooool0023o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`08ooooo`;o00004oooool0023ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Hooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`07ooooo`03o`000?oooooo000001?ooooo
000Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol007oooooooooo
o`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oooooooooo
o`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool01oooool2o`0001Cooooo000P
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0S
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool01_ooool2o`0001Gooooo000Poooo
o`;o00002?ooool00ol0003oooooooooo`0Iooooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`05ooooo`03o`000?oooooo000001Gooooo000Pooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol007ooooooooooo`0Rooooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool01Oooool2o`0001Kooooo000Pooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol007ooooooooooo`0Rooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool01?ooool2o`0001Oooooo000Pooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool06Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool01?ooool2o`0001Oooooo000Pooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool00oooool2o`0001Sooooo000Pooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool00_ooool00ol0003oooooo`00000Hooooo`008?ooool2o`0000So
oooo00?o0000ooooooooool06Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool00_ooool2o`0001Wooooo000Pooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo
00Co001ooooooooooooooooo0_l0000Jooooo`008?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01Sooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`06o`00
Ooooooooooooo`000?oooooo00006_ooool0023ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Hooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oo
ooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool08_ooool00ol007oo
ooooooooo`02o`0001_ooooo000Booooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Hooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool0
8_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool0
8_ooool01?l007ooooooo`000?l0000Looooo`004Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Sooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Ool0003o0000
01gooooo000Aooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?ooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0S
ooooo`03o`00Oooooooooooo02;ooooo0_l0000Nooooo`004_ooool3o`0000?ooooo00Co0000oooo
oooooooo00001?ooool3o`0000So001o00?o0000o`00Ool007l0dOl007l2o`0001?o001o3?ooool0
017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`00Oooooooooooo02;ooooo00?o
001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o
001oooooooooool08?ooool2o`000003o`00Oooooooooooo01gooooo000Aooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool05_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo01oooooo
0_l000000ooooooo001oooooo`0Nooooo`004_ooool3o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool05_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooo
oooooooo01kooooo0_l00002ooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooo
oooo01gooooo0_l00003ooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo
01cooooo0_l00004ooooo`03o`00Oooooooooooo01gooooo000Pooooo`;o00003?ooool00ol0003o
ooooooooo`0Eooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oo
ooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool06oooool2o`0000Go
oooo00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Dooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oooooo
ooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool06_ooool00ol0003ooooo
ooooo`05ooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool04oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o
001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo01Wooooo00?o
0000ooooooooool01_ooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`0H
ooooo`03o`000?oooooooooo00Oooooo00?o001oooooooooool07Oooool0023ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Booooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001ooooo
ooooool05_ooool2o`0000[ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Aooooo`03o`00Oooooooooooo02;ooooo00?o001ooooooooo
ool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001ooooooooo
ool05Oooool00ol0003oooooooooo`0:ooooo`03o`00Oooooooooooo01gooooo000Pooooo`;o0000
4Oooool00ol0003oooooooooo`0@ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool0
8_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool0
5?ooool00ol0003oooooooooo`0;ooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool03oooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooo
oooooooo01;ooooo0_l0000>ooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool03_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooo
oooo017ooooo00?o0000ooooooooool03_ooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o001oooooooooool08_ooool00ol0
07ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol0
07ooooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o001oooooooooool07Oooool0023o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?o
oooo00?o001oooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00Oooooooooooo01go
oooo000Pooooo`03o`000?oooooooooo01Gooooo0_l0000<ooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02?ooooo
00?o001oooooooooool03Oooool2o`0001?ooooo00?o001oooooooooool07Oooool0023ooooo0_l0
000Hooooo`03o`000?oooooooooo00Wooooo00?o001oooooooooool08_ooool00ol007oooooooooo
o`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007oooooooooo
o`0;ooooo`;o00005Oooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Sooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`09
ooooo`;o00005oooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003oooooooooo`0Ioooo
o`;o00002?ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo00Sooooo00?o0000oooo
ooooool05oooool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Gooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007ooooooooooo`06ooooo`;o
00006_ooool00ol007ooooooooooo`0Mooooo`003?ooool3o`0000Cooooo0_l00004ooooo`;o0000
1Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o001oooooooooool0
8_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool0
8oooool00ol007ooooooooooo`04ooooo`;o00007?ooool00ol007ooooooooooo`0Mooooo`003Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0Mooooo`;o00001?ooool00ol007ooooooooooo`0Rooooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03
o`00Oooooooooooo00;ooooo0_l0000Nooooo`03o`00Oooooooooooo01gooooo000=ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`?o00007ol007l00ol0003o001oo`00O`2Io`00O`;o0000=?l007l<ooooo`003Oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Pooooo`;o000000?oooooo`00Ooooool08oooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08oooool00ol007oo0000o`00000R
ooooo`03o`00Oooooooooooo01gooooo000=ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02;ooooo00?o
0000o`00Ooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o
001oooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000<
ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool08_ooool00ol007ooooooooooo`0Qooooo`;o000000?o001oooooooooool0
8_ooool00ol007ooooooooooo`0Mooooo`003Oooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool08oooool00ol007oo0000o`00000Rooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Oooooo`;o00000_oo
ool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooo
oooo02?ooooo00?o001oooooooooool00_l0000Pooooo`03o`00Oooooooooooo02;ooooo00?o001o
ooooooooool08_ooool00ol007ooooooooooo`0Mooooo`;o00001?ooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o001ooooo
ooooool00_ooool2o`0001kooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Roooo
o`03o`00Oooooooooooo01[ooooo0ol00006ooooo`03o`00Oooooooooooo02;ooooo00?o001ooooo
ooooool07Oooool0023ooooo0_l0000Tooooo`03o`00Oooooooooooo00Cooooo0_l0000Looooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Gooooo`?o
00002Oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo01gooooo000Pooooo`03o`00
0?oooooooooo02?ooooo00?o001oooooooooool01_ooool2o`0001[ooooo00?o001oooooooooool0
8_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo01Cooooo0ol0000<ooooo`03o`00
Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool08ooo
ool00ol007ooooooooooo`08ooooo`?o00005oooool00ol007ooooooooooo`0Rooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool04?ooool4o`0000oooooo00?o001oooooooooool08_oo
ool00ol007ooooooooooo`0Mooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooo
oooo00_ooooo0ol0000Dooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool0
0ol007ooooooooooo`0=ooooo`?o00004oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooo
oooo01gooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool03_ooool3o`00
017ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
00Wooooo1?l0000Fooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023o
oooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0Aooooo`?o00003_ooool00ol007oo
ooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool01_ooool3o`0001[o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Mooooo`008?ooool2o`0002Cooooo
00?o001oooooooooool05?ooool3o`0000_ooooo00?o001oooooooooool08_ooool00ol007oooooo
ooooo`0Rooooo`03o`00Oooooooooooo00;ooooo1?l0000Mooooo`03o`00Oooooooooooo02;ooooo
00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool08oooool00ol007oooooooooo
o`0Gooooo`Co00001oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo1Ol0
000Qooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000
ooooooooool08oooool00ol007ooooooooooo`0Kooooo`Co00000oooool00ol007ooooooooooo`0R
ooooo`03o`00Oooooooooooo01gooooo1Ol000000ol007ooooooooooo`0Sooooo`03o`00Oooooooo
oooo02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool08oooool00ol0
07ooooooooooo`0Oooooo`Ko00008_ooool00ol007ooooooooooo`0Iooooo`Co00001Oooool00ol0
07ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023o
oooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo00Ko
00007?ooool00ol007ooooooooooo`0Fooooo`?o00002Oooool00ol007ooooooooooo`0Sooooo`03
o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool0
8oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo00Kooooo1ol0000Eooooo`03o`00
Oooooooooooo00_ooooo2ol0000<ooooo`03o`00Oooooooooooo02?ooooo00?o001oooooooooool0
8_ooool00ol007ooooooooooo`0Mooooo`008?ooool2o`0002Cooooo00?o001oooooooooool08_oo
ool00ol007ooooooooooo`0=ooooob?o00005oooool00ol007ooooooooooo`0Sooooo`03o`00Oooo
oooooooo02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool08oooool0
0ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool0
0ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool0
023ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo
02;ooooo00?o001oooooooooool07Oooool0023ooooo00?o0000ooooooooool08oooool00ol007oo
ooooooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oo
ooooooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool000cooooo
0ol00002ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool08oooool00ol007oooooo
ooooo`0Rooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool08_ooool00ol007oooooo
ooooo`0Sooooo`03o`00Oooooooooooo02;ooooo00?o001oooooooooool07Oooool000gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0Rooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool08_ooool00ol007ooooooooooo`0Sooooo`03o`00Oooooooooooo02;o
oooo00?o001oooooooooool07Oooool000gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo0ol0003ao`00O`cooooo000=ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo0?oo
oooo0oooool000gooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool0ooooool3ooooo`003?ooool2o`0000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`000?oooooo1Oooool000gooooo00?o0000oooo
ooooool00_ooool3o`0000Cooooo0_l0003oooooo`Kooooo002Mooooo`?o0000P?ooool009kooooo
00?o0000ooooooooool0Ooooool005Gooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l0
0007ooooo`?o00000_ooool5o`0000Oooooo0ol000000ooooooo0000o`00000Cooooo`?o00000ooo
ool4o`000004ooooool0003o0000o`0000Wooooo1?l00003ooooo`?o00001?ooool2o`0000Wooooo
0ol00005ooooo`03o`000?oooooooooo00Go0000@_ooool005Kooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool02?ooool0
1?l0003oooooooooool0000Dooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooool000001_ooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo043ooooo001Fooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooo`000009ooooo`Co00002?ooool01?l0003ooooo
ooooool00002ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`?o00000_ooool5o`0000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool00ol0003o
ooooooooo`12ooooo`00E_ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Sooooo0_l0000Fooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@Oooool005Kooooo00Co0000oooooooo
oooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002Oooool3o`0000?ooooo1?l00008oooo
o`03o`000?oooooo000001Cooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o0000
00Sooooo1?l00002ooooo`?o00000_ooool4o`0000[ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo043ooooo001Fooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo00Co0000oooooooooooo0000>?ooool00ol0003oooooooooo`09ooooo`;o00002Ooo
ool01Ol0003ooooooooooooooooo000004;ooooo001Eooooo`Co00002Oooool00ol0003ooooooooo
o`02ooooo`;o00004oooool2o`0000Oooooo0ol000000ooooooo0000o`00000gooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02?ooool3o`0004?ooooo003oooooob7ooooo003ooooo
ob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-17.5645, -9.63372, \
0.536078, 0.800671}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Animation of crank-rocker mecha par 2 (\[Psi]\[Rule]f\[Psi]2)\
\>", \
"Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pa = par2\)], "Input"],

Cell[BoxData[
    \({A0x \[Rule] 42, A0y \[Rule] 29, \[Gamma]0 \[Rule] \(-57\)\ \[Degree], 
      a \[Rule] 41.5`, b \[Rule] 117, c \[Rule] 129, 
      d \[Rule] 85, \[Kappa] \[Rule] 180\ \[Degree], 
      k \[Rule] 52}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(f\[Psi]i = f\[Psi]2;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rA0x = A0x /. pa;\)\), "\n", 
    \(\(rA0y = A0y /. pa;\)\), "\n", 
    \(\(rB0x = d\ Cos[\[Gamma]0] /. pa;\)\), "\n", 
    \(\(rB0y = d\ Sin[\[Gamma]0] /. pa;\)\), "\n", 
    \(\(rax\  = \ 
        A0x\  + \ a\ Cos[\[CurlyPhi] + \[Gamma]0] /. pa;\)\), "\n", 
    \(\(ray\  = \ 
        A0y\  + \ a\ Sin[\[CurlyPhi] + \[Gamma]0] /. pa;\)\), "\n", 
    \(\(rbx\  = \ \(A0x\  + \ b\ Cos[\[Psi] + \[Gamma]0]\  + 
              d\ Cos[\[Gamma]0] /. \[Psi] \[Rule] f\[Psi]i\) /. 
          pa;\)\), "\n", 
    \(\(rby\  = \ \(A0y\  + \ b\ Sin[\[Psi] + \[Gamma]0]\  + 
              d\ Sin[\[Gamma]0] /. \[Psi] \[Rule] f\[Psi]i\) /. 
          pa;\)\), "\n", 
    \(\(rkx\  = \ \(\(xK /. \[Delta] \[Rule] f\[Delta]\) /. \[Psi] \[Rule] 
              f\[Psi]i\) /. pa;\)\), "\n", 
    \(\(rky\  = \ \(\(yK /. \[Delta] \[Rule] f\[Delta]\) /. \[Psi] \[Rule] 
              f\[Psi]i\) /. pa;\)\), "\n", 
    \(\(lmax\  = \ Max[a, b, c, d] /. pa;\)\), "\n", 
    \(\(Plo0 = 
        Plot[0, {i, 0, 1}, 
          PlotRange \[Rule] {{\(-100\), 300}, {\(-150\), 200}}, 
          Frame \[Rule] True, AspectRatio \[Rule] Automatic, 
          PlotLabel \[Rule] "\<Coupling Path par set 2)\>"];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{108, 94.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001/0000GR000`400?l00000o`00003oK?ooool0
06cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?oo
ool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00
K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/oooo
o`00K?ooool006cooooo000/oooooaCo000000?oooooo`000?l000000_l0000Wooooo`00:oooool0
0ol0003oooooo`00000Co`000005ooooool0003o0000ooooool000009_ooool002Gooooo1Ol00004
oooooa?o000000Goooooo`000?l0003oooooo`00000Vooooo`00;_oooolCo`000005ooooool0003o
0000ooooool000009_ooool002_ooooo1_l000000ooooooo0000o`000004o`000003ooooool0003o
000000Ko000000Goooooo`000?l0003oooooo`00000Vooooo`00:oooool00ol0003oooooo`000003
o`000003ooooool0003o000000Co000000?oooooo`000?l000001_l000001Ooooooo0000o`000?oo
oooo000002Kooooo000[oooooaGo000000?oooooo`000?l000000_l0000Wooooo`00K?ooool001_o
oooo0ol00004ooooo`;o00001?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo01?o0000;Oooool001Co
oooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`Co000000?oooooo`000?oo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo000Looooo`04o`00
0?ooooooooooooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`006_ooool5o`0000;o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`006oooool2o`0000Cooooo00Co0000
oooooooooooo00000_ooool4o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0[ooooo`007?ooool01?l0003oooooooooooooool4o`0000?ooooo1?l0
00000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:ooo
ool0023ooooo1?l00003ooooo`Co000000?oooooo`000?l000004Ol0000]ooooo`008?ooool5o`00
00;ooooo1?l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:oooool001_ooooo0ol00004ooooo`?o00000_ooool4o`000003ooooool0003ooooo00?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`007?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00004
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool001_ooooo0ol00002oooo
o`Go00000_ooool4o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0[ooooo`007?ooool01?l0003oooooooooooooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0:oooool001[ooooo1Ol000000ooooooo0000o`000003o`0000;ooooo1?l000000ooo
oooo0000ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool001_o
oooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool0
01cooooo00Co0000oooooooooooooooo1Ol00002ooooo`Co000000?oooooo`000?ooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo000Kooooo`?o00000_ooool2o`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000Bo`0002gooooo000Joooo
o`06o`000?oooooo0000ooooool0003ooooo1Ol00002ooooo`Co0000@Oooool000;o00005_ooool3
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo01Cooooo0ol0000Xooooo`0000?o0000ooooooooool06?ooool3o`0000Cooooo0_l0
0004ooooo`;o00006?ooool00ol0003oooooooooo`0Wooooo`000ol00002ooooo`Go000000?ooooo
o`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l0
0007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l0
00001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00003ooooo`0000Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00000_oo
ool00004o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003oooooooooo`09
ooooo`?o00000_ooool5o`0000;ooooo00?o0000ooooooooool00oooool00004o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?o
oooo0003o`0000Cooooo00Co0000oooooooooooooooo0ol00003ooooo`Co00000oooool5o`0000Oo
oooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002?ooool4o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo0ol00002oooo
o`Co00000oooool000Oooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`03oooo
o`001Oooool3o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000oooooooo
ool00_ooool2o`0002oooooo00?o0000ooooooooool00oooool006cooooo001/ooooo`00K?ooool0
06cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?oo
ool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00
K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/oooo
o`00K?ooool00001\
\>"],
  ImageRangeCache->{{{0, 107}, {93.5, 0}} -> {-1118.62, -1005.7, 22.778, \
22.778}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Do[
  PloMecha1 = Graphics[{
        Circle  [{rA0x,rA0y},a/.pa],

        Circle  [{rA0x,rA0y},lmax/100],
        Circle  [{rax,ray},lmax/100],
        Circle  [{rbx,rby},lmax/100],
        Circle  [{rkx,rky},lmax/100],
        Circle  [{rB0x,rB0y},lmax/100],
        
\t\tLine  [{{rA0x,rA0y}, {rB0x,rB0y}}],
\t\tLine  [{{rA0x,rA0y}, {rax,ray}}],
\t\tLine  [{{rB0x,rB0y}, {rbx,rby}}],
\t\tLine  [{{rax,ray}, {rbx,rby}, {rkx,rky}, {rax,ray}}],

        Text  [A0,{rA0x+lmax/30, rA0y-lmax/30}], 
        Text  [A ,{rax+lmax/30, ray+lmax/30}], 
        Text  [B ,{rbx+lmax/30, rby+lmax/30}], 
        Text  [K ,{rkx+lmax/30, rky+lmax/30}], 
        Text  [B0,{rB0x+lmax/30,rB0y-lmax/30}]}]; 
   Show[Plo0, plo3, PloMecha1];
 ,{\[CurlyPhi],0, 2 Pi, Pi/6}];  \
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.41151 .36049 .00323 0 365.73 arc
s
newpath
.24334 .0853 .00323 0 365.73 arc
s
newpath
.47929 .47142 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.41151 .36049 L
s
.36574 .19678 m
.24334 .0853 L
s
.41151 .36049 m
.24334 .0853 L
.47929 .47142 L
.41151 .36049 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.42226 .37124 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.25409 .09605 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.49004 .48217 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>_oo
ool2o`000;cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>Oooool3
o`000;cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>Oooool4o`00
0;_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>_ooool2o`000003
ooooool0003ooooo0;Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>_ooool5o`000;Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000kooooo`?o00000_oo
ool00ol0003oooooooooo`2eooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>_ooool2
o`000005ooooool0003oooooooooool00000]oooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0jooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`2d
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Wooooo1?l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool01oooool000Oo
oooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Oooooo0005o`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
0_l0000looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`2^ooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[oooool00ol0003o
ooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo
00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l0002]ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2Xooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Z?ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0YOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Tooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooo`000003o`0000Cooooo0_l0002Hooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo09Kooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool3o`0000?ooooo00Co0000oooo
oooooooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool4o`0000;ooooo00Co0000oooo
oooooooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool01?l0003oooooo`000?l00002
ooooo`04o`000?ooooooooooo`0009Sooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool5o`0000?ooooo0_l0002H
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0W?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09go
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0WOooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000=
ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07
ooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo0006ooooo`Go00001Oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Kooooo`?o00002Ooo
ool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo09gooooo00?o0000ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`05o`000?oo
ooooooooooooool00000Woooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Fooooo`05o`000?ooooooooooooooool00000Woooool00ol0003oooooooooo`07ooooo`00
3?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooo`00002Pooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool06?ooool2o`000:3ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`;o0000X?ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`2Mooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Iooooo`;o0000Woooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01Wooooo0_l0002Oooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003oooooo`00
002Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooo`00002Nooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0002M
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Ioooo
o`05o`000?ooooooooooooooool00000Voooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000009cooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo09Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Uooo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo09Kooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2Fooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Ko
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0UOooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04oooool<o`0000Cooooo00?o0000
ooooooooool0U?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00kooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`03o`000?oooooooooo09?ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo00cooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo1?l0002Dooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`0009?ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool3o`0009;ooooo00?o0000ooooooooool01ooo
ool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool2
o`0000oooooo00?o0000ooooooooool02Oooool3o`000004ooooool0003o0000o`0008kooooo00?o
0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00Kooooo0_l0000Aooooo`03o`000?oooooooooo00Wooooo1_l0
002?ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`000004o`0008oooooo00?o0000ooooooooool01ooo
ool001?ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo000Cooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01oooool01ol0003ooooooooooooooooo0000ooooool0
00000_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`;o
00000_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o0000
1Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l000001Ooooooo0000
oooooooooooo000008cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooo000008cooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0008_ooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`04o`000?ooooooooooo`0001Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0008Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0008[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool01?l0003ooooooooo
ool00029ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooool000006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooool00000ROooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`04o`000?ooooooooooo`0008Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool2o`0001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooo000008Sooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`;o00006Oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooool00000Qoooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Eooooo`;o000000Goooooo`00
0?l0003o0000ooooo`03o`0001;ooooo0_l00028ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo0_l0000Eooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool0000Booooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool2o`0001Gooooo1Ol000000ooooooo0000o`000002
ooooo`03o`000?oooooooooo013ooooo0_l00027ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo0_l0000Fooooo`05o`000?oooooo0000o`000?ooool00_l00002
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00005_ooool00ol0003oooooo`000002o`00
0005ooooool0003oooooooooool000004oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Gooooo`Co000000Goooooo`00
0?ooooooooooo`00000Cooooo`;o0000Q_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo0_l0000Fooooo`Co00000oooool2o`0001Cooooo00?o0000ooooool00000Q?ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000cooooo`03o`000?oooooo000008Go
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0003?ooooo
00Co0000oooooooooooo0000Q?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`;o0000<oooool01?l0003oooooooooool00024ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000booooo`03o`000?oooooooooo00;ooooo
0_l00022ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0
000booooo`03o`000?oooooooooo00;ooooo0ol00021ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool2o`0001Kooooo<ol0001aooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooo`00000?ooooo`Ko00007?ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000cooooo0ol0001_ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooool000003Oooool2o`0002;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`00000<ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool2o`00017ooooo0_l0001]ooooo`03
o`000?oooooooooo00Oooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
>oooool01?l0003oooooooooool00009ooooo`;o00009?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo0000017ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`00
3?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0000Kooooo0ol0000Uooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooo00004?ooool2o`0006cooooo00?o0000ooooooooool01ooo
ool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`05ooooo`?o000000?oooooo`000?l000004?ooool00ol0003oooooooooo`1Xooooo`?o0000
2Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`03ooooo`;o0000:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0_l0000Wooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool2o`0002;o
oooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`00023ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00007Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01So
oooo0_l0000Vooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooool0000:ooooo`;o00005_ooool2o`0002Oo
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`04o`000?ooooooooooo`0000cooooo0_l0000Aooooo`?o0000:Oooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00Co0000oooooooooooo00003_ooool5o`0000[ooooo0_l0000/ooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`04o`000?ooooooooooo`0001?o
oooo2_l0000]ooooo`03o`000?oooooooooo06_ooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`04o`000?ooooooooooo`0004[ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0004Wo
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`04o`000?ooooooooooo`0004Wooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0004So
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`04o`000?ooooooooooo`0004Sooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00Co0000oooooooooooo0000Aoooool00ol0003o
ooooooooo`1^ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003ooooo
ooooool00017ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooool00016ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01Ol0003ooooo
oooooooooooo000004Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool00000A?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`1booooo`;o00002Oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1doooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo07Gooooo00?o0000oooooooo
ool01oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0_l0001hooooo`03o`00
0?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03Cooooo0_l0001kooooo`03o`000?oooooooooo00Oooooo0008ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`;o0000??ooool00ol0003oooooooooo`07ooooo`;o0000<oooool00ol0003oooooooooo`1i
ooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0O?ooool00ol0003ooooooooo
o`07ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0/ooooo`;o0000Ooooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Wooooo0_l00021ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0=ooooo`;o00009Oooool2o`0008Cooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00oooooo0_l0000Qooooo`;o
0000QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
4Oooool3o`0001_ooooo0ol00028ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool05?ooool3o`0001Cooooo1?l0002;ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05oooool6
o`0000[ooooo1?l0002?ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool07Oooool:o`0009?ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Ooo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001ooo
ool3o`0000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`2hooooo`?o00002Oooool000Sooooo00Co
0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o0000
0oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`04o`00
0?ooooooooooooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Kooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Coooooo?l00009
ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`3oooooo`Sooooo0006ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo2_ooool000Kooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo0000ooooool:ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o0000ooooool;oooo
o`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000=?ooool00ol0003oooooooooo`12ooooo`00
Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2o`0000?ooooo0ol00004ooooo`;o000000?o
ooooo`000?ooool00ol00002ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`00
0?l0003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`?o00001?ooool4o`0000?ooooo
0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00009ooooo`Co
00000oooool3o`0000Cooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`10ooooo`00
DOooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`05o`000?ooooooooooooooool000003_ooool00ol0003oooooo`000006ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`10ooooo`00D?oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003o
ooooooooo`09ooooo`?o00000_ooool5o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo0ol00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooooooool2o`0000Wooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`00
0?oooooooooo00Cooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`04
o`000?ooooooooooooooo`?o00000oooool4o`0000?ooooo1Ol00007ooooo`04o`000?oooooooooo
o`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Sooooo1?l00003ooooo`;o00000oooool2
o`000003ooooool0003o000000Sooooo1?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo047ooooo001Aooooo`04o`000?oooooo
ooooo`0001Gooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`12ooooo`00D_ooool3o`0001?ooooo
0ol00005ooooo`03o`000?oooooooooo01?ooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo
0_l0000_ooooo`03o`000?oooooooooo00Wooooo0ol00018ooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.44744 .4004 .00323 0 365.73 arc
s
newpath
.18323 .21547 .00323 0 365.73 arc
s
newpath
.55395 .47494 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.44744 .4004 L
s
.36574 .19678 m
.18323 .21547 L
s
.44744 .4004 m
.18323 .21547 L
.55395 .47494 L
.44744 .4004 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.45819 .41115 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.19398 .22622 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.5647 .48569 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool05oooool4o`0000Cooooo0_l0002Hooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0002Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool3o`0000?ooooo00Co0000oooooooo
oooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Sooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002H
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool05_ooool6o`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool03Oooool9o`000003ooooool0003o0000
00?o00000oooool2o`0009Sooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Cooooo2Ol0000=ooooo`03o`000?oooooooooo09gooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>Oooool9o`0001Kooooo00?o0000ooooooooool0
WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Zooooo`;o00001?oo
ool9o`0000;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02[ooooo1_l0000;ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0[ooooo`04o`000?oooooo0000o`0000cooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;?ooool00ol0
003oooooooooo`02o`0000_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Loooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0:oooool3o`0000;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09gooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo
00000oooool2o`0000Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03
o`000?oooooooooo00Oooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
:_ooool4o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo09gooooo00?o0000ooooooooool01oooool000cooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0=Oooool2o`0000Co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oo
oooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo0_l0000hooooo`05o`000?ooooooooooooooool000007?ooool00ol0003oooooooooo`2Koooo
o`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03Sooooo0_l000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo
09gooooo00?o0000ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0>_ooool2o`0001cooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0>oooool2o`0001_ooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`07ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03_o
oooo0ol0000Iooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo09ko
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003ooooo
ooooooooool2o`0001Kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo09gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Cooooo0_l0000Cooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo0_l0000@ooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`08ooooo`;o00003oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`03o`000?oooooooooo09gooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03_ooool2o`0000Wooooo00?o0000oooo
ooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
4Oooool2o`0000Kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01;ooooo0_l00005ooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Mooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Eooooo`;o00000_ooool00ol0
003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool05oooool00ol0003oooooo`00002Pooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool2o`000:3ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Iooooo`;o0000Woooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo01?ooooo3?l0002Kooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03_ooool5o`0000Kooooo00Ko0000oooo
ooooooooooooo`000?ooool2o`0009Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo0_l00000
1?oooooo0000o`000?l0002Eooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2
o`0000?ooooo0_l0002Dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo
00Oooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00So
oooo0_l0000?ooooo`03o`000?oooooooooo00Kooooo0_l00003ooooo`03o`000?oooooooooo093o
oooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00Kooooo0_l0000Aooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooooooo0_l0002@ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool2o`0000?ooooo00?o0000oooo
ooooool0SOooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004oooo
ooco00002Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<oooo
o`;o00000_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool2o`000003ooooool0003ooooo
08cooooo00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013o
oooo00?o0000ooooool00000S?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`0Aooooo`;o
0000S?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`05o`00
0?ooooooooooooooool000005_ooool00ol0003oooooooooo`0Cooooo`;o0000R_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00Co0000oooooooooooo00005oooool00ol0003o
ooooooooo`0Cooooo`?o0000R?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00Co0000oooooooooooo00005oooool00ol0003oooooooooo`0Aooooo`Wo0000QOooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0001Oo
oooo00?o0000ooooooooool03oooool2o`0000?ooooo0_l000000ooooooo0000o`000026ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool00000
6?ooool00ol0003oooooooooo`0=ooooo`;o00001Oooool6o`0008Gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`00000Hooooo`03o`000?oo
oooooooo00_ooooo0_l00008ooooo`?o00000_ooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Iooooo`03o`000?oooooo
oooo00Wooooo0_l0000:ooooo`?o00000oooool2o`0008;ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`;o00006Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1nooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool2o`0001Gooooo0_l000001?oooooo0000o`000?l00002oooo
o`;o00000oooool2o`0000gooooo0_l00007ooooo`;o0000Ooooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`;o00005Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00ol0000@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0O?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o
00005Oooool5o`0000;ooooo00Co0000ooooool0003o00004oooool00ol0003oooooooooo`07oooo
o`;o0000O?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o
00005_ooool01?l0003oooooo`000?l00002ooooo`;o000000?oooooo`000?ooool04_ooool00ol0
003oooooooooo`08ooooo`;o0000Noooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`;o00005_ooool00ol0003oooooo`000004o`0000;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0001Oooooo1?l000001Ooooooo0000
oooooooooooo000001?ooooo00?o0000ooooooooool02oooool2o`0007Sooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000looooo`;o00005_ooool4o`0000?ooooo0_l0000Dooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0M?ooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo0_l0000cooooo`03o`000?oooooooooo00kooooo0_l0001eooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000cooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`;o0000<oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0003;o
oooo00?o0000ooooooooool04oooool2o`00077ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool2o`0003;ooooo00?o0000ooooooooool05Oooool2o`0006oooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`;o00005_oooolco`000003ooooool0
003o000006kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
000000oooooo1_l0000Looooo`03o`000?oooooooooo01Cooooo1?l000000ooooooo0000o`00001[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ool000003Oooool2o`0002;ooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool0001/
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ool000003?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Oooooo0ol0001]oooo
o`03o`000?oooooooooo00Oooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0>oooool01?l0003oooooooooool00009ooooo`;o00009?ooool00ol0003oooooooooo`0Goooo
o`?o0000KOooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`04o`000?oooooo
ooooo`0000Kooooo0ol0000Uooooo`03o`000?oooooooooo01Sooooo00Co0000ooooool0003o0000
K?ooool00ol0003oooooooooo`07ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo0000J_ooool3o`00
00Wooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0kooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01Sooooo0ol000000ooooooo0000o`00001[ooooo`03o`000?oooooo
oooo00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`03ooooo`;o0000:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0_l0000Wooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool2
o`0002;ooooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`00023ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00007Oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo01Sooooo0_l0000Vooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000:ooooo`;o00005_ooool2
o`0002Oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0000cooooo0_l0000Aooooo`?o0000:Oooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00Co0000oooooooooooo00003_ooool5o`0000[ooooo0_l0000/ooooo`03o`000?oooooo
oooo06_ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`04o`000?oooooooooo
o`0001?ooooo2_l0000]ooooo`03o`000?oooooooooo06_ooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0004[ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0004Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0004Wooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0004Sooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0004Sooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00Co0000oooooooooooo0000Aoooool0
0ol0003oooooooooo`1^ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool01?l0
003oooooooooool00017ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00016ooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01Ol0
003ooooooooooooooooo000004Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool00000A?ooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1booooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo07Gooooo00?o0000
ooooooooool01oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0_l0001hoooo
o`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03Cooooo0_l0001kooooo`03o`000?oooooooooo00Oooooo0008
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`07ooooo`;o0000<oooool00ol0003ooooo
ooooo`1iooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0O?ooool00ol0003o
ooooooooo`07ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0/ooooo`;o0000Ooooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0_l00021ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`;o00009Oooool2o`0008Cooooo00?o
0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00oooooo0_l0000Q
ooooo`;o0000QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool04Oooool3o`0001_ooooo0ol00028ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool05?ooool3o`0001Cooooo1?l0002;ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
5oooool6o`0000[ooooo1?l0002?ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool07Oooool:o`0009?ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooooooo
ool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`001oooool3o`0000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000So
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`2hooooo`?o00002Oooool000So
oooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007oooo
o`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008oooo
o`04o`000?ooooooooooooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool000Kooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
o?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo2_ooool0
00Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000ooooool:ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o0000oooo
ool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000=?ooool00ol0003oooooooooo`12
ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2o`0000?ooooo0ol00004ooooo`;o
000000?oooooo`000?ooool00ol00002ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo
0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`?o00001?ooool4o`00
00?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00009
ooooo`Co00000oooool3o`0000Cooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`10
ooooo`00DOooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooo`000006ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`10oooo
o`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00000oooool0
0ol0003oooooooooo`09ooooo`?o00000_ooool5o`0000;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo0ol00002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooooooool2o`00
00Wooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo001@oooo
o`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00004
ooooo`04o`000?ooooooooooooooo`?o00000oooool4o`0000?ooooo1Ol00007ooooo`04o`000?oo
ooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Sooooo1?l00003ooooo`;o0000
0oooool2o`000003ooooool0003o000000Sooooo1?l00002ooooo`?o00000_ooool4o`0000Sooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo047ooooo001Aooooo`04o`00
0?ooooooooooo`0001Gooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`12ooooo`00D_ooool3o`00
01?ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo1?l00009ooooo`03o`000?oooooooooo
00;ooooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo0ol00018ooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.45861 .45293 .00323 0 365.73 arc
s
newpath
.17912 .29202 .00323 0 365.73 arc
s
newpath
.57127 .51779 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.45861 .45293 L
s
.36574 .19678 m
.17912 .29202 L
s
.45861 .45293 m
.17912 .29202 L
.57127 .51779 L
.45861 .45293 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.46936 .46368 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.18987 .30277 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.58202 .52854 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool05oooool4o`0000Cooooo0_l0002Hooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0002Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool3o`0000?ooooo00Co0000oooooooo
oooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Sooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002H
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool06?ooool4o`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool05oooool5o`0000?ooooo0_l0002Hoooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Eooooo`;o
00000oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool04oooool2o`0000Gooooo00?o0000ooooooooool0
WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo017ooooo0_l00007ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`;o00002Oooool0
0ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
09gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00co
oooo0_l0000<ooooo`03o`000?oooooooooo09cooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00[ooooo0_l0000>ooooo`03o`000?oooooooooo09gooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`08ooooo`;o00004?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool2o`0001;ooooo00?o0000
ooooooooool0WOooool00ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01?ooool2o`0001Cooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00;ooooo0_l0000Fooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool0
00Kooooo1Ol00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2
o`0003cooooo00?o0000ooooooooool00_l0000Hooooo`03o`000?oooooooooo09_ooooo0ol00009
ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0>oooool3o`0001[ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07
ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0j
ooooo`;o00007?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000<oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0h
ooooo`;o000000?oooooo`000?ooool06oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo
oooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0=_ooool2o`00
00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0<oooool2o`0000Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000<_ooool2o`0000Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Mooooo`;o00002Oooool001_ooooo00?o0000
ooooooooool0;oooool2o`0000[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo0_l0000<oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0Yooooo`Co00003_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
:Oooool3o`0000oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Wooooo1Ol0000=ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool2
o`0002_ooooo00?o0000ooooooooool00_l0000<ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0WOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02[ooooo00Go0000oooo
oooooooo0000ooooo`02o`0000[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02[ooooo0ol00004oooo
o`;o00002?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00005oooo
o`;o00001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00006oooo
o`;o00001Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0:Oooool4o`0000Wooooo0_l00003ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003Wooooo0_l000000ooooooo0000ooooo`0Jooooo`03o`000?oooooooooo09gooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0jooooo`;o00006oooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000J
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool01?l0003oooooo`000?l0000Hooooo`03o`000?oooooooooo09kooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooooooool2
o`0001Kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo0ol0000>ooooo`co0000Voooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Co
oooo0_l00008ooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`;o0000VOooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01_ooool2o`0000Cooooo
0_l0000;ooooo`03o`000?oooooooooo00Gooooo0ol0002Eooooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`000?ooool03?oo
ool00ol0003oooooooooo`08ooooo`;o0000U?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo0ol0000=ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`07ooooo`005?ooool2o`00
00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`;o000000?oooooo`00
0?l000003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo093ooooo00?o0000oooo
ooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00Kooooo0_l00005ooooo`;o00002_ooool00ol0003oooooooooo`0<oooo
o`;o0000T?ooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`;o00002?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08gooooo00?o0000oooo
ooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo0_l00005ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0Roooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>oooo
o`;o00000oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08_ooooo00?o0000oooo
ooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0@ooooo`Co00005?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000oooooooooooo
ooooo`00000Eooooo`?o00004oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o
00004oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo00;o00004_ooool00ol0003o
ooooooooo`27ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003ooooo
ooooool0000Gooooo`04o`000?ooooooooooooooo`?o00004?ooool00ol0003oooooooooo`28oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooo
oooo00005oooool00ol0003oooooooooo`03ooooo`?o00003oooool00ol0003oooooooooo`27oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool0
00006?ooool00ol0003oooooooooo`05ooooo`;o00003_ooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool00000
6?ooool00ol0003oooooooooo`06ooooo`?o00003Oooool00ol0003oooooooooo`26ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Iooooo`03o`000?oo
oooooooo00Sooooo0ol0000;ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`;o00006Oooool00ol0003oooooooooo`0:ooooo`?o00002Oooool0
0ol0003oooooooooo`25ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool2o`00
01Gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002Oooool2o`0000Sooooo00?o0000
ooooooooool0Q_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`;o00005Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00002Ooo
ool3o`0000Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`;o00005Oooool5o`0000;ooooo00Co0000oooooooooooo00002ooo
ool3o`0000Gooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`;o00005_ooool01?l0003oooooo`000?l00002ooooo`04o`000?oo
ooooooooo`0000gooooo0ol00003ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool2o`0001Kooooo00Co0000ooooool0003o0000
0_ooool01?l0003oooooooooool0000>ooooo`?o00000_ooool00ol0003oooooooooo`25ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Goooooa3o0000
2Oooool4o`0008Oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`;o00005_oo
ool4o`0000?ooooo0_l00008ooooo`ko0000QOooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo03_ooooo0_l0000booooo`Ko0000Poooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`;o0000<_ooool2o`000004ooooool0003o0000o`0008?ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0003;ooooo2?l00021oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000booooo`;o
000000?oooooo`000?ooool00_ooool2o`00083ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool2o`0003;ooooo0_l000000ooooooo0000ooooo`04ooooo`;o0000
O_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo0_l0000Foooooc?o0000LOoo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000003oooool6
o`0001cooooo0ol00009ooooo`;o00002Oooool3o`0006oooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`00000=ooooo`;o00008_ooool00ol0
003oooooooooo`0;ooooo`;o00002Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000003?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00gooooo0ol00008ooooo`;o0000KOooool00ol0003o
ooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo
00Co0000oooooooooooo00002Oooool2o`0002Cooooo00?o0000ooooooooool03oooool2o`0000So
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0000Kooooo0ol0000Uooooo`03o`000?oooooooooo01;ooooo0_l00006
ooooo`;o0000K?ooool00ol0003oooooooooo`07ooooo`004?ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Cooooo0_l00005ooooo`03o`000?oo
oooooooo06Sooooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Fooooo`;o00001?ooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000Wooooo`03o`000?oooooooooo01Wooooo0_l00002ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool2o`0002So
oooo00?o0000ooooooooool06oooool3o`0006cooooo00?o0000ooooooooool01oooool000cooooo
1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo
0_l0000Wooooo`03o`000?oooooooooo01gooooo1?l0001Zooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000Uooooo`03o`000?oooooooooo01oooooo1?l000000ooooooo0000o`00001Vooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0002?ooooo0_l0000Rooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
I?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooooooool2o`00023ooooo00?o0000ooooooooool08_ooool01Ol0003ooooo
o`000?oooooo000006Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0000Mooooo`03o`000?oooooooooo02?o
oooo00Co0000ooooool0003o0000JOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool06?ooool2o`00
02Kooooo00Go0000ooooool0003oooooo`00001Xooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00002_ooool2o`0001Kooooo0_l0000W
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000cooooo0_l0
000Aooooo`?o0000:Oooool00ol0003oooooo`000002o`000003ooooool0003o000006Kooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0
000>ooooo`Go00002_ooool2o`0002cooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0003cooooo00Co0000oooooooooooo00004oooool:o`0002gooooo00?o
0000ooooooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000
oooooooooooo0000B_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000BOooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000
oooooooooooo0000BOooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000B?ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000
oooooooooooo0000B?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool01?l0003oooooooooool00017ooooo`03o`000?oooooooooo06kooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0004Oooooo00?o
0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`04o`000?ooooooooooo`0004Kooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool00000AOoo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo07;ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`07ooooo`001oooool3
o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0>Oooool2o`0007Sooooo00?o0000ooooooooool01oooool0
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
=?ooool2o`0007_ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0_l0000looooo`03
o`000?oooooooooo00Oooooo0_l0000cooooo`03o`000?oooooooooo07Wooooo0ol00009ooooo`00
2?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Oooooo0007ooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02cooooo0_l0001o
ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0:Oooool2o`00087ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0POooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00gooooo0_l0000Uooooo`;o0000Q?ooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool03oooool2o`00027ooooo0_l00025ooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Aooooo`?o00006oooool3
o`0008Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Dooooo`?o00005?ooool4o`0008_ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`Ko00002_ooool4o`0008oo
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Mooooo`[o0000Toooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00000oooool3o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`002?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000l
ooooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool01?l0003oooooooooooooool4
o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00003ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co0000oooooooooooooooo1Ol0
0003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooooooo
ool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001_ooool5
o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo0009ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
0?oooooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooo`[o
oooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo001Rooooo`?o00005_oo
ool3o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo001Sooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo0000ooooo`03o`00
00;ooooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00_l00000
0ooooooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00007
ooooo`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo1?l00003ooooo`?o00001?oo
ool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo043ooooo001Aooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo0ol0
0002ooooo`Go00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00002ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool01?ooool3
o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo00Co0000oooooooooooooooo
0ol00003ooooo`Co00000oooool5o`0000Oooooo00Co0000oooooooooooo00000_ooool2o`0000?o
oooo1?l00003ooooo`?o00002?ooool4o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00002?ooool4o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0@Oooool0057ooooo00Co0000oooooooooooo00005Oooool00ol0
003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo04;ooooo001Booooo`?o00004oooool3o`0000Gooooo00?o0000
ooooooooool04oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0002oooooo00?o0000
ooooooooool02Oooool3o`0004Sooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.44201 .50401 .00323 0 365.73 arc
s
newpath
.18163 .31372 .00323 0 365.73 arc
s
newpath
.54697 .58071 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.44201 .50401 L
s
.36574 .19678 m
.18163 .31372 L
s
.44201 .50401 m
.18163 .31372 L
.54697 .58071 L
.44201 .50401 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.45276 .51476 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.19238 .32447 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.55772 .59146 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool05oooool4o`0000Cooooo0_l0002Hooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0002Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool3o`0000?ooooo00Co0000oooooooo
oooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Sooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002H
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool06?ooool4o`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool05oooool5o`0000?ooooo0_l0002Hoooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`;o
00000_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool05?ooool2o`0000Cooooo00?o0000ooooooooool0
WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Mooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04Oooool2
o`0000Oooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`0>ooooo`;o00002_ooool00ol0003oooooooooo`2Looooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`03o`000?oooooooooo09gooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09
ooooo`;o00003oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000=oooo
o`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07oooo
o`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Kooooo0_l0000Booooo`03o`000?oooooo
oooo09gooooo00?o0000ooooooooool01oooool000Kooooo1Ol00005ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo09_ooooo0ol00009ooooo`004?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`03ooooo`;o00005Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo
oooo00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03_ooooo00Co0000oooooooooooooooo0_l0000Gooooo`03o`000?oooooooooo09gooooo00?o
0000ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00006Oooool00ol0003ooooo
ooooo`2Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o
0000ooooooooool0>oooool3o`0001Wooooo00?o0000ooooooooool0W_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0ioooo
o`?o00006oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o
0000>?ooool2o`0000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Mooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0dooooo`;o00001Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0aooooo`;o00002?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002oooooo
0_l0000;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0WOooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo02cooooo0_l0000=ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Wooooo0ol0000?oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0Zooooo`Co00003Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
:oooool01?l0003oooooo`000?l0000<ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0W_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002cooooo00?o0000ooooooooool0
0_l0000;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0WOooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo02_ooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo00000_ooool2o`0000Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0Zooooo`Co00001_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0eooooo`;o00001?ooool00ol0003oooooooooo`0Coooo
o`co0000Voooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0gooooo`05
o`000?ooooooooooooooool000004?ooool5o`0000Kooooo00?o0000ooooooooool00oooool2o`00
09Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000iooooo`04o`000?ooooooooooo`00
00kooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo0ol0002Eooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>Oooool3o`0000gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`08ooooo`;o0000U?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool01oooool001Cooooo0_l0
0005ooooo`03o`000?oooooooooo03_ooooo0ol00008ooooo`;o00003oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool01oooool001?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000Gooooo
0_l0000Aooooo`03o`000?oooooooooo00cooooo0_l0002@ooooo`03o`000?oooooooooo00Oooooo
000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo08gooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo
00001?ooooolo`0000Wooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000001?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo00Oooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l0000@ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool000001oooool2o`0000go
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000??ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`27ooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00003?ooool2o`0000Wo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000003oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Qoooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Kooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0001;ooooo0_l00005
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo0_l0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`25ooooo`;o00002Oooool001_ooooo00?o0000oooooooo
ool0>oooool2o`0001Gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00004oooool00ol0
003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo0_l0000Eooooo`05o`000?oooooo0000ooooool000000_ooool01?l0003oooooooooool0000B
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool2o`0001Gooooo1Ol00002ooooo`04o`000?ooooooooooo`0001?ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`;o00005_ooool00ol0003oooooo`000002o`000005ooooool0003oooooooooool000004oooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo0_l0000Fooooo`05o`000?oooooo0000o`000?ooool00_l00002ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`;o00005oooool4o`000005ooooool0003oooooooooool000004oooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool2o`00
01Kooooo1?l000000ooooooo0000ooooo`02o`0001Cooooo00?o0000ooooooooool0Q?ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Looooo`;o000000?oooooo`000?oo
ool04_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo0_l0000Nooooo`Co00004Oooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Pooooo`?o00004?oo
ool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo0_l0000Qooooo`?o00003_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Sooooo`?o00003?ooool00ol0
003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool2o`0001Ko
oooo<ol0001aooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
o`00000?ooooo`Ko00004?ooool2o`0000[ooooo00?o0000ooooooooool05?ooool3o`0006oooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`00
000=ooooo`;o00005oooool3o`0000Sooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`1]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooool000003?ooool00ol0003oooooooooo`0Iooooo`;o00001_ooool00ol0003oooooooooo`0H
ooooo`;o0000KOooool00ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00002Oooool2o`0001kooooo0_l00004
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07
ooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000Kooooo0ol0000Qooooo`;o0000
0_ooool00ol0003oooooooooo`0Jooooo`;o0000K?ooool00ol0003oooooooooo`07ooooo`004?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Tooooo`?o00007Oooool00ol0003o
ooooooooo`1Xooooo`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo02Gooooo0ol0000Mooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool01oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Oooooo0_l00000
1?oooooo0000o`000?l0000Jooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01ooo
ool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool00oooool2o`0002Sooooo00Go0000oooooooooooooooo
o`00000Kooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool000cooooo1Ol0
0003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0_l0
000Wooooo`So00006Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
000Uooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool2o`0000?ooooo00?o0000ooooool0
00001?ooool2o`0001Kooooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`00023o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00005Oooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00Go0000ooooooooooooooooo`000006ooooo`;o00007Oooool00ol0003oooooooooo`04ooooo`;o
00002?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo01Sooooo0_l0000Booooo`;o00004_ooool00ol0003oooooooooo`1Zooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo
00002_ooool2o`0001Kooooo0_l0000Fooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`00
0?ooooooooooo`0000cooooo0_l0000Aooooo`?o00006Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool01?l0003oooooooooool0000>ooooo`Go00002_ooool2o`0001gooooo0_l0000=ooooo`03
o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`04o`00
0?ooooooooooo`0001?ooooo2_l0000Qooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo
0000?oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06cooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00010ooooo`;o
00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00Co0000oooooooooooo0000@_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool01?l0003oooooooooool00013ooooo`;o00000oooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo
0000AOooool01?l0003oooooooooool0001`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o
0000??ooool01?l0003oooooooooool00016ooooo`;o0000L?ooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000A_ooool3o`00073ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00016oooo
o`Co000000?oooooo`000?l00000K?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`05o`000?ooooooooooooooool00000AOooool00ol0003oooooo`000002oooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool01Ol0003ooooooooooooooooo000004Cooooo00Ko0000oooooooooooo0000ooooool0
001^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`10ooooo`04o`000?ooooooooooooooo`;o0000Kooo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000KOooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000KOooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`02ooooo`?o000000?oooooo`00
0?l00000K?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`1eooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0iooooo`;o0000
N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0dooooo`;o0000Noooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool01oooool2o`0003?ooooo00?o0000
ooooooooool0NOooool3o`0000Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07cooooo00?o
0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0;?ooool2o`0007oooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`;o0000POooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool2o`0002Gooooo0_l00024oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0?ooooo`;o
00008Oooool2o`0008Gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo017ooooo0ol0000Kooooo`?o0000R?ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Cooooo0ol0000Dooooo`Co0000Rooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01Oooooo1_l0000:ooooo`Co0000Soooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo2_l0002Cooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oo
oooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool000Oooooo0ol00003ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`002?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`0000Wooooo
0008ooooo`04o`000?ooooooooooooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
1oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
2?ooool01?l0003oooooooooooooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0006ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooooco00002Oooool000Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool0ooooool8ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooo`[o
oooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`000?oooooo2_ooool000Oooooo0ol00004ooooo`;o00001?ooool2o`00
0?oooooo2oooool006;ooooo0ol0000Fooooo`?o00009_ooool3o`0003Cooooo00?o0000oooooooo
ool0@_ooool006?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0@Oooool005;ooooo0_l00003ooooo`?o00001?oo
ool2o`000003ooooool0003ooooo00?o00000_ooool5o`000003ooooool0003o000000?o000000Go
ooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o00001oooool3o`0000Cooooo
1?l00003ooooo`;o00000_ooool6o`0000Oooooo0ol00003ooooo`Co000000Coooooo`000?l0003o
00002Oooool4o`0000?ooooo0ol00004ooooo`;o00002?ooool5o`0000Cooooo00?o0000oooooooo
ool0@?ooool0057ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooool000001_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000?o
oooo00?o0000ooooooooool02Oooool3o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o0000
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo
0_l00009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`00
D?ooool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co
00001?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l00003ooooo`Go00001oooool01?l0
003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00008ooooo`Co00000oooool2
o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l00008
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`11ooooo`00DOooool0
1?l0003oooooooooool0000Eooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0@_ooool005;ooooo
0ol0000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`Co00002Oooool00ol0003ooooo
ooooo`02ooooo`;o0000;oooool00ol0003oooooooooo`09ooooo`?o0000B?ooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.4021 .53994 .00323 0 365.73 arc
s
newpath
.1805 .30563 .00323 0 365.73 arc
s
newpath
.49143 .63439 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.4021 .53994 L
s
.36574 .19678 m
.1805 .30563 L
s
.4021 .53994 m
.1805 .30563 L
.49143 .63439 L
.4021 .53994 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.41285 .55069 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.19125 .31638 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.50218 .64514 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool05oooool4o`0000Cooooo0_l0002Hooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0002Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool3o`0000?ooooo00Co0000oooooooo
oooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Sooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002H
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool06?ooool4o`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool05oooool5o`0000?ooooo0_l0002Hoooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`05
o`000?ooooooooooooooool00000Woooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`03o`000?oooooooooo09go
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Booooo`;o00001_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`;o00002Oooool00ol0003oooooooooo`2M
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0=oooo
o`;o00002oooool00ol0003oooooooooo`2Looooo`;o00002Oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00[ooooo0_l0000>ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`;o00004?oo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000=ooooo`?o00001?ooool2
o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`;o00004_ooool0
0ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo09gooooo00?o
0000ooooooooool01oooool000Kooooo1Ol00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool00oooool2o`0001Gooooo00?o
0000ooooooooool0Voooool3o`0000Wooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooooooo`;o0000
5oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo
00006Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`?o
00006_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go0000
0oooool2o`0000Gooooo00?o0000ooooooooool0>_ooool2o`0001_ooooo00?o0000ooooooooool0
W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0hooooo`;o000000?o
ooooo`000?ooool06_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000fooooo`;o00001?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09gooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0cooooo`;o00001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`;o00002Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0;_ooool2o`0000_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000/ooooo`;o00003_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo09gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Yooooo`?o
00003oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0:Oooool5o`0000gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:ooo
ool2o`000003ooooool0003ooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02_ooooo0ol0000=
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0002cooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo09gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00;o00002oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:_ooool4o`0000;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09ko
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0C
ooooo`co0000Voooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool5o`0000Kooooo00?o0000oooo
ooooool00oooool2o`0009Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000fooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool2o`0000_ooooo00?o0000oooooooo
ool01Oooool3o`0009Gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Sooooo0_l0002Dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03Oooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo00Oooooo
000Dooooo`;o00001Oooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`0000[ooooo
0_l0000?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooool000002?ooool2o`00017ooooo00?o0000ooooooooool03?ooool2o`00093ooooo
00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0jooooo`;o00002?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0SOooool00ol0003oooooooooo`07ooooo`004oooool01?l0003ooooooooo
ool00004ooooooco00002Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0kooooo`;o00001Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`07ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo0ol00003ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo
000Dooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02
o`0001Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000F
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00Ko0000oooooooooooo0000ooooool0000Eooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0Qoooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000001_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00002?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo0_l00009ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`25ooooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0>oooool2o`0000[ooooo00?o0000ooooooooool02?ooool2o`000004ooooool0
003o0000o`0000;ooooo0_l0000Cooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool2o`0000_ooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00004_ooool00ol0003o
ooooooooo`26ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
0_l0000<ooooo`03o`000?oooooooooo00Kooooo1Ol00002ooooo`04o`000?ooooooooooo`0001?o
oooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`;o00003?ooool2o`0000Sooooo00Co0000ooooool0003o00000_ooool01?l0003o
ooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool2o`0000gooooo0_l00007ooooo`04o`000?oooooo0000o`00
00;ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000>ooooo`;o00001oooool4o`00
0005ooooool0003oooooooooool000004oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool2o`0000oooooo0_l00005ooooo`Co00000oooool2o`00
01Cooooo00?o0000ooooooooool0Q?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo0_l0000@ooooo`;o00002?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Go
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`00017ooooo
0_l00007ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0QOooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00004_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0QOooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00004oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00005?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003cooooo0_l0000EooooocCo0000LOooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooool000003oooool7o`0000Kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Dooooo`?o0000Koooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000gooooo0_l00007ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooo`00000<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo0_l0001]ooooo`03o`000?oooooo
oooo00Oooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool01?l0
003oooooooooool00009ooooo`;o00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooo
oooo00Oooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00001_ooool3o`0000oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo
0_l0001/ooooo`03o`000?oooooooooo00Oooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool2o`0003cooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0J?ooool3o`0000Wooooo000@ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Gooooo0_l0
0003ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0_l0
000Gooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool5o`0000?ooooo0_l00005
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool2o`0001Sooooo0_l00002
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool0000Hooooo`;o000000?oooooo`000?ooool02?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006Oooool2
o`000003ooooool0003ooooo00Gooooo0_l0000Rooooo`03o`000?oooooooooo06Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo0_l0000Hooooo`?o00001Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01Ol0
003ooooooooooooooooo000000Kooooo0_l0000Gooooo`?o00000oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01Gooooo1Ol0000V
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool01?l0003oooooooooool0000:ooooo`;o00005_ooool2o`0002Oooooo00?o0000
ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0000cooooo0_l0000Aooooo`Go000000Coooooo`000?l0003o00008ooo
ool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00Co0000oooooooooooo00003_ooool5o`0000[ooooo0_l00003ooooo`05o`000?oo
oooo0000ooooool000009?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool01?l0003oooooooooool0000Cooooo`[o00001Oooool5o`0002?ooooo
00?o0000ooooooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co
0000oooooooooooo00008oooool01?l0003oooooo`000?l0000Sooooo`03o`000?oooooooooo06co
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003ooooo
ooooool0000Sooooo`05o`000?oooooo0000ooooool000008Oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooo
oooo00009?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0002?ooooo0_l00004ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0K_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0002Wooooo0_l0000Mooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`04o`000?ooooooooooo`0002[ooooo0_l0000Kooooo`03o`000?oooooo
oooo06kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0002_ooooo0_l0000Jooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000/ooooo`;o00006?ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00Go0000ooooooooooooooooo`00000/ooooo`;o00005oooool00ol0003oooooooooo`1`
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000oooo
ooooooooooooo`00000]ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
07;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07;o
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07?ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0MOooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo0_l00004oooo
o`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`08ooooo`;o0000N?ooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00oooool2o`0007_ooooo00?o
0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo0_l0000looooo`03o`000?oooooooooo00Oooooo
0_l0000_ooooo`05o`000?ooooooooooooooool00000Noooool3o`0000Wooooo0008ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0]oooo
o`?o0000O_ooool00ol0003oooooooooo`07ooooo`001oooool2o`0000Cooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0/ooooo`?o0000O_ooool00ol0003oooooooooo`07
ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o0000N_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0007_ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`;o00009Oooool2o`00
00Gooooo00?o0000ooooool00000O?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003co
oooo00?o0000ooooooooool03oooool2o`00027ooooo0_l00007ooooo`;o0000O?ooool2o`0000Wo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04Oooool3o`0001_ooooo
0ol00009ooooo`03o`000?oooooo000007cooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Dooooo`?o00005?ooool4o`0000cooooo00Co
0000oooooooooooo0000Noooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Oooooo1_l0000:ooooo`Co00003oooool3o`000003ooooool0
003o000007[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Mooooo`[o0000Toooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o0000
0oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`002?ooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool01?l0003ooooo
ooooooooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00003ooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co0000oooooooo
oooooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o
0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooooooo
ool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo0009
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo0?oooooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
003oooooo`[ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo001Roooo
o`?o00005_ooool3o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo001Sooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo0000
ooooo`03o`0000;ooooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?oo
ool00_l000000ooooooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;o
oooo1_l00007ooooo`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo1?l00003oooo
o`?o00001?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo043ooooo001Aooooo`06
o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`03o`000?oooooooooo
00Wooooo0ol00002ooooo`Go00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000
oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000oooooooo
ool01?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo00Co0000oooo
oooooooooooo0ol00003ooooo`Co00000oooool5o`0000Oooooo00Co0000oooooooooooo00000_oo
ool2o`0000?ooooo1?l00003ooooo`?o00002?ooool4o`0000?ooooo0_l00003ooooo`;o000000?o
ooooo`000?l000002?ooool4o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0@Oooool0057ooooo00Co0000oooooooooooo0000
5Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Booooo`?o00004oooool3o`0000Go
oooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0002oo
oooo00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.34957 .55111 .00323 0 365.73 arc
s
newpath
.17836 .27781 .00323 0 365.73 arc
s
newpath
.41859 .66128 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.34957 .55111 L
s
.36574 .19678 m
.17836 .27781 L
s
.34957 .55111 m
.17836 .27781 L
.41859 .66128 L
.34957 .55111 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.36032 .56186 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.18911 .28856 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.42934 .67203 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool05oooool4o`0000Cooooo0_l0002Hooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0002Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool3o`0000?ooooo00Co0000oooooooo
oooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Sooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002H
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool06?ooool4o`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool05_ooool6o`0000?ooooo0_l0002Hoooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Dooooo`;o
00001?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool04_ooool2o`0000Kooooo00?o0000ooooooooool0
WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00oooooo0ol00008ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`;o00002oooool0
0ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02oooool2o`0000gooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool02?ooool3o`0000oo
oooo00?o0000ooooooooool0W?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool01_ooool2o`0001;ooooo00?o0000ooooooooool0WOooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Cooooo0_l0
000Dooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool01?l0003oooooooooooooool3o`0001Kooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo03_ooooo00Co0000ooooool0003o00006Oooool00ol0003oooooooooo`2Mooooo`03o`000?oo
oooooooo00Oooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo0_l0000Kooooo`03o`000?oooooooooo09gooooo
00?o0000ooooooooool01oooool000Kooooo1Ol00005ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool2o`0003Wooooo1?l0000Looooo`03o`000?oooooooooo09_ooooo
0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=_ooool2o`0000?ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`2Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<Oooool3o`0000Oooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo
000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0;oooool2o`0000[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo02gooooo0_l0000<ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Zoooo
o`?o00003_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000Zooooo`;o00004?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo09gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Yooooo`Co0000
3_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000=ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0Zooooo`;o000000?oooooo`000?ooool03?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0:_ooool3o`0000kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02[ooooo00Co0000oooo
ool0003o00003Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000[ooooo`04o`000?oooooo0000o`0000gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`2Mooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0:Oooool5o`0000gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo09kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000aooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Mooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool<o`0009_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo1Ol00006ooooo`03
o`000?oooooooooo00?ooooo0_l0002Iooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0_l0000;ooooo`03o`00
0?oooooooooo00Gooooo0ol0002Eooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`08ooooo`;o0000U?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0=_ooool2o`00
00?ooooo00?o0000ooooooooool02?ooool2o`0000oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0000A
ooooo`03o`000?oooooooooo00cooooo0_l0002@ooooo`03o`000?oooooooooo00Oooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Coooooo?l0
0009ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooool000001_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03[ooooo0_l00005ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000D
ooooo`;o00001Oooool00ol0003oooooooooo`0jooooo`;o00001?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool000005_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool2o`0000;ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`;o000000?oooooo`000?ooool05_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo08Oooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`00
0?oooooo0000o`0001Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000ooooool0003o
00005oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooo`000?l0000Gooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`05o`000?oooooo0000ooooool000005_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool2o`0000;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`;o00000oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l00003
ooooo`;o00004?ooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000Cooooo`03o`000?oo
oooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2
o`0000Cooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00004_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo0_l00005ooooo`03o`000?oooooooooo00gooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool0QOooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00001Oooool00ol0003ooooooooo
o`0>ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00004oooool00ol0003o
ooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
0_l00006ooooo`03o`000?oooooooooo00gooooo00Co0000ooooool0003o00000_ooool01?l0003o
ooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool2o`0000Kooooo0_l0000?ooooo`Co000000Goooooo`000?oo
ooooooooo`00000Cooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`;o00001oooool00ol0003oooooooooo`0<ooooo`Co00000oooool2o`0001Co
oooo00?o0000ooooooooool0Q?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
0_l00008ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0
0008ooooo`;o00003oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0000Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0000[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Kooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0000[ooooo0_l0000=ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo0_l0000;ooooo`03o`000?oooooooooo00Sooooo<ol0001aooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`00000:ooooo`;o00000ooo
ool6o`0000;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Dooooo`?o0000Kooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
000000_ooooo00Co0000ooooool0003o00002?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Sooooo0_l0001]ooooo`03o`000?oooooo
oooo00Oooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool01?l0
003oooooooooool00009ooooo`Co00002Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`04o`000?ooooooooooo`0000Kooooo0ol00003ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Jooooo`;o0000K?ooool00ol0003ooooo
ooooo`07ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
0_l0000looooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo06Sooooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool01_ooool2o`0000Oooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool000co
oooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`;o00002_ooool2
o`0000Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0_l0000;ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000;ooooo`;o00001?ooool00ol0003oooooooooo`0?ooooo`;o00008_ooool00ol0
003oooooooooo`1Yooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00002_ooool01Ol0003ooooooooooooooooo
0000017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000006
ooooo`;o00002Oooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01_ooool2o`000003ooooool0
003ooooo00gooooo0_l0000Vooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000:ooooo`;o00001ooo
ool00ol0003oooooo`00000<ooooo`;o00009oooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00003?oo
ool2o`0000Gooooo0ol00009ooooo`?o0000:Oooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00003_oo
ool5o`000004ooooool0003o0000o`0000Kooooo0_l0000/ooooo`03o`000?oooooooooo06_ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`04o`000?ooooooooooo`0001?ooooo
2_l0000]ooooo`03o`000?oooooooooo06_ooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`04o`000?ooooooooooo`0001Gooooo0_l000001?oooooo0000o`000?l0000_ooooo`03
o`000?oooooooooo06cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool01?l0003oooooooooool0000Eooooo`;o00000_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool01?l0003oooooooooool0000Eooooo`Go0000;oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo
00005_ooool3o`0002oooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0001Kooooo00?o0000ooooool0
0000;oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool01?l0003oooooooooool0000Gooooo`03o`000?oooooo000002gooooo00?o0000oooooooo
ool0K_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo
00005_ooool2o`000003ooooool0003ooooo02cooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0001[o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000Iooooo`;o
0000:_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool2o`0002Gooooo00?o
0000ooooooooool0L_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo0_l0000Qooooo`03
o`000?oooooooooo07Gooooo00?o0000ooooooooool01oooool000Oooooo0ol00004ooooo`;o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool07Oooool2o`0007Sooooo00?o0000ooooooooool0
1oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo0_l0001koooo
o`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000??ooool00ol0003oooooooooo`07
ooooo`;o00006Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07Wooooo0ol00009
ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07cooooo00?o
0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`;o0000Ooooool00ol0003ooooo
ooooo`07ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04?ooool2o`00087ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo0_l0000@
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0=ooooo`;o00005_ooool00ol0003oooooooooo`0<oooo
o`;o0000Q?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooooooo
ool03oooool2o`0001Gooooo00?o0000ooooooooool02Oooool2o`0008Gooooo0_l00009ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo017ooooo0ol0000Booooo`03o`00
0?oooooooooo00Kooooo0ol00028ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool05?ooool3o`00013ooooo0_l00002ooooo`Co0000Rooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01Oooooo1_l0000:ooooo`Ko0000SOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo2_l000001Ooooooo0000oooooooooooo
000008kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooo000008oooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo02Sooooo0_l0002?ooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo000008oooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0008kooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Wooooo`?o000000?oooooo`000?l00000SOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo0007ooooo`?o00000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009oooo
o`002?ooool01?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
00Oooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
00Sooooo00Co0000oooooooooooooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oo
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooooolo`0000Wooooo0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo0?oooooo2?ooool000Kooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:
ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0003oooooo`[ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0
003oooooo`_ooooo001Rooooo`?o00005_ooool3o`0002Kooooo0ol0000dooooo`03o`000?oooooo
oooo04;ooooo001Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo047ooooo001Booooo`;o00000oooool3o`0000Co
oooo0_l000000ooooooo0000ooooo`03o`0000;ooooo1Ol000000ooooooo0000o`000003o`000005
ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`000002o`0000Oooooo0ol00004oooo
o`Co00000oooool2o`0000;ooooo1_l00007ooooo`?o00000oooool4o`000004ooooool0003o0000
o`0000Wooooo1?l00003ooooo`?o00001?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooo
oooo043ooooo001Aooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
043ooooo001@ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003
ooooo`03o`000?oooooooooo00Wooooo0ol00002ooooo`Go00000_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool3o`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oooooooooooooo
o`;o00002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool0
053ooooo00?o0000ooooooooool01?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool4
o`0000Cooooo00Co0000oooooooooooooooo0ol00003ooooo`Co00000oooool5o`0000Oooooo00Co
0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002?ooool4o`0000?ooooo
0_l00003ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo0ol00002ooooo`Co0000
2?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0@Oooool0057ooooo
00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Boooo
o`?o00004oooool3o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000oooo
ooooool00_ooool2o`0002oooooo00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.29849 .53451 .00323 0 365.73 arc
s
newpath
.18032 .23444 .00323 0 365.73 arc
s
newpath
.34613 .65547 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.29849 .53451 L
s
.36574 .19678 m
.18032 .23444 L
s
.29849 .53451 m
.18032 .23444 L
.34613 .65547 L
.29849 .53451 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.30924 .54526 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.19107 .24519 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.35688 .66622 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool05oooool4o`0000Cooooo0_l0002Hooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool0002Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool3o`0000?ooooo00Co0000oooooooo
oooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Sooooo00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002H
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool06?ooool4o`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool04oooool9o`0000?ooooo0_l0002Hoooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`Go
00001oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool02_ooool4o`0000cooooo00?o0000ooooooooool0
WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Gooooo1Ol0000@ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooooooool4o`0001Gooooo00?o
0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0j
ooooo`Go00006Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000=_ooool5o`000003ooooool0003ooooo01_ooooo00?o0000ooooooooool0W?ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo037ooooo1?l00006ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`;o000000?oooooo`000?l000000ol0000:ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0Yooooo`Go00003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09gooooo00?o
0000ooooooooool01oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0Z
ooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0WOooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0[ooooo`04o`000?oo
ooooooooo`0000cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03o`00
0?oooooooooo00Oooooo0006ooooo`Go00001Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000/ooooo`?o00003Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo09_ooooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool0000<ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`00
3?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0[ooooo`;o
000000?oooooo`000?ooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09go
oooo00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo02[ooooo1?l0000=ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`003?ooool5o`0000?ooooo
0_l00005ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0WOooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
;_ooool2o`0000_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000<Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0WOooool2o`0000Wo
oooo000Kooooo`03o`000?oooooooooo033ooooo0_l00009ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
<oooool2o`0000Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Mooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0dooooo`;o00001Oooool00ol0003ooooo
ooooo`0Cooooo`co0000Voooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool5o`0000Kooooo00?o
0000ooooooooool00oooool2o`0009Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000f
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool2o`0000_ooooo00?o0000
ooooooooool01Oooool3o`0009Gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo0_l0002Dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Aooooo`03
o`000?oooooooooo00Oooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0fooooo`;o0000
0oooool00ol0003oooooooooo`08ooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo093ooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000002?ooool2o`00017o
oooo00?o0000ooooooooool03?ooool2o`00093ooooo00?o0000ooooooooool01oooool001?ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0gooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0SOooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004oooo
ooco00002Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0hoooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?ooool01?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Roooool0
0ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>Oooool00ol0
003oooooo`000004ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0iooooo`?o00000oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`07ooooo`006oooool2o`0003_ooooo0_l0
0002ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`27ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>_ooool2o`0000;ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000G
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000001Sooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo0ol0000Hooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0Q_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o0000
6Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000looooo`?o00006?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo08Gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`?o00005?ooool2
o`000004ooooool0003o0000o`0000;ooooo0_l0000Cooooo`03o`000?oooooooooo08Kooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool3o`0001Cooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0
Q_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`Co00004ooo
ool5o`0000;ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l000000ooooooo0000oooo
o`0Cooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00004oooool00ol0003o
ooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
0_l000000ooooooo0000o`00000Cooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooo
oooo00004oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo0_l00002ooooo`03o`000?oooooooooo01;ooooo1?l000001Ooooooo
0000oooooooooooo000001?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003cooooo0_l00002ooooo`03o`000?oooooooooo017ooooo1?l00003ooooo`;o
00005?ooool00ol0003oooooooooo`24ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0
>oooool2o`0000;ooooo0_l0000Dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00000ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0QOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00000oooool2
o`0001;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`;o00004Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool2o`0000Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`;o00001?ooool2o`0000oooooo=?l0001aooooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Sooooo1_l0
000Looooo`03o`000?oooooooooo01Cooooo0ol0001_ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000001?ooool2o`0000Oooooo0_l00004
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ool000001?ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Sooooo0_l0001]ooooo`03o`000?oooooooooo00Oooooo000=ooooo`?o
00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000<ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03_ooooo00Co0000oooooooooooo00001?ooool5o`0000Oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Jooooo`;o0000K?ooool00ol0003oooooooooo`07ooooo`004?ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Xooooo`?o00002Oooool0013ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo
00Go0000ooooooooooooooooo`000003ooooo`?o00001oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`00
3?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00ol00007ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`;o00001?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
0_l00002ooooo`03o`000?oooooooooo01[ooooo0_l0000Rooooo`03o`000?oooooooooo06Wooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo1?l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00Go0000ooooooooooooooooo`000006ooooo`Co00006oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool01?l0003oooooooooool00008ooooo`;o00006_ooool2o`0002Kooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`04o`000?ooooooooooo`0000Sooooo1_l0000Dooooo`;o00009oooool00ol0003ooooo
ooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co
0000oooooooooooo00002?ooool3o`000003ooooool0003o0000017ooooo0ol0000Yooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool01?l0003oooooooooool00008ooooo`Go000000?oooooo`000?l000000ol0000:ooooo`;o0000
;?ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??oo
ool01?l0003oooooooooool00009ooooo`?o00001oooool:o`0002gooooo00?o0000ooooooooool0
Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000
2Oooool3o`0003kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000[ooooo0_l0000mooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool01?l0003oooooooooool00009ooooo`?o0000?Oooool00ol0003oooooooooo`1]ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000
2oooool2o`0003_ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??oo
ool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
K_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000
3?ooool2o`0003Wooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00Go0000ooooooooooooooooo`00000<ooooo`;o0000=oooool00ol0003ooooo
ooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo07;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02_ooool2o`0003?ooooo00?o0000ooooooooool0L_ooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`1eooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0
0005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02cooooo0_l0001hooooo`03o`000?oooooooooo00Oooooo0008
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`;o0000;?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02Sooooo0_l0001kooooo`03o`000?oooooooooo00Oo
oooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`;o0000??ooool00ol0003oooooooooo`07ooooo`;o00002Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo07Wooooo0ol00009ooooo`002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool2
o`0002Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`07ooooo`001oooool2o`00
00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02?ooooo0_l0001oooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`;o0000POooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
087ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0=ooooo`;o00001Oooool00ol0003oooooooooo`0Mooooo`;o0000Q?ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool03oooool2o`0000?ooooo
00?o0000ooooool000006oooool2o`0008Gooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo017ooooo0ol000000ooooooo0000o`00000Hooooo`?o0000R?oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01Cooooo1?l000000ooooooo0000o`00000@ooooo`Co0000Roooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo1ol0000:oooo
o`Co0000Soooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooool000001?ooool:o`0009?ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`;o0000
X_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooo`00002Pooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`000:3ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Eooooo`?o000000?ooooo
o`000?l00000Woooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2ioooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o00001Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool000Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003ooooo
ooooo`2hooooo`?o00002Oooool000Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Go
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooooooo
o`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Kooooo1Ol00003ooooo`;o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`000?oooooo2_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001oooool3o`00
00Cooooo0_l00004ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o
0000=?ooool00ol0003oooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_oo
ool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go000000?o
ooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
0_l00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo
1?l000001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00008ooooo`Go
00001?ooool00ol0003oooooooooo`10ooooo`00DOooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0ol0
0003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`?o00000_ooool5o`0000;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo043o
oooo001@ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o0000
00Coooooo`000?l0003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o00000oooool4o`00
00?ooooo1Ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3
o`0000Sooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo1?l00002
ooooo`?o00000_ooool4o`0000Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo047ooooo001Aooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool06_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`12ooooo`00D_ooool3o`0001?ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo
1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo
0ol00018ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.26256 .4946 .00323 0 365.73 arc
s
newpath
.19224 .17986 .00323 0 365.73 arc
s
newpath
.2909 .62147 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.26256 .4946 L
s
.36574 .19678 m
.19224 .17986 L
s
.26256 .4946 m
.19224 .17986 L
.2909 .62147 L
.26256 .4946 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.27331 .50535 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.20299 .19061 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.30165 .63222 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0^?ooool3o`00
00Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0002gooooo0_l0000=ooooo`03o`000?oooooooooo01Oooooo1?l00004ooooo`;o0000
V?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02cooooo1ol00008ooooo`03o`000?oo
oooooooo01Sooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0002Hooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo1?l00002ooooo`_o0000
6?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0009Sooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool2o`0000;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0;o`0000gooooo0ol00003ooooo`04o`000?ooooooooooo`00
09Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00_ooooo2ol00002ooooo`04o`000?oooooo0000
o`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0^ooooo`?o00002_ooool00ol0003oooooooooo`0Fooooo`Ko00000_ooool0
1?l0003oooooooooool0002Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo01Oooooo1Ol00003ooooo`;o0000V?oo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0;Oooool4o`0000[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0W?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000=ooooo`?o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`003?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0`ooooo`;o00002Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09go
oooo00?o0000ooooooooool01oooool000Kooooo1Ol00005ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool2o`0003;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo09_ooooo0ol00009ooooo`004?ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`07ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000coooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Moooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000=Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0WOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09kooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0W_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo09gooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03Gooooo0_l00004ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0W_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
3?l0002Kooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`Go00001_ooool00ol0003ooooooooo
o`03ooooo`;o0000VOooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`;o00002oooool00ol0003oooooooooo`05ooooo`?o0000UOoo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool2o`0009Cooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooo
oooo000000cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo097ooooo00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooo
oooo03Oooooo00Go0000ooooooooooooooooo`00000:ooooo`;o00003oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool01oooool001?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0gooooo`;o00000_ooool00ol0003ooooooooo
o`06ooooo`;o00004Oooool00ol0003oooooooooo`0<ooooo`;o0000T?ooool00ol0003ooooooooo
o`07ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0SOooool00ol0003oooooooooo`07ooooo`004oooool01?l0003ooooooooo
ool00004ooooooco00002Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0hooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01oooool001?ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0hooooo`;o000000?oooooo`000?oo
ool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0Roooool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0
>Oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000jooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo08Oooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0jooooo`;o00000_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0jooooo`;o00000_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0jooooo`;o000000?oooooo`000?ooool05oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>_ooool2
o`000003ooooool0003ooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`26
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03[ooooo0ol0000Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003cooooo0_l0000Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Eooooo`;o0000
00Coooooo`000?l0003o00000_ooool2o`0001?ooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00005Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Eooooo`Go
00000_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0001Kooooo00Co0000ooooool0
003o00000_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0001Kooooo00Co0000oooo
ool0003o00000_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0001Oooooo1?l00000
1Ooooooo0000oooooooooooo000001?ooooo00?o0000ooooooooool0QOooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0003cooooo0_l0000Fooooo`Co00000oooool2o`0001Cooooo00?o0000
ooooooooool0Q?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0ol0000Coooo
o`;o00007Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo0ol0000Aooooo`;o00007oooool00ol0003oooooooooo`25ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0ol0000?ooooo`;o0000
8Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo0ol0000=ooooo`;o00008_ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo1?l0000;ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo0_l000000ooooooo0000ooooo`08ooooo`;o00002Ooooolco`00077ooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo0000o`0000Oooooo0_l00005oooo
o`Ko00007?ooool00ol0003oooooooooo`0Dooooo`?o0000Koooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo0000o`0000Gooooo0_l00005oooo
o`;o00008_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooo`000?l00003oooo
o`;o00001_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Sooooo0_l0001]oooo
o`03o`000?oooooooooo00Oooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`04o`0000Kooooo0_l0000Tooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00;o00001Oooool3o`0002Gooooo00?o0000ooooooooool06_ooool2o`00
06cooooo00?o0000ooooooooool01oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`02o`000003ooooool0003o0000
00;o0000:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06Sooooo0ol00009oooo
o`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`02o`0000;ooooo0_l0000Xooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool4o`0000?o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Ko00009oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00Co0000oooooooooooooooo1?l0000Xooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool5o`00
00?ooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooooooo1?l0000W
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000looooo`04o`000?ooooooooooooooo`;o00000_ooool0
0ol0003oooooooooo`0Qooooo`;o00008_ooool00ol0003oooooooooo`1Yooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`00
023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000Cooooo0_l0000Mooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`;o00009_ooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`;o00005_ooool2
o`0002Oooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0000;ooooo0_l00008ooooo`;o00004Oooool3
o`0002Wooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool02?ooool5
o`0000[ooooo0_l0000/ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool03Oooool:
o`0002gooooo00?o0000ooooooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo
03_ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo06kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000n
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo07;ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo07?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000>oooool00ol0003o
ooooooooo`1dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000oooooooo
ool0MOooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o0000
1Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
0000>?ooool2o`0007Sooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0003Kooooo00?o0000
ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00Kooooo1?l000000ooooooo0000o`00000`ooooo`;o0000Nooo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool0
1oooool2o`0000;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1iooooo`?o0000
2Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`?o
0000<?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Oooooo0007ooooo`;o0000
1?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`08ooooo`?o0000;_ooool2o`0007oooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool01?l0003oooooo`000?l0000[oooo
o`;o0000POooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_l0000Yooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`07ooooo`?o000000?oooooo`000?l000000_l0000Uooooo`;o0000Q?ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool03oooool2o`00027ooooo0_l0
0025ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0A
ooooo`?o00006oooool3o`0008Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Dooooo`?o00005?ooool4o`0008_ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`Ko
00002_ooool4o`0008oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Mooooo`[o0000Toooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2ioooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007oooo
o`?o00000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
00Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool01?l0
003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00003
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co0000
oooooooooooooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003co
oooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000
ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`0000Wo
oooo0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo0?oooooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0003oooooo`[ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo
001Rooooo`?o00005_ooool3o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo001S
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l000000ooo
oooo0000ooooo`03o`0000;ooooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000
o`000?ooool00_l000000ooooooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000oooool2
o`0000;ooooo1_l00007ooooo`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo1?l0
0003ooooo`?o00001?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo043ooooo001A
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo043ooooo001@oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`03o`000?oo
oooooooo00Wooooo0ol00002ooooo`Go00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`;o00002Oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000
ooooooooool01?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo00Co
0000oooooooooooooooo0ol00003ooooo`Co00000oooool5o`0000Oooooo00Co0000oooooooooooo
00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002?ooool4o`0000?ooooo0_l00003ooooo`;o
000000?oooooo`000?l000002?ooool4o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0@Oooool0057ooooo00Co0000oooooooo
oooo00005Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Booooo`?o00004oooool3
o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2
o`0002oooooo00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.25139 .44207 .00323 0 365.73 arc
s
newpath
.21846 .12126 .00323 0 365.73 arc
s
newpath
.26467 .57139 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.25139 .44207 L
s
.36574 .19678 m
.21846 .12126 L
s
.25139 .44207 m
.21846 .12126 L
.26467 .57139 L
.25139 .44207 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.26214 .45282 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.22921 .13201 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.27542 .58214 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03?ooooo0_l00006ooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Go00000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`00
03Cooooo1?l00004ooooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0cooooo`;o00000_ooool2o`0000;ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0cooooo`;o00000_oo
ool00ol0003oooooo`000002o`000;cooooo00?o0000ooooooooool01oooool000Oooooo0_l00004
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0cooooo`Co00001?ooool2o`000;_ooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03?ooooo0_l0
0002ooooo`06o`000?ooooooooooooooool0003ooooo0_l0002iooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooooooool2o`000;Oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000dooooo`Co
00001?ooool00ol0003oooooooooo`03ooooo`;o0000]?ooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`;o0000
/oooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool2o`000;7ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool2o`00
0:kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00cooooo0_l0002/ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0>ooooo`;o0000Z_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Gooooo0_l0
0005ooooo`03o`000?oooooooooo013ooooo0_l00005ooooo`Co00001?ooool2o`0009Sooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04_ooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0002Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`;o00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0009Sooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo
1Ol00003ooooo`04o`000?ooooooooooo`0009Sooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo
1?l00002ooooo`04o`000?ooooooooooo`0009Sooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002Hooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oo
oooo1Ol00003ooooo`;o0000V?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09gooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0eooooo`;o00001?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0=Oooool2o`0000Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Moooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09gooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`2Looooo`;o00002Oooool001_ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool000go
oooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool000Kooooo1Ol00005ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0003Oooooo0_l00003oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Voooool3o`0000Wooooo000@ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0foooo
o`;o00000oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo09gooooo00?o0000oooo
ooooool01oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0=oooool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000001cooooo00?o
0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`003?ooool5o`0000?ooooo0_l00005
ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=oooool0
1Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0W_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000006ooo
ool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000>?ooool0
1Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0WOooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00000Kooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=oooool2
o`0000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03Oooooo0_l00002ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0hooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool0W_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`00
01_ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Wo
oooo00Co0000oooooooooooo00006oooool00ol0003oooooooooo`2Mooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>?ooool01?l0003o
ooooooooool0000Kooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000Kooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>?ooool01?l0003o
ooooooooool0000Kooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>?ooool2o`000003ooooool0003ooooo01[ooooo00?o0000oooooooo
ool0W_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Wooooo0_l000000ooooooo0000
ooooo`0Jooooo`03o`000?oooooooooo09gooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0hooooo`;o000000?oooooo`000?ooool06_ooool00ol0003oooooooooo`2Nooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000006oooool0
0ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooool000006oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000006oooool00ol0003o
ooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooool000005Oooool<o`0009_ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooo`00000@ooooo`Go00001_ooool00ol0003ooooooooo
o`03ooooo`;o0000VOooool00ol0003oooooooooo`07ooooo`006oooool2o`0003[ooooo00?o0000
ooooool000003_ooool2o`0000_ooooo00?o0000ooooooooool01Oooool3o`0009Gooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0iooooo`?o00003Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo0_l0002Dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03Wooooo0ol0000<ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o0000
1Oooool00ol0003oooooooooo`0iooooo`?o00002_ooool2o`0000oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>_ooool2o`0000Sooooo0_l0000Aooooo`03o`00
0?oooooooooo00cooooo0_l0002@ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>_ooool2o`0000Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0
1oooool001?ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>_ooool2o`0000Kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0
1oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0jooooo`;o0000
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
Roooool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>_oo
ool2o`0000Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo08[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>_ooool2
o`0000?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo08[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>_ooool2o`00
00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
08Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000kooooo`;o00000_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Qoooool2o`0000Wo
oooo000Kooooo`03o`000?oooooooooo03[ooooo0_l00002ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00005oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`26
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Ioooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003cooooo0_l0000Iooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Eooooo`;o0000
00Coooooo`000?l0003o00000_ooool2o`0001?ooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00005Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Eooooo`Go
00000_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0001Kooooo00Co0000ooooool0
003o00000_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool?o`0000Wooooo00Co0000oooo
ool0003o00000_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0000;ooooo00?o0000
ooooooooool02?ooool>o`000005ooooool0003oooooooooool000004oooool00ol0003ooooooooo
o`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool5o`0001?ooooo1?l00003
ooooo`;o00005?ooool00ol0003oooooooooo`24ooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool2o`000003ooooool0003ooooo033ooooo00?o0000ooooooooool0QOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o000000?oooooo`000?oo
ool0<?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo0ol0000booooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool3o`00037ooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`?o0000<Oooool0
0ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool3o`00
01Gooooo<ol0001aooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooo`00000?ooooo`Ko00007?ooool00ol0003oooooooooo`0Dooooo`?o0000Koooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000gooooo
0_l0000Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0KOooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`;o0000KOooool00ol0003ooooooooo
o`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00Co0000
ooooool0003o00002Oooool2o`0002Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1[ooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00Co0000ooooool0003o
00001_ooool3o`0002Gooooo00?o0000ooooooooool06_ooool2o`0006cooooo00?o0000oooooooo
ool01oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o
0000??ooool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo06Sooooo0ol00009ooooo`004?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool01Ol0
003oooooo`000?oooooo000000?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool000cooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000002
ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`04o`000?oooooo0000o`0000;ooooo
0_l0000Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`07ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00Co
0000ooooool0003o00000_ooool2o`0002Oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Ko
0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooooooool08Oooool2o`00
02;ooooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`;o00008?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`02o`0000Kooooo0_l0000Mooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool06?ooool2o`00
02Kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`04o`000?ooooooooooo`0000[ooooo0_l0000Fooooo`;o00009oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00Co0000oooooooooooo00003?ooool2o`00017ooooo0ol0000Yooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003o
ooooooooool0000>ooooo`Go00002_ooool2o`0002cooooo00?o0000ooooooooool0Joooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00Co0000oooooooooooo00004oooool:o`00
02gooooo00?o0000ooooooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool00_l00019ooooo`03o`000?oooooooooo06cooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02o`0004Sooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00;o0000B?ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_l00017
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`03o`0004Kooooo00?o0000ooooooooool0K_ooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool01?l000000ooooooo
0000o`000011ooooo`03o`000?oooooooooo06kooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool02?l0003oooooooooool0003oooooo`000?oooooo0000@_ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000
oooooooooooooooo0ol00013ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooooooool2o`000003ooooool0
003ooooo043ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000?ooo
ool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
1?l0003oooooooooooooool3o`000003ooooool0003o000003gooooo00?o0000ooooooooool0L_oo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0iooooo`;o0000N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0dooooo`;o0000Noooool00ol0
003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool01oooool2
o`0003?ooooo00?o0000ooooooooool0NOooool3o`0000Wooooo0008ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo07cooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool2o`0007oooooo00?o0000ooooooooool0
1oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`;o0000POoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Oooool2o`00
02Gooooo0_l00024ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`0?ooooo`;o00008Oooool2o`0008Gooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo017ooooo0ol0000Kooooo`?o0000R?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Cooooo0ol0
000Dooooo`Co0000Roooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo01Oooooo1_l0000:ooooo`Co0000Soooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo2_l0002Coooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool000Oooooo0ol00003ooooo`?o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool0
^?ooool3o`0000Wooooo0008ooooo`04o`000?ooooooooooooooo`Co00000oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`001oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`002?ooool01?l0003oooooooooooooool5o`0000?ooooo0_l00005ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooo
ooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Ooo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0006ooooo`Go00000oooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`001oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooooco00002Oooool000Wooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0ooooool8ooooo`001_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0003oooooo`[ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo2_ooool000Oooooo0ol00004oooo
o`;o00001?ooool2o`000?oooooo2oooool006;ooooo0ol0000Fooooo`?o00009_ooool3o`0003Co
oooo00?o0000ooooooooool0@_ooool006?ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0@Oooool005;ooooo0_l0
0003ooooo`?o00001?ooool2o`000003ooooool0003ooooo00?o00000_ooool5o`000003ooooool0
003o000000?o000000Goooooo`000?l0003o0000ooooo`02o`000003ooooool0003o000000;o0000
1oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Oooooo0ol00003ooooo`Co0000
00Coooooo`000?l0003o00002Oooool4o`0000?ooooo0ol00004ooooo`;o00002?ooool5o`0000Co
oooo00?o0000ooooooooool0@?ooool0057ooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooool000001_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`?o00000ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool3o`0000?ooooo00?o0000ooooooooool02Oooool3o`0000;ooooo1Ol00002ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`10ooooo`00
D?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`06ooooo`?o00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co
0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`000004oooo
ool0003o0000ooooo`Co00001?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l00003oooo
o`Go00001oooool01?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00008
ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool3
o`0000;ooooo1?l00008ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`11ooooo`00DOooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo01[ooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool0@_ooool005;ooooo0ol0000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`Co0000
2Oooool00ol0003oooooooooo`02ooooo`;o0000;oooool00ol0003oooooooooo`09ooooo`?o0000
B?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.26799 .39099 .00323 0 365.73 arc
s
newpath
.25789 .06865 .00323 0 365.73 arc
s
newpath
.27206 .52093 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.26799 .39099 L
s
.36574 .19678 m
.25789 .06865 L
s
.26799 .39099 m
.25789 .06865 L
.27206 .52093 L
.26799 .39099 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.27874 .40174 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.26864 .0794 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.28281 .53168 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000
ooooool0003o0000^Oooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`04o`000?oooooo0000o`000;Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooo`000003o`000;Oooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`04o`000?oooooo0000o`0000;ooooo00?o0000ooooooooool0/oooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000000_l000000ooo
oooo0000ooooo`2eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooool000000ol0002gooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`2dooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000ooooool0003o
00000_ooool2o`000;Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooo`000003o`000003ooooool0003ooooo0;Cooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000looooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0/Ooo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000001_ooool0
0ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000002?ooool00ol0003o
ooooooooo`2_ooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000002Oooool00ol0003ooooo
ooooo`2^ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooool000002_ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo00Oo
oooo0005o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo0_l0000looooo`04o`000?oooooo0000o`0000Wooooo00?o0000
ooooooooool0Zoooool3o`0000Wooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00002oooool00ol0
003oooooooooo`2[ooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00001?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool0000<ooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool01ooo
ool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo03_ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`2Yooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00003_oo
ool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
1?l0003oooooooooool0000>ooooo`03o`000?oooooooooo0:Oooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool0Yooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo
ooooo`00013ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool0YOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo
ooooo`0001;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool0Xooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo
ooooo`0001Cooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00Co0000oooooooooooo00005?ooool00ol0003oooooo`000003o`0000Cooooo0_l0
002Hooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0
000Eooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`2Fooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co
0000oooooooooooo00005_ooool2o`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`2Fooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00Co0000oooooooooooo00005oooool3o`0000?ooooo00Co0000oooooooooooo0000V?ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`00
01Oooooo1?l00002ooooo`04o`000?ooooooooooo`0009Sooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000Gooooo`04o`000?oooooo
0000o`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00Co0000oooooooooooo00005_ooool5o`0000?ooooo0_l0002Hooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000Iooooo`03o`00
0?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000Iooooo`03o`00
0?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000Iooooo`03o`00
0?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`04o`000?oo
ooooooooo`0001Wooooo00?o0000ooooooooool0W?ooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`2Mooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_l0
000Hooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`02o`0001Sooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
03_ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo09gooooo00?o0000
ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000001Sooooo
00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`001_ooool5o`0000Gooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool01Ol0003ooooo
oooooooooooo000001Sooooo00?o0000ooooooooool0Voooool3o`0000Wooooo000@ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`05
o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo
00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oooooooooo09gooooo00?o0000
ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00000Hooooo`03o`000?oo
oooooooo09gooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool0
0ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000
ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000001Oooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00Go0000
ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo09gooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000
ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000001Oooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`2Nooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00
000Gooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`2Mooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000001Oooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`2Nooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00
000Gooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool0W_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`05o`000?oooooo
ooooooooool000005oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool0WOoo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00
000Gooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000ooooooooool0W_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`05o`000?oooooo
ooooooooool000005oooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooooooo0_l0000Fooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooooooool2o`00013ooooo3?l0002Kooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooooooo0_l0000;ooooo`Go00001_oo
ool00ol0003oooooooooo`03ooooo`;o0000VOooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00Co0000oooooooooooooooo0_l00009ooooo`;o00002oooool00ol0003ooooooooo
o`05ooooo`?o0000UOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02?ooool2o`0009Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo097ooooo00?o0000oooo
ooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo093ooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooooooo0_l0000Aooooo`03o`000?oooooooooo00cooooo0_l0002@ooooo`03o`000?oooooooooo
00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooo
oooooooo00001?ooooolo`0000Wooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000001Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02
ooooo`;o00005Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08_ooooo00?o0000
ooooooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00Co0000oooo
oooooooooooo0_l0000Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
ooooo`?o00005?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooooooool7
o`00013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`29ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool01_l0003oooooooooool0003oooooo`0000;ooooo0_l0
000Aooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Qoooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00Go0000oooooooooooo0000ooooo`07o`0000oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00Go0000oooooooooooo0000ooooo`02o`000003ooooool0
003ooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooo`000002ooooo`;o000000?oooooo`000?ooool00oooool2o`0000cooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000007oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`?o
00002?ooool2o`0000Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`26ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool2o`0000?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l00003ooooo`03o`000?oo
oooooooo00_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003o00000_ooool2o`0001?ooooo
00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`?o00000oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00000oooool00ol0003ooooooooo
o`0?ooooo`Go00000_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0000?ooooo00?o
0000ooooooooool04?ooool4o`0000;ooooo00Co0000oooooooooooo00004oooool00ol0003ooooo
ooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0
0003ooooo`03o`000?oooooooooo013ooooo00Co0000ooooool0003o00000_ooool01?l0003ooooo
ooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool2o`0000?ooooo00?o0000ooooooooool04Oooool4o`000005oooo
ool0003oooooooooool000004oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000??ooool2o`0000?ooooo00?o0000ooooooooool04?ooool4o`0000?ooooo
0_l0000Dooooo`03o`000?oooooooooo08Cooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`;o00000oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0000?ooooo0_l0000^
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool2o`0000?ooooo0_l0000^ooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0000Cooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo0_l00004ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
Q_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo0_l00004ooooo`03o`000?oo
oooooooo00oooooo<ol0001aooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00Wooooo1_l0000Looooo`03o`000?oooooo
oooo01Cooooo0ol0001_ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`07ooooo`;o00008_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`;o0000KOooool00ol0003o
ooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`;o00009?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool000cooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0>oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`?o00009Ooo
ool00ol0003oooooooooo`0Jooooo`;o0000K?ooool00ol0003oooooooooo`07ooooo`004?ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`07o`000?oo
ooooooooooooool0003oooooo`000002ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Xooooo`?o00002Oooool0013ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00Wo0000oooooooo
ooooooooo`000?oooooo0000ooooool00000:?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`;o000000?o
ooooo`000?ooool09_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool2o`0002Sooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<
ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03
ooooo`;o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02oooo
o`Co00009Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00;ooooo1?l000000ooooooo
0000o`00000Pooooo`;o00008_ooool00ol0003oooooooooo`1Yooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo0000ooooo`;o
00008?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000ooooool0003ooooo0_l0000Mooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04
o`000?ooooooooooo`0000?ooooo0_l00004ooooo`03o`000?oooooooooo01Sooooo0_l0000Voooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000Cooooo0_l0000Foooo
o`;o00009oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00005
ooooo`;o00004Oooool3o`0002Wooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000;ooooo0ol00000
0ooooooo0000o`000006ooooo`Go00002_ooool2o`0002cooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00Co0000oooooooooooo00004oooool:
o`0002gooooo00?o0000ooooooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo
03_ooooo00Co0000oooooooooooo0000B_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000BOooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00Co0000oooooooooooo0000BOooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000B?ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00Co0000oooooooooooo0000B?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool01?l0003oooooooooool00017ooooo`03o`000?oooooo
oooo06kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooooooo
o`0004Oooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0004Kooooo00?o0000ooooooooool0L?ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`05o`000?oooooooooo
ooooool00000AOooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo07;ooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo07Cooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`07
ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0>Oooool2o`0007Sooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07
ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0=?ooool2o`0007_ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
0_l0000looooo`03o`000?oooooooooo00Oooooo0_l0000cooooo`03o`000?oooooooooo07Wooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Oo
oooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02cooooo0_l0001oooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0:Oooool2o`00087ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0POooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00gooooo0_l0000Uooooo`;o0000Q?ooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool03oooool2o`00027ooooo0_l00025
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Aoooo
o`?o00006oooool3o`0008Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Dooooo`?o00005?ooool4o`0008_ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`Ko0000
2_ooool4o`0008oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Mooooo`[o0000Toooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o
00000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000So
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool01?l0003o
ooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00003oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co0000oooo
oooooooooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo
00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooo
ooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo
0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo0?oooooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0003oooooo`[ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo001R
ooooo`?o00005_ooool3o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo001Soooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo
0000ooooo`03o`0000;ooooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`00
0?ooool00_l000000ooooooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000oooool2o`00
00;ooooo1_l00007ooooo`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo1?l00003
ooooo`?o00001?ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo043ooooo001Aoooo
o`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo043ooooo001@ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`03o`000?oooooo
oooo00Wooooo0ol00002ooooo`Go00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Ko
0000oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000oooo
ooooool01?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?ooool4o`0000Cooooo00Co0000
oooooooooooooooo0ol00003ooooo`Co00000oooool5o`0000Oooooo00Co0000oooooooooooo0000
0_ooool2o`0000?ooooo1?l00003ooooo`?o00002?ooool4o`0000?ooooo0_l00003ooooo`;o0000
00?oooooo`000?l000002?ooool4o`0000;ooooo0ol00002ooooo`Co00002?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0@Oooool0057ooooo00Co0000oooooooooooo
00005Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Booooo`?o00004oooool3o`00
00Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`00
02oooooo00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.3079 .35506 .00323 0 365.73 arc
s
newpath
.29875 .03269 .00323 0 365.73 arc
s
newpath
.31159 .48501 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.3079 .35506 L
s
.36574 .19678 m
.29875 .03269 L
s
.3079 .35506 m
.29875 .03269 L
.31159 .48501 L
.3079 .35506 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.31865 .36581 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.3095 .04344 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.32234 .49576 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`09ooooo`;o0000[oooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo0_l0002_ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2Oooool4o`000:gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo0_l00000
0ooooooo0000ooooo`2[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`0:ooooo`?o0000[?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02_ooool01?l0003oooooo`000?l0002/ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool01?l0003o
ooooo`000?l0002/ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02Oooool5o`000:cooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`000:co
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0:ooooo`04o`000?ooooooooooo`000:cooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool0
0000Zoooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
2_ooool01Ol0003ooooooooooooooooo00000:[ooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00002[ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0:Oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Vooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`2Vooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool02_ooool2o`0000Kooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`07
ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Uoooo
o`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:Gooooo00?o0000
ooooooooool01oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo0ol00009ooooo`002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0:?ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Soooo
o`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o
00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo0:;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Qooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`2Qooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:7o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0X?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool4o`0000Cooooo0_l0002Hoooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00[ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0002H
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`;o000000Goooooo`000?ooooooooooo`000002
ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo0ol00003oooo
o`04o`000?ooooooooooo`0009Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo1?l00002oooo
o`04o`000?ooooooooooo`0009Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00Co0000oooo
ool0003o00000_ooool01?l0003oooooooooool0002Hooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo1Ol00003
ooooo`;o0000V?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09gooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo09cooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09gooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09gooooo00?o0000
ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`001_ooool5
o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Vooo
ool3o`0000Wooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01ooo
ool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02oooool2o`0000gooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`07ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool02oooool2o`0000cooooo00?o0000ooooooooool0W_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00_ooooo0_l0000<ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`;o00003?ooool00ol0003o
ooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooo
ooooo`0;ooooo`;o00003?ooool00ol0003oooooooooo`2Mooooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo09kooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0WOoo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo09kooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0W_ooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo09gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo09kooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`co0000Voooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00cooooo00?o0000ooooool000001?l00006ooooo`03o`000?oooooooooo00?ooooo0_l0002Ioooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0;ooooo`?o
00002oooool00ol0003oooooooooo`05ooooo`?o0000UOooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool02oooool3o`0000_ooooo00?o0000ooooooooool0
2?ooool2o`0009Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0:ooooo`05o`000?oooooo0000o`000?ooool00ol00007ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`07ooooo`005?oo
ool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`;o00000_oo
ool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo093ooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`Go00002?oo
ool00ol0003oooooooooo`0<ooooo`;o0000T?ooool00ol0003oooooooooo`07ooooo`004oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`Co00002Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo08gooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?oo
ooolo`0000Wooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0003o0000
2Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0
1oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool4o`0000Wooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o00001Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go
0000ooooooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`27ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0
>oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08Sooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooo`00000<ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000cooooo0_l00006ooooo`05o`000?oo
ooooooooooooool000006?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo0_l0000=ooooo`;o00001_ooool01Ol0003ooooooooo
oooooooo000001Sooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo0_l0000>ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
6?ooool00ol0003oooooooooo`25ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool2o`0000kooooo00?o0000ooooooooool01?ooool2o`000004ooooool0003o0000o`0000;ooooo
0_l0000Cooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool2o`0000kooooo00?o0000ooooooooool01?ooool01Ol0003oooooo`00
0?oooooo000000;ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`26ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000>ooooo`03o`00
0?oooooooooo00Cooooo1Ol00002ooooo`04o`000?ooooooooooo`0001?ooooo00?o0000oooooooo
ool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o0000
3_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooo
oooo00004oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo0_l0000>ooooo`03o`000?oooooooooo00Gooooo00Co0000ooooool0
003o00000_ooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0000kooooo00?o0000oooo
ooooool01_ooool4o`000005ooooool0003oooooooooool000004oooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool2o`0000kooooo00?o0000oooo
ooooool01Oooool4o`0000?ooooo0_l0000Dooooo`03o`000?oooooooooo08Cooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`;o00003_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool2o`0000kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000>ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`;o00003_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo08Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`00
00kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool2o`0000kooooo00?o0000ooooooooool01Ooooolco`00077o
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000gooooo
00?o0000ooooool000001Ol0000Looooo`03o`000?oooooooooo01Cooooo0ol0001_ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000003?oo
ool3o`0002;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000003?ooool4
o`000003ooooool0003o000001gooooo00?o0000ooooooooool06?ooool2o`0006gooooo00?o0000
ooooooooool01oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0000Wooooo0_l00002ooooo`04o`000?ooooooooooo`0001kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000<
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03_ooooo00Co0000oooooooooooo00001_ooool3o`0000Cooooo00?o0000ooooool0
00007_ooool00ol0003oooooooooo`0Jooooo`;o0000K?ooool00ol0003oooooooooo`07ooooo`00
4?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`05ooooo`;o00007oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo06Sooooo0ol00009ooooo`004?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000M
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07
ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool0000Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`;o00002?ooool3o`000003oooo
ool0003o000001[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`03ooooo`;o00009oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002?ooooo0_l0000Rooooo`03o`000?oo
oooooooo06Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooooooo0_l0000Pooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`05o`000?ooooooooooooooool000001_ooool2o`0001gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Hooooo`;o00009_oo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00Co0000oooooooooooo00002_ooool2o`0001Kooooo0_l0000Wooooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool0000<ooooo`;o00004Oooool3o`0002Wooooo00?o0000ooooooooool0Jooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo
ooooo`0000kooooo1Ol0000:ooooo`;o0000;?ooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000??ooool01?l0003oooooooooool0000Cooooo`[o0000;Ooo
ool00ol0003oooooooooo`1[ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool0001:ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00019ooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool00019ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00018ooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool00018ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`04o`000?ooooooooooo`0004Oooooo00?o0000ooooooooool0K_oo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000Aooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00Co0000oooooooooooo0000A_ooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`00
0015ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool01Ol0003ooooooooooooooooo000004Cooooo00?o0000ooooooooool0LOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool0L_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0M?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo0007
ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0iooooo`;o0000N?ooool00ol0003oooooooooo`07
ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Oooooo0008
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0dooooo`;o0000Noooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`0003co
oooo00?o0000ooooooooool01oooool2o`0003?ooooo00?o0000ooooooooool0NOooool3o`0000Wo
oooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool01oooool000Oo
oooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool2
o`0007oooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Yooooo`;o0000POooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`21ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool03Oooool2o`0002Gooooo0_l00024ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`0?ooooo`;o00008Oooool2o`0008Gooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo017ooooo0ol0000K
ooooo`?o0000R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01Cooooo0ol0000Dooooo`Co0000Roooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Oooooo1_l0000:ooooo`Co
0000Soooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo01gooooo2_l0002Cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo
00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0ol00003oooo
o`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo0008ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2
o`0003cooooo00?o0000ooooooooool0^?ooool3o`0000Wooooo0008ooooo`04o`000?oooooooooo
ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001oooool2o`0000?ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool01?l0003ooooooooooooo
ool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2i
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0006
ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooooco00002Oooool000Wooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0ooooool8ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0003oooooo`[ooooo0006ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oo
oooo2_ooool000Oooooo0ol00004ooooo`;o00001?ooool2o`000?oooooo2oooool006;ooooo0ol0
000Fooooo`?o00009_ooool3o`0003Cooooo00?o0000ooooooooool0@_ooool006?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0@Oooool005;ooooo0_l00003ooooo`?o00001?ooool2o`000003ooooool0003ooooo
00?o00000_ooool5o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`02
o`000003ooooool0003o000000;o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6
o`0000Oooooo0ol00003ooooo`Co000000Coooooo`000?l0003o00002Oooool4o`0000?ooooo0ol0
0004ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0@?ooool0057ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooool000001_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00?o0000ooooooooool02Ooo
ool3o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`04
ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co00001?ooool01?l0003ooooooooo
ooooool3o`0000?ooooo1?l00003ooooo`Go00001oooool01?l0003oooooooooool00002ooooo`;o
00000oooool4o`0000?ooooo0ol00008ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo
0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l00008ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`11ooooo`00DOooool01?l0003oooooooooool0000Eoooo
o`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool0@_ooool005;ooooo0ol0000Cooooo`?o00001Oooool0
0ol0003oooooooooo`0Cooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o0000;oooool0
0ol0003oooooooooo`09ooooo`?o0000B?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.36043 .34389 .00323 0 365.73 arc
s
newpath
.30909 .0255 .00323 0 365.73 arc
s
newpath
.38112 .47223 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.36043 .34389 L
s
.36574 .19678 m
.30909 .0255 L
s
.36043 .34389 m
.30909 .0255 L
.38112 .47223 L
.36043 .34389 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.37118 .35464 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.31984 .03625 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.39187 .48298 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->0,
  AnimationCycleRepetitions->0,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0:_ooooo00?o
0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00_ooooo0ol0002[
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<oooo
o`Co0000Z_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00cooooo0_l00002ooooo`03o`000?oooooooooo0:Oooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`;o0000
0_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool03Oooool3o`000:[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo
ooooo`000:Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooo
oooo00gooooo0_l000000ooooooo0000ooooo`2Wooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0<ooooo`Co0000Z_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00gooooo0_l0002[ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooo`00002Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool03_ooool2o`000:[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`;o0000Z_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00kooooo00?o0000ooooool00000ZOooool00ol0003oooooooooo`07ooooo`006oooool2o`0003co
oooo00?o0000ooooooooool03_ooool00ol0003oooooo`00002Xooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo00000:Wooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0>ooooo`04o`000?ooooooooooo`000:Sooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0>ooooo`;o000000?oooooo`000?ooool0Yooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooool00000Z?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000Yoooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool03oooool01?l0
003oooooooooool0002Vooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooo`000:Oooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooo
ooooool00000Y_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00002Vooooo`03o`000?oooooo
oooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool04?ooool01?l0003oooooooooool0002Vooooo`03o`000?oooooo
oooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04?oo
ool01Ol0003ooooooooooooooooo00000:Gooooo00?o0000ooooooooool01oooool000Go00000ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001?ooool2o`0003cooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo0000
0:?ooooo0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo013ooooo00Go0000ooooooooooooooooo`00002Uooooo`03o`000?oooooooooo00Oooooo0008
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool01oooool000Oooooo0_l0
0004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Rooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00?ooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo017ooooo
00Go0000ooooooooooooooooo`00002Tooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0:7ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2Pooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:3o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0X?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool4o`0000Cooooo0_l0002Hoooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00?o0000oooo
ooooool0U_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool2o`000005ooooool0003ooooooooo
ool000000_ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`?o
00000oooool01?l0003oooooooooool0002Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`04
o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo0000V?ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooo`000?l00002ooooo`04o`000?ooooooooooo`0009Sooooo00?o
0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo01?ooooo00Co0000
oooooooooooooooo1Ol00003ooooo`;o0000V?ooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01?o
oooo0_l00005ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0W?ooool2o`0000Wooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0WOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo01Cooooo0_l00004ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0
1oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Mooooo`03o`000?oo
oooooooo00Oooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool01oooool000Kooooo1Ol0
0005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0003cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09_ooooo
0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0WOooool00ol0003oooooooooo`07ooooo`003?ooool4o`0000?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo
000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01Gooooo0_l00003ooooo`03o`000?oooooooooo09gooooo
00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000X?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00Co
0000oooooooooooo0000X?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000X?ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool05_ooool01?l0003ooooooooo
ool0002Oooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Fooooo`04o`000?ooooooooooo`000:3ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`000:3ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooo00000:3ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo00000:3ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooo00000:3ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo01Oooooo00?o0000ooooool00000Woooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool05oooool00ol0003oooooo`00002Pooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooo`00002Pooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool05oooool3o`000:3ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`;o0000X?ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01So
oooo0_l0002Pooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooo
ooooo`0Hooooo`;o0000Woooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool06?ooool2o`000:3ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`;o0000X?ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo0_l0002Poooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool06Oooool2o`0009oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Cooooo`co0000Voooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00kooooo1Ol00005ooooo`?o000000?o
ooooo`000?l000000ol0002Iooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`0<ooooo`;o00002oooool01Ol0003ooooooooooooooooo000000?ooooo0ol0
002Eooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo1Ol00006ooooo`;o0000U?ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool2o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool0TOooool00ol0
003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`08ooooo`;o00003oooool2o`000003ooooool0003ooooo00Wooooo00?o0000oooooooo
ool0T?ooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool2o`00017ooooo0ol0000<ooooo`;o
0000T?ooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`?o
00003_ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`00
0?ooooooooooo`0000Coooooo?l00009ooooo`004oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`;o
00004Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo0_l0000Aooooo`03o`000?oooooooooo08_ooooo00?o0000oooooooo
ool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Cooooo`;o000000?oooooo`000?ooool04?ooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go
0000ooooooooooooooooo`00000Fooooo`;o000000?oooooo`000?ooool04?ooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go
0000ooooooooooooooooo`00000Fooooo`;o000000?oooooo`000?ooool04Oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool01?l0003ooooooooo
ool0000Gooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool0Qoooool2o`0000Wo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00005oooool01?l0003o
ooooooooool0000Cooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0000Gooooo`04o`000?oooooooooo
o`0001Cooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooo000001Sooooo00Go0000ooooooooooooooooo`00000C
ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooo`00000Hooooo`05o`000?ooooooooooooooool000005?ooool0
0ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo0_l0000Iooooo`05o`000?ooooooooooooooool000005?ooool00ol0003oooooooooo`26
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool2o`0001Wooooo00Go0000oooo
ooooooooooooo`00000Dooooo`03o`000?oooooooooo08Gooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`;o00005Oooool2o`000004ooooool0003o0000o`0000;ooooo0_l0000C
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool2o`0001Gooooo00Go0000ooooooooooooooooo`000002ooooo`;o000000?ooooo
o`000?ooool04Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo0_l0000Eooooo`Go00000_ooool4o`0001?ooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o
00005_ooool01?l0003oooooo`000?l00002ooooo`04o`000?oooooo0000o`0001?ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`;o00005_ooool01?l0003oooooo`000?l00002ooooo`04o`000?oooooo0000o`0001?ooooo00?o
0000ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`;o00005oooool4o`000003ooooool0003ooooo00;o00004oooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool2o`0001Kooooo1?l00003oooo
o`;o00005?ooool00ol0003oooooooooo`24ooooo`;o00002Oooool001_ooooo00?o0000oooooooo
ool0>oooool2o`0001kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`25ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Nooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`;o00007oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo08Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2
o`0001oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Nooooo`?o00004Oooool00ol0
003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool2o`0001Ko
oooo<ol0001aooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
o`00000?ooooo`Ko00002_ooool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo01Co
oooo0ol0001_ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooool000003Oooool2o`00013ooooo00?o0000ooooool000003oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo013ooooo0_l0
000?ooooo`03o`000?oooooooooo01Sooooo0_l0001]ooooo`03o`000?oooooooooo00Oooooo000=
ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0
0009ooooo`;o00004oooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0000Eooooo`04o`000?ooooooooooo`0000cooooo00?o0000oooo
ooooool06_ooool2o`0006cooooo00?o0000ooooooooool01oooool0013ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003o000000_ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1Xooooo`?o00002Oooool0013ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`;o0000
:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
1oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00?ooooo0_l0000Wooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008oooool2o`0002;ooooo00?o0000ooooooooool0JOoo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooooooool2o`00023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Go0000
ooooooooooooooooo`000006ooooo`;o00007Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo01Sooooo0_l0000Vooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool0000:ooooo`;o00005_ooool2o`0002Oooooo00?o0000ooooooooool0Jooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo
ooooo`0000cooooo0_l0000Aooooo`?o0000:Oooool00ol0003oooooooooo`1[ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00003_oo
ool5o`0000[ooooo0_l0000/ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`04o`000?ooooooooooo`0001?ooooo2_l0000]ooooo`03o`000?oo
oooooooo06_ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo
ooooo`0004[ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0004Wooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo
ooooo`0004Wooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0004Sooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?oooooo
ooooo`0004Sooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool2
o`0003cooooo00Co0000oooooooooooo0000Aoooool00ol0003oooooooooo`1^ooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool00017ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
1?l0003oooooooooool00016ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000004Gooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`05o`000?ooooooooooooooool00000A?ooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`1booooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Loooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool01oooool000Oooooo0ol00004
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Wooooo0_l0001hooooo`03o`000?oooooooooo00Oooooo0008oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool01oooool000Sooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Cooooo
0_l0001kooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000??ooool00ol0003o
ooooooooo`07ooooo`;o0000<oooool00ol0003oooooooooo`1iooooo`?o00002Oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`07ooooo`001oooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0/ooooo`;o0000Ooooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`00
00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Wooooo0_l00021ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0=ooooo`;o00009Oooool2o`0008Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo00oooooo0_l0000Qooooo`;o0000QOooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04Oooool3o`0001_ooooo0ol00028
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool05?ooool3o`0001Cooooo1?l0002;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool05oooool6o`0000[ooooo1?l0002?ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
7Oooool:o`0009?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooo
ooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001oooool3o`0000?ooooo0ol00004oooo
o`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool000Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool0
0ol0003oooooooooo`2hooooo`?o00002Oooool000Sooooo00Co0000oooooooooooooooo1?l00003
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00000oooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go00000ooo
ool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wo
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Kooooo1Ol00003
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3ooooo
o`Sooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`000?oooooo2_ooool000Kooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`00
1oooool3o`0000Cooooo0_l00004ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0
000Vooooo`?o0000=?ooool00ol0003oooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11
ooooo`00D_ooool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool00ol00002oooo
o`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?ooooo
o`000?l000000_l00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3
o`0000?ooooo1?l000001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l0
0008ooooo`Go00001?ooool00ol0003oooooooooo`10ooooo`00DOooool01_l0003oooooooooool0
003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`?o00000_oo
ool5o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo043ooooo001@ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooooooo00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000_ooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002
ooooo`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o0000
0oooool4o`0000?ooooo1Ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co
00000oooool3o`0000Sooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000So
oooo1?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo047ooooo001Aooooo`04o`000?ooooooooooo`0001Gooooo00?o0000oooo
ooooool06_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`12ooooo`00D_ooool3o`0001?ooooo0ol00005ooooo`03o`000?oooooo
oooo01?ooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo0_l0000_ooooo`03o`000?oooooo
oooo00Wooooo0ol00018ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.355 .4475 .10375 0 365.73 arc
s
newpath
.355 .4475 .00323 0 365.73 arc
s
newpath
.41151 .36049 .00323 0 365.73 arc
s
newpath
.24334 .0853 .00323 0 365.73 arc
s
newpath
.47929 .47142 .00323 0 365.73 arc
s
newpath
.36574 .19678 .00323 0 365.73 arc
s
.355 .4475 m
.36574 .19678 L
s
.355 .4475 m
.41151 .36049 L
s
.36574 .19678 m
.24334 .0853 L
s
.41151 .36049 m
.24334 .0853 L
.47929 .47142 L
.41151 .36049 L
s
gsave
.36575 .43675 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.42226 .37124 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.25409 .09605 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.49004 .48217 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.37649 .18603 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->-12,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>_oo
ool2o`000;cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>Oooool3
o`000;cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>Oooool4o`00
0;_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>_ooool2o`000003
ooooool0003ooooo0;Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>_ooool5o`000;Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000kooooo`?o00000_oo
ool00ol0003oooooooooo`2eooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>_ooool2
o`000005ooooool0003oooooooooool00000]oooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0jooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`2d
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Wooooo1?l000000ooo
oooo0000ooooo`02ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool01oooool000Oo
oooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Oooooo0005o`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
0_l0000looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`2^ooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[oooool00ol0003o
ooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo
00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l0002]ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`2Xooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Z?ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0YOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Tooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooo`000003o`0000Cooooo0_l0002Hooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo09Kooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Wooooo0_l00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool3o`0000?ooooo00Co0000oooo
oooooooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool4o`0000;ooooo00Co0000oooo
oooooooo0000V?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool01?l0003oooooo`000?l00002
ooooo`04o`000?ooooooooooo`0009Sooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool5o`0000?ooooo0_l0002H
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo09gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0W?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09go
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0WOooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo000=
ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`07
ooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00Oooooo0006ooooo`Go00001Oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Kooooo`?o00002Ooo
ool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo09gooooo00?o0000ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`05o`000?oo
ooooooooooooool00000Woooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Fooooo`05o`000?ooooooooooooooool00000Woooool00ol0003oooooooooo`07ooooo`00
3?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooo`00002Pooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool06?ooool2o`000:3ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`;o0000X?ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`2Mooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Iooooo`;o0000Woooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01Wooooo0_l0002Oooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003oooooo`00
002Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooo`00002Nooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool0002M
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Ioooo
o`05o`000?ooooooooooooooool00000Voooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000009cooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo09Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Uooo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo09Kooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2Fooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Ko
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0UOooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04oooool<o`0000Cooooo00?o0000
ooooooooool0U?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00kooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`03o`000?oooooooooo09?ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo00cooooo0_l0000;ooooo`03o`000?oooooooooo00Gooooo1?l0002Dooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`0009?ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool3o`0009;ooooo00?o0000ooooooooool01ooo
ool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool2
o`0000oooooo00?o0000ooooooooool02Oooool3o`000004ooooool0003o0000o`0008kooooo00?o
0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00Kooooo0_l0000Aooooo`03o`000?oooooooooo00Wooooo1_l0
002?ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`000004o`0008oooooo00?o0000ooooooooool01ooo
ool001?ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo000Cooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01oooool01ol0003ooooooooooooooooo0000ooooool0
00000_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`;o
00000_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o0000
1Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo0_l000001Ooooooo0000
oooooooooooo000008cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooo000008cooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0008_ooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`04o`000?ooooooooooo`0001Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0008Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0008[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003oooooooooool0
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool01?l0003ooooooooo
ool00029ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooool000006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooool00000ROooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`04o`000?ooooooooooo`0008Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool2o`0001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooo000008Sooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`;o00006Oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooool00000Qoooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Eooooo`;o000000Goooooo`00
0?l0003o0000ooooo`03o`0001;ooooo0_l00028ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo0_l0000Eooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool0000Booooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool2o`0001Gooooo1Ol000000ooooooo0000o`000002
ooooo`03o`000?oooooooooo013ooooo0_l00027ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo0_l0000Fooooo`05o`000?oooooo0000o`000?ooool00_l00002
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00005_ooool00ol0003oooooo`000002o`00
0005ooooool0003oooooooooool000004oooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Gooooo`Co000000Goooooo`00
0?ooooooooooo`00000Cooooo`;o0000Q_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo0_l0000Fooooo`Co00000oooool2o`0001Cooooo00?o0000ooooool00000Q?ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000cooooo`03o`000?oooooo000008Go
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`0003?ooooo
00Co0000oooooooooooo0000Q?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`;o0000<oooool01?l0003oooooooooool00024ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000booooo`03o`000?oooooooooo00;ooooo
0_l00022ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0
000booooo`03o`000?oooooooooo00;ooooo0ol00021ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool2o`0001Kooooo<ol0001aooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooo`00000?ooooo`Ko00007?ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000cooooo0ol0001_ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooool000003Oooool2o`0002;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`00000<ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool2o`00017ooooo0_l0001]ooooo`03
o`000?oooooooooo00Oooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
>oooool01?l0003oooooooooool00009ooooo`;o00009?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo0000017ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`00
3?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0000Kooooo0ol0000Uooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooo00004?ooool2o`0006cooooo00?o0000ooooooooool01ooo
ool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`05ooooo`?o000000?oooooo`000?l000004?ooool00ol0003oooooooooo`1Xooooo`?o0000
2Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`003?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`03ooooo`;o0000:?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo00?ooooo0_l0000Wooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008oooool2o`0002;o
oooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`00023ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00007Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01So
oooo0_l0000Vooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooool0000:ooooo`;o00005_ooool2o`0002Oo
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`04o`000?ooooooooooo`0000cooooo0_l0000Aooooo`?o0000:Oooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00Co0000oooooooooooo00003_ooool5o`0000[ooooo0_l0000/ooooo`03o`000?oooooooooo06_o
oooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`04o`000?ooooooooooo`0001?o
oooo2_l0000]ooooo`03o`000?oooooooooo06_ooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`04o`000?ooooooooooo`0004[ooooo00?o0000ooooooooool0K?ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0004Wo
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`04o`000?ooooooooooo`0004Wooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0004So
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`04o`000?ooooooooooo`0004Sooooo00?o0000ooooooooool0K_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00Co0000oooooooooooo0000Aoooool00ol0003o
ooooooooo`1^ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool01?l0003ooooo
ooooool00017ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool01?l0003oooooooooool00016ooooo`03o`000?oooooooooo073o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool01Ol0003ooooo
oooooooooooo000004Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool00000A?ooool00ol0003o
ooooooooo`1aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`1booooo`;o00002Oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`1doooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo07Gooooo00?o0000oooooooo
ool01oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Wooooo0_l0001hooooo`03o`00
0?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03Cooooo0_l0001kooooo`03o`000?oooooooooo00Oooooo0008ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`;o0000??ooool00ol0003oooooooooo`07ooooo`;o0000<oooool00ol0003oooooooooo`1i
ooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0O?ooool00ol0003ooooooooo
o`07ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0/ooooo`;o0000Ooooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Wooooo0_l00021ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0=ooooo`;o00009Oooool2o`0008Cooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00oooooo0_l0000Qooooo`;o
0000QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
4Oooool3o`0001_ooooo0ol00028ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool05?ooool3o`0001Cooooo1?l0002;ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05oooool6
o`0000[ooooo1?l0002?ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool07Oooool:o`0009?ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Ooo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001ooo
ool3o`0000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`2hooooo`?o00002Oooool000Sooooo00Co
0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o0000
0oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`04o`00
0?ooooooooooooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Kooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Coooooo?l00009
ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`3oooooo`Sooooo0006ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo2_ooool000Kooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo0000ooooool:ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o0000ooooool;oooo
o`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000=?ooool00ol0003oooooooooo`12ooooo`00
Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2o`0000?ooooo0ol00004ooooo`;o000000?o
ooooo`000?ooool00ol00002ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`00
0?l0003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`?o00001?ooool4o`0000?ooooo
0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00009ooooo`Co
00000oooool3o`0000Cooooo0_l00008ooooo`Go00001?ooool00ol0003oooooooooo`10ooooo`00
DOooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`05o`000?ooooooooooooooool000003_ooool00ol0003oooooo`000006ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`10ooooo`00D?oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003o
ooooooooo`09ooooo`?o00000_ooool5o`0000;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo0ol00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooooooool2o`0000Wooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`00
0?oooooooooo00Cooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`04
o`000?ooooooooooooooo`?o00000oooool4o`0000?ooooo1Ol00007ooooo`04o`000?oooooooooo
o`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Sooooo1?l00003ooooo`;o00000oooool2
o`000003ooooool0003o000000Sooooo1?l00002ooooo`?o00000_ooool4o`0000Sooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo047ooooo001Aooooo`04o`000?oooooo
ooooo`0001Gooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`12ooooo`00D_ooool3o`0001?ooooo
0ol00005ooooo`03o`000?oooooooooo01?ooooo1?l00009ooooo`03o`000?oooooooooo00;ooooo
0_l0000_ooooo`03o`000?oooooooooo00Wooooo0ol00018ooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["par set 3  (\[Psi]->f\[Psi]", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(par3 = {A0x \[Rule] 22, 
        A0y \[Rule] 59, \[Gamma]0 \[Rule] \(-57\)\ \[Degree], a \[Rule] 58.5, 
        b \[Rule] 180, c \[Rule] 115 + 47, 
        d \[Rule] 85 + 35.5, \[Kappa] \[Rule] 0\ Degree, 
        k \[Rule] 47}\)], "Input",
  CellChangeTimes -> {{3.419852365989037*^9, 3.4198524491248837`*^9}}],

Cell[BoxData[
    \({A0x \[Rule] 22, A0y \[Rule] 59, \[Gamma]0 \[Rule] \(-57\)\ \[Degree], 
      a \[Rule] 58.5`, b \[Rule] 180, c \[Rule] 162, 
      d \[Rule] 120.5`, \[Kappa] \[Rule] 0, k \[Rule] 47}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(xKpar = \(\(xK /. \[Delta] -> f\[Delta]\) /. \[Psi] -> f\[Psi]\) /. 
          par3;\)\), "\n", 
    \(\(yKpar = \(\(yK /. \[Delta] -> f\[Delta]\) /. \[Psi] -> f\[Psi]\) /. 
          par3;\)\), "\n", 
    \(\(plo3\  = \ 
        ParametricPlot[{xKpar, yKpar}, {\[CurlyPhi], 0\ Degree, 360\ Degree}, 
          PlotRange \[Rule] {{0, 130}, {0, 120}}, 
          GridLines \[Rule] Automatic, 
          PlotLabel \[Rule] "\<Path of K - par set 2\>"];\)\)}], "Input",
  CellChangeTimes -> {{3.4198524708446827`*^9, 3.4198524779235077`*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.00769231 0 0.00515028 [
[.15385 -0.0125 -6 -9 ]
[.15385 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.46154 -0.0125 -6 -9 ]
[.46154 -0.0125 6 0 ]
[.61538 -0.0125 -6 -9 ]
[.61538 -0.0125 6 0 ]
[.76923 -0.0125 -9 -9 ]
[.76923 -0.0125 9 0 ]
[.92308 -0.0125 -9 -9 ]
[.92308 -0.0125 9 0 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.15385 0 m
.15385 .61803 L
s
.30769 0 m
.30769 .61803 L
s
.46154 0 m
.46154 .61803 L
s
.61538 0 m
.61538 .61803 L
s
.76923 0 m
.76923 .61803 L
s
.92308 0 m
.92308 .61803 L
s
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.15385 0 m
.15385 .00625 L
s
[(20)] .15385 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(40)] .30769 -0.0125 0 1 Mshowa
.46154 0 m
.46154 .00625 L
s
[(60)] .46154 -0.0125 0 1 Mshowa
.61538 0 m
.61538 .00625 L
s
[(80)] .61538 -0.0125 0 1 Mshowa
.76923 0 m
.76923 .00625 L
s
[(100)] .76923 -0.0125 0 1 Mshowa
.92308 0 m
.92308 .00625 L
s
[(120)] .92308 -0.0125 0 1 Mshowa
.125 Mabswid
.03846 0 m
.03846 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.5 0 m
.5 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(20)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(40)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(60)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(80)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(100)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(120)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
123.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(par) show
159.000 13.000 moveto
(set) show
183.000 13.000 moveto
(2) show
189.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.69285 .20551 m
.7275 .20473 L
.76373 .20384 L
.78114 .20346 L
.79044 .20329 L
.79903 .20316 L
.80286 .20312 L
.80687 .20308 L
.80894 .20306 L
.81121 .20305 L
.81517 .20303 L
.81872 .20303 L
.82249 .20303 L
.82601 .20305 L
.82919 .20307 L
.83128 .20309 L
.83324 .20312 L
.83687 .20318 L
.84072 .20325 L
.84482 .20336 L
.85205 .2036 L
.8585 .20389 L
.86537 .20429 L
.87265 .20482 L
.88653 .20623 L
.8979 .20787 L
.90916 .21006 L
.91893 .21255 L
.92713 .21518 L
.93478 .21821 L
.94219 .22182 L
.95369 .22931 L
.95912 .23399 L
.96361 .23873 L
.96786 .24423 L
.97175 .25064 L
.9746 .25671 L
.97672 .26263 L
.97841 .26914 L
.97912 .27289 L
.97961 .27636 L
.97979 .27796 L
.97995 .27966 L
.98006 .28114 L
.98015 .28274 L
.98022 .28447 L
.98026 .2861 L
.98027 .2871 L
.98027 .28806 L
.98024 .28985 L
Mistroke
.98019 .29143 L
.98011 .29312 L
.98002 .29472 L
.9799 .29618 L
.97955 .2998 L
.97911 .30323 L
.97788 .31039 L
.97603 .31838 L
.97075 .33488 L
.96405 .35049 L
.95627 .36524 L
.93318 .39913 L
.90605 .42956 L
.86938 .4622 L
.83009 .49042 L
.73818 .53915 L
.68832 .5583 L
.6306 .57543 L
.57454 .5875 L
.54259 .5925 L
.52838 .5943 L
.51321 .59595 L
.49803 .5973 L
.48427 .59827 L
.47764 .59865 L
.47047 .599 L
.46375 .59927 L
.45748 .59947 L
.45367 .59957 L
.45018 .59965 L
.44632 .59971 L
.4442 .59973 L
.44218 .59975 L
.44024 .59977 L
.43817 .59978 L
.43447 .59978 L
.43241 .59978 L
.43048 .59977 L
.42837 .59975 L
.42609 .59973 L
.42261 .59968 L
.4188 .5996 L
.41115 .5994 L
.40408 .59914 L
.39753 .59885 L
.3832 .598 L
.36779 .59677 L
.34027 .59376 L
.31409 .58986 L
.29057 .58545 L
Mistroke
.24339 .57374 L
.19559 .55731 L
.15517 .53881 L
.11725 .51609 L
.08525 .49066 L
.07281 .4783 L
.0612 .46476 L
.05129 .45088 L
.04383 .4381 L
.03781 .42512 L
.03351 .41283 L
.03179 .4064 L
.03032 .39934 L
.02974 .39579 L
.02925 .39199 L
.02906 .39015 L
.0289 .38841 L
.02879 .38686 L
.02869 .38515 L
.02861 .38357 L
.02857 .38209 L
.02854 .38053 L
.02853 .37885 L
.02855 .37738 L
.02858 .37583 L
.02863 .37451 L
.02871 .37306 L
.02882 .37135 L
.02894 .36979 L
.02929 .36631 L
.02972 .3631 L
.03021 .36007 L
.03148 .35389 L
.03329 .34716 L
.03825 .33381 L
.04438 .32178 L
.05144 .31087 L
.06128 .2986 L
.07218 .28748 L
.09665 .26819 L
.12854 .25006 L
.16319 .23587 L
.18535 .22891 L
.20765 .2232 L
.22871 .21881 L
.25309 .21474 L
.27903 .21143 L
.29279 .21003 L
.30793 .20876 L
.32253 .20775 L
Mistroke
.33616 .20699 L
.35019 .20638 L
.36377 .20592 L
.37854 .20555 L
.38709 .2054 L
.39521 .20529 L
.39962 .20524 L
.40385 .2052 L
.40771 .20518 L
.41185 .20515 L
.41636 .20514 L
.42057 .20513 L
.42316 .20513 L
.42561 .20512 L
.43021 .20513 L
.43395 .20514 L
.43807 .20515 L
.44241 .20517 L
.44647 .20519 L
.46174 .2053 L
.47868 .20546 L
.4972 .20567 L
.5362 .2061 L
.5471 .2062 L
.55876 .2063 L
.56878 .20636 L
.57419 .20639 L
.5799 .20642 L
.58487 .20643 L
.5875 .20644 L
.59032 .20645 L
.59528 .20646 L
.59991 .20646 L
.6027 .20646 L
.60574 .20645 L
.60861 .20645 L
.61125 .20644 L
.61626 .20643 L
.62158 .20641 L
.63123 .20635 L
.64026 .20628 L
.65015 .20618 L
.66074 .20605 L
.69285 .20551 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249.875, 154.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i0000VR000`400?l00000o`00003onOooool0
03Wooooo1Ol00003ooooo`;o00006?ooool3o`0000?ooooo0_l0000Fooooo`?o00001?ooool2o`00
01Oooooo0ol00004ooooo`;o00005?ooool3o`0000Cooooo0_l00004ooooo`;o00004?ooool3o`00
00;ooooo1Ol00003ooooo`;o00005Oooool003[ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`0Booooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Eooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000Doooo
o`00>oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Gooooo1Ol00002oooo
o`04o`000?ooooooooooo`0001Cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0001Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
01Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`00013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0001Cooooo000looooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`0Cooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00005?ooool4o`00
00?ooooo00Co0000oooooooooooo00005_ooool3o`0000?ooooo00Co0000oooooooooooo00005?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00004?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`0Booooo`00>Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00005_ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001Cooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000Eooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01;ooooo000iooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Gooooo`;o00000oooool01?l0
003oooooooooool0000Eooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00005Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00004oooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000?ooooo`;o00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00005?ooool003[ooooo0ol0
0004ooooo`;o00006Oooool00ol0003oooooooooo`02ooooo`;o00005oooool2o`0000Cooooo0_l0
000Gooooo`?o00001?ooool2o`0001Gooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0
000Aooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o00005Oooool00?Wooooo003ioooo
o`00nOooool00?Wooooo000Ooooooloo00002oooool001oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool0
01oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo
00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo
00?o001oooooooooool06Oooool001oooooo0_l0000Nooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0M
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0M
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0I
ooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0Mooooo`03
o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`00
7oooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7?ooool00ol007ooooooooooo`0Iooooo`007oooool2o`0001kooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooo
oooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooo
oooo01Wooooo000Oooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01go
oooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wo
oooo000Oooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01gooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000O
ooooo`;o00007_ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001o
ooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool0017ooooo1Ol00003ooooo`;o
00001?ooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`0Iooooo`004_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Moooo
o`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01gooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Dooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool3o`000<co001o2oooool0
017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool06Oooool0017ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00?o001oooooooooool06Oooool001;ooooo0ol00004ooooo`;o00001?oo
ool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?oo
ool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?oo
ool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool2o`00
01kooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo
01Wooooo000Oooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01gooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo
00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo
000Oooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01gooooo00?o001o
ooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001o
ooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Ooooo
o`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo01Wooooo000Oooooo`;o00007_ooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool0
7Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool0
6Oooool001oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool0
01oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool06Oooool001oooooo0_l0000Nooooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003ooooo
ooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooo
ooooo`0Iooooo`007oooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`004oooool3o`0000?ooooo0_l00004
ooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo01Wooooo000Dooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000001oooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`05ooooo`Co00004oooool00ol007ooooooooooo`0Iooooo`004Oooool5o`0000;ooooo00Co0000
oooooooooooo00000oooool3o`0003oo001oIOl00004o`00Oa3o00005?l007l;ooooo`004Oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`0Dooooo`_o00007Oooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01gooooo00?o001oooooooooool06Oooool4o`0001_ooooo000Booooo`03o`000?oo
oooo000000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Mooooo`03o`00
Oooooooooooo00oooooo1Ol00009ooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool0
7Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oo`000?l00000
6Oooool001?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`0:ooooo`Go00003_ooool00ol007ooooooooooo`0Looooo`03o`00
Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00
Oooooooooooo00?o00005_ooool001Cooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o
0000ooooooooool07Oooool00ol007ooooooooooo`06ooooo`Co00004oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo00?ooooo00?o0000ooooooooool04oooool001oooooo0_l0000N
ooooo`04o`00Ooooooooooooooooo`Go00005oooool00ol007ooooooooooo`0Looooo`03o`00Oooo
oooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooo
oooooooo00Cooooo00?o0000ooooooooool04_ooool001oooooo00?o0000ooooooooool07Oooool0
1?l007oo0000o`000?l0000Looooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool01Ooo
ool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`0Kooooo`?o00007oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00Kooooo00?o0000ooooooooool04?ooool0
01oooooo00?o0000ooooooooool06Oooool2o`0000;ooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Looooo`03o`00Oooooooooooo00Oooooo00?o0000ooooooooool03oooool001oo
oooo00?o0000ooooooooool05oooool2o`0000Cooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Looooo`03o`00Oooooooooooo00Oooooo00?o0000ooooooooool03oooool001oooooo
00?o0000ooooooooool05Oooool2o`0000Kooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Looooo`03o`00Oooooooooooo00Oooooo00?o0000ooooooooool03oooool001oooooo0_l0
000Eooooo`03o`000?oooooooooo00Kooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooooooo
o`0Looooo`03o`00Oooooooooooo00Sooooo00?o0000ooooooooool03_ooool001oooooo00?o0000
ooooooooool04_ooool2o`0000Wooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo00Sooooo00?o0000ooooooooool03_ooool001oooooo00?o0000oooo
ooooool04?ooool2o`0000_ooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Loooo
o`03o`00Oooooooooooo00Wooooo00?o0000ooooooooool03Oooool001oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0;ooooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooooooo
ool07?ooool00ol007ooooooooooo`09ooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00?o001oooooooooool02Oooool00ol0003oooooooooo`0=ooooo`007ooo
ool2o`0000kooooo00?o0000ooooooooool03Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01cooooo00?o001oooooooooool02Oooool00ol0003oooooooooo`0=ooooo`007oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00Wooooo00?o0000ooooooooool03Oooool0
01oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`09ooooo`03o`000?oooooooooo
00gooooo000Booooo`?o00001?ooool2o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0@ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oo
ooooooooo`09ooooo`03o`000?oooooooooo00gooooo000Aooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001ooooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`004Oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000oooool3o`0000Wo001o00?o0000o`00Ool007l0^ol007l0
0ol0003o001oo`00O`02o`00O`_ooooo000Aooooo`Co00000oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol007ooooooooooo`0M
ooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0M
ooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool02Oooool00ol0003oooooooooo`0=
ooooo`004Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`00Oooooooooooo01gooooo00?o001o
ooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001o
ooooooooool07?ooool00ol007ooooooooooo`08ooooo`03o`000?oooooooooo00kooooo000Boooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo00Sooooo00?o0000ooooooooool03_ooool001?ooooo0_l00004oooo
o`;o00001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo00Sooooo00?o0000oooo
ooooool03_ooool001oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03
o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`07ooooo`03
o`000?oooooooooo00oooooo000Oooooo`;o00001_ooool00ol0003oooooooooo`0Eooooo`03o`00
Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`07ooooo`03o`00
0?oooooooooo00oooooo000Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_oo
ool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool01ooo
ool00ol0003oooooooooo`0?ooooo`007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Kooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooo
oooo00Kooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Fooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol0
07ooooooooooo`06ooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05_ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01co
oooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01co
oooo00?o001oooooooooool01_ooool00ol0003oooooooooo`0@ooooo`007oooool2o`0000Cooooo
0_l0000Hooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooo
ooooo`05ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool05oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o
001oooooooooool01?ooool00ol0003oooooooooo`0Booooo`007oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Oooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo00Cooooo00?o0000ooooooooool04_ooool001oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Gooooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07?ooool00ol007ooooooooooo`03ooooo`03o`000?oooooooooo01?ooooo000Oooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool00_ooool00ol0003oooooooooo`0Dooooo`00
7oooool2o`0000Cooooo00?o0000ooooooooool05oooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00Go001oooooooooooooooooo`00000Gooooo`007oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Looooo`05o`00Ooooooooooooooooool000005oooool001oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Gooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool0
7?ooool01?l007ooooooooooool0000Hooooo`004_ooool3o`0000Cooooo0_l00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00
Oooooooooooo01cooooo00?o001oooooool000006Oooool0017ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Fooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oo
ooooo`00000Iooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Ool0003ooooo01Wooooo000Booooo`?o
00000oooool01?l0003oooooooooool00003ooooo`?o00001?l007l00ol0003o001oo`00O`2do`00
O`03o`000?l007oo001o00ko001o2oooool0017ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0F
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0M
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool06oooool00ol0003o001oooooo`0J
ooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Jooooo`03o`000?oooooo001o01_ooooo000Booooo`?o00001?ooool2
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01gooooo00?o001oooooooooool06?ooool2o`0000;ooooo00?o001oooooooooool06Oooool0
01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo
01gooooo00?o001oooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00Oooooooooooo
01Wooooo000Oooooo`;o00001oooool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01go
oooo00?o001oooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`00Oooooooooooo01Wo
oooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol007oooooo
ooooo`0Iooooo`007oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07Oooool00ol007ooooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o
001oooooooooool06Oooool001oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0B
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0M
ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool04oooool00ol0003oooooooooo`06
ooooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001ooooo
ooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01;ooooo00?o0000oooo
ooooool01oooool00ol007ooooooooooo`0Iooooo`007oooool2o`0000_ooooo00?o0000oooooooo
ool04?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001ooooooooo
ool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo013ooooo0_l0000:ooooo`03
o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
4?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool0
7Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo00oooooo00?o0000ooooooooool0
2_ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00oooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Looooo`03o`00Oooo
oooooooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0>ooooo`03o`000?oo
oooooooo00_ooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0>ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool03?ooool2
o`0000kooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool02oooool00ol0
003oooooooooo`0>ooooo`03o`00Oooooooooooo01Wooooo000Oooooo`;o00003oooool00ol0003o
ooooooooo`0<ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool02_ooool00ol0003o
ooooooooo`0?ooooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo00oooooo
0_l0000<ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool02?ooool2o`0001;ooooo
00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`09ooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07?ooool00ol007oooooooooo
o`0Mooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool01_ooool2o`0001Cooooo00?o
001oooooooooool06Oooool000cooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`00Oooooooooooo01gooooo00?o001o
ooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o001o
ooooooooool01?ooool2o`0001Kooooo00?o001oooooooooool06Oooool000gooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo00?o
001oooooooooool00_ooool2o`0001Sooooo00?o001oooooooooool06Oooool000gooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`00Oooooooooooo01gooooo
00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01gooooo
00?o001oooooooooool00_l0000Jooooo`03o`00Oooooooooooo01Wooooo000=ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`?o
00005Ol007l2o`0008Oo001o00?o0000o`00Ool007l0:ol007l;ooooo`003Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool07Oooool2o`00
01gooooo00?o001oooooooooool06Oooool000cooooo0_l00004ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Hooooo`;o00000oooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Kooooo`;o000000?o001oooooooooool07?ooool00ol007ooooooooooo`0I
ooooo`003Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo00?o0000oooo
ooooool06_ooool2o`000003ooooool007oooooo01kooooo00?o001oooooooooool07?ooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01Wooooo0_l00002ooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool07?ooool00ol0003o
001oooooo`0Nooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007oo
ooooooooo`0Gooooo`;o00001?ooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wo
oooo000Oooooo`;o00007_ooool3o`0001gooooo00?o001oooooooooool07?ooool00ol007oooooo
ooooo`0Mooooo`03o`00Oooooooooooo01Gooooo0_l00006ooooo`03o`00Oooooooooooo01cooooo
00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool00ol007oooooooooo
o`03o`0001[ooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooo
oooooooo01;ooooo0ol00008ooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Ooo
ool001oooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`03ooooo`?o00005oooool0
0ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool04?ooool2
o`0000_ooooo00?o001oooooooooool07?ooool00ol007ooooooooooo`0Iooooo`007oooool00ol0
003oooooooooo`0Mooooo`03o`00Oooooooooooo00Kooooo0_l0000Eooooo`03o`00Oooooooooooo
01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0=ooooo`?o00003Oooool00ol0
07ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooooooo01go
oooo00?o001oooooooooool02?ooool2o`0001?ooooo00?o001oooooooooool07?ooool00ol007oo
ooooooooo`0Mooooo`03o`00Oooooooooooo00[ooooo0ol0000@ooooo`03o`00Oooooooooooo01co
oooo00?o001oooooooooool06Oooool001oooooo0_l0000Nooooo`03o`00Oooooooooooo00[ooooo
0ol0000@ooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol007oooooo
ooooo`06ooooo`Co00004oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo
000Oooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool03Oooool2o`0000kooooo00?o
001oooooooooool07?ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo00;ooooo1?l0
000Gooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000
ooooooooool07Oooool00ol007ooooooooooo`0?ooooo`Co00002_ooool00ol007ooooooooooo`0L
ooooo`03o`00Oooooooooooo01gooooo00?o001oo`000?l000000_l0000Kooooo`03o`00Oooooooo
oooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool07Oooool00ol0
07ooooooooooo`0Cooooo`Go00001Oooool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo
01[ooooo1?l0000Oooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oo
oooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Hooooo`Go000000?o001ooooooooo
ool07?ooool00ol007ooooooooooo`0Gooooo`?o00000oooool00ol007ooooooooooo`0Mooooo`03
o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool001oooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`0Mooooo`Go00006_ooool00ol007ooooooooooo`0Booooo`Go0000
1_ooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool0
6Oooool001oooooo0_l0000Nooooo`03o`00Oooooooooooo01gooooo00?o001oooooooooool00_oo
ool5o`0001Gooooo00?o001oooooooooool01oooool;o`0000_ooooo00?o001oooooooooool07Ooo
ool00ol007ooooooooooo`0Looooo`03o`00Oooooooooooo01Wooooo000Oooooo`03o`000?oooooo
oooo01gooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`07oooooaoo00005_ooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool0
00cooooo0ol00002ooooo`Go00000oooool2o`0000Cooooo00?o0000ooooooooool07Oooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool00ol0
07ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool000go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01cooooo00?o001oooooooooool07Oooool00ol007ooooooooooo`0Mooooo`03o`00Oooooooo
oooo01cooooo00?o001oooooooooool06Oooool000gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07Oooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool07Oooool0
0ol007ooooooooooo`0Mooooo`03o`00Oooooooooooo01cooooo00?o001oooooooooool06Oooool0
00gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooooooo0ol0003<o`00O`_ooooo000=ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0=_ooooo000<ooooo`;o00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000gOooool000gooooo
00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0003Nooooo`00Soooool3o`0006Oooooo002@
ooooo`03o`000?oooooooooo06Kooooo0017ooooo`?o00001?ooool4o`0000?ooooo0_l00002oooo
o`Ko00001oooool3o`0000;ooooo1Ol00007ooooo`?o000000?oooooo`000?l000004oooool3o`00
00?ooooo1?l000001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00008
ooooo`Go0000=Oooool004Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000Doooo
o`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooool000001_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
03Gooooo0018ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`000009ooooo`Co00002?ooool01?l0003oooooooooool0
0002ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`?o00000_ooool5o`0000;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0eooooo`00B?ooool3o`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo0_l0000Fooooo`06
o`000?ooooooooooo`000?oooooo00000_ooool01?l0003oooooooooooooool2o`0000Wooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0dooooo`00B?ooool01?l0003oooooooooool00002ooooo`;o0000
0oooool4o`0000?ooooo0ol00009ooooo`?o00000oooool4o`0000Sooooo00?o0000ooooool00000
5?ooool4o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo
0ol00002ooooo`Co00002?ooool01Ol0003ooooooooooooooooo000003Gooooo0018ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000>?ooool00ol0003oooooooooo`08oooo
o`05o`000?ooooooooooooooool00000=Oooool004Oooooo1?l00009ooooo`03o`000?oooooooooo
00;ooooo0_l0000Cooooo`;o00001oooool3o`000003ooooool0003o000003Oooooo00?o0000oooo
ooooool02Oooool3o`0003Kooooo003iooooo`00nOooool00001\
\>"],
  ImageRangeCache->{{{0, 248.875}, {153.375, 0}} -> {-20.0782, -10.9164, \
0.631499, 0.943189}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[plo1, plo2, plo3, 
        PlotLabel \[Rule] "\<Path of K - par set 1+2+3\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.77556e-17 0.00769231 0 0.00515028 [
[.15385 -0.0125 -6 -9 ]
[.15385 -0.0125 6 0 ]
[.30769 -0.0125 -6 -9 ]
[.30769 -0.0125 6 0 ]
[.46154 -0.0125 -6 -9 ]
[.46154 -0.0125 6 0 ]
[.61538 -0.0125 -6 -9 ]
[.61538 -0.0125 6 0 ]
[.76923 -0.0125 -9 -9 ]
[.76923 -0.0125 9 0 ]
[.92308 -0.0125 -9 -9 ]
[.92308 -0.0125 9 0 ]
[-0.0125 .10301 -12 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -12 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -12 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -12 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -18 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -77 0 ]
[.5 .63053 77 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .61803 L
s
.15385 0 m
.15385 .61803 L
s
.30769 0 m
.30769 .61803 L
s
.46154 0 m
.46154 .61803 L
s
.61538 0 m
.61538 .61803 L
s
.76923 0 m
.76923 .61803 L
s
.92308 0 m
.92308 .61803 L
s
0 0 m
1 0 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 .61803 m
1 .61803 L
s
0 g
.15385 0 m
.15385 .00625 L
s
[(20)] .15385 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(40)] .30769 -0.0125 0 1 Mshowa
.46154 0 m
.46154 .00625 L
s
[(60)] .46154 -0.0125 0 1 Mshowa
.61538 0 m
.61538 .00625 L
s
[(80)] .61538 -0.0125 0 1 Mshowa
.76923 0 m
.76923 .00625 L
s
[(100)] .76923 -0.0125 0 1 Mshowa
.92308 0 m
.92308 .00625 L
s
[(120)] .92308 -0.0125 0 1 Mshowa
.125 Mabswid
.03846 0 m
.03846 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.5 0 m
.5 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .10301 m
.00625 .10301 L
s
[(20)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(40)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(60)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(80)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(100)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(120)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .02575 m
.00375 .02575 L
s
0 .0515 m
.00375 .0515 L
s
0 .07725 m
.00375 .07725 L
s
0 .12876 m
.00375 .12876 L
s
0 .15451 m
.00375 .15451 L
s
0 .18026 m
.00375 .18026 L
s
0 .23176 m
.00375 .23176 L
s
0 .25751 m
.00375 .25751 L
s
0 .28327 m
.00375 .28327 L
s
0 .33477 m
.00375 .33477 L
s
0 .36052 m
.00375 .36052 L
s
0 .38627 m
.00375 .38627 L
s
0 .43777 m
.00375 .43777 L
s
0 .46353 m
.00375 .46353 L
s
0 .48928 m
.00375 .48928 L
s
0 .54078 m
.00375 .54078 L
s
0 .56653 m
.00375 .56653 L
s
0 .59228 m
.00375 .59228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -138 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Path) show
93.000 13.000 moveto
(of) show
111.000 13.000 moveto
(K) show
123.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(par) show
159.000 13.000 moveto
(set) show
183.000 13.000 moveto
(1) show
189.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
195.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
201.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
213.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.896 .43677 m
.93601 .39293 L
.95327 .3677 L
.96388 .34812 L
.97012 .33369 L
.97472 .32009 L
.97639 .31388 L
.97777 .30764 L
.97872 .30225 L
.97935 .29757 L
.97976 .29335 L
.97991 .2913 L
.97997 .29015 L
.98002 .2891 L
.98005 .28813 L
.98008 .28711 L
.98009 .28653 L
.98009 .28599 L
.9801 .28499 L
.98009 .28405 L
.98008 .28319 L
.98006 .28226 L
.98003 .28128 L
.98 .28048 L
.97995 .27963 L
.97986 .27812 L
.97971 .27636 L
.97956 .27479 L
.97913 .27143 L
.97854 .26796 L
.97717 .26208 L
.97561 .25708 L
.9736 .25201 L
.96876 .24298 L
.96355 .23591 L
.95728 .2294 L
.95072 .22406 L
.94331 .21927 L
.92883 .21241 L
.92088 .20962 L
.91205 .20711 L
.90335 .20512 L
.89359 .20335 L
.88387 .20197 L
.87463 .20094 L
.86534 .20015 L
.85989 .19978 L
.85483 .19948 L
.84465 .19903 L
.83892 .19885 L
Mistroke
.8334 .19871 L
.82811 .19861 L
.82512 .19857 L
.8224 .19854 L
.81983 .19851 L
.81848 .1985 L
.81704 .1985 L
.81578 .19849 L
.81439 .19848 L
.81378 .19848 L
.81312 .19848 L
.81251 .19848 L
.81193 .19848 L
.81123 .19848 L
.81085 .19848 L
.81045 .19848 L
.81005 .19848 L
.80963 .19848 L
.80887 .19848 L
.80816 .19848 L
.80751 .19848 L
.80679 .19848 L
.80602 .19848 L
.80426 .19849 L
.80261 .1985 L
.79949 .19851 L
.79371 .19856 L
.78736 .19863 L
.77502 .19881 L
.76156 .19905 L
.7362 .19958 L
.7074 .20018 L
.67763 .20072 L
.66157 .20095 L
.65281 .20106 L
.64326 .20116 L
.6346 .20124 L
.62477 .20131 L
.62038 .20134 L
.61558 .20136 L
.61132 .20138 L
.60671 .2014 L
.60418 .2014 L
.60187 .20141 L
.5995 .20141 L
.59729 .20142 L
.5947 .20142 L
.59333 .20142 L
.59263 .20142 L
.59187 .20142 L
Mistroke
.59059 .20142 L
.5894 .20142 L
.58866 .20142 L
.58796 .20142 L
.58665 .20142 L
.58594 .20142 L
.58527 .20142 L
.58401 .20142 L
.58266 .20142 L
.58118 .20142 L
.5785 .20141 L
.57601 .20141 L
.5702 .2014 L
.56393 .20138 L
.55306 .20133 L
.54087 .20127 L
.51716 .20113 L
.50277 .20104 L
.49474 .20099 L
.4858 .20094 L
.47762 .20091 L
.47311 .20089 L
.4681 .20087 L
.46581 .20087 L
.46336 .20086 L
.46124 .20086 L
.45889 .20086 L
.45664 .20086 L
.45419 .20086 L
.45184 .20086 L
.44967 .20086 L
.44784 .20086 L
.44611 .20086 L
.44417 .20087 L
.44207 .20087 L
.43766 .20089 L
.43348 .20091 L
.42948 .20093 L
.42496 .20097 L
.41617 .20105 L
.40474 .20121 L
.39761 .20134 L
.39049 .20149 L
.38305 .20168 L
.37377 .20195 L
.349 .20297 L
Mfstroke
.70552 .19863 m
.74005 .19756 L
.77608 .19636 L
.79337 .19584 L
.8026 .1956 L
.81112 .1954 L
.81888 .19525 L
.8229 .19519 L
.82711 .19514 L
.8306 .19511 L
.8344 .19509 L
.83782 .19508 L
.84098 .19508 L
.84291 .19509 L
.84496 .1951 L
.8486 .19513 L
.8508 .19516 L
.85286 .19519 L
.85666 .19526 L
.8635 .19545 L
.86727 .19559 L
.87067 .19574 L
.8827 .19646 L
.88848 .19694 L
.89461 .19755 L
.90673 .19915 L
.91866 .20136 L
.92896 .20394 L
.93755 .20671 L
.94507 .20973 L
.95234 .21334 L
.96363 .22083 L
.96895 .22553 L
.97336 .23028 L
.97751 .2358 L
.98133 .24224 L
.98411 .24834 L
.98618 .25428 L
.98782 .26081 L
.9885 .26458 L
.98898 .26807 L
.98915 .26967 L
.9893 .27138 L
.9894 .27285 L
.98949 .27447 L
.98955 .27623 L
.98958 .27723 L
.98959 .27814 L
.98959 .27992 L
.98956 .28161 L
Mistroke
.9895 .2832 L
.98942 .28489 L
.98932 .2865 L
.98921 .28797 L
.98884 .2916 L
.9884 .29504 L
.98716 .30223 L
.98531 .31025 L
.98004 .32681 L
.97338 .34248 L
.96565 .35727 L
.9427 .39128 L
.91574 .4218 L
.8793 .45455 L
.84024 .48287 L
.74884 .53182 L
.69923 .55108 L
.64179 .56835 L
.58597 .58055 L
.55416 .58564 L
.54001 .58748 L
.5249 .58916 L
.50978 .59055 L
.49607 .59156 L
.48947 .59196 L
.48232 .59233 L
.47563 .59262 L
.46938 .59283 L
.46211 .59303 L
.45826 .5931 L
.45414 .59316 L
.45207 .59318 L
.44982 .59319 L
.4477 .5932 L
.44574 .59321 L
.44203 .5932 L
.44016 .59319 L
.4381 .59317 L
.43439 .59313 L
.431 .59307 L
.42728 .593 L
.42337 .59289 L
.4168 .59268 L
.40963 .59237 L
.39468 .59152 L
.38068 .59045 L
.35485 .58775 L
.32768 .58385 L
.29905 .57849 L
.24957 .56589 L
Mistroke
.20159 .54882 L
.16171 .52991 L
.12897 .50994 L
.09835 .4857 L
.07583 .46202 L
.05843 .43667 L
.05121 .42203 L
.04621 .40835 L
.04431 .40136 L
.04348 .39768 L
.04273 .3938 L
.04219 .39041 L
.04171 .38668 L
.04154 .38505 L
.04138 .3833 L
.04126 .38177 L
.04116 .38015 L
.04108 .37845 L
.04103 .37688 L
.041 .37519 L
.041 .37423 L
.041 .37333 L
.04102 .37172 L
.04107 .37024 L
.04113 .36862 L
.04123 .36691 L
.04147 .36395 L
.04176 .36119 L
.04267 .35499 L
.04407 .34827 L
.04607 .34107 L
.05095 .32824 L
.05724 .31609 L
.06437 .30524 L
.08349 .28366 L
.09678 .27227 L
.11076 .26225 L
.14378 .24397 L
.17915 .22994 L
.20001 .22356 L
.22059 .21836 L
.24614 .21316 L
.27168 .20912 L
.29828 .20594 L
.31285 .20456 L
.32867 .20334 L
.34239 .20247 L
.35782 .20168 L
.37221 .20111 L
.38593 .20069 L
Mistroke
.40235 .20033 L
.4118 .20019 L
.42064 .20009 L
.42846 .20002 L
.43295 .19999 L
.43718 .19997 L
.44165 .19996 L
.44577 .19995 L
.44805 .19994 L
.45055 .19994 L
.45512 .19994 L
.45961 .19994 L
.46386 .19995 L
.4677 .19996 L
.47187 .19997 L
.48131 .20001 L
.49009 .20005 L
.52379 .20025 L
.54191 .20035 L
.55218 .20039 L
.55707 .2004 L
.56161 .20042 L
.56588 .20042 L
.57043 .20043 L
.57501 .20043 L
.58008 .20043 L
.58445 .20043 L
.58917 .20042 L
.59363 .2004 L
.59773 .20039 L
.60772 .20034 L
.61703 .20027 L
.62727 .20018 L
.63822 .20005 L
.66055 .19969 L
.68073 .19927 L
.70552 .19863 L
Mfstroke
.69285 .20551 m
.7275 .20473 L
.76373 .20384 L
.78114 .20346 L
.79044 .20329 L
.79903 .20316 L
.80286 .20312 L
.80687 .20308 L
.80894 .20306 L
.81121 .20305 L
.81517 .20303 L
.81872 .20303 L
.82249 .20303 L
.82601 .20305 L
.82919 .20307 L
.83128 .20309 L
.83324 .20312 L
.83687 .20318 L
.84072 .20325 L
.84482 .20336 L
.85205 .2036 L
.8585 .20389 L
.86537 .20429 L
.87265 .20482 L
.88653 .20623 L
.8979 .20787 L
.90916 .21006 L
.91893 .21255 L
.92713 .21518 L
.93478 .21821 L
.94219 .22182 L
.95369 .22931 L
.95912 .23399 L
.96361 .23873 L
.96786 .24423 L
.97175 .25064 L
.9746 .25671 L
.97672 .26263 L
.97841 .26914 L
.97912 .27289 L
.97961 .27636 L
.97979 .27796 L
.97995 .27966 L
.98006 .28114 L
.98015 .28274 L
.98022 .28447 L
.98026 .2861 L
.98027 .2871 L
.98027 .28806 L
.98024 .28985 L
Mistroke
.98019 .29143 L
.98011 .29312 L
.98002 .29472 L
.9799 .29618 L
.97955 .2998 L
.97911 .30323 L
.97788 .31039 L
.97603 .31838 L
.97075 .33488 L
.96405 .35049 L
.95627 .36524 L
.93318 .39913 L
.90605 .42956 L
.86938 .4622 L
.83009 .49042 L
.73818 .53915 L
.68832 .5583 L
.6306 .57543 L
.57454 .5875 L
.54259 .5925 L
.52838 .5943 L
.51321 .59595 L
.49803 .5973 L
.48427 .59827 L
.47764 .59865 L
.47047 .599 L
.46375 .59927 L
.45748 .59947 L
.45367 .59957 L
.45018 .59965 L
.44632 .59971 L
.4442 .59973 L
.44218 .59975 L
.44024 .59977 L
.43817 .59978 L
.43447 .59978 L
.43241 .59978 L
.43048 .59977 L
.42837 .59975 L
.42609 .59973 L
.42261 .59968 L
.4188 .5996 L
.41115 .5994 L
.40408 .59914 L
.39753 .59885 L
.3832 .598 L
.36779 .59677 L
.34027 .59376 L
.31409 .58986 L
.29057 .58545 L
Mistroke
.24339 .57374 L
.19559 .55731 L
.15517 .53881 L
.11725 .51609 L
.08525 .49066 L
.07281 .4783 L
.0612 .46476 L
.05129 .45088 L
.04383 .4381 L
.03781 .42512 L
.03351 .41283 L
.03179 .4064 L
.03032 .39934 L
.02974 .39579 L
.02925 .39199 L
.02906 .39015 L
.0289 .38841 L
.02879 .38686 L
.02869 .38515 L
.02861 .38357 L
.02857 .38209 L
.02854 .38053 L
.02853 .37885 L
.02855 .37738 L
.02858 .37583 L
.02863 .37451 L
.02871 .37306 L
.02882 .37135 L
.02894 .36979 L
.02929 .36631 L
.02972 .3631 L
.03021 .36007 L
.03148 .35389 L
.03329 .34716 L
.03825 .33381 L
.04438 .32178 L
.05144 .31087 L
.06128 .2986 L
.07218 .28748 L
.09665 .26819 L
.12854 .25006 L
.16319 .23587 L
.18535 .22891 L
.20765 .2232 L
.22871 .21881 L
.25309 .21474 L
.27903 .21143 L
.29279 .21003 L
.30793 .20876 L
.32253 .20775 L
Mistroke
.33616 .20699 L
.35019 .20638 L
.36377 .20592 L
.37854 .20555 L
.38709 .2054 L
.39521 .20529 L
.39962 .20524 L
.40385 .2052 L
.40771 .20518 L
.41185 .20515 L
.41636 .20514 L
.42057 .20513 L
.42316 .20513 L
.42561 .20512 L
.43021 .20513 L
.43395 .20514 L
.43807 .20515 L
.44241 .20517 L
.44647 .20519 L
.46174 .2053 L
.47868 .20546 L
.4972 .20567 L
.5362 .2061 L
.5471 .2062 L
.55876 .2063 L
.56878 .20636 L
.57419 .20639 L
.5799 .20642 L
.58487 .20643 L
.5875 .20644 L
.59032 .20645 L
.59528 .20646 L
.59991 .20646 L
.6027 .20646 L
.60574 .20645 L
.60861 .20645 L
.61125 .20644 L
.61626 .20643 L
.62158 .20641 L
.63123 .20635 L
.64026 .20628 L
.65015 .20618 L
.66074 .20605 L
.69285 .20551 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{401, 247.75},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006A0000mb000`400?l00000o`00003ooooooonB
ooooo`00Doooool5o`0000?ooooo0_l0000^ooooo`?o00000oooool2o`0002gooooo0ol00004oooo
o`;o0000;Oooool3o`0000Cooooo0_l0000Zooooo`?o00001?ooool2o`0000Cooooo0_l0000Woooo
o`?o00000_ooool5o`0000?ooooo0_l0000Sooooo`00E?ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0002kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002_o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Oooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
02;ooooo001Eooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:oooool5o`00
00;ooooo00Co0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo0000:_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00009oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00008_ooool005Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo02Wooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0000[oooo
o`Co00000oooool01?l0003oooooooooool0000/ooooo`?o00000oooool01?l0003oooooooooool0
000Zooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool0000Wooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo023ooooo001Cooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000/ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000:ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002_ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Oooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08?ooool005?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002gooooo0_l00003oooo
o`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Yooooo`;o
00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002Kooooo0_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000Rooooo`00E?oo
ool3o`0000Cooooo0_l0000_ooooo`03o`000?oooooooooo00;ooooo0_l0000^ooooo`;o00001?oo
ool2o`0002gooooo0ol00004ooooo`;o0000:oooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0002Sooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l0000Sooooo`00oooooonB
ooooo`00oooooonBooooo`00oooooonBooooo`00oooooonBooooo`00oooooonBooooo`008ooooooo
o`00067o00003_ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ioooo
o`008oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008ooo
ool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0
003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003ooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0Wooooo`008oooool2o`0003Cooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Soooo
o`03o`000?oooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`00
0?oooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo02Oooooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oo
oooo000Sooooo`;o0000=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000oooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09ooo
ool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?o
oooo0_l0000dooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003ooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Woooo
o`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`004ooo
ool5o`0000?ooooo0_l00006ooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Dooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`005Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo0ol0003oo`00Oeko001o
3_ooool001Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool09oooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool001?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool001Co
oooo0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003ooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0W
ooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool2o`0003Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`00
0?oooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo02Oooooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oo
oooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000S
ooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo02Oooooo000Sooooo`;o0000=?ooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000oooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09ooo
ool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?o
oooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o
0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool09oooool002?ooooo0_l0000dooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Woooo
o`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008ooo
ool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0
003oooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo02?ooooo?ol00007ooooo`03o`00Oooooooooooo
02Oooooo000Eooooo`?o00000oooool2o`0000Kooooo00?o0000ooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo01cooooo?Ol00006ooooofGo00002_ooool5o`0000;o
oooo00?o001oooooooooool09oooool001Kooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo00OoooooO_l0000Jooooo`03o`00Oooooooooooo00Oooooo4Ol0000:ooooo`Ko
00002Oooool4o`0002Sooooo000Cooooo`Go00000_ooool01?l0003oooooooooool00005ooooo`?o
0000I?l007l?o`0000So001o@Ol0000Wo`00Oc;o00004Ol007l=o`0000?o001o1ol00006o`00O`?o
00005ol007l>ooooo`004oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0Yooooo`Go00000ooooolDo`00
02Cooooo00?o001oooooooooool06_oooolWo`0002Sooooo00?o001oooooooooool09Oooool8o`00
00;ooooo0ol000000ooooooo001oooooo`03ooooo`?o00008_ooool001Cooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03?ooooo00?o001ooooo
ooooool08oooool>o`0000;ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0;Oooool4o`000004ooooool0003o0000
o`0000Kooooo0_l0000Pooooo`005Oooool2o`0000?ooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`0cooooo`03o`00Oooooooooooo01cooooo2ol0000<ooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo037ooooo1_l00006ooooo`;o00007_ooool001Kooooo00?o0000ooooooooool00_ooool2o`00
00Kooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0Gooooo`_o00004Oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooo000000Co00001Oooool00ol0003oooooooooo`0Koooo
o`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo01?ooooo2Ol0000Gooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00Co001ooooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo
01[ooooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool03oooool5o`0001oo
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`04ooooo`?o00001?ooool2o`0001[o
oooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool02oooool4o`0002Cooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`06ooooo`;o00001Oooool00ol0003ooooo
ooooo`0Gooooo`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo00Sooooo1?l0
000Wooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool01oooool2o`0000Gooooo00?o
0000ooooooooool05_ooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`05
ooooo`Co0000:_ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00Sooooo0_l00005
ooooo`03o`000?oooooooooo01Gooooo000Sooooo`;o0000=?ooool00ol007ooooooooooo`02oooo
o`Co0000;Oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Eooooo`008oooool00ol0003oooooooooo`0cooooo`03
o`00Oooooooo000000;o0000<Oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00[o
oooo0_l00004ooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo03;ooooo
1?l0000cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool02oooool2o`0000Cooooo
00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool0<?ooool4o`0003Gooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0<ooooo`;o00001?ooool00ol0003ooooooooo
o`0Booooo`008oooool00ol0003oooooooooo`0^ooooo`?o00000_ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool03Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01;ooooo000Sooooo`03o`000?oooooooooo02_ooooo1?l00004oooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0=oooo
o`;o00001?ooool00ol0003oooooooooo`0Aooooo`008oooool00ol0003oooooooooo`0Yooooo`Co
00001_ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo000Sooooo`03o`00
0?oooooooooo02Oooooo1?l00008ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0>ooooo`;o00000oooool00ol0003oooooooooo`0Aooooo`008ooo
ool00ol0003oooooooooo`0Uooooo`Co00002_ooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool03oooool2o`0000;ooooo00?o0000ooooooooool04Ooo
ool002?ooooo0_l0000Uooooo`?o00003?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool03oooool2o`0000?ooooo00?o0000ooooooooool04?ooool0
02?ooooo00?o0000ooooooooool08_ooool3o`0000kooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo013ooooo00Go0000ooooooooooooooooo`00000B
ooooo`008oooool00ol0003oooooooooo`0Pooooo`?o00004?ooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool04?ooool01Ol0003ooooooooooooooooo
000001;ooooo000Sooooo`03o`000?oooooooooo01kooooo0_l000000ooooooo0000ooooo`0@oooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Aoooo
o`04o`000?ooooooooooo`0001;ooooo000Sooooo`03o`000?oooooooooo01gooooo00Co0000oooo
oooooooo00004_ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool04Oooool01?l0003oooooooooool0000Booooo`008oooool00ol0003oooooooooo`0L
ooooo`04o`000?oooooo0000o`0001?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo017ooooo00Go0000ooooooooooooooooo`00000Aooooo`008ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooo000001Gooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo017ooooo00Go0000oooooooooooooooo
o`00000Aooooo`008oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo000001Kooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo017ooooo00Go
0000ooooooooooooooooo`00000Aooooo`008oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooo000001Oooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo017ooooo00Go0000ooooooooooooooooo`00000Aooooo`008oooool2o`0001Wooooo00?o
0000ooooool000006?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool04Oooool01Ol0003ooooooooooooooooo0000017ooooo000Sooooo`03o`000?oo
oooooooo01Oooooo00Co0000oooooooooooo00006?ooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool04Oooool01?l0003oooooooooool0000Booooo`00
8oooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`0001Wooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo017ooooo00Co0000oooooooo
oooo00004_ooool002?ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0000Joooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Aoooo
o`04o`000?ooooooooooo`0001;ooooo000Sooooo`03o`000?oooooooooo01Cooooo00Co0000oooo
oooooooo00006oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool04Oooool01?l0003oooooooooool0000Booooo`008oooool00ol0003oooooooooo`0C
ooooo`04o`000?ooooooooooo`0001cooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo017ooooo00Co0000oooooooooooo00004_ooool001Cooooo0ol0
0004ooooo`;o00001_ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0001gooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo017ooooo
00Co0000oooooooooooo00004_ooool001?ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000N
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0A
ooooo`04o`000?ooooooooooo`0001;ooooo000Cooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo013ooooo00Go0000oooooooooooo
ooooo`00000Nooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0@ooooo`;o000000?oooooo`000?ooool04_ooool001?ooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000Gooooo0ol0000?o`00O`05o`000?l007oo001oo`00Ool00000ool007m1o`00
O`04o`000?l007oo001oo`0000Go001o3_ooool001?ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00008?oo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool04?oo
ool01?l0003oooooooooool0000Cooooo`005?ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000Qooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0@ooooo`03
o`000?oooooo000001Cooooo000Eooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0
3_ooool01?l0003oooooooooool0000Qooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0?ooooo`;o000000?oooooo`000?ooool04oooool002?ooooo
00?o0000ooooooooool03Oooool01?l0003oooooooooool0000Rooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0?ooooo`;o000000?oooooo`000?oo
ool04oooool002?ooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool0000Rooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0?ooooo`03
o`000?oooooo000001Gooooo000Sooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo
00008oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool03oooool00ol0003oooooo`00000Eooooo`008oooool00ol0003oooooooooo`0<ooooo`04o`00
0?ooooooooooo`0002?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo00kooooo0_l000000ooooooo0000ooooo`0Dooooo`008oooool00ol0003ooooo
ooooo`0;ooooo`04o`000?ooooooooooo`0002Cooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo00kooooo00?o0000ooooool000005_ooool002?ooooo
0_l0000<ooooo`04o`000?ooooooooooo`0002Cooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo00kooooo00?o0000ooooool000005_ooool002?ooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000002Cooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00gooooo0_l000000ooooooo
0000ooooo`0Eooooo`008oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0002Go
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00go
oooo00?o0000ooooool000005oooool002?ooooo00?o0000ooooooooool02_ooool01?l0003ooooo
ooooool0000Uooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0=ooooo`03o`000?oooooo000001Oooooo000Sooooo`03o`000?oooooooooo00Wooooo
00Go0000ooooooooooooooooo`00000Uooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0<ooooo`?o00006?ooool002?ooooo00?o0000ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000002Gooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo00cooooo00?o0000ooooool000006?ooool002?ooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000002Kooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00_ooooo0ol0000Iooooo`00
8oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000009_ooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool02oooool00ol0003o
ooooo`00000Iooooo`008oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool0
00009_ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool02_ooool00ol0003oooooo`00000Jooooo`008oooool2o`0000Wooooo00Go0000oooooooooooo
ooooo`00000Vooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`09ooooo`;o000000?oooooo`000?ooool06Oooool002?ooooo00?o0000ooooooooool0
2?ooool01Ol0003ooooooooooooooooo000002Kooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo00Wooooo00?o0000ooooool000006oooool002?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00Sooooo
0ol0000Looooo`008oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool09?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool02?ooool00ol0003oooooo`00000Looooo`008oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool01oooool00ol0003oooooo`00000M
ooooo`008oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool09?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool01_ooool3o`0001kooooo000Sooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Tooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`06ooooo`03o`000?oooooo000001kooooo000Sooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`05ooooo`03o`00
0?oooooo000001oooooo000Sooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Tooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`04ooooo`?o00008?ooool002?ooooo0_l00008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool09?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool01?ooool00ol0003oooooo`00000Pooooo`008oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool00oooool00ol0
003oooooo`00000Qooooo`008oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool09?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool00_ooool3o`0002;ooooo000Sooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`00000Vooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`02ooooo`03o`000?oooooo000002;ooooo000Sooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000Vooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool01ol007oooooooooooooooooo0000ooooool000008oooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo
03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo
00?o00009?ooool001Cooooo0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooool000000_l0000Uooooo`004oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00Co001oo`000?l0003o00009_ooool001?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`?o00009oooool001Cooooo0ol00003ooooo`04o`000?oooooo
ooooo`0000Gooooo0ol00009o`00O`03o`000?l007oo001o00;o001o00?o0000o`00Ool007l0ool0
07l`o`00O`?o00006_l007l>ooooo`004oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08_ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo037ooooo
0ol0000Yooooo`004oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08_ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo033ooooo0ol000000ol007oo
ooooooooo`0Wooooo`005?ooool3o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0;oooool3o`000003ooooool007oooooo02Sooooo000Sooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool0;_ooool2o`0000?ooooo00?o001oooooooooool09ooo
ool002?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo023ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0]ooooo`;o00001?ooool0
0ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool07oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo
03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo
02cooooo0_l00005ooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?o
oooo00?o001oooooooooool0:oooool2o`0000Kooooo00?o001oooooooooool09oooool002?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0Zooooo`;o00001oooool00ol007oooooo
ooooo`0Wooooo`008oooool2o`0000kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Nooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0:Oooool2o`0000Sooooo00?o
001oooooooooool09oooool002?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0X
ooooo`;o00002Oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo02Kooooo0ol0000:ooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Looooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool09Oooool00ol0003oooooo`00000;ooooo`03
o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Kooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
9?ooool00ol0003oooooo`00000<ooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool08oooool00ol0003oooooo`00000=ooooo`03o`00Oooo
oooooooo02Oooooo000Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Jooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool0
0ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool08_ooool3
o`0000kooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0Qooooo`;o00004?ooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo01oooooo0ol0000Aooooo`03o`00Oooooooooooo02Oo
oooo000Sooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0Nooooo`;o00004oooool00ol007oooooo
ooooo`0Wooooo`008oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool05oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo01gooooo0_l0
000Dooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool06oooool3o`0001Gooooo00?o001oooooooooool09oooool002?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0Jooooo`;o00005oooool00ol007ooooooooooo`0Woooo
o`008oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo01Wooooo0_l0000Hooooo`03
o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
6?ooool00ol0003oooooooooo`0Hooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool05_ooool2o`0001_ooooo00?o001oooooooooool09ooo
ool002?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Eooooo`;o00007?ooool0
0ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00?ooooo0_l0000Aooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol0
07ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool04oooool2o`00
01kooooo00?o001oooooooooool09oooool002?ooooo0_l0000Looooo`;o00001Oooool00ol0003o
ooooooooo`0>ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool04Oooool3o`0001oo
oooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00gooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooo
ooooo`0?ooooo`?o00008Oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo00kooooo0_l0000Sooooo`03o`00Oooooooooooo02Oooooo000S
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool2o`0000cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0<ooooo`;o00009Oooool00ol007ooooooooooo`0W
ooooo`008oooool00ol0003oooooooooo`0Pooooo`;o00001Oooool00ol0003oooooooooo`09oooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo03?ooooo00?o001oooooooooool02_ooool2o`0002Oooooo00?o001ooooo
ooooool09oooool002?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Sooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`08ooooo`;o
0000:Oooool00ol007ooooooooooo`0Wooooo`003_ooool3o`0000Cooooo0_l00004ooooo`;o0000
1_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00Kooooo0_l0000[ooooo`03o`00
Oooooooooooo02Oooooo000?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool00oooool2o`0000Oooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`04ooooo`;o
0000;Oooool00ol007ooooooooooo`0Wooooo`003oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool00_ooool2o`0002oooooo00?o001oooooooooool09oooool000oooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo0ol0000V
o`00O`;o00001_l007l00ol0003o001oo`00O`3Mo`00O`;o0000COl007l>ooooo`003oooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`0Xooooo`;o00001Oooool2o`0000;ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<ooo
ool01?l007oo0000o`000?l0000booooo`03o`00Oooooooooooo02Oooooo000>ooooo`;o00001?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`04ooooo`;o000000?o001oooooooooool0<oooool00ol007oo
ooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool2o`0003Co
oooo00?o001oooooooooool09oooool000oooooo00?o0000ooooooooool00oooool2o`0000Cooooo
0_l00006ooooo`03o`000?oooooooooo02_ooooo0_l00006ooooo`03o`000?oooooooooo03?ooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo037ooooo
0_l000000ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oo
oooooooo02gooooo0_l00004ooooo`03o`00Ool0003o000003?ooooo00?o001oooooooooool0<ooo
ool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02oooooo0_l00002ooooo`03o`00Oooo
oooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000ooooooooool0;oooool2
o`0000;ooooo00?o001oooooooooool00_l0000aooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0]ooooo`;o00001?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ool007l01?ooool2o`0002oooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo02_ooooo0_l00006ooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool09oooool002?ooooo00?o0000ooooooooool0<_ooool2o`0000Kooooo0_l0000]ooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Xooooo`?o
00002?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo000Sooooo`03o`00
0?oooooooooo03?ooooo00?o001oo`000?l000001_ooool2o`0002_ooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Kooooo0ol0000:ooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo0_l0000dooooo`03o`00Oooo
oooooooo00;o00001_ooool2o`0002Wooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo02?ooooo1?l0000<ooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`02
ooooo`;o00001_ooool2o`0002Oooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo027ooooo0ol0000?ooooo`03o`00Oooooooooooo03?ooooo00?o001o
ooooooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`04oooo
o`;o00001_ooool2o`0002Gooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0coooo
o`03o`00Oooooooooooo01oooooo0ol0000Aooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`06ooooo`;o
00001_ooool2o`0002?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo01cooooo0ol0000Dooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`08ooooo`;o0000
1_ooool3o`00023ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo01Wooooo1?l0000Fooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
9oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0:ooooo`;o00001ooo
ool3o`0001gooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooo
oooooooo01Kooooo1Ol0000Hooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09ooo
ool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0<ooooo`;o00002?ooool3
o`0001[ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooo
oooo01;ooooo1_l0000Kooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool0
02?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0>ooooo`?o00002?ooool3o`00
01Oooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo
00oooooo1_l0000Nooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?o
oooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0Aooooo`?o00002?ooool3o`0001Co
oooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo00_o
oooo1ol0000Qooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo
0_l0000dooooo`03o`00Oooooooooooo01Cooooo0ol00008ooooo`?o00004Oooool00ol007oooooo
ooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool02?ooool7o`0002Cooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003ooooooooo
o`0cooooo`03o`00Oooooooooooo01Oooooo0ol00008ooooo`Co00003Oooool00ol007oooooooooo
o`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool01?ooool7o`0002Sooooo00?o
001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0c
ooooo`03o`00Oooooooooooo01[ooooo0ol00009ooooo`Go00002?ooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooool000001?l000001?oooooo0000o`000?l0
000[ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000
ooooooooool0<oooool00ol007ooooooooooo`0Mooooo`?o00002oooool4o`0000Cooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0`ooooo`Go00000_ooool4o`0002kooooo00?o001o
ooooooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0coooo
o`03o`00Oooooooooooo023ooooo1?l0000;ooooo`Go0000=Oooool00ol007ooooooooooo`0[oooo
o`Go00000_ooool5o`0003;ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Woooo
o`008oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo02Cooooo1?l0000;ooooo`03
o`00Ool0003o000000?o0000<?ooool00ol007ooooooooooo`0Vooooo`Go00000_ooool5o`000003
ooooool007oooooo03Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0Wooooo`00
8oooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo02Sooooo1?l00007ooooo`03o`00
Oooooooooooo00?ooooo1ol0000Yooooo`03o`00Oooooooooooo027ooooo1Ol00002ooooo`Go0000
1_ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0
9oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0/ooooo`Ko000000?o
ooooo`00Ooooool02oooool:o`0001oooooo00?o001oooooooooool05_ooool;o`000003ooooool0
003o000000Co00002oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0b
ooooo`Oo00004Oooool7o`0001Sooooo00?o001oooooooooool03?ooool:o`0000Oooooo1Ol0000A
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0W
ooooo`008oooool2o`0003Cooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`03oooo
o`Go00004ooooolWo`0000cooooo1Ol0000Fooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool02?ooool7o`0002Cooooo00?o001ooooooooo
ool03Oooool;o`0001_ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo02Oooooo000Sooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0
<oooool00ol007ooooooooooo`0?oooooa?o00004Oooool00ol007ooooooo`00000=o`0002Kooooo
00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo02Oooooo
000Sooooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007oooooooooo
o`0Roooooa?o0000=?ooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o
001oooooooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0c
ooooo`03o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool002?ooooo00?o0000oooo
ooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooo
ooooool09oooool002?ooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03
o`00Oooooooooooo03?ooooo00?o001oooooooooool09oooool000kooooo0ol00002ooooo`Go0000
0oooool2o`0000Kooooo00?o0000ooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool0<oooool00ol007ooooooooooo`0cooooo`03o`00
Oooooooooooo03?ooooo00?o001oooooooooool09oooool000oooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool0<oooool00ol007ooooooooooo`0cooooo`03o`00Oooooooooooo03?ooooo00?o001ooooooooo
ool09oooool000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Gooooo0ol0003oo`00Oeko001o3_ooool000oooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0oooooombooooo`00
3oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`3oooooog;ooooo000>ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo0000oooooomdooooo`003oooool00ol0003oooooooooo`02oooo
o`?o00001?ooool2o`000?ooooooMOooool00?ooooooT_ooool00=3ooooo0ol0002nooooo`00dOoo
ool00ol0003oooooooooo`2mooooo`00R?ooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6
o`0000Oooooo0ol00002ooooo`Go00001oooool3o`000003ooooool0003o000001?ooooo0ol00003
ooooo`Co000000Coooooo`000?l0003o00002Oooool4o`0000?ooooo0ol00004ooooo`;o00002Ooo
ool3o`0000Gooooo00?o0000ooooooooool01Ol00004ooooo`04o`000?ooooooooooooooo`?o0000
MOooool008Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000Dooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooo
ool000001_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`1booooo`00ROooool00ol0003oooooooooo`03ooooo`?o00000ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool4o`0000So
oooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00?o0000ooooooooool02Oooool3o`00
00;ooooo1Ol00002ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool5o`00
00;ooooo00?o0000ooooooooool00_ooool5o`0000Cooooo00?o0000ooooooooool0L_ooool008Wo
oooo0ol00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`08ooooo`;o00005_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooo
oooooooo0_l00009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0007Gooooo0029oooo
o`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co00000oooool3o`0000Wooooo0ol00003
ooooo`Co00002?ooool00ol0003oooooo`00000Dooooo`Co00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l0000:ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0L_ooool008Wooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?oo
ool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo00Wooooo0_l00009ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000007Cooooo0028ooooo`Co
00002Oooool00ol0003oooooooooo`02ooooo`;o00004oooool2o`0000Oooooo0ol000000ooooooo
0000o`00000gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool3o`0000Wo
oooo0ol0001eooooo`00oooooonBooooo`00oooooonBooooo`00\
\>"],
  ImageRangeCache->{{{0, 400}, {246.75, 0}} -> {-13.2047, -7.40527, 0.370298, \
0.553066}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Animation of crank-rocker mecha par 3 ( ",
  Cell[BoxData[
      \(\(f\[Psi]i = f\[Psi];\)\)], "Input"]
}], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pa = par3\)], "Input"],

Cell[BoxData[
    \({A0x \[Rule] 22, A0y \[Rule] 59, \[Gamma]0 \[Rule] \(-57\)\ \[Degree], 
      a \[Rule] 58.5`, b \[Rule] 180, c \[Rule] 162, 
      d \[Rule] 120.5`, \[Kappa] \[Rule] 0, k \[Rule] 47}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(f\[Psi]i = f\[Psi];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rA0x = A0x /. pa;\)\), "\n", 
    \(\(rA0y = A0y /. pa;\)\), "\n", 
    \(\(rB0x = d\ Cos[\[Gamma]0] /. pa;\)\), "\n", 
    \(\(rB0y = d\ Sin[\[Gamma]0] /. pa;\)\), "\n", 
    \(\(rax\  = \ 
        A0x\  + \ a\ Cos[\[CurlyPhi] + \[Gamma]0] /. pa;\)\), "\n", 
    \(\(ray\  = \ 
        A0y\  + \ a\ Sin[\[CurlyPhi] + \[Gamma]0] /. pa;\)\), "\n", 
    \(\(rbx\  = \ \(A0x\  + \ b\ Cos[\[Psi] + \[Gamma]0]\  + 
              d\ Cos[\[Gamma]0] /. \[Psi] \[Rule] f\[Psi]i\) /. 
          pa;\)\), "\n", 
    \(\(rby\  = \ \(A0y\  + \ b\ Sin[\[Psi] + \[Gamma]0]\  + 
              d\ Sin[\[Gamma]0] /. \[Psi] \[Rule] f\[Psi]i\) /. 
          pa;\)\), "\n", 
    \(\(rkx\  = \ \(\(xK /. \[Delta] \[Rule] f\[Delta]\) /. \[Psi] \[Rule] 
              f\[Psi]i\) /. pa;\)\), "\n", 
    \(\(rky\  = \ \(\(yK /. \[Delta] \[Rule] f\[Delta]\) /. \[Psi] \[Rule] 
              f\[Psi]i\) /. pa;\)\), "\n", 
    \(\(lmax\  = \ Max[a, b, c, d] /. pa;\)\), "\n", 
    \(\(Plo0 = 
        Plot[0, {i, 0, 1}, 
          PlotRange \[Rule] {{\(-100\), 300}, {\(-150\), 200}}, 
          Frame \[Rule] True, AspectRatio \[Rule] Automatic, 
          PlotLabel \[Rule] "\<Coupling Path par set 3)\>"];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{108, 94.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001/0000GR000`400?l00000o`00003oK?ooool0
06cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?oo
ool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00
K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/oooo
o`00K?ooool006cooooo000/oooooaCo000000?oooooo`000?l000000_l0000Wooooo`00:oooool0
0ol0003oooooo`00000Co`000005ooooool0003o0000ooooool000009_ooool002Gooooo1Ol00004
oooooa?o000000Goooooo`000?l0003oooooo`00000Vooooo`00;_oooolCo`000005ooooool0003o
0000ooooool000009_ooool002_ooooo1_l000000ooooooo0000o`000004o`000003ooooool0003o
000000Ko000000Goooooo`000?l0003oooooo`00000Vooooo`00:oooool00ol0003oooooo`000003
o`000003ooooool0003o000000Co000000?oooooo`000?l000001_l000001Ooooooo0000o`000?oo
oooo000002Kooooo000[oooooaGo000000?oooooo`000?l000000_l0000Wooooo`00K?ooool001_o
oooo0ol00004ooooo`;o00001?ooool2o`0004;ooooo000Looooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo01?o0000;Oooool001Co
oooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`Co000000?oooooo`000?oo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo000Looooo`04o`00
0?ooooooooooooooo`;o00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`006_ooool5o`0000;o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`006oooool2o`0000Cooooo00Co0000
oooooooooooo00000_ooool4o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0[ooooo`007?ooool01?l0003oooooooooooooool4o`0000?ooooo1?l0
00000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:ooo
ool0023ooooo1?l00003ooooo`Co000000?oooooo`000?l000004Ol0000]ooooo`008?ooool5o`00
00;ooooo1?l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:oooool001_ooooo0ol00004ooooo`?o00000_ooool4o`000003ooooool0003ooooo00?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`007?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00004
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool001_ooooo0ol00002oooo
o`Go00000_ooool4o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0[ooooo`007?ooool01?l0003oooooooooooooool2o`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0:oooool001[ooooo1Ol000000ooooooo0000o`000003o`0000;ooooo1?l000000ooo
oooo0000ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool001_o
oooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool0
01cooooo00Co0000oooooooooooooooo1Ol00002ooooo`Co000000?oooooo`000?ooool00oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo000Kooooo`?o00000_ooool2o`00
00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00000Bo`0002gooooo000Joooo
o`06o`000?oooooo0000ooooool0003ooooo1Ol00002ooooo`Co0000@Oooool000;o00005_ooool3
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo01Cooooo0ol0000Xooooo`0000?o0000ooooooooool06?ooool3o`0000Cooooo0_l0
0004ooooo`;o00006?ooool00ol0003oooooooooo`0Wooooo`000ol00002ooooo`Go000000?ooooo
o`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l0
0007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l0
00001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00003ooooo`0000Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00000_oo
ool00004o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003oooooooooo`09
ooooo`?o00000_ooool5o`0000;ooooo00?o0000ooooooooool00oooool00004o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?o
oooo0003o`0000Cooooo00Co0000oooooooooooooooo0ol00003ooooo`Co00000oooool5o`0000Oo
oooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003ooooo`?o00002?ooool4o`00
00?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool4o`0000;ooooo0ol00002oooo
o`Co00000oooool000Oooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`03oooo
o`001Oooool3o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000oooooooo
ool00_ooool2o`0002oooooo00?o0000ooooooooool00oooool006cooooo001/ooooo`00K?ooool0
06cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?oo
ool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00
K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/ooooo`00K?ooool006cooooo001/oooo
o`00K?ooool00001\
\>"],
  ImageRangeCache->{{{0, 107}, {93.5, 0}} -> {-1118.62, -1005.7, 22.778, \
22.778}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Do[
  PloMecha1 = Graphics[{
        Circle  [{rA0x,rA0y},a/.pa],

        Circle  [{rA0x,rA0y},lmax/100],
        Circle  [{rax,ray},lmax/100],
        Circle  [{rbx,rby},lmax/100],
        Circle  [{rkx,rky},lmax/100],
        Circle  [{rB0x,rB0y},lmax/100],
        
\t\tLine  [{{rA0x,rA0y}, {rB0x,rB0y}}],
\t\tLine  [{{rA0x,rA0y}, {rax,ray}}],
\t\tLine  [{{rB0x,rB0y}, {rbx,rby}}],
\t\tLine  [{{rax,ray}, {rbx,rby}, {rkx,rky}, {rax,ray}}],

        Text  [A0,{rA0x+lmax/30, rA0y-lmax/30}], 
        Text  [A ,{rax+lmax/30, ray+lmax/30}], 
        Text  [B ,{rbx+lmax/30, rby+lmax/30}], 
        Text  [K ,{rkx+lmax/30, rky+lmax/30}], 
        Text  [B0,{rB0x+lmax/30,rB0y-lmax/30}]}]; 
   Show[Plo0, plo3, PloMecha1];
 ,{\[CurlyPhi],0, 2 Pi, Pi/6}];  \
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  RenderingOptions->{"RenderThickness"->False}],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.38465 .39984 .0045 0 365.73 arc
s
newpath
.69667 .65805 .0045 0 365.73 arc
s
newpath
.47518 .47476 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.38465 .39984 L
s
.41407 .12235 m
.69667 .65805 L
s
.38465 .39984 m
.69667 .65805 L
.47518 .47476 L
.38465 .39984 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.39965 .41484 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.71167 .67305 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.49018 .48976 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0ol0002Aooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00002Aooooo`03o`000?oooooooooo
00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`04o`000?oooooo
ooooo`00093ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09_ooool0
1?l0003oooooooooool0002@ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2<ooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2<ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08_ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`28ooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo08Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Pooo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08;ooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0POooool00ol0003ooooo
ooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`07ooooo`001_oo
ool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000
??ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
O_ooool3o`0000Wooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
1oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo07gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0OOooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo07_ooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1hooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Moooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0MOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0LOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`07ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Coooooo?l0
0009ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool00_ooool4o`0000cooooo1?l0000booooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooo000000;o00004oooool4o`00033ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>Oooool4
o`0001Kooooo00Co0000oooooooooooooooo0ol0000]ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo00Gooooo0_l0000/ooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`07ooooo`?o0000:_ooool00ol0003oooooooooo`1/
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000=_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool3o`0002[ooooo00?o0000oooo
ooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03?ooooo0_l00006ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool4o`0002[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000000Go00009_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00000_ooool2o`0002Sooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Go0000:?ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
1?l0003oooooo`000?ooool2o`0002Oooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0002oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002
ooooo`;o00009_ooool00ol0003oooooooooo`1Xooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0000Voooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooo`00000Uooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo0000o`0002Cooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00gooooo00Co0000ooooool0003o00008oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3_ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool0I_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo
00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooo
ooooo`00000Rooooo`03o`000?oooooooooo06Cooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool2o`00023ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool2o`00023ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`?o
00007?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`00000bo`0000gooooo00?o0000ooooooooool0HOooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0>ooooo`Oo00006Oooool00ol0003oooooooooo`04ooooo`Co00003oooool3o`0000[ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?l000003Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Kooooo00Co0000ooooool0003o00003oooool2o`0000Wooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`;o000000Goooooo`00
0?ooooooooooo`00000Nooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o00004?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool01ooo
ool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo
0ol00003ooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool01_ooool2o`0000;o
oooo0_l0000>ooooo`;o00002Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00Oo
oooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0002Ko
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000Looooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooool000000_ooool2o`0000kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Mooooo`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooo`000?l00002
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooooooo`Ko000000Goooooo`000?ooooooooooo`00000Looooo`03
o`000?oooooooooo00Cooooo0ol000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00007?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`00
00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool01?l0003oooooo`000?l00002ooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooooooool03oooool2o`0000Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo0ol00003ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool04?oo
ool2o`0000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o00009Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool3o`0000Cooooo0_l0000Mooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo05_ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`?o00008oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`0Eoooo
o`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`04
o`000?ooooooooooo`0002oooooo00?o0000ooooooooool05_ooool2o`000003ooooool0003ooooo
00oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000;_ooool00ol0
003oooooooooo`0Iooooo`;o00004Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool01?l0003o
ooooooooool0000^ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o00009_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool06Oooool00ol0
003oooooo`00000Aooooo`03o`000?oooooooooo05Oooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000;_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00;o00003oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04_ooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool00_ooool2o`0000oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooo
oooo0000;_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000]oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0002gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Sooooo00?o0000oooooooo
ool04Oooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Cooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo0000;?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo0_l0000;oooo
o`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0002cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000Zooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0?ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`07ooooo`006oooool2o`0002_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Dooooo`;o00002?ooool00ol0003oooooooooo`1Aooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool01oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Fooooo`;o00007_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01oooooo0_l00005ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool01oooool000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo0_l0000Tooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool2o`00037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`;o00007?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1<ooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Oooooo00Go0000oooooooooooo
ooooo`00001@ooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00001?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Cooooo`;o0000:oooool01Ol0003ooooooooooooooooo000004oooooo00?o0000
ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01?ooooo0_l0000Dooooo`;o0000;_ooool2o`000003ooooool0003ooooo
04kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooool00000C_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0eooooo`;o00001?ooool00ol0003ooooo
ooooo`0=ooooo`;o00003oooool2o`0001Cooooo0_l0000dooooo`;o0000C_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003Sooooo0ol000000ooooooo0000ooooo`0@ooooo`;o00002_oo
ool3o`0001Cooooo0_l0000gooooo`;o0000C?ooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo03[ooooo0_l0000Cooooo`?o00001_ooool00ol0003oooooooooo`0Booooo`?o0000>_ooool3
o`0004_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`00
01Gooooo0ol000000ooooooo0000o`00000Aooooo`Co0000?Oooool2o`000003ooooool0003ooooo
04Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooo`000003o`00017ooooo2Ol0000:ooooo`Co0000@_ooool2o`0004_ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03oooooa7o0000
2Oooool:o`0004Oooooo1?l00018ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0Koooool01?l0003oooooooooool00017ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`1_ooooo`04o`000?oo
ooooooooo`0004Kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo06oooooo0ol00018ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0Koooool01?l0003oooooooooool00017ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Koooool0
1?l0003oooooooooool00017ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0K_ooool4o`0004Sooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oo
oooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00000oooool3o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`002?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000loooo
o`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool01?l0003oooooooooooooool4o`00
00?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00003ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co0000oooooooooooooooo1Ol00003
ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001_ooool5o`00
00?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo0009ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0?oo
oooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooo`[ooooo
0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo001Rooooo`?o00005_ooool3
o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo001Sooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo0000ooooo`03o`0000;o
oooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00007oooo
o`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo1?l00003ooooo`?o00001?ooool2
o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo043ooooo001Aooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00?o0000ooooooooool02Oooool3
o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00[ooooo0_l00005
ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002oooo
o`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o00000ooo
ool4o`0000?ooooo1Ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co0000
0oooool3o`0000Sooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo
1?l00002ooooo`?o00000_ooool4o`0000cooooo00Go0000ooooooooooooooooo`000013ooooo`00
DOooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0@_ooool0
05;ooooo0ol0000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`Co00002Oooool00ol0
003oooooooooo`02ooooo`;o0000;oooool00ol0003oooooooooo`09ooooo`?o0000B?ooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.43531 .4561 .0045 0 365.73 arc
s
newpath
.83251 .53521 .0045 0 365.73 arc
s
newpath
.55055 .47905 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.43531 .4561 L
s
.41407 .12235 m
.83251 .53521 L
s
.43531 .4561 m
.83251 .53521 L
.55055 .47905 L
.43531 .4561 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.45031 .4711 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.84751 .55021 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.56555 .49405 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0_l000000ooooooo0000ooooo`2?ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo
000008oooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooooooo00Oooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
08[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`28ooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08Kooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`21ooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`20ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Noooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo07Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Moooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo07Gooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Loooool00ol0003ooooooooo
o`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07ooooo`001_ooool5
o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0K_oo
ool3o`0000Wooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01ooo
ool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo06Sooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`1Xooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Rooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0G?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo05cooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
@_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0F?ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool0EOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0E?ooool00ol0003ooooooooo
o`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`07
ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Coooooo?l00009
ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool00_ooool4o`0000cooooo1?l0001Booooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooo000000;o00004oooool4o`00053ooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>Oooool4o`00
01Kooooo00Co0000oooooooooooooooo0ol0001>ooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000F
ooooo`03o`000?oooooooooo00Gooooo0_l0001=ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0_l0001<ooooo`03
o`000?oooooooooo04Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0cooooo`;o0000
1_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo04?ooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0002[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo0ol0001<ooooo`03o`000?oooooo
oooo03cooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`Co0000C?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Ko
oooo1Ol000000ooooooo0000o`000003o`0004Sooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`;o00000oooool3o`000005oooo
ool0003o0000o`000?ooool01Ol00014ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04oooool2o`0000Kooooo00Go0000oooooooooooo
ooooo`000007ooooo`Go0000@?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo017ooooo0_l00008ooooo`Go00003?ooool5o`0003cooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo=_l0
000eooooo`03o`000?oooooooooo03Kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool7o`0000[ooooo0_l0000=
ooooo`03o`000?oooooo000001Oooooo1Ol0000dooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00gooooo0_l0000>ooooo`;o00003oooool2o`0001Sooooo0ol00002oooo
o`Go0000<?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooo000000cooooo0_l0000Aooooo`;o00006_ooool3o`000003ooooool0003o000000;o
oooo1Ol0000/ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool000gooooo
0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00_ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Iooooo`;o000000?oooooo`000?ooool01oooool5o`0002Sooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool3o`0000?ooooo00?o0000oooooooo
ool02?ooool2o`0001Gooooo00?o0000ooooooooool06Oooool3o`0000kooooo1Ol0000Tooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool0013ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`;o00009_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l000001?oooooo0000o`000?l00002oooo
o`;o00000oooool2o`0001Oooooo00?o0000ooooooooool06Oooool3o`0001?ooooo1Ol0000Poooo
o`03o`000?oooooooooo02oooooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo0ol0000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooool000006?oo
ool5o`0001cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`003?ooool4
o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool5o`0000;ooooo
00Co0000ooooool0003o00007?ooool00ol0003oooooooooo`0Hooooo`04o`000?oooooo0000o`00
01cooooo1Ol0000Hooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool000co
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000000oooool2o`000003ooooool0003ooooo01_ooooo00?o0000oooo
ooooool05oooool6o`00023ooooo1Ol0000Dooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04
o`000?oooooo0000ooooo`?o00000_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool09Oooool5o`00013ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`Co00000_ooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:_ooool5o`00
00cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo0ol00004ooooo`;o00007Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02oo
oooo1Ol00008ooooo`03o`000?oooooooooo02[ooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`?o00008oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Cooooo
1Ol00004ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool00000
;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03Wooooo2?l0000Yooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04ooo
ool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
?_ooool2o`000003ooooool0003ooooo02Oooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0002oooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`10ooooo`;o0000:Oooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co
0000oooooooooooo0000;_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo047ooooo
1?l0000Vooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool04oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0@_ooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o00009_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0002ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`00
02Cooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?o
oooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04?ooooo0ol0000Vooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0A?ooool01?l0003oooooooooool0000Uooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool01?l0
003oooooooooool0000^ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A?ooool0
1?l0003oooooooooool0000Uooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000]ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0A?ooool4o`0002Kooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo
ooooo`0002gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000:?ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo
ooooo`0002gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1^ooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo
ooooo`0002cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1_ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooool0000/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0L?oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo013ooooo00Go0000ooooooooooooooooo`00000Zooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0L?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000Yooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0L_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0002_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`1booooo`;o00002Oooool001_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool01oooool000Oooooo0ol00004
ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0F
ooooo`;o0000N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0^ooooo`;o00002oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05?ooool2o`0007_ooooo
00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo0_l0000aooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01oooool2o`0001cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1iooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool01oooool000Oo
oooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo0_l0001oooooo`03o`000?oooooo
oooo00Oooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Cooooo`;o00005?ooool2o`00087ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo
00?o0000ooooooooool03Oooool2o`0000oooooo0_l0000Dooooo`;o0000Q?ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003Sooooo0ol000000ooooooo0000ooooo`0@ooooo`;o00002_oo
ool3o`0001Cooooo0_l00025ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>_ooool2
o`0001?ooooo0ol00006ooooo`03o`000?oooooooooo01;ooooo0ol00028ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Eooooo`?o000000?oooooo`00
0?l000004Oooool4o`0008_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooo`000003o`00017ooooo2Ol0000:ooooo`Co0000Soooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo
4Ol00009ooooo`[o0000Toooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00000oooool3o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`002?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000l
ooooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool01?l0003oooooooooooooool4
o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00003ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co0000oooooooooooooooo1Ol0
0003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooooooo
ool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001_ooool5
o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo0009ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
0?oooooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooo`[o
oooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo001Rooooo`?o00005_oo
ool3o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo001Sooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo0000ooooo`03o`00
00;ooooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00_l00000
0ooooooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00007
ooooo`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo1?l00003ooooo`?o00001?oo
ool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo043ooooo001Aooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00?o0000ooooooooool02Ooo
ool3o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooo
ooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00[ooooo0_l0
0005ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002
ooooo`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o0000
0oooool4o`0000?ooooo1Ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co
00000oooool3o`0000Sooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000So
oooo1?l00002ooooo`?o00000_ooool4o`0000cooooo00Go0000ooooooooooooooooo`000013oooo
o`00DOooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo01[ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0@_oo
ool005;ooooo0ol0000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`Co00002Oooool0
0ol0003oooooooooo`02ooooo`;o0000;oooool00ol0003oooooooooo`09ooooo`?o0000B?ooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.45105 .53015 .0045 0 365.73 arc
s
newpath
.85502 .50125 .0045 0 365.73 arc
s
newpath
.56825 .52177 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.45105 .53015 L
s
.41407 .12235 m
.85502 .50125 L
s
.45105 .53015 m
.85502 .50125 L
.56825 .52177 L
.45105 .53015 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.46605 .54515 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.87002 .51625 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.58325 .53677 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Ko00000_ooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0_l00002ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`001oooool2o`0000Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Ko
oooo0_l0002:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Q_ooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`24oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03ooo
ool2o`0008;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1nooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo07cooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool06?ooool2o`0007_ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1goooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo07Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0M?ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool08Oooool2o`0007Cooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1`ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01oooool000gooooo0ol00004oooo
o`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000<ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool01oooool000Kooooo1Ol00005ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0[ooooo`;o0000J_ooool3o`0000Wooooo000@ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool01oooool0
00cooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03?ooooo
0_l0001Uooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0HOooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo03cooooo0_l0001Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0F_ooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo05Oooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`16oooo
o`;o0000EOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0Coooool2o`0004oooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`1;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0Doooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Oooooo000Doooo
o`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`07oooo
o`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1Gooooo`;o0000B?ooool00ol0003oooooooooo`07oooo
o`004oooool01?l0003oooooooooool00004ooooooco00002Oooool001?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo1?l0000<oooo
o`Co0000GOooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000002o`00
01?ooooo1?l0001Kooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01oooool001Co
oooo0_l00005ooooo`03o`000?oooooooooo03Wooooo1?l0000Fooooo`04o`000?oooooooooooooo
o`?o0000FOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03Sooooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`05oooo
o`;o0000F?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03Kooooo0_l00003ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`08ooooo`;o0000Eoooool2o`0003oooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0cooooo`;o00001_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1Fooooo`;o0000>?ooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0FOooool2
o`0003;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000Zooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o
0000:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?oooolco`0004Kooooo0_l0000Yooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo1ol0000Iooooo`03o`00
0?oooooooooo01Oooooo0ol00015ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00gooooo0_l0000Oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
0000023ooooo00?o0000ooooooooool06Oooool2o`0004Gooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`00
0?ooool08?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01oooool3o`0000?ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Jooooo`;o0000A_ooool2o`0002Cooooo00?o0000ooooooooool01oooool0
013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o00009_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l00000
1?oooooo0000o`000?l00002ooooo`;o00007?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo03oooooo2?l0000Qooooo`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0booooo`go00001Oooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`Go00000_ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool09Oooool>o`0001;ooooo1Ol0000Pooooo`03o`000?oooooooooo00Oooooo000<oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00007?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01Wooooo3_l0000Pooooo`04o`000?ooooooooooo`0001oooooo
00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00007?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00cooooo3ol0000/ooooo`04o`000?ooooooooooo`0001oo
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000?ooooo
00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Iooooo`?o000000?oooooo`000?l0
00003Ol0000hooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
2ol0000Kooooo`03o`000?oooooooooo013ooooo4?l00014ooooo`04o`000?ooooooooooo`0001ko
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`?o00002?oooolCo`0000Oooooo
0ol00004oooooa3o00001oooool4o`000003ooooool0003o000004?ooooo00Co0000oooooooooooo
00007oooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000Vooooo`oo00005_ooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo047ooooo1?l0000Pooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool01?l0003ooooo
ooooool0000^ooooo`?o00006oooool01Ol0003oooooo`000?oooooo000006Sooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`04
o`000?ooooooooooo`0002oooooo0ol000001?oooooo0000o`000?l0000Eooooo`03o`000?oooooo
oooo00;o0000JOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo01Cooooo00Ko0000oooooooooooo0000ooooool0001Xooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04ooo
ool01?l0003oooooooooool0000^ooooo`03o`000?oooooo000000Co00005_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000Vooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000;_ooool01_l0003o
ooooooooool0003oooooo`0001Kooooo00?o0000ooooooooool00ol000000ooooooo0000o`00001U
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Coooo
o`04o`000?ooooooooooo`0002kooooo00Ko0000oooooooooooo0000ooooool0000Fooooo`03o`00
0?oooooooooo06cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0002kooooo00Go0000oooooooooooo
ooooo`00000Fooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0002ko
oooo00?o0000ooooooooool00_l0000Fooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`04o`00
0?ooooooooooo`0002gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1^ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
4Oooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Sooooo00?o0000ooooooooool0
4Oooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0K_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
4Oooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo017ooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool0
0000:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo077ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo07;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000[ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0L_ooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`1dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oo
oooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool05_ooool2o`0007Sooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07So
oooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;_ooool2o`00
00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01Cooooo0_l0001kooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000<Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l0000Looooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0NOooool3o`0000Wooooo0008ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1looooo`03o`000?oo
oooooooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`;o0000
Ooooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool04oooool2o`0001Cooooo0_l00021ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03Gooooo0_l00004ooooo`03o`000?oooooooooo00gooooo0_l0000?ooooo`;o00005?ooool2o`00
08Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000hooooo`?o000000?oooooo`000?oo
ool04?ooool2o`0000[ooooo0ol0000Dooooo`;o0000QOooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03[ooooo0_l0000Cooooo`?o00001_ooool00ol0003oooooooooo`0Booooo`?o0000
R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`;o00005Ooo
ool3o`000003ooooool0003o0000017ooooo1?l0002;ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000000ol0000Aooooo`Wo00002_ooool4
o`0008oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`03oooooa7o00002Oooool:o`0009?ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Ooo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001ooo
ool3o`0000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`2hooooo`?o00002Oooool000Sooooo00Co
0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o0000
0oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`04o`00
0?ooooooooooooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Kooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Coooooo?l00009
ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`3oooooo`Sooooo0006ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo2_ooool000Kooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo0000ooooool:ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o0000ooooool;oooo
o`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000=?ooool00ol0003oooooooooo`12ooooo`00
Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2o`0000?ooooo0ol00004ooooo`;o000000?o
ooooo`000?ooool00ol00002ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`00
0?l0003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`?o00001?ooool4o`0000?ooooo
0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00009ooooo`Co
00000oooool3o`0000Cooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`10ooooo`00
DOooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`05o`000?ooooooooooooooool000003_ooool00ol0003oooooo`000006ooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo043ooooo
001@ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`03
o`000?oooooooooo00Wooooo0ol00002ooooo`Go00000_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`;o0000
2Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`0:ooooo`;o00001Oooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003ooooo
ooooo`04ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co00001?ooool01?l0003o
ooooooooooooool3o`0000?ooooo1?l00003ooooo`Go00001oooool01?l0003oooooooooool00002
ooooo`;o00000oooool4o`0000?ooooo0ol00008ooooo`Co00000oooool2o`0000?ooooo0_l00000
0ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l0000<ooooo`05o`000?oooooo
ooooooooool00000@oooool0057ooooo00Co0000oooooooooooo00005Oooool00ol0003ooooooooo
o`0Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo04;ooooo001Booooo`?o00004oooool3o`0000Gooooo00?o0000ooooooooool0
4oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0002oooooo00?o0000ooooooooool0
2Oooool3o`0004Sooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.42766 .60215 .0045 0 365.73 arc
s
newpath
.82804 .54122 .0045 0 365.73 arc
s
newpath
.54382 .58447 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.42766 .60215 L
s
.41407 .12235 m
.82804 .54122 L
s
.42766 .60215 m
.82804 .54122 L
.54382 .58447 L
.42766 .60215 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.44266 .61715 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.84304 .55622 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.55882 .59947 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0ol0002Aooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool0002@ooooo`03o`000?oooooo
oooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`05o`000?oo
ooooooooooooool00000Soooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0S?ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000??ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0ROooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08Wooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo08Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0QOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0P_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
O_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07cooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`1looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
07_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1f
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool01oooool000gooooo0ol00004ooooo`;o00001Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool01oooool000Kooooo1Ol00005ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo06oooooo0ol00009ooooo`004?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`07ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo
000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo06cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Zooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0I?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo05kooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
05gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo05Oooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`07ooooo`004oooool0
1?l0003oooooooooool00004ooooooco00002Oooool001?ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo1?l0000<ooooo`Co0000D?oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000002o`0001?ooooo1?l0
001>ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01oooool001Cooooo0_l00005
ooooo`03o`000?oooooooooo03Wooooo1?l0000Fooooo`04o`000?ooooooooooooooo`?o0000C?oo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03Sooooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`05ooooo`;o0000Booo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03Kooooo0_l00003ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`08ooooo`;o0000B_ooool00ol0003oooooooooo`1;ooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0<oooool2o`0000Kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`07oooo
o`006oooool2o`0002oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`16ooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0?oooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01?oooolco`0003Gooooo00?o0000ooooooooool0>Oooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0>ooooo`Oo00006Oooool00ol0003oooooooooo`0Gooooo`?o0000<oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`;o00007oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo01Wooooo
0_l0000cooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01oooool000gooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool02_ooool2o`000003ooooool0003ooooo023ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01ooo
ool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo
0ol00003ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06_ooool2o`0003Cooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`07ooooo`004?ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000Vooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02o`000004ooooool0003o0000o`0000;o
oooo0_l0000Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0booooo`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool000cooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go0000
0oooool2o`0000Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooo`0001cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool3o`0000?ooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0002Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo0ol00004ooooo`;o00007Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0;Oooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo1?l0000Rooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000cooooo0_l0
000Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool04oooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo000002_ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0C
ooooo`04o`000?ooooooooooo`00013ooooo0_l0000Mooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0?_ooool3o`0002[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001;ooooo0_l0
000Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>oooool6o`0002[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0C
ooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo03Cooooo2?l00003ooooo`Go00009oooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0002Kooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0
000Eooooo`;o00005oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02kooooo2?l0
000<ooooo`04o`000?ooooooooooo`0002Gooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00005oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09oooool8o`0001?ooooo
00Co0000oooooooooooo00009_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo00006?ooool2o`0001Co
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Qooooo`Wo00006Oooool3o`0002Oo
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Booooo`04o`000?ooooooooooo`0001[ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo2Ol0000Pooooo`04o`000?ooooooooooo`00
02Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Booooo`04o`000?ooooooooooo`0001_ooooo0_l0000@ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool05?ooool9o`0002Oooooo00Co0000oooooooooooo00009_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
017ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool03Oooool:o`0002cooooo1?l0000Wooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000:?ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooooooo
o`0001kooooo0_l0000=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool:
o`0005gooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
017ooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Oooooo0_l00002ooooo`[o0000IOooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00008Oooool2
o`0000Wooooo00?o0000ooooooooool05?ooool;o`0006_ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooo
ooooool000008_ooool2o`0000Kooooo00?o0000ooooooooool03oooool;o`00077ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?oooo
o`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo2Ol00005ooooo`03o`000?oooooo000000;o000000?oooooo`000?l00000K?ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`;o00000_ooool00ol0
003oooooooooo`05ooooo`So00002_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool2o`0002_ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo0ol000000ooo
oooo0000o`000005o`00013ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00001]oooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool09?ooool4o`0001Oooooo00?o0000oooooooo
ool00_ooool2o`0006oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8oooool3o`0001Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`00001^ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_l0
00001?oooooo0000o`000?l0000Aooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
0000KOooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o0000
1Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`0>ooooo`;o00001_ooool3o`000003ooooool0003o000006cooooo00?o0000oooooooo
ool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool01?l0003oooooooooooooool5
o`0000oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0^ooooo`;o00002oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000>ooooo`;o0000Nooo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`00037ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`;o00007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo000000gooooo00?o0000ooooooooool0NOooool3o`0000Wooooo0008ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo07cooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Kooooo0_l0000;ooooo`;o0000Ooooool00ol0003oooooooooo`07oooo
o`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool04oooool2o`0001Cooooo0_l00021ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`21ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`03o`000?oo
oooooooo00gooooo0_l0000?ooooo`;o00005?ooool2o`0008Cooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000hooooo`?o000000?oooooo`000?ooool04?ooool2o`0000[ooooo0ol0000D
ooooo`;o0000QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03[ooooo0_l0000Coooo
o`?o00001_ooool00ol0003oooooooooo`0Booooo`?o0000R?ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`;o00005Oooool3o`000003ooooool0003o0000017o
oooo1?l0002;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooool000000ol0000Aooooo`Wo00002_ooool4o`0008oooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03oooooa7o00002Ooo
ool:o`0009?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooooooo
o`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o
00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0
003oooooooooo`2hooooo`?o00002Oooool000Sooooo00Co0000oooooooooooooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00000oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??oo
ool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Kooooo1Ol00003oooo
o`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3oooooo`So
oooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`000?oooooo2_ooool000Kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001ooo
ool3o`0000Cooooo0_l00004ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000V
ooooo`?o0000=?ooool00ol0003oooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11oooo
o`00D_ooool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go
000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`00
0?l000000_l00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`00
00?ooooo1?l000001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00009
ooooo`?o00001Oooool00ol0003oooooooooo`10ooooo`00DOooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo0ol00002
ooooo`Go00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool0
0ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`00
0004ooooool0003o0000ooooo`Co00001?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l0
0003ooooo`Go00001oooool01?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo
0ol00008ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co0000
0_ooool3o`0000;ooooo1?l0000<ooooo`05o`000?ooooooooooooooool00000@oooool0057ooooo
00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Boooo
o`?o00004oooool3o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000oooo
ooooool00_ooool2o`0002oooooo00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.3714 .65281 .0045 0 365.73 arc
s
newpath
.77314 .60158 .0045 0 365.73 arc
s
newpath
.48795 .63795 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.3714 .65281 L
s
.41407 .12235 m
.77314 .60158 L
s
.3714 .65281 m
.77314 .60158 L
.48795 .63795 L
.3714 .65281 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.3864 .66781 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.78814 .61658 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.50295 .65295 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0ol0002Aooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool0002@ooooo`03o`000?oooooo
oooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`05o`000?oo
ooooooooooooool00000Soooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Vooooo`05o`000?ooooooooooooooool00000Soooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0R_ooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o
0000??ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`24ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo083ooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`21ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo083ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1looooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07_o
oooo00?o0000ooooooooool01oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo07Wooooo00?o0000oooooooo
ool01oooool000Kooooo1Ol00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool2o`0003cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo07Oooooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`00
3?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1gooooo`03
o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go0000
0oooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo07Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1booooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo077ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o
0000??ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0K_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
06cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Joooool00ol0003o
ooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo06Wooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo06Wooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo06Cooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`07ooooo`004oooool01?l0003ooooooooo
ool00004ooooooco00002Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00;ooooo1?l0000<ooooo`Co0000@Oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooo`000002o`0001?ooooo1?l0000oooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`000?oo
oooooooo03Wooooo1?l0000Fooooo`04o`000?ooooooooooooooo`?o0000??ooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Sooooo00Co
0000oooooooooooo00005_ooool00ol0003oooooooooo`05ooooo`;o0000>oooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Kooooo0_l0
0003ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000f
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`;o0000>_ooool00ol0003oooooooooo`1Kooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0<oooool2o`0000Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`07ooooo`006oooool2o`00
02oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Gooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo05Oo
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000Zooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0D_ooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01?oooolco`00027ooooo00?o0000ooooooooool0COooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>
ooooo`Oo00006Oooool00ol0003oooooooooo`0Gooooo`?o00007oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0=ooooo`;o00007oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo01Wooooo0_l0000Nooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool01oooool000gooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2_ooool2o`000003ooooool0003ooooo023ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool01oooool000cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool06_ooool2o`0001oooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`07ooooo`004?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo0_l0000Vooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02o`000004ooooool0003o0000o`0000;ooooo0_l0000Loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`18oooo
o`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooooooo1Ol00002ooooo`04o`000?ooooooooooo`0001co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01?l0003o
ooooooooool0000Looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`00
01cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000?o
oooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo0ol00004ooooo`;o00007Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0A?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
0ol0000Sooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01?ooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04ooo
ool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`04o`000?oo
ooooooooo`0000cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
3Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o00009_oo
ool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
?oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04ooo
ool01?l0003oooooooooool0000>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`04o`000?oo
ooooooooo`0000kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo0000
3oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000?ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Sooooo00?o0000ooooooooool04Ooo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03_ooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo0000
4Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000Aooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool03oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool01oooool001_ooooo0_l0000[ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0iooooo`;o0000=oooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo03Kooooo1_l0000gooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo02oooooo2?l00004ooooo`Co0000=Oooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`So00003Oooool01?l0003ooooo
ooooool0000dooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Fooooo`;o00008oooool9o`0001Cooooo00Co0000oooooooooooo0000=?ooool00ol0003o
ooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`Wo00007?ooool3o`00
03Gooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0;_ooool2
o`0000_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05?ooool2o`0001Kooooo2Ol0000Tooooo`04o`000?oooooo
ooooo`0003Cooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo0_l0000aooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool2o`0000oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo2Ol0000/ooooo`04o`00
0?ooooooooooo`0003;ooooo0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07oooo
o`Wo0000<oooool4o`0003Gooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool3o`0000;ooooo2_l0001c
ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`;o00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo0_l0000Boooo
o`[o0000Noooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool9o`000004ooooool0003o0000o`00
07oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=Oooool2o`0000Co
oooo00?o0000ooooooooool03Oooool2o`0000cooooo0_l000000ooooooo0000o`000007ooooo`So
00001Oooool2o`0000Cooooo0ol000000ooooooo0000o`00001jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000>?ooool3o`000003ooooool0003ooooo013ooooo0_l0000:ooooo`?o0000
0_ooool8o`0000[ooooo0_l00007ooooo`04o`000?ooooooooooo`0007[ooooo0_l00009ooooo`00
6oooool00ol0003oooooooooo`0jooooo`;o00004oooool3o`0000Kooooo1_l0000?ooooo`?o0000
2Oooool00ol0003oooooo`00001looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo0_l0000Eooooo`?o000000?oooooo`000?l000000_ooool3o`000004ooooool0
003o0000o`0000Sooooo1?l0000<ooooo`;o0000OOooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000?o00004Oooool:o`0000?ooooo00?o
0000ooooooooool00oooool4o`00013ooooo00?o0000ooooool00000O?ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo4Ol00009
ooooo`[o00005?ooool01?l0003oooooooooool0001kooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07_ooool00ol0003oooooo`00000I
ooooo`?o000000?oooooo`000?l00000N_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo00?o0000ooooooooool07_ooool00ol0003oooooo`00002Hooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Nooooo`;o0000V_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooooooo
o`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o
00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool000Sooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0
003oooooooooo`2hooooo`?o00002Oooool000Sooooo00Co0000oooooooooooooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00000oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2
o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??oo
ool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Kooooo1Ol00003oooo
o`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3oooooo`So
oooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`000?oooooo2_ooool000Kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001ooo
ool3o`0000Cooooo0_l00004ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000V
ooooo`?o0000=?ooool00ol0003oooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11oooo
o`00D_ooool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go
000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`00
0?l000000_l00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`00
00?ooooo1?l000001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00009
ooooo`?o00001Oooool00ol0003oooooooooo`10ooooo`00DOooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo0ol00002
ooooo`Go00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool0
0ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`00
0004ooooool0003o0000ooooo`Co00001?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l0
0003ooooo`Go00001oooool01?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo
0ol00008ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co0000
0_ooool3o`0000;ooooo1?l0000<ooooo`05o`000?ooooooooooooooool00000@oooool0057ooooo
00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Boooo
o`?o00004oooool3o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000oooo
ooooool00_ooool2o`0002oooooo00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.29735 .66855 .0045 0 365.73 arc
s
newpath
.70211 .65481 .0045 0 365.73 arc
s
newpath
.41478 .66456 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.29735 .66855 L
s
.41407 .12235 m
.70211 .65481 L
s
.29735 .66855 m
.70211 .65481 L
.41478 .66456 L
.29735 .66855 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.31235 .68355 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.71711 .66981 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.42978 .67956 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0ol0002Aooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00002Aooooo`03o`000?oooooooooo
00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`04o`000?oooooo
ooooo`00093ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09_ooool0
1?l0003oooooooooool0002@ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2<ooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08_ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`28ooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo08?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Pooo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo087ooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo087o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0POooool00ol0003ooooo
ooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo083ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`07ooooo`001_oo
ool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000
??ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
OOooool3o`0000Wooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo07gooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo07cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0O?ooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo07[ooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1gooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
07Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0M_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0M?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Cooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo07?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0L_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1booooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0L?ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo077o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0L?ooool00ol0003ooooo
ooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`07ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`1^ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Coooooo?l0
0009ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool00_ooool4o`0000cooooo1?l0000dooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooo000000;o00004oooool4o`00037ooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>Oooool4
o`0001Kooooo00Co0000oooooooooooooooo0ol0000_ooooo`03o`000?oooooooooo06cooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo00Gooooo0_l0000]ooooo`03o`000?oooooooooo06cooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool2o`0003Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0_l0000[oooo
o`03o`000?oooooooooo06[ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0cooooo`;o
00001_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo06Kooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Ioooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Sooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000X
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04
oooooc?o00003oooool00ol0003oooooooooo`1Oooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo1ol0000Ioooo
o`03o`000?oooooooooo01Oooooo0ol0000<ooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00gooooo0_l0000Oooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooo0000023ooooo00?o0000ooooooooool06Oooool2o`0000_ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`;o000000?o
ooooo`000?ooool08?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool01oooool3o`0000?ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Jooooo`;o00002oooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo00Oooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool2o`0002Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;o000000Coooooo`000?l0003o00000_ooool2o`0001cooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05_ooooo0ol00009ooooo`00
4?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`07ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooooooool5o`0000;ooooo00Co0000oooooooooooo00007?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`07ooooo`003?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00007?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`?o00000oooool01?l0003ooooo
ooooool0000Looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o00009Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0000Cooooo
0_l0000Mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1Iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0002?ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0C
ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000Vooooo`03o`000?oooooo
oooo01?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Eooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0E?oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo017ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000:?ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0D_ooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo013ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0002_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Coooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0F
ooooo`;o00009oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Oooooo0008oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0^ooooo`;o00002oooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool000006oooool00ol0003oooooooooo`0Dooooo`;o
0000:oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`;o0000<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo0_l000000ooo
oooo0000ooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`1:ooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo0_l0000Iooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo0_l0000Hooooo`03o`000?oooooooooo01?ooooo0_l0000aooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooo000001Gooooo0_l0000Dooooo`;o0000=?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`04o`000?oooooooooo
o`0001?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=Oooool2o`00
00Cooooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool2o`0000oooooo0_l0000D
ooooo`;o0000>?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000>?ooool3o`000003ooooool0003ooooo00[ooooo00?o0000ooooooooool00oooool2o`00
00[ooooo0ol0000Dooooo`;o0000>_ooool3o`0004Sooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0jooooo`;o00002oooool00ol0003oooooooooo`05ooooo`?o00001_ooool00ol0003o
ooooooooo`0Booooo`?o0000:ooooolDo`0004Wooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool2o`0000[ooooo00?o0000ooooooooool02?ooool3o`000003oooo
ool0003o000000gooooo00Co0000oooooooooooooooo1?l0000:ooooobGo00004?ooool3o`0004Wo
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
o`000003o`0000Kooooo00?o0000ooooooooool02?oooolXo`0003Cooooo1?l00016ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00ooo
oolGo`0000?ooooo3?l00018ooooo`04o`000?ooooooooooo`0004Gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo000001cooooo0ol000000ooooooo0000o`000014ooooo`04o`000?ooooooooooo`0004Gooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo00Wooooo0ol0
00001?oooooo0000o`000?l0000Hooooo`04o`000?ooooooooooo`0004Gooooo0ol00015ooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool000006Oooool00ol0003oooooo`000016ooooo`04o`000?ooooooooooo`00
04Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0:ooooo`Go00006Oooool2o`0004Oooooo00Co0000oooooooooooo0000AOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooool000006_ooool00ol0003oooooo`000015ooooo`Co0000A_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooool000006_ooool01?l0003oooooooooool0002>ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Hooooo`?o000000?oooooo`000?l00000SOooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool02oooool2o`000:cooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooo
ooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0ol00003ooooo`?o00001?oo
ool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo0008ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0003cooooo
00?o0000ooooooooool0^?ooool3o`0000Wooooo0008ooooo`04o`000?ooooooooooooooo`Co0000
0oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`001oooool2o`0000?ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool01?l0003oooooooooooooool5o`0000?o
oooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2i
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o
0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0006ooooo`Go0000
0oooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`001oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooooco00002Oooool000Wooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0oooo
ool8ooooo`001_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool0003oooooo`[ooooo0006ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo2_ooool0
00Oooooo0ol00004ooooo`;o00001?ooool2o`000?oooooo2oooool006;ooooo0ol0000Fooooo`?o
00009_ooool3o`0003Cooooo00?o0000ooooooooool0@_ooool006?ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
@Oooool005;ooooo0_l00003ooooo`?o00001?ooool2o`000003ooooool0003ooooo00?o00000_oo
ool5o`000003ooooool0003o000000?o000000Goooooo`000?l0003o0000ooooo`02o`000003oooo
ool0003o000000;o00001oooool3o`0000Cooooo1?l00003ooooo`;o00000_ooool6o`0000Oooooo
0ol00003ooooo`Co000000Coooooo`000?l0003o00002Oooool4o`0000?ooooo0ol00004ooooo`;o
00002Oooool3o`0000Gooooo00?o0000ooooooooool0@?ooool0057ooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo
000000kooooo00?o0000ooooool000001_ooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00002ooooo`?o00000oooool00ol0003oooooooooo`09ooooo`?o
00000_ooool5o`0000;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`03o`000?oooooooooo00Kooooo0ol00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00000_ooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02_ooool2o`0000Go
oooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool01?ooool3o`0000;ooooo
0_l000001?oooooo0000o`000?ooool4o`0000Cooooo00Co0000oooooooooooooooo0ol00003oooo
o`Co00000oooool5o`0000Oooooo00Co0000oooooooooooo00000_ooool2o`0000?ooooo1?l00003
ooooo`?o00002?ooool4o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?l000002?ooool4
o`0000;ooooo0ol00002ooooo`Co00003?ooool01Ol0003ooooooooooooooooo000004?ooooo001A
ooooo`04o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool06_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`08ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`12ooooo`00
D_ooool3o`0001?ooooo0ol00005ooooo`03o`000?oooooooooo01?ooooo1?l00009ooooo`03o`00
0?oooooooooo00;ooooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo0ol00018ooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.22535 .64516 .0045 0 365.73 arc
s
newpath
.62775 .69095 .0045 0 365.73 arc
s
newpath
.34209 .65844 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.22535 .64516 L
s
.41407 .12235 m
.62775 .69095 L
s
.22535 .64516 m
.62775 .69095 L
.34209 .65844 L
.22535 .64516 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.24035 .66016 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.64275 .70595 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.35709 .67344 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0ol0002Aooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00002Aooooo`03o`000?oooooooooo
00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
0000097ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09_ooool01?l0
003oooooooooool0002@ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo0000093ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo02Gooooo00Go0000oooo
ooooooooooooo`00002?ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0SOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2<
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08_ooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2:ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Roooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2:ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`29ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0R?ooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`28oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo08Kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo
0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01oooool000cooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0QOooool00ol0003oooooooooo`07ooooo`001_ooool5o`0000Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0P_ooool3o`0000Wooooo000@ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`03
o`000?oooooooooo00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo08Cooooo00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08?ooooo00?o0000oooooooo
ool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`23ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
087ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`20
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`1oooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0O?ooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0OOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07cooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0N_ooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0N_ooool00ol0003oooooooooo`07ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool01oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00Oooooo
000Cooooo`04o`000?ooooooooooo`0000Coooooo?l00009ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool4o`0000cooooo
1?l0000Yooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool01oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000;o0000
4oooool4o`0002Kooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`005?oo
ool2o`0000Gooooo00?o0000ooooooooool0>Oooool4o`0001Kooooo00Co0000oooooooooooooooo
0ol0000Tooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>?ooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo00Gooooo
0_l0000Rooooo`03o`000?oooooooooo07Oooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0=_ooool2o`0000?ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Moooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0003Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Sooooo0_l0000Pooooo`03o`000?oooooooooo07Gooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0cooooo`;o00001_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1eooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
07?ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Loooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0Loooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0002[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1`ooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo073ooooo
00?o0000ooooooooool01oooool001_ooooo0_l0000Xooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`04ooooocCo0000L?ooool2o`0000Wooooo000K
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>
ooooo`Oo00006Oooool00ol0003oooooooooo`0Gooooo`?o0000Koooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool03Oooool2o`0001oooooo00?o0000ooooooooool06?ooool2o`0006oooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00cooooo00?o0000ooooool000008?ooool00ol0003oooooooooo`0Gooooo`04
o`000?oooooo0000o`0006gooooo00?o0000ooooooooool01oooool000gooooo0ol00004ooooo`;o
00001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02_ooool2o`000003ooooool0003ooooo023ooooo00?o0000ooooooooool05oooool01?l0003o
ooooooooool0001]ooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`07ooooo`?o00000oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01Sooooo00Co0000ooooool0003o0000K?ooool00ol0003ooooooooo
o`07ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0
000Vooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02o`000004ooooool0003o0000o`0000;ooooo0_l0000Looooo`03o`000?oooooooooo01Sooooo
00Co0000oooooooooooo0000J_ooool3o`0000Wooooo000@ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00Co0000
oooooooooooo0000K?ooool00ol0003oooooooooo`07ooooo`003?ooool4o`0000?ooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooooooool5o`0000;ooooo00Co0000oooooooooooo
00007?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000006cooooo00?o0000oooooooo
ool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000Loooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooool00000K?ooool00ol0003oooooooooo`07oooo
o`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01Wooooo0_l0001/oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0ol00003ooooo`04
o`000?ooooooooooo`0001cooooo00?o0000ooooooooool06Oooool2o`0006cooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000Uooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`?o00001?ooool2o`0001gooooo00?o0000oooooooo
ool06Oooool2o`0006_ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`?o0000
8oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooool00000Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000Joooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooool00000Joooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Kooooo00?o
0000ooooooooool04oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000006Wooooo0_l00009ooooo`00
6oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Wooooo00Go0000oooooooo
ooooooooo`00001Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Booooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000Xooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`1Uooooo`;o00002Oooool001_ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Aooooo`06o`000?ooooooooooo`000?oooooo0000:_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00Ko0000oooo
oooooooo0000ooooool0000Zooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000002[ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;o0000:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00Ko0000oooooooooooo0000ooooool0
000Xooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000:oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Hoooool2o`0000Wooooo000Koooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00gooooo0_l00004ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`07ooooo`001ooo
ool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00_ooooo0_l00006ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05_oo
ool2o`0001?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo0_l00007ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0;_ooool2o`0000Wooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01Cooooo0_l0000Gooooo`03o`000?oooooooooo067ooooo00?o0000oooooooo
ool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo0_l0000aooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ool000002Oooool2o`0001cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo05oooooo0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00002oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01?ooooo0_l0000Looooo`03o`000?oooooooooo063ooooo00?o0000oooooooo
ool01oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005ooooo`03o`00
0?oooooooooo03?ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04oooool2o`0001Cooooo0_l0000Nooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
o`000004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0dooooo`So00003oooool2o`0000oooooo0_l0
000Dooooo`;o00008_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000=_ooool@o`0000Sooooo0_l0000:ooooo`?o00005?ooool2o`0002Cooooo00?o0000
ooooooooool0G_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03Kooooo00Co0000oooo
oooooooooooo0_l00008ooooo`[o000000?oooooo`000?l000000ol00004ooooo`03o`000?oooooo
oooo01;ooooo0ol0000Vooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0=_ooool7o`00013ooooo2ol0000Aooooo`Co0000:_ooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Oo
oooo00Ko0000ooooool0003oooooo`000?ooool4o`00017ooooo3ol00004ooooo`Co0000;_ooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03Oooooo00Go0000ooooool0003oooooo`000005oooooa7o000000Goooooo`000?l0003o0000oooo
o`02o`0000;ooooo3ol0000^ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0000Hooooo`04o`000?oo
ooooooooo`00017ooooo2_l0000Uooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000hooooo`;o00000_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooo000001_ooooo2_l0000Looooo`03o`000?oooooooooo05cooooo0_l00009ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo0_l0000Uooooo`[o00005?ooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00000]ooooo`[o00002oooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool05_ooool01?l0003oooooooooool0000eooooo`[o00000_ooool3o`00
05cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Eooooo`?o000000?oooooo`000?l00000?Oooool6o`0005cooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1Kooooo`?o0000
G?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0GOoo
ool4o`0005Sooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo05kooooo00Co0000oooooooooooo0000F?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo0000F?oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo05kooooo0ol0001Iooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0G_ooool01?l0003oooooooooool0001Hooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0G_ooool01?l0
003oooooooooool0001Hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0GOooool4o`0005Wooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007
ooooo`?o00000oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool0
1?l0003oooooooooooooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l0
0003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co
0000oooooooooooooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
03cooooo00?o0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o
0000ooooooooool0^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`00
00Wooooo0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo0?oooooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool0003oooooo`[ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_o
oooo001Rooooo`?o00005_ooool3o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo
001Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l00000
0ooooooo0000ooooo`03o`0000;ooooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o
0000o`000?ooool00_l000000ooooooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000ooo
ool2o`0000;ooooo1_l00007ooooo`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo
1?l00003ooooo`?o00001?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo043ooooo
001Aooooo`06o`000?ooooooooooo`000?oooooo00000oooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0@?oo
ool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo
00?o0000ooooooooool02Oooool3o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l0
0009ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00[ooooo0_l00005ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oo
oooooooo00Cooooo0ol00002ooooo`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`04o`00
0?ooooooooooooooo`?o00000oooool4o`0000?ooooo1Ol00007ooooo`04o`000?ooooooooooo`00
00;ooooo0_l00003ooooo`Co00000oooool3o`0000Sooooo1?l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000000Sooooo1?l00002ooooo`?o00000_ooool4o`0000cooooo00Go0000oooo
ooooooooooooo`000013ooooo`00DOooool01?l0003oooooooooool0000Eooooo`03o`000?oooooo
oooo01[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool0@_ooool005;ooooo0ol0000Cooooo`?o00001Oooool00ol0003ooooooooo
o`0Cooooo`Co00002Oooool00ol0003oooooooooo`02ooooo`;o0000;oooool00ol0003ooooooooo
o`09ooooo`?o0000B?ooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo
8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.17469 .5889 .0045 0 365.73 arc
s
newpath
.56105 .71035 .0045 0 365.73 arc
s
newpath
.28678 .62413 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.17469 .5889 L
s
.41407 .12235 m
.56105 .71035 L
s
.17469 .5889 m
.56105 .71035 L
.28678 .62413 L
.17469 .5889 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.18969 .6039 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.57605 .72535 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.30178 .63913 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0_l0002Booooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00002Aooooo`03o`000?oooooooooo
00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
0000097ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooo`00002Aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0002Aooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Uooooo`05o`000?oooooooooooooo
ool00000Soooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool09Oooool01Ol0003ooooooooooooooooo0000093ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`05o`000?oooooooooooooo
ool00000T?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2>ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0S?ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2<ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08[ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`29ooooo`;o00002Oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool01oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`29ooooo`03
o`000?oooooooooo00Oooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool000Ko
oooo1Ol00005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`00
03cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
08Kooooo0ol00009ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`003?ooool4o`0000?o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo
00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`0000Go
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`26ooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0Q_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`26ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Q?ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`24ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08Cooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo08?ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`23ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo087ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo087ooooo00?o0000oooooooo
ool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0POooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooooco
00002Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00;ooooo1?l0000<ooooo`Co00008Oooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0>oooool00ol0003oooooo`000002o`0001?ooooo1?l0000Nooooo`03o`000?oooooooooo083o
oooo00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`000?oooooooooo03Wooooo
1?l0000Fooooo`04o`000?ooooooooooooooo`?o00006oooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo
00005_ooool00ol0003oooooooooo`05ooooo`;o00006Oooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool01oooool001_ooooo0_l0000fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`;o00005ooo
ool00ol0003oooooooooo`1nooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0<oooool2
o`0000Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1mooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo07gooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo07gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07gooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo07gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000Zooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0Noooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1kooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1koooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1?oooolco`00077ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03_ooool7o`0001Wooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`08ooooo`?o0000Koooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool2
o`0001oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooool000008?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l0001]ooooo`03o`000?oooooooooo
00Oooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0Pooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo00Oooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`07ooooo`?o00000oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool2o`0006cooooo00?o0000ooooooooool01oooool0013o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o00009_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l000001?oo
oooo0000o`000?l00002ooooo`;o00007?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0J?ooool3o`0000Wooooo000@ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo
000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooooooo`Go
00000_ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00007?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07
ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ool000000oooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo0ol00003ooooo`04o`000?ooooooooooo`0001cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000Uooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`?o00001?ooool2o`0001gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06Wooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`Go00008oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`;o0000:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00000oooool2o`0002[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Cooooo`05o`000?ooooooooooo`000?ooool00_l0000/ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02o`0002gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo06_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Cooooo`Co0000;_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool2
o`0002Kooooo00?o0000ooooooooool04_ooool2o`0000;ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Joooool2
o`0000Wooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03oooool3o`00
0005ooooool0003oooooooooool00000;_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo0_l00004ooooo`04o`000?oooooooooo
o`0002kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0:ooooo`;o00001_ooool01?l0003oooooooooool0000^ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool2o`00
00Sooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo0_l0000:ooooo`04o`000?oooooooooo
o`0002gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000Xooooo`03o`000?oooooooooo
00?ooooo0_l0000<ooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06kooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0Wooooo`04o`000?ooooooooooooooo`;o00003_ooool01?l0003oooooooooool0
000/ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1_ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00Co0000
ooooool0003o00004?ooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo01?ooooo
00Go0000ooooooooooooooooo`00001booooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo02Oooooo1?l0000@ooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003o
ooooooooo`0Dooooo`05o`000?ooooooooooooooool00000L_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0Xooooo`Ko00003Oooool01Ol0003ooooooooooooooooo0000
02Wooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00001cooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo0ol000000ooooooo0000o`000003o`0000[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Ko
oooo0_l0001dooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000:_ooool2o`0000;ooooo
00Co0000oooooooooooooooo0ol00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07;ooooo0_l00009ooooo`00
6oooool00ol0003oooooooooo`0Yooooo`Go00001_ooool4o`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Zooooo`?o00002_oo
ool5o`0000Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooo000007Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooo`00000=ooooo`Co00000oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01Oooooo00Co0000oooooooooooo0000M?ooool00ol0003oooooooooo`07ooooo`001oooool3
o`0000Cooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`;o00003_ooool0
0ol0003oooooo`000003o`000003ooooool0003ooooo027ooooo00?o0000ooooooooool05_ooool2
o`0000?ooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`0Zooooo`;o000000?oooooo`000?ooool03?ooool00ol0003ooooooooo
o`02ooooo`Ko00007oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0^ooooo`;o00002oooool00ol0003oooooooooo`05ooooo`Go00007?ooool00ol0003ooooo
ooooo`0Dooooo`;o00001oooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`;o0000<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Ko
oooo1ol0000Hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1_ooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0ol000000ooooooo0000o`000003o`00
01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool01?l0003oooooo`000?l00003ooooo`Co00004?oo
ool00ol0003oooooooooo`0Cooooo`;o00002oooool00ol0003oooooooooo`1aooooo`03o`000?oo
oooooooo00Oooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
1?l0003oooooo`000?l00006ooooo`Co00002oooool2o`0001Cooooo0_l0000>ooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`03o`000?oooooo
oooo00Kooooo1?l00007ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03Gooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000000_ooool2o`00
00Wooooo1?l00002ooooo`;o00005?ooool2o`00017ooooo00?o0000ooooooooool0L?ooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003Sooooo0ol000000ooooooo0000ooooo`09ooooo`04
o`000?ooooooooooo`0000?ooooo0_l0000:ooooo`Co00004oooool2o`0001?ooooo00?o0000oooo
ooooool0Koooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03[ooooo0_l00009ooooo`?o
000000?oooooo`000?l000001?ooool3o`0000Kooooo00?o0000ooooooooool00_ooool3o`0000go
oooo0ol0000Eooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool2o`0001Gooooo0ol000000ooooooo0000o`000008ooooo`?o0000
1_ooool4o`0001Wooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000?o00004Oooool9o`0000Sooooo1_l0
000Mooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`03oooooa7o00002Oooool:o`000003ooooool0003o
000000;o00007?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0:oooool4o`0001Wooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooooooo
ool0;_ooool4o`0001Oooooo00?o0000ooooooooool0KOooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0<Oooool4o`0001Cooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo03Gooooo0ol0000Aooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0hooooo`?o00003_ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0>oooool3o`0000cooooo00?o0000ooooooooool0KOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03ko
oooo0ol00009ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo047ooooo0ol00006ooooo`03o`000?oooooooooo06cooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo04Cooooo0ol0
0003ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`17ooooo`?o000000?oooooo`000?l00000KOooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
04[ooooo0_l000000ooooooo0000ooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0Boooool2o`0006gooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1<ooooo`Co0000
J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo04gooooo00Co0000oooooooooooo0000JOooool00ol0003oooooooooo`07ooooo`006ooo
ool2o`0003cooooo00?o0000ooooooooool0COooool01?l0003oooooooooool0001Xooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`1=ooooo`?o0000J_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo04gooooo00Co0000oooooooooooo0000JOooool00ol0003oooooooooo`07ooooo`001oooool3
o`0000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo04gooooo00Co0000oooooooooooo0000JOooool00ol0003oooooooooo`07ooooo`002?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0C?ooool4o`0006[ooooo
00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003ooooo
ooooo`2hooooo`?o00002Oooool000Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0007ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Go
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0
003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooooooo
o`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Kooooo1Ol00003ooooo`;o0000
1?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`000?oooooo2_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001oooool3o`00
00Cooooo0_l00004ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o
0000=?ooool00ol0003oooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_oo
ool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go000000?o
ooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l00000
0_l00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo
1?l000001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00009ooooo`?o
00001Oooool00ol0003oooooooooo`10ooooo`00DOooool01_l0003oooooooooool0003oooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000;ooooo0ol00003ooooo`03o`000?oooooooooo00Wooooo0ol00002ooooo`Go
00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool00ol0003o
ooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`000004oooo
ool0003o0000ooooo`Co00001?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l00003oooo
o`Go00001oooool01?l0003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00008
ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool3
o`0000;ooooo1?l0000<ooooo`05o`000?ooooooooooooooool00000@oooool0057ooooo00Co0000
oooooooooooo00005Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Booooo`?o0000
4oooool3o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000ooooooooool0
0_ooool2o`0002oooooo00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.15895 .51485 .0045 0 365.73 arc
s
newpath
.50928 .71805 .0045 0 365.73 arc
s
newpath
.26059 .5738 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.15895 .51485 L
s
.41407 .12235 m
.50928 .71805 L
s
.15895 .51485 m
.50928 .71805 L
.26059 .5738 L
.15895 .51485 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.17395 .52985 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.52428 .73305 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.27559 .5888 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0_l0002Booooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool2o`0009;ooooo00?o0000ooooooooool01oooool000Oo
oooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool00000TOooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`00
00Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo0000
097ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Uooooo`04o`000?ooooooooooo`00097ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000T?ooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool01?l0003o
ooooooooool0002Aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0002Aooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09?ooool01Ol0003o
oooooooooooooooo0000097ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0S_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2>ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`2=ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0S_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0SOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2=
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S?ooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo08gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
SOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2=ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08_o
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01oooool000cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Roooool0
0ol0003oooooooooo`07ooooo`001_ooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`;o0000??ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0ROooool3o`0000Wooooo000@ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooo
oooo00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01oooool0
00cooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Wooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0R_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`29ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`28ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0ROooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0ROooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`28
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Qoooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo08Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`28ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Q_ooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`07ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04
o`000?ooooooooooo`0000Coooooo?l00009ooooo`004oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool4o`0000cooooo1?l0000Koooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000;o00004oooool4o`00
01Sooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Go
oooo00?o0000ooooooooool0>Oooool4o`0001Kooooo00Co0000oooooooooooooooo0ol0000Eoooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>?ooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo00Gooooo0_l0000Coooo
o`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0=_ooool2o`0000?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07ooooo`00
6oooool2o`0003Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Sooooo0_l0000Aooooo`03o`000?oooooooooo08Cooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0cooooo`;o00001_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`25ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08?ooooo0_l0
0009ooooo`006oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0Q?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Q?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Q?oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
02[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`22ooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08?ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08?ooooo00?o0000oooo
ooooool01oooool001_ooooo0_l0000Xooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`04oooooc?o0000LOooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`Oo0000
6Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo0ol0001_ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0=ooooo`;o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooo`00000Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool2
o`0006gooooo00?o0000ooooooooool01oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool2o`00
0003ooooool0003ooooo023ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool000cooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo0ol00003ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`;o0000K?ooool0
0ol0003oooooooooo`07ooooo`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo0_l0000Vooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02o`000004ooooool0003o0000o`0000;ooooo0_l0000Looooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Xooooo`?o00002Ooo
ool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooooooo1Ol00002ooooo`04o`000?ooooooooooo`0001cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo02Cooooo0_l0000Eooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0001cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooo000000Wo00003?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooool000000oooool01?l0003oooooooooool0000Looooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Cooooo0_l000000ooooooo0000o`000006
oooooa;o00001oooool3o`0000?ooooo00Co0000oooooooooooo00007?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0002Gooooo0ol000001?oooooo0000o`000?l0000@ooooo`03o`000?oo
oooooooo00;ooooo2ol00004ooooo`;o00007Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo02Cooooo0_l00003ooooo`?o00003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo0ol0000Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
02Gooooo1Ol00002ooooo`;o00003Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool2o`000003ooooool0003ooooo
00Cooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo0_l000000ooooooo0000ooooo`05oooo
o`;o00002_ooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooool000002Oooool2o`0000Sooooo00Co0000oooo
oooooooo0000;_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Uoooo
o`?o00002oooool2o`0000Kooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07
ooooo`006oooool2o`0002Kooooo00?o0000ooooooooool03?ooool2o`0000Gooooo00Co0000oooo
oooooooo0000;_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool03_ooool2o`0000?ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo0_l000001Ooo
oooo0000oooooooooooo000002kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0@ooooo`?o00000_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1]oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04_ooool2o`000003ooooool0003ooooo02cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo000000;o0000
;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Sooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooo`000002o`0002cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo06kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?l000000ooooooo0000o`00000V
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1_
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool04Oooool01ol0003oooooooooool0003oooooo`000?ooool00_l0000Wooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04?ooool0
1?l0003oooooooooooooool2o`000003ooooool0003o000000;o00009?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo0ol00003ooooo`;o00008_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooo`000004ooooo`;o00008?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`07ooooo`006oooool2o`00
02_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo0ol0000Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1booooo`;o00002Oooool001_ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0=ooooo`04o`000?ooooooooooooooo`?o000000?oooooo`000?l000001Oooool2
o`0001_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo07?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool2o`00
01Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
07Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool2o`0001Ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool01oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool3o`0001?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`03ooooo`;o0000N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`;o00004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`0^ooooo`;o00002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00cooooo0_l0000?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_l0001koooo
o`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000<Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo0_l0000>ooooo`;o00003?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooo000007_ooooo0ol00009ooooo`002?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0<ooooo`;o00002_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo07cooooo00?o
0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`;o00001oooool00ol0003ooooo
ooooo`0Cooooo`?o0000O_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool2o`0000?ooooo0_l0
000Dooooo`;o00000_ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00kooooo0_l000000ooooooo0000ooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0eooooo`;o00001?ooool00ol0003oooooooooo`0=ooooo`;o00003oooool3o`00
01?ooooo0_l00005ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000hooooo`?o000000?oooooo`000?ooool04?ooool2o`0000[ooooo0ol00003ooooo`;o
00003oooool2o`0000Oooooo00?o0000ooooooooool0Noooool2o`0000Wooooo000Kooooo`03o`00
0?oooooooooo03[ooooo0_l0000Cooooo`?o00001_ooool00ol0003oooooooooo`06ooooo`;o0000
2_ooool3o`0000Wooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`;o00005Oooool3o`000003ooooool0003o000000[ooooo0_l0
0005ooooo`Co00003Oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000000ol0000Aooooo`Wo00002Oooool5
o`00017ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo4Ol00009ooooo`[o000000?oooooo`00
0?l000004_ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0:Oooool2o`00017ooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
:oooool2o`0000oooooo00?o0000ooooooooool0N_ooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0;Oooool2o`0000gooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo02oooooo0_l0000<ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0`ooooo`;o00002oooool00ol0
003oooooooooo`1jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0<_ooool2o`0000Wooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Cooooo
0_l00007ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0g
ooooo`;o00001?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>Oooool2o`0000;ooooo00?o0000oooo
ooooool0N_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03_ooooo00Co0000oooooooooooo0000Noooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo1?l0001jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
?Oooool2o`000003ooooool0003ooooo07Sooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`;o0000N_ooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0?oooool4o`0007Kooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo043ooooo00Co0000oooo
oooooooo0000M_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo043ooooo00Co0000oooooooooooo0000M_ooool00ol0003oooooooooo`07
ooooo`001oooool3o`0000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo043ooooo0ol0001gooooo`03o`000?oooooooooo00Oooooo0008ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`10ooooo`04o`000?oooooo
ooooo`0007Kooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`10ooooo`04o`000?ooooooooooo`0007Kooooo00?o0000ooooooooool0
1oooool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo03oooooo1?l0001eooooo`?o0000
2Oooool000Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo0007ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Gooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2ioooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool000Kooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oo
oooo2_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001oooool3o`0000Cooooo0_l00004oooo
o`;o0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000=?ooool00ol0003o
ooooooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2o`0000?ooooo0ol0
0004ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go000000?oooooo`000?l000000ol0
00001Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`?o0000
1?ooool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l000001?oooooo0000
o`000?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00009ooooo`?o00001Oooool00ol0003o
ooooooooo`10ooooo`00DOooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooo`000006
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo0ol00003ooooo`03o`000?oooooooooo00Wooooo0ol00002ooooo`Go00000_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool0053ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
1_ooool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oo
ooooooooooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool00ol0003oooooooooo`10ooooo`00
D?ooool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co
00001?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l00003ooooo`Go00001oooool01?l0
003oooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00008ooooo`Co00000oooool2
o`0000?ooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l0000<
ooooo`05o`000?ooooooooooooooool00000@oooool0057ooooo00Co0000oooooooooooo00005Ooo
ool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo04;ooooo001Booooo`?o00004oooool3o`0000Gooooo
00?o0000ooooooooool04oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0002oooooo
00?o0000ooooooooool02Oooool3o`0004Sooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.18234 .44285 .0045 0 365.73 arc
s
newpath
.47788 .71976 .0045 0 365.73 arc
s
newpath
.26809 .52319 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.18234 .44285 L
s
.41407 .12235 m
.47788 .71976 L
s
.18234 .44285 m
.47788 .71976 L
.26809 .52319 L
.18234 .44285 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.19734 .45785 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.49288 .73476 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.28309 .53819 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0_l0002Booooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool2o`0009;ooooo00?o0000ooooooooool01oooool000Oo
oooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo0_l0002Booooo`03o`000?oooooo
oooo00Oooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo0_l0002Booooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool01?l0003o
ooooooooool0002Aooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`0Uooooo`04o`000?ooooooooooo`00093ooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000TOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Go
oooo00Co0000oooooooooooo0000TOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00Go0000ooooooooooooooooo`00002Aoooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool09?ooool01Ol0003ooooooooooooooooo0000097ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooooooooooo
ool00000TOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02Cooooo00Go0000ooooooooooooooooo`00002Aooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0S_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08kooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0S_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0S_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08gooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2<ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo08gooooo00?o0000ooooooooool01oooool000gooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08go
oooo00?o0000ooooooooool01oooool000Kooooo1Ol00005ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo08_ooooo0ol00009ooooo`004?ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0SOooool00ol0003o
ooooooooo`07ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`2<ooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2;oooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo08cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Roooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0R_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08_ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0Roooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08[ooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo08[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0R_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo08[ooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`07ooooo`004ooo
ool01?l0003oooooooooool00004ooooooco00002Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo1?l0000<ooooo`Co0000
6?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000002o`0001?ooooo
1?l0000Eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool001Cooooo0_l0
0005ooooo`03o`000?oooooooooo03Wooooo1?l0000Fooooo`04o`000?ooooooooooooooo`?o0000
4_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03Sooooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`05ooooo`;o0000
4?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03Kooooo0_l00003ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01ooo
ool001_ooooo0_l0000fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`08ooooo`;o00003Oooool00ol0003oooooooooo`28ooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0<oooool2o`0000Kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0R?ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0R?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0002oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`27oooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo08Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo08Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:_ooool3
o`0000kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0Yooooo`Co00003_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02[ooooo0ol0000>ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oo
oooo00?o0000ooooooooool01oooool001_ooooo0_l0000Zooooo`03o`000?oooooo000000Go0000
2_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`26ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooo`000002ooooo`;o00002oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`27ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01ol00009
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooo
oooo000008Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:?ooool0
2_l0003ooooooooooooooooo0000ooooool0003oooooo`000?ooool2o`0000Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000ROooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00029ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000ROooool00ol0003oooooooooo`07
ooooo`006oooool2o`0002Sooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?oooolc
o`00077ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000ooooo`0?ooooo`Oo00006Oooool0
1?l0003oooooooooool0000Fooooo`?o0000Koooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo0_l00003ooooo`;o00003oooool2
o`0001oooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool2
o`0000?ooooo0_l0000=ooooo`03o`000?oooooo0000023ooooo00?o0000ooooool000006Oooool2
o`0006gooooo00?o0000ooooooooool01oooool000gooooo0ol00004ooooo`;o00001Oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00Ko0000oooooooooooo0000ooooool0
000:ooooo`;o000000?oooooo`000?ooool08?ooool00ol0003oooooo`00000Jooooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooo000000;ooooo0_l00005ooooo`?o00000oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooo000001[ooooo0_l0001/ooooo`03o`000?oooooooooo00Oooooo
000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0002Kooooo
00?o0000ooooooooool04_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`;o
000000Coooooo`000?l0003o00000_ooool2o`0001cooooo00?o0000ooooool000006oooool00ol0
003oooooooooo`1Xooooo`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`03ooooo`?o00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00006oooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`;o00001_ooool2o`0000;ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0001cooooo0_l0000Kooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003ooooo
o`000004ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000oooool01?l0003o
ooooooooool0000Looooo`;o00006oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo
00Oooooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool3o`00
0003ooooool0003ooooo00;ooooo00Co0000oooooooooooo00007?ooool00ol0003oooooo`00000J
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooooooo`?o00001_ooool3
o`0000?ooooo00Co0000oooooooooooo00007?ooool00ol0003oooooo`00000Jooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000Uooooo`03o`000?oooooo
oooo01Cooooo00Co0000oooooooooooooooo0ol00006ooooo`?o00001?ooool2o`0001gooooo00?o
0000ooooool000006_ooool00ol0003oooooooooo`1Yooooo`;o00002Oooool001_ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooooooo`Co00001Ooo
ool3o`0002?ooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool0
1_l0003ooooooooooooooooo0000ooooo`?o000000?oooooo`000?l000009oooool00ol0003ooooo
o`00000Jooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000?ooooo
1?l0000Xooooo`03o`000?oooooo000001[ooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooo`000?l0000Xooooo`03o`000?oooooo000001Wo
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00000oooool2o`0000;o
oooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo
06_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`0Sooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool0Joooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0002Kooooo00?o0000ooooooooool04oooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool08_oo
ool01?l0003oooooooooool0000Hooooo`03o`000?oooooooooo06_ooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
0_ooool3o`000003ooooool0003o000000;ooooo00?o0000ooooooooool08Oooool01Ol0003ooooo
oooooooooooo000001Oooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000005_ooool00ol0
003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo
01oooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Boooo
o`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00Co0000oooo
oooooooo00003_ooool2o`0001gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01oooool001_ooooo0_l0000Xoooo
o`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00003oooool2o`0001cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06kooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00Co0000oooo
oooooooo00004?ooool2o`0001[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0001;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo073ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1a
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0L_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo07Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00001?ooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0_l0001hooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo0_l00009ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo02kooooo0_l0000;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05?ooool2o`0000Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`06ooooo`;o0000Noooool00ol0003oooooooooo`07ooooo`002?ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool2o`00037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`;o0000
5Oooool2o`0000Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07Wooooo0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`05
o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool01oooool000Oooooo0_l00004ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
0000017ooooo00Co0000oooooooooooooooo0_l0001oooooo`03o`000?oooooooooo00Oooooo0008
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0C
ooooo`;o00004_ooool01?l0003oooooo`000?l00021ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00004Oooool2o`0008?ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=Oooool2o`0000Cooooo00?o0000
ooooooooool03Oooool2o`0000oooooo0_l00004ooooo`03o`000?oooooooooo00gooooo0_l00024
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000>?ooool3o`000003ooooool0003ooooo
013ooooo0_l0000:ooooo`?o00001oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`00
0?ooool0P_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03[ooooo0_l0000Cooooo`?o
00001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo0ol00003ooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool2o`0001Gooooo0ol000000ooooooo0000o`00000=ooooo`04o`000?ooooooooooooooo`Co
00001_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooool000000ol0000Aooooo`Wo00002_ooool4o`0000[ooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00?ooooo4Ol00009ooooo`[o00000_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Zooooo`;o00002_ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0P?ooool2o`0000Wooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
POooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`21ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`07ooooo`006oooool2o`0003co
oooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooooooo000008;ooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooo
ooooooooo`000022ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool00022ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooo`000022ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0=_ooool2o`0008;ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0eooooo`04o`000?oooooo0000o`00087ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0fooooo`;o0000P_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000
ooooooooool0=oooool4o`0007kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo0000O_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Sooooo00Co0000oooo
oooooooo0000O_ooool00ol0003oooooooooo`07ooooo`001oooool3o`0000?ooooo0ol00004oooo
o`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Sooooo0ol0001ooooo
o`03o`000?oooooooooo00Oooooo0008ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`0007kooooo00?o0000ooooooooool01ooo
ool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0hooooo`04o`000?oo
ooooooooo`0007kooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`03o`00
0?oooooooooo03Oooooo1?l0001mooooo`?o00002Oooool000Sooooo00Co0000oooooooooooooooo
1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00000oooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0008ooooo`04o`000?ooooooooooooooo`Go
00000oooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooo
oooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[o
oooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo
0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2j
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??oo
ool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Kooooo
1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Coooooo?l00009ooooo`002Oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`3oooooo`Sooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`000?oooooo2_ooool000Kooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool:
ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o0000ooooool;ooooo`00H_ooool3o`0001Ko
oooo0ol0000Vooooo`?o0000=?ooool00ol0003oooooooooo`12ooooo`00Hoooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`11ooooo`00D_ooool2o`0000?ooooo0ol00004ooooo`;o000000?oooooo`000?ooool00ol0
0002ooooo`Go000000?oooooo`000?l000000ol000001Ooooooo0000o`000?l0003ooooo00;o0000
00?oooooo`000?l000000_l00007ooooo`?o00001?ooool4o`0000?ooooo0_l00002ooooo`Ko0000
1oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00009ooooo`Co00000oooool3o`0000Co
oooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`10ooooo`00DOooool01_l0003ooooo
ooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000;ooooo0ol00003ooooo`03o`000?oooooooooo00Wo
oooo0ol00002ooooo`Go00000_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0
003oooooo`0000?ooooo00?o0000ooooooooool01_ooool3o`0000;ooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`;o00002Oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0:ooooo`;o
00001Oooool00ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`04ooooo`?o0000
0_ooool2o`000004ooooool0003o0000ooooo`Co00001?ooool01?l0003oooooooooooooool3o`00
00?ooooo1?l00003ooooo`Go00001oooool01?l0003oooooooooool00002ooooo`;o00000oooool4
o`0000?ooooo0ol00008ooooo`Co00000oooool2o`0000?ooooo0_l000000ooooooo0000o`000008
ooooo`Co00000_ooool3o`0000;ooooo1?l0000<ooooo`05o`000?ooooooooooooooool00000@ooo
ool0057ooooo00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`0Jooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo04;o
oooo001Booooo`?o00004oooool3o`0000Gooooo00?o0000ooooooooool04oooool4o`0000Wooooo
00?o0000ooooooooool00_ooool2o`0002oooooo00?o0000ooooooooool02Oooool3o`0004Sooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.2386 .39219 .0045 0 365.73 arc
s
newpath
.47674 .71979 .0045 0 365.73 arc
s
newpath
.30769 .48723 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.2386 .39219 L
s
.41407 .12235 m
.47674 .71979 L
s
.2386 .39219 m
.47674 .71979 L
.30769 .48723 L
.2386 .39219 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.2536 .40719 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.49174 .73479 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.32269 .50223 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0_l0002Booooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool2o`0009;ooooo00?o0000ooooooooool01oooool000Oo
oooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo0_l0002Booooo`03o`000?oooooo
oooo00Oooooo0008ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00001Oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo02Kooooo0_l0002Booooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool01?l0003o
ooooooooool0002Aooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`0Uooooo`04o`000?ooooooooooo`00093ooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co0000oooooooooooo0000TOooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Go
oooo00Co0000oooooooooooo0000TOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00Go0000ooooooooooooooooo`00002Aoooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool09?ooool01Ol0003ooooooooooooooooo0000097ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Tooooo`05o`000?oooooooooooooo
ool00000TOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02Cooooo00Go0000ooooooooooooooooo`00002Aooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0S_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08oooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0S_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo08kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0S_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08gooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo08kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2<ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo08gooooo00?o0000ooooooooool01oooool000gooooo0ol00004ooooo`;o0000
1Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08go
oooo00?o0000ooooooooool01oooool000Kooooo1Ol00005ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool2o`0003cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo08_ooooo0ol00009ooooo`004?ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0SOooool00ol0003o
ooooooooo`07ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2=ooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000loooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2;oooo
o`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo08cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0S?ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0Roooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08_ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0Roooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08[ooooo0_l00009ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Roooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08Wooooo0_l00009
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001Cooooo0_l00005ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo08[ooooo00?o0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`07ooooo`004ooo
ool01?l0003oooooooooool00004ooooooco00002Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo1?l0000<ooooo`Co0000
5oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000002o`0001?ooooo
1?l0000Eooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool001Cooooo0_l0
0005ooooo`03o`000?oooooooooo03Sooooo1Ol0000Fooooo`04o`000?ooooooooooooooo`?o0000
4_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03Oooooo0_l000000ooooooo0000o`00000Fooooo`03o`000?oooooooooo00Gooooo0_l0
000@ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0=_ooool4o`000003ooooool0003ooooo01Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000fooooo`04o`000?ooooooooooooooo`Ko00004oooool00ol0003oooooooooo`08
ooooo`;o00003Oooool00ol0003oooooooooo`28ooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0<oooool2o`0000Cooooo0ol000000ooooooo0000ooooo`0Booooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01?ooool5o`0001?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`06ooooo`?o00005?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Oooooo0ol0000Dooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00000B
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000;oooool00ol0003oooooooooo`09oooo
o`Go00004Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0Qoooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02_ooool2o`000003ooooool0003ooooo013ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo0000ooooool0
00004?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03?oo
ool01Ol0003oooooooooool0003ooooo00;o00003Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002[ooooo00?o
0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000ROooool2o`0000Wo
oooo000Kooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;o00002Oooool00ol0003oooooooooo`0Hooooo`05o`00
0?ooooooooooooooool00000R_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo0000R_ooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool06_ooool01Ol0003ooooooooooooooooo000008Wooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01_ooooo00Co0000
oooooooooooo0000ROooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooooooo
ool2o`0000Gooooo00?o0000ooooooooool07?ooool00ol0003oooooo`000029ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo<ol0
001aooooo`;o00002Oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooo
ool7o`0001Wooooo00?o0000ooooool000005oooool3o`0006oooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooooooo1Ol0000Oooooo`03o`000?oooooo000001Wooooo00?o
0000ooooooooool0KOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`Co00008?ooool2o`0001[ooooo0_l0001]ooooo`03o`000?oooooooooo00Oooooo000=oooo
o`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?l0000Qooooo`;o00006oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000<ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`07ooooo`?o00000oooool3o`000003ooooool0003o
000001cooooo0_l0000Kooooo`;o0000K?ooool00ol0003oooooooooo`07ooooo`004?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000Vooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000002o`000004ooooool0003o
0000o`0000;ooooo0_l0000Looooo`;o00007?ooool00ol0003oooooooooo`1Xooooo`?o00002Ooo
ool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;o00000oooool4o`0000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooo`00
000Kooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool000cooooo1?l00003
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo2?l00002ooooo`03o`00
0?oooooooooo01[ooooo0_l0000Kooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
1oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo0_l000001_oooooo0000ooooool0003oooooo`0000;ooooo00?o0000oooo
ooooool06_ooool2o`0001_ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07oooo
o`003?ooool5o`0000?ooooo0_l00005ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooool0
003oooooo`000?ooool2o`000003ooooool0003ooooo01_ooooo0_l0000Kooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool:o`00
01cooooo0_l0000Kooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000Uooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`?o00001?ooool2o`0001gooooo0_l0000Kooooo`03o`000?oooooooooo06Wo
oooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`?o00001_ooool00ol0003ooooo
ooooo`0Jooooo`;o00006oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool01Ol0003ooooooooo
oooooooo0000017ooooo0_l0000Kooooo`;o00006oooool00ol0003oooooooooo`1Zooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04ooo
ool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo01Wooooo0_l0000Kooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool0
6?ooool2o`0001[ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000
5?ooool2o`0001Sooooo00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
4oooool01?l0003oooooooooool0000Eooooo`;o00005oooool01?l0003oooooooooool0000Ioooo
o`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000Vooooo`03
o`000?oooooooooo01?ooooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`0Eoooo
o`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool0Joooool2o`0000Wooooo000Koooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000G
ooooo`03o`000?oooooooooo01Cooooo00Co0000oooooooooooo00006?ooool00ol0003ooooooooo
o`1/ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool04_ooool01?l0003oooooooooool0000Gooooo`;o00005Oooool01?l0003ooooooooo
ool0000Gooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0001Sooooo
00?o0000ooooooooool04oooool01?l0003oooooooooool0000Gooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Booooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool04Oooool01Ol0003o
oooooooooooooooo000001Kooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo00006_ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000005_ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000:?ooool00ol0
003oooooooooo`0Aooooo`04o`000?ooooooooooo`0001[ooooo0_l0000Aooooo`05o`000?oooooo
ooooooooool000005Oooool00ol0003oooooooooo`1^ooooo`;o00002Oooool001_ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0001_ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0Koooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00007?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool04?ooool01Ol0003ooooooooooooooooo000001_ooooo0_l0000=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1`ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03oooool0
1Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07;ooooo00?o0000
ooooooooool01oooool001_ooooo0_l0000[ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07;ooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Kooooo`;o00001oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1eooooo`03o`000?oo
oooooooo00Oooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00[ooooo0_l0
001hooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo
0_l00002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1hooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02ko
oooo0_l0000;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo00Kooooo0_l0001kooooo`03o`000?oooooooooo00Oo
oooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`;o0000<Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo0_l0000Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1iooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooo`00000=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`07ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo0000
3Oooool00ol0003oooooooooo`02ooooo`;o0000Ooooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04ooo
ool2o`0000Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02o`00087ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000Poooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0eooooo`;o00001?ooool00ol0003oooooooooo`0=oooo
o`;o00003oooool2o`0000Sooooo0_l0000:ooooo`;o0000Q?ooool00ol0003oooooooooo`07oooo
o`006oooool2o`0003Sooooo0ol000000ooooooo0000ooooo`0@ooooo`;o00002_ooool3o`0000_o
oooo00?o0000ooooooooool01_ooool3o`0008Cooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0jooooo`;o00004oooool3o`0000Kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`?o00000_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo0_l0000Eooooo`?o000000?oooooo`000?l000004Ooo
ool4o`0000Gooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooo000000?o00004Oooool9o`0000[ooooo1_l00008
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`03oooooa7o00002Oooool:o`0000Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`21ooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0aooooo`05o`000?ooooooooooooooool00000Q?ooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo037ooooo00Go0000oooooooo
ooooooooo`000024ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003o
ooooooooo`0booooo`04o`000?ooooooooooo`0008?ooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo0000Poooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03?o
oooo00Co0000oooooooooooo0000Poooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000Poooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Gooooo
0_l00023ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0=Oooool3o`0008;ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0eooooo`?o0000P_ooool00ol0003oooooooooo`07
ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0=oooool4o`0007kooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooo
oooo0000O_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03Sooooo00Co0000oooooooooooo0000O_ooool00ol0003oooooooooo`07oooo
o`001oooool3o`0000?ooooo0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03Sooooo0ol0001oooooo`03o`000?oooooooooo00Oooooo0008ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0hooooo`04o`000?oooooooooo
o`0007kooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`0007kooooo00?o0000ooooooooool01ooo
ool000Sooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo03Oooooo1?l0001mooooo`?o00002Ooo
ool000Sooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0007ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
0008ooooo`04o`000?ooooooooooooooo`Go00000oooool2o`0000Gooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool0
01_ooooo0_l0000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o
00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool000Kooooo1Ol00003ooooo`;o00001?ooool2o`0000Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Coooooo?l00009ooooo`002Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`3oooooo`Sooooo0006ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo
2_ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo0000ooooool:ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o
0000ooooool;ooooo`00H_ooool3o`0001Kooooo0ol0000Vooooo`?o0000=?ooool00ol0003ooooo
ooooo`12ooooo`00Hoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`11ooooo`00D_ooool2o`0000?ooooo0ol00004
ooooo`;o000000?oooooo`000?ooool00ol00002ooooo`Go000000?oooooo`000?l000000ol00000
1Ooooooo0000o`000?l0003ooooo00;o000000?oooooo`000?l000000_l00007ooooo`?o00001?oo
ool4o`0000?ooooo0_l00002ooooo`Ko00001oooool3o`0000?ooooo1?l000001?oooooo0000o`00
0?l00009ooooo`Co00000oooool3o`0000Cooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`10ooooo`00DOooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooo`000006oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo043ooooo001@ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo
0ol00003ooooo`03o`000?oooooooooo00Wooooo0ol00002ooooo`Go00000_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool0053ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_oo
ool3o`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00002ooooo`04o`000?oooooo
ooooooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`0:ooooo`;o00001Oooool00ol0003oooooooooo`10ooooo`00D?oo
ool00ol0003oooooooooo`04ooooo`?o00000_ooool2o`000004ooooool0003o0000ooooo`Co0000
1?ooool01?l0003oooooooooooooool3o`0000?ooooo1?l00003ooooo`Go00001oooool01?l0003o
ooooooooool00002ooooo`;o00000oooool4o`0000?ooooo0ol00008ooooo`Co00000oooool2o`00
00?ooooo0_l000000ooooooo0000o`000008ooooo`Co00000_ooool3o`0000;ooooo1?l0000<oooo
o`05o`000?ooooooooooooooool00000@oooool0057ooooo00Co0000oooooooooooo00005Oooool0
0ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo04;ooooo001Booooo`?o00004oooool3o`0000Gooooo00?o
0000ooooooooool04oooool4o`0000Wooooo00?o0000ooooooooool00_ooool2o`0002oooooo00?o
0000ooooooooool02Oooool3o`0004Sooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.31265 .37645 .0045 0 365.73 arc
s
newpath
.53493 .71501 .0045 0 365.73 arc
s
newpath
.37714 .47467 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.31265 .37645 L
s
.41407 .12235 m
.53493 .71501 L
s
.31265 .37645 m
.53493 .71501 L
.37714 .47467 L
.31265 .37645 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.32765 .39145 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.54993 .73001 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.39214 .48967 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0_l0002Booooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00002Aooooo`03o`000?oooooooooo
00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
0000097ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooo`00002Aooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0002Aooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`00
093ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Go
oooo00Go0000ooooooooooooooooo`00002@ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo0000
093ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0S_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0SOooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08cooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo08gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0SOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0Roooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0R_ooool2o`0000Wooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo
00Oooooo000=ooooo`?o00001?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0R_ooool00ol0003o
ooooooooo`07ooooo`003?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo0006ooooo`Go
00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000loooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`28oooo
o`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool000cooooo1?l00003ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`07oooo
o`003?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0ROooool00ol0003oooooooooo`07ooooo`003?ooool5o`0000?ooooo0_l00005ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
ROooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`28ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Qoooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
08Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0R?ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0Qoooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Kooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`25ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Oooooo000K
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`25ooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
1oooool001_ooooo0_l0000looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`23ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Q?ooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo
00Oooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00Oo
oooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Q?ooool00ol0003o
ooooooooo`07ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool03?ooool3o`0000Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Co
ooooo?l00009ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool00_ooool4o`0000Kooooo0ol00003ooooo`Co00007_ooool00ol0003o
ooooooooo`23ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0>oooool00ol0003oooooo`000002o`0000_ooooo0ol000001Ooooooo
0000o`000?l0003ooooo00Co00006oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo
00Oooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0iooooo`Co00003_ooool3o`0000;o
oooo00Co0000oooooooooooo00000oooool3o`0001Sooooo00?o0000ooooooooool0Poooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`00
00oooooo1_l000000ooooooo0000ooooo`06ooooo`;o00005oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`;o0000=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo
00Go0000ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00Sooooo0_l0000Dooooo`03
o`000?oooooooooo087ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0cooooo`;o0000
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool0
3?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00gooooo00Go0000ooooool0003o0000ooooo`02o`0000kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo0_l0000?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0POoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000004?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool001_o
oooo0_l0000_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`04o`000?oooooo0000o`00013ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`20ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool0000Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0POooool00ol0
003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000004?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o
00004?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo083ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`20ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0P?oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0
000@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0P?ooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0002[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0O_ooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`05o`000?oooooo
ooooooooool000002?ooool2o`00013ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000002Ooo
ool2o`00013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00002oooool2o`00013ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`04o`000?oooooo
ooooo`0000cooooo0ol0000?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0002Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooo000000Kooooo<ol0001aooooo`;o00002Oooool0
01_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00cooooo00?o0000ooooool000001_l00007ooooo`?o00003oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00cooooo0ol0001_ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`?o
00003oooool3o`000003ooooool0003o000000[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo
00?o0000ooooool000004?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03oooool2o`0006gooooo00?o0000ooooooooool01oooool000gooooo
0ol00004ooooo`;o00001Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo013ooooo0ol0000=ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1[ooooo`03o`00
0?oooooooooo00Oooooo000<ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`07ooooo`?o000000Coooooo`000?oooooo00004Oooool2o`0000kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0?ooooo`;o0000K?ooool00ol0003oooooooooo`07oooo
o`004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000Voooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06o`00
00;ooooo0_l0000<ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo06Sooooo0ol00009ooooo`004?ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00Wo0000ooooooooooooooooo`000?oo
oooo0000ooooool000000_ooool01?l0003oooooooooool0000;ooooo`04o`000?oooooo0000o`00
00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool01oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooooooo1Ol00002ooooo`04o`000?ooooooooooo`0000[ooooo0ol0
00000ooooooo0000o`00000<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`?o00000ooo
ool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0
1oooool000cooooo1Ol00003ooooo`;o00001Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`?o00000ooo
ool01?l0003oooooooooool0000?ooooo`;o00002oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`?o00000oooool01?l0003oooooooooool0000@ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000Uooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`?o00001?oo
ool2o`0001;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0JOooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo0ol0000Hooooo`;o00002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000T
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0002Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00009_ooool2o`0000Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06_ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Coooo
o`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooo
oooooooo0000:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o00009_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0002Sooooo0_l00004
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1[
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Coooo
o`04o`000?ooooooooooo`0002Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00Co0000oooo
oooooooo0000:_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000Zooooo`;o00000_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0KOoo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01;ooooo00Co0000oooooooooooo0000:oooool00ol0003oooooo`00000>ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo0000;?oo
ool2o`0000oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1^ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o0000:?ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo
ooooo`0002cooooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0K_oo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooool0000/ooooo`;o00003oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooool000003_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool01ooo
ool001_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooo
ooooooooool00000:_ooool00ol0003oooooooooo`02o`0000gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000002Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0LOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000[oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00Cooooo0_l0000<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0L_ooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Loooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000007Ko
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`08ooooo`;o00002oooool00ol0003oooooo`00001gooooo`03o`000?oooooooooo00Oooooo
0007ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`;o0000N?ooool00ol0003ooooooooo
o`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01oooool2o`0007Wooooo00?o0000ooooooooool01oooool000Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0;_ooool2o`0000_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00cooooo0_l00006ooooo`;o000000?oooooo`000?oo
ool0N?ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool2o`00037ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`;o00007?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00001gooooo`?o00002Oooool0
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00Oooooo
0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo0000o`00
00Kooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool2o`0001Co
oooo0_l00008ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0eooooo`;o00001?ooool00ol0003oooooooooo`0=ooooo`;o00003oooool2o`0001Cooooo
0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003Sooooo0ol000000ooooooo0000ooooo`0@ooooo`;o00002_oo
ool3o`0001Cooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0M?oo
ool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03[ooooo0_l0000Cooooo`?o00001_ooool0
0ol0003oooooooooo`0Booooo`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`00
01Gooooo0ol000000ooooooo0000o`00000Aooooo`Co00003?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooo`000003o`00017ooooo2Ol0000:ooooo`Co00004Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooooooool01oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`03oooooa7o00002Oooool:o`0001Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool01oooool001_ooooo0_l0000l
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1c
ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0ooooo
o`05o`000?ooooooooooooooool00000M_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo03oooooo00Go0000ooooooooooooooooo`00001f
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0@?ooool01?l0003oooooooooool0001fooooo`03o`000?oooooooooo00Oooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0@Oooool01?l0003oooooooooool0001e
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0@Oooool01?l0003oooooooooool0001eooooo`03o`000?oooooooooo00Oooooo000Koooo
o`;o0000??ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo000007Cooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo04?ooooo0_l0001eooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
@oooool2o`0007Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`14ooooo`?o0000Loooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo04Cooooo0ol0001cooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0A?ooool3o`00
07?ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`16ooooo`Co0000L?ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo
00?o0000ooooooooool0Aoooool01?l0003oooooooooool0001^ooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`17ooooo`04o`000?ooooooooooo`0006oo
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`17ooooo`?o0000L?ooool00ol0003oooooooooo`07ooooo`001oooool3o`0000?ooooo0ol0
0004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo04Oooooo00Co
0000oooooooooooo0000Koooool00ol0003oooooooooo`07ooooo`002?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0Aoooool01?l0003oooooooooool0001_oooo
o`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0A_ooool4o`00073ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000loooo
o`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool01?l0003oooooooooooooool4o`00
00?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00003ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co0000oooooooooooooooo1Ol00003
ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001_ooool5o`00
00?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo0009ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0?oo
oooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooo`[ooooo
0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo001Rooooo`?o00005_ooool3
o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo001Sooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo0000ooooo`03o`0000;o
oooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00007oooo
o`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo1?l00003ooooo`?o00001?ooool2
o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo043ooooo001Aooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00?o0000ooooooooool02Oooool3
o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00[ooooo0_l00005
ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002oooo
o`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o00000ooo
ool4o`0000?ooooo1Ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co0000
0oooool3o`0000Sooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo
1?l00002ooooo`?o00000_ooool4o`0000cooooo00Go0000ooooooooooooooooo`000013ooooo`00
DOooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0@_ooool0
05;ooooo0ol0000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`Co00002Oooool00ol0
003oooooooooo`02ooooo`;o0000;oooool00ol0003oooooooooo`09ooooo`?o0000B?ooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .875 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.25 0.0025 0.375 0.0025 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -18 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -6 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -12 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -18 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .875 .125 0 ]
[ 1 0 .125 0 ]
[.5 .8875 -74 0 ]
[.5 .8875 74 12 ]
[ 0 0 0 0 ]
[ 1 .875 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-50)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(50)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(100)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(150)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(200)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(250)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(300)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-100)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-50)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(0)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(50)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(100)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(150)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(200)] -0.0125 .875 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
.25 Mabswid
0 0 m
0 .875 L
s
0 .86875 m
0 .875 L
s
.125 .86875 m
.125 .875 L
s
.25 .86875 m
.25 .875 L
s
.375 .86875 m
.375 .875 L
s
.5 .86875 m
.5 .875 L
s
.625 .86875 m
.625 .875 L
s
.75 .86875 m
.75 .875 L
s
.875 .86875 m
.875 .875 L
s
.125 Mabswid
.025 .87125 m
.025 .875 L
s
.05 .87125 m
.05 .875 L
s
.075 .87125 m
.075 .875 L
s
.1 .87125 m
.1 .875 L
s
.15 .87125 m
.15 .875 L
s
.175 .87125 m
.175 .875 L
s
.2 .87125 m
.2 .875 L
s
.225 .87125 m
.225 .875 L
s
.275 .87125 m
.275 .875 L
s
.3 .87125 m
.3 .875 L
s
.325 .87125 m
.325 .875 L
s
.35 .87125 m
.35 .875 L
s
.4 .87125 m
.4 .875 L
s
.425 .87125 m
.425 .875 L
s
.45 .87125 m
.45 .875 L
s
.475 .87125 m
.475 .875 L
s
.525 .87125 m
.525 .875 L
s
.55 .87125 m
.55 .875 L
s
.575 .87125 m
.575 .875 L
s
.6 .87125 m
.6 .875 L
s
.65 .87125 m
.65 .875 L
s
.675 .87125 m
.675 .875 L
s
.7 .87125 m
.7 .875 L
s
.725 .87125 m
.725 .875 L
s
.775 .87125 m
.775 .875 L
s
.8 .87125 m
.8 .875 L
s
.825 .87125 m
.825 .875 L
s
.85 .87125 m
.85 .875 L
s
.9 .87125 m
.9 .875 L
s
.925 .87125 m
.925 .875 L
s
.95 .87125 m
.95 .875 L
s
.975 .87125 m
.975 .875 L
s
.25 Mabswid
0 .875 m
1 .875 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.25 Mabswid
1 0 m
1 .875 L
s
0 .375 m
1 .375 L
s
.25 0 m
.25 .875 L
s
gsave
.5 .8875 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Coupling) show
117.000 13.000 moveto
(Path) show
147.000 13.000 moveto
(par) show
171.000 13.000 moveto
(set) show
195.000 13.000 moveto
(3) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.000 13.000 moveto
(L) show
207.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .875 L
0 .875 L
closepath
clip
newpath
.5 Mabswid
.25 .375 m
.25 .375 L
.25001 .375 L
.25001 .375 L
.25001 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25002 .375 L
.25003 .375 L
.25003 .375 L
.25003 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25004 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25005 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25006 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25007 .375 L
.25008 .375 L
.25008 .375 L
.25008 .375 L
.25009 .375 L
.25009 .375 L
.25009 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.2501 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25011 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25012 .375 L
.25013 .375 L
.25013 .375 L
Mistroke
.25013 .375 L
.25013 .375 L
.25013 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25014 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25015 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25016 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25017 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25018 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.25019 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.2502 .375 L
.25021 .375 L
.25021 .375 L
.25021 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25022 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25023 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25024 .375 L
.25025 .375 L
.25025 .375 L
Mistroke
.25025 .375 L
.25025 .375 L
.25026 .375 L
.25026 .375 L
.25026 .375 L
.25027 .375 L
.25027 .375 L
.25027 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25028 .375 L
.25029 .375 L
.25029 .375 L
.25029 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.2503 .375 L
.25031 .375 L
.25031 .375 L
.25031 .375 L
.25032 .375 L
.25032 .375 L
.25032 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25033 .375 L
.25034 .375 L
.25034 .375 L
.25034 .375 L
.25035 .375 L
.25035 .375 L
.25035 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25036 .375 L
.25037 .375 L
.25037 .375 L
.25037 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25038 .375 L
.25039 .375 L
.25039 .375 L
.25039 .375 L
.2504 .375 L
Mistroke
.2504 .375 L
.2504 .375 L
.2504 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25041 .375 L
.25042 .375 L
.25042 .375 L
.25042 .375 L
.25043 .375 L
.25043 .375 L
.25043 .375 L
.25044 .375 L
.25044 .375 L
.25044 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25045 .375 L
.25046 .375 L
.25046 .375 L
.25046 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25047 .375 L
.25048 .375 L
.25048 .375 L
.25048 .375 L
.25049 .375 L
.25049 .375 L
.25049 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.2505 .375 L
.25051 .375 L
.25051 .375 L
.25051 .375 L
.25052 .375 L
.25052 .375 L
.25052 .375 L
.25053 .375 L
.25053 .375 L
.25053 .375 L
.25054 .375 L
.25054 .375 L
.25054 .375 L
Mistroke
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25055 .375 L
.25056 .375 L
.25056 .375 L
.25056 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25057 .375 L
.25058 .375 L
.25058 .375 L
.25058 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.25059 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.2506 .375 L
.25061 .375 L
.25061 .375 L
.25061 .375 L
.25062 .375 L
.25062 .375 L
.25062 .375 L
.25063 .375 L
.25063 .375 L
.25063 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25064 .375 L
.25065 .375 L
.25065 .375 L
.25065 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25066 .375 L
.25067 .375 L
.25067 .375 L
.25067 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25068 .375 L
.25069 .375 L
Mistroke
.25069 .375 L
.25069 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.2507 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25071 .375 L
.25072 .375 L
.25072 .375 L
.25072 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25073 .375 L
.25074 .375 L
.25074 .375 L
.25074 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25075 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25076 .375 L
.25077 .375 L
.25077 .375 L
.25077 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25078 .375 L
.25079 .375 L
.25079 .375 L
.25079 .375 L
.2508 .375 L
.2508 .375 L
.2508 .375 L
.25081 .375 L
.25081 .375 L
.25081 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25082 .375 L
.25083 .375 L
Mistroke
.25083 .375 L
.25083 .375 L
.25084 .375 L
.25084 .375 L
.25084 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25085 .375 L
.25086 .375 L
.25086 .375 L
.25086 .375 L
.25087 .375 L
.25087 .375 L
.25087 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25088 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.25089 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.2509 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25091 .375 L
.25092 .375 L
.25092 .375 L
.25092 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25093 .375 L
.25094 .375 L
.25094 .375 L
.25094 .375 L
.25095 .375 L
.25095 .375 L
.25095 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
.25096 .375 L
Mistroke
.25097 .375 L
.25097 .375 L
.25097 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25098 .375 L
.25099 .375 L
.25099 .375 L
.25099 .375 L
.251 .375 L
.251 .375 L
.251 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25101 .375 L
.25102 .375 L
.25102 .375 L
.25102 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25103 .375 L
.25104 .375 L
.25104 .375 L
.25104 .375 L
.25105 .375 L
.25105 .375 L
.25105 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25106 .375 L
.25107 .375 L
.25107 .375 L
.25107 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25108 .375 L
.25109 .375 L
.25109 .375 L
.25109 .375 L
.2511 .375 L
.2511 .375 L
.2511 .375 L
.25111 .375 L
.25111 .375 L
.25111 .375 L
Mistroke
.25111 .375 L
.25111 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25112 .375 L
.25113 .375 L
.25113 .375 L
.25113 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25114 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25115 .375 L
.25116 .375 L
.25116 .375 L
.25116 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25117 .375 L
.25118 .375 L
.25118 .375 L
.25118 .375 L
.25119 .375 L
.25119 .375 L
.25119 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.2512 .375 L
.25121 .375 L
.25121 .375 L
.25121 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25122 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25123 .375 L
.25124 .375 L
.25124 .375 L
.25124 .375 L
.25125 .375 L
.25125 .375 L
Mistroke
.25125 .375 L
.25126 .375 L
.25126 .375 L
.25126 .375 L
.25127 .375 L
.25127 .375 L
.25127 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25128 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.25129 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.2513 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25131 .375 L
.25132 .375 L
.25132 .375 L
.25132 .375 L
.25133 .375 L
.25133 .375 L
.25133 .375 L
.25134 .375 L
.25134 .375 L
.25134 .375 L
.25135 .375 L
.25135 .375 L
.25135 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25136 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25137 .375 L
.25138 .375 L
.25138 .375 L
.25138 .375 L
.25139 .375 L
Mistroke
.25139 .375 L
.25139 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.2514 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25141 .375 L
.25142 .375 L
.25142 .375 L
.25142 .375 L
.25143 .375 L
.25143 .375 L
.25143 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25144 .375 L
.25145 .375 L
.25145 .375 L
.25145 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25146 .375 L
.25147 .375 L
.25147 .375 L
.25147 .375 L
.25148 .375 L
.25148 .375 L
.25148 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.25149 .375 L
.2515 .375 L
.2515 .375 L
.2515 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25151 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25152 .375 L
.25153 .375 L
.25153 .375 L
Mistroke
.25153 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25154 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25155 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25156 .375 L
.25157 .375 L
.25157 .375 L
.25157 .375 L
.25158 .375 L
.25158 .375 L
.25158 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.25159 .375 L
.2516 .375 L
.2516 .375 L
.2516 .375 L
.25161 .375 L
.25161 .375 L
.25161 .375 L
.25162 .375 L
.25162 .375 L
.25162 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25163 .375 L
.25164 .375 L
.25164 .375 L
.25164 .375 L
.25165 .375 L
.25165 .375 L
.25165 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25166 .375 L
.25167 .375 L
.25167 .375 L
.25167 .375 L
Mistroke
.25168 .375 L
.25168 .375 L
.25168 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.25169 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.2517 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25171 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25172 .375 L
.25173 .375 L
.25173 .375 L
.25173 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25174 .375 L
.25175 .375 L
.25175 .375 L
.25175 .375 L
.25176 .375 L
.25176 .375 L
.25176 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25177 .375 L
.25178 .375 L
.25178 .375 L
.25178 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.25179 .375 L
.2518 .375 L
.2518 .375 L
.2518 .375 L
.25181 .375 L
.25181 .375 L
Mistroke
.25181 .375 L
.25181 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25182 .375 L
.25183 .375 L
.25183 .375 L
.25183 .375 L
.25184 .375 L
.25184 .375 L
.25184 .375 L
.25185 .375 L
.25185 .375 L
.25185 .375 L
.25186 .375 L
.25186 .375 L
.25186 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25187 .375 L
.25188 .375 L
.25188 .375 L
.25188 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.25189 .375 L
.2519 .375 L
.2519 .375 L
.2519 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25191 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25192 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25193 .375 L
.25194 .375 L
.25194 .375 L
.25194 .375 L
.25195 .375 L
.25195 .375 L
.25195 .375 L
Mistroke
.25195 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25196 .375 L
.25197 .375 L
.25197 .375 L
.25197 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25198 .375 L
.25199 .375 L
.25199 .375 L
.25199 .375 L
.252 .375 L
.252 .375 L
.252 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25201 .375 L
.25202 .375 L
.25202 .375 L
.25202 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25203 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25204 .375 L
.25205 .375 L
.25205 .375 L
.25205 .375 L
.25206 .375 L
.25206 .375 L
.25206 .375 L
.25207 .375 L
.25207 .375 L
.25207 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25208 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
.25209 .375 L
Mistroke
.2521 .375 L
.2521 .375 L
.2521 .375 L
.2521 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25211 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25212 .375 L
.25213 .375 L
.25213 .375 L
.25213 .375 L
.25214 .375 L
.25214 .375 L
.25214 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25215 .375 L
.25216 .375 L
.25216 .375 L
.25216 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25217 .375 L
.25218 .375 L
.25218 .375 L
.25218 .375 L
.25219 .375 L
.25219 .375 L
.25219 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.2522 .375 L
.25221 .375 L
.25221 .375 L
.25221 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25222 .375 L
.25223 .375 L
.25223 .375 L
Mistroke
.25223 .375 L
.25224 .375 L
.25224 .375 L
.25224 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25225 .375 L
.25226 .375 L
.25226 .375 L
.25226 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25227 .375 L
.25228 .375 L
.25228 .375 L
.25228 .375 L
.25229 .375 L
.25229 .375 L
.25229 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.2523 .375 L
.25231 .375 L
.25231 .375 L
.25231 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25232 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25233 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25234 .375 L
.25235 .375 L
.25235 .375 L
.25235 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25236 .375 L
.25237 .375 L
.25237 .375 L
.25237 .375 L
Mistroke
.25237 .375 L
.25238 .375 L
.25238 .375 L
.25238 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.25239 .375 L
.2524 .375 L
.2524 .375 L
.2524 .375 L
.25241 .375 L
.25241 .375 L
.25241 .375 L
.25242 .375 L
.25242 .375 L
.25242 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25243 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25244 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25245 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25246 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25247 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25248 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.25249 .375 L
.2525 .375 L
.2525 .375 L
Mistroke
.2525 .375 L
Mfstroke
.47518 .47476 m
.48644 .47438 L
.49821 .47395 L
.50387 .47376 L
.50689 .47368 L
.50969 .47362 L
.51093 .4736 L
.51223 .47358 L
.51291 .47357 L
.51364 .47356 L
.51493 .47355 L
.51608 .47355 L
.51731 .47355 L
.51845 .47356 L
.51949 .47357 L
.52017 .47358 L
.5208 .4736 L
.52198 .47362 L
.52323 .47366 L
.52457 .47371 L
.52692 .47383 L
.52901 .47397 L
.53125 .47416 L
.53361 .47442 L
.53812 .47511 L
.54182 .4759 L
.54548 .47697 L
.54865 .47817 L
.55132 .47945 L
.5538 .48092 L
.55621 .48268 L
.55995 .48631 L
.56171 .48858 L
.56317 .49088 L
.56455 .49355 L
.56582 .49666 L
.56675 .49961 L
.56743 .50248 L
.56798 .50564 L
.56821 .50746 L
.56837 .50915 L
.56843 .50992 L
.56848 .51075 L
.56852 .51147 L
.56855 .51224 L
.56857 .51309 L
.56858 .51388 L
.56859 .51436 L
.56859 .51482 L
.56858 .5157 L
Mistroke
.56856 .51646 L
.56854 .51728 L
.5685 .51806 L
.56847 .51877 L
.56835 .52052 L
.56821 .52219 L
.56781 .52567 L
.56721 .52955 L
.56549 .53755 L
.56331 .54513 L
.56079 .55229 L
.55328 .56874 L
.54446 .58351 L
.53255 .59936 L
.51978 .61305 L
.48991 .63671 L
.4737 .646 L
.45494 .65432 L
.43672 .66018 L
.42634 .66261 L
.42172 .66348 L
.41679 .66428 L
.41186 .66493 L
.40739 .66541 L
.40523 .66559 L
.4029 .66576 L
.40072 .66589 L
.39868 .66599 L
.39744 .66604 L
.39631 .66607 L
.39505 .6661 L
.39436 .66612 L
.39371 .66613 L
.39308 .66613 L
.39241 .66614 L
.3912 .66614 L
.39053 .66614 L
.38991 .66613 L
.38922 .66612 L
.38848 .66611 L
.38735 .66609 L
.38611 .66605 L
.38362 .66595 L
.38133 .66583 L
.3792 .66569 L
.37454 .66527 L
.36953 .66468 L
.36059 .66322 L
.35208 .66133 L
.34443 .65918 L
Mistroke
.3291 .6535 L
.31357 .64552 L
.30043 .63654 L
.28811 .62552 L
.27771 .61317 L
.27366 .60717 L
.26989 .6006 L
.26667 .59386 L
.26425 .58766 L
.26229 .58136 L
.26089 .57539 L
.26033 .57227 L
.25985 .56885 L
.25967 .56712 L
.25951 .56528 L
.25944 .56438 L
.25939 .56354 L
.25936 .56278 L
.25932 .56195 L
.2593 .56119 L
.25928 .56047 L
.25928 .55971 L
.25927 .5589 L
.25928 .55818 L
.25929 .55743 L
.25931 .55679 L
.25933 .55609 L
.25936 .55525 L
.2594 .5545 L
.25952 .55281 L
.25966 .55125 L
.25982 .54978 L
.26023 .54678 L
.26082 .54352 L
.26243 .53703 L
.26442 .53119 L
.26672 .5259 L
.26991 .51994 L
.27346 .51455 L
.28141 .50518 L
.29178 .49638 L
.30304 .48949 L
.31024 .48612 L
.31748 .48334 L
.32433 .48121 L
.33225 .47924 L
.34068 .47763 L
.34516 .47695 L
.35008 .47633 L
.35482 .47584 L
Mistroke
.35925 .47548 L
.36381 .47518 L
.36822 .47495 L
.37302 .47478 L
.3758 .4747 L
.37844 .47465 L
.37988 .47463 L
.38125 .47461 L
.38251 .47459 L
.38385 .47458 L
.38532 .47458 L
.38669 .47457 L
.38753 .47457 L
.38832 .47457 L
.38982 .47457 L
.39103 .47458 L
.39237 .47458 L
.39378 .47459 L
.3951 .4746 L
.40006 .47465 L
.40557 .47473 L
.41159 .47483 L
.42426 .47504 L
.42781 .47509 L
.4316 .47514 L
.43485 .47517 L
.43661 .47519 L
.43847 .4752 L
.44008 .47521 L
.44094 .47521 L
.44185 .47521 L
.44347 .47522 L
.44497 .47522 L
.44588 .47522 L
.44686 .47521 L
.4478 .47521 L
.44866 .47521 L
.45029 .4752 L
.45201 .47519 L
.45515 .47516 L
.45808 .47513 L
.4613 .47508 L
.46474 .47502 L
.47518 .47476 L
Mfstroke
newpath
.305 .5225 .14625 0 365.73 arc
s
newpath
.305 .5225 .0045 0 365.73 arc
s
newpath
.38465 .39984 .0045 0 365.73 arc
s
newpath
.69667 .65805 .0045 0 365.73 arc
s
newpath
.47518 .47476 .0045 0 365.73 arc
s
newpath
.41407 .12235 .0045 0 365.73 arc
s
.305 .5225 m
.41407 .12235 L
s
.305 .5225 m
.38465 .39984 L
s
.41407 .12235 m
.69667 .65805 L
s
.38465 .39984 m
.69667 .65805 L
.47518 .47476 L
.38465 .39984 L
s
gsave
.32 .5075 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A0) show
1.000 setlinewidth
grestore
gsave
.39965 .41484 -66.0312 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
1.000 setlinewidth
grestore
gsave
.71167 .67305 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
1.000 setlinewidth
grestore
gsave
.49018 .48976 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
1.000 setlinewidth
grestore
gsave
.42907 .10735 -69 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B0) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 252},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationCycleOffset->1,
  AnimationCycleRepetitions->Infinity,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000o2000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00>?ooool3o`0000Cooooo0_l0
000Gooooo`;o00006_ooool3o`0000Cooooo0_l0000Cooooo`?o00001?ooool2o`0000Cooooo0_l0
000@ooooo`?o00000oooool3o`0000Cooooo0_l0000@ooooo`Go00000oooool2o`0000Cooooo0_l0
000?ooooo`Go00000_ooool3o`0000Cooooo0_l0000Aooooo`?o00001?ooool2o`0000Cooooo0_l0
0003ooooo`00=oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
5Oooool01?l0003oooooooooool0000Hooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool0000Cooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000oooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`00<Oooool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool1o`00007ooooo0Oooool003_ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00oooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool003Oooooo
1?l00003ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool4o`00
00?ooooo00Co0000oooooooooooo00004oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00004?ooool01?l0003oooooooooooooool4o`0000?o
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`06o`000?ooooooooooooooool0
003ooooo1?l00003ooooo`04o`000?ooooooooooo`0001?ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`7o00000Oooool1ooooo`00=oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0001Gooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0001;ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00003oooool2o`0000?ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000?ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000kooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`00=oooool5
o`0000?ooooo0_l0000Gooooo`;o00006Oooool5o`0000?ooooo0_l0000Dooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o00004Oooool01?l0003oooooooooooooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l0000@ooooo`?o00000_ooool5o`0000?ooooo0_l0
000Aooooo`?o00001?ooool2o`0000Cooooo0_l00003ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`006oooooolo`0000Wooooo000Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000K
ooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool09?ooool4o`0000Cooooo0_l0
002;ooooo`;o00002Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0U
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003ooooo
ooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo00Oo
oooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool3o`0000?ooooo
00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Gooooo
00Co0000ooooool0003o00000_ooool01?l0003oooooooooool0002;ooooo`03o`000?oooooooooo
00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09Oooool4
o`0000;ooooo00Co0000oooooooooooo0000Roooool00ol0003oooooooooo`07ooooo`001Ol00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`;o0000??ooool00ol0003oooooooooo`0Tooooo`Go00000oooool2o`0008[ooooo
0ol00009ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Ko
oooo0ol0002Aooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00002Aooooo`03o`000?oooooooooo
00Oooooo0007ooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Vooooo`04o`000?oooooo
ooooo`00093ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2
o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool09_ooool0
1?l0003oooooooooool0002@ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08gooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2<ooooo`;o00002Oooool001_o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2<ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08_ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo08[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`28ooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
08Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0QOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo08Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Pooo
ool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo08;ooooo0_l00009ooooo`006oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0POooool00ol0003ooooo
ooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool01oooool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`07ooooo`001_oo
ool5o`0000Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`;o0000
??ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
O_ooool3o`0000Wooooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
1oooool000cooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01oooool000cooooo1Ol00003ooooo`;o00001Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo07gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0OOooool00ol0
003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo07_ooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1looooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`07
ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1hooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`006oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Moooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00Oooooo
000Kooooo`;o0000??ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0MOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Gooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo07Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Looo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0LOooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0LOooool00ol0003ooooo
ooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0LOooool00ol0003ooooooooo
o`07ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooooooo00Oooooo000Cooooo`04o`000?ooooooooooo`0000Coooooo?l0
0009ooooo`004oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool00_ooool4o`0000cooooo1?l0000booooo`03o`000?oooooooooo06oooooo00?o
0000ooooooooool01oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooo000000;o00004oooool4o`00033ooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`07ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0>Oooool4
o`0001Kooooo00Co0000oooooooooooooooo0ol0000]ooooo`03o`000?oooooooooo06kooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo00Gooooo0_l0000/ooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=_ooool2o`0000?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`07ooooo`?o0000:_ooool00ol0003oooooooooo`1/
ooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000=_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool3o`0002[ooooo00?o0000oooo
ooooool0Joooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03?ooooo0_l00006ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool4o`0002[ooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000000Go00009_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00000_ooool2o`0002Sooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Go0000:?ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
1?l0003oooooo`000?ooool2o`0002Oooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`07ooooo`006oooool2o`0002oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooo`000002
ooooo`;o00009_ooool00ol0003oooooooooo`1Xooooo`;o00002Oooool001_ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0000Voooo
o`03o`000?oooooooooo06Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooo`00000Uooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo0000o`0002Cooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00gooooo00Co0000ooooool0003o00008oooool00ol0003oooooooooo`1Wooooo`03
o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3_ooool01Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool0I_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo
00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool01oooool001_ooooo0_l0000Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooo
ooooo`00000Rooooo`03o`000?oooooooooo06Cooooo0_l00009ooooo`006oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool2o`00023ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool2o`00023ooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`?o
00007?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o0000
:?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`00000bo`0000gooooo00?o0000ooooooooool0HOooool2o`0000Wooooo
000Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0>ooooo`Oo00006Oooool00ol0003oooooooooo`04ooooo`Co00003oooool3o`0000[ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool2o`0000?ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`06ooooo`?o000000?oooooo`000?l000003Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Kooooo00Co0000ooooool0003o00003oooool2o`0000Wooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`07ooooo`003Oooool3o`0000Cooooo0_l00005ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`;o000000Goooooo`00
0?ooooooooooo`00000Nooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o00004?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool01ooo
ool000cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo
0ol00003ooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool01_ooool2o`0000;o
oooo0_l0000>ooooo`;o00002Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo00Oo
oooo000@ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool2o`0002Ko
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000Looooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooool000000_ooool2o`0000kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1Mooooo`?o00002Oooool0013ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooo`000?l00002
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo00Oooooo000<ooooo`Co00000oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooooooo`Ko000000Goooooo`000?ooooooooooo`00000Looooo`03
o`000?oooooooooo00Cooooo0ol000000ooooooo0000o`000003ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00Oo
oooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooo00007?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Oooooo000<ooooo`Go00000oooool2o`00
00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool01?l0003oooooo`000?l00002ooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooooooool03oooool2o`0000Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo0ol00003ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooooooool04?oo
ool2o`0000Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo00Oooooo000Kooooo`;o00009Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool3o`0000Cooooo0_l0000Mooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo05_ooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`?o00008oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`0Eoooo
o`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05[ooooo00?o0000oooo
ooooool01oooool001_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Cooooo`04
o`000?ooooooooooo`0002oooooo00?o0000ooooooooool05_ooool2o`000003ooooool0003ooooo
00oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000;_ooool00ol0
003oooooooooo`0Iooooo`;o00004Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo
00Oooooo000Kooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04oooool01?l0003o
ooooooooool0000^ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo00Oooooo000Kooooo`;o00009_ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool06Oooool00ol0
003oooooo`00000Aooooo`03o`000?oooooooooo05Oooooo0_l00009ooooo`006oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000;_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00;o00003oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04_ooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool00_ooool2o`0000oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`07oooo
o`006oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooo
oooo0000;_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000]oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0002gooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0002Sooooo00?o0000oooooooo
ool04Oooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Cooooo0_l00009oooo
o`006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo0000;?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo0_l0000;oooo
o`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0002cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000Zooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0?ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`07ooooo`006oooool2o`0002_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Dooooo`;o00002?ooool00ol0003oooooooooo`1Aooooo`;o0000
2Oooool001_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool01oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Go
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Fooooo`;o00007_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01oooooo0_l00005ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool01oooool000So
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0;_ooool2o`0000_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo0_l0000Tooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`07ooooo`002?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool2o`00037ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`;o00007?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1<ooooo`?o00002Oooool000Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Oooooo00Go0000oooooooooooo
ooooo`00001@ooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o00001?ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Cooooo`;o0000:oooool01Ol0003ooooooooooooooooo000004oooooo00?o0000
ooooooooool01oooool000Sooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00005oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01?ooooo0_l0000Dooooo`;o0000;_ooool2o`000003ooooool0003ooooo
04kooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooool00000C_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0eooooo`;o00001?ooool00ol0003ooooo
ooooo`0=ooooo`;o00003oooool2o`0001Cooooo0_l0000dooooo`;o0000C_ooool00ol0003ooooo
ooooo`07ooooo`006oooool2o`0003Sooooo0ol000000ooooooo0000ooooo`0@ooooo`;o00002_oo
ool3o`0001Cooooo0_l0000gooooo`;o0000C?ooool2o`0000Wooooo000Kooooo`03o`000?oooooo
oooo03[ooooo0_l0000Cooooo`?o00001_ooool00ol0003oooooooooo`0Booooo`?o0000>_ooool3
o`0004_ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool2o`00
01Gooooo0ol000000ooooooo0000o`00000Aooooo`Co0000?Oooool2o`000003ooooool0003ooooo
04Wooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooo`000003o`00017ooooo2Ol0000:ooooo`Co0000@_ooool2o`0004_ooooo00?o0000oooooooo
ool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03oooooa7o0000
2Oooool:o`0004Oooooo1?l00018ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0Koooool01?l0003oooooooooool00017ooooo`03o`00
0?oooooooooo00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`1_ooooo`04o`000?oo
ooooooooo`0004Kooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo06oooooo0ol00018ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0Koooool01?l0003oooooooooool00017ooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Koooool0
1?l0003oooooooooool00017ooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0K_ooool4o`0004Sooooo00?o0000ooooooooool01oooool0
01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo
00Oooooo000Kooooo`;o0000??ooool00ol0003oooooooooo`2iooooo`;o00002Oooool001_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo
000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03o`000?oo
oooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o00000oooool3o`0000Co
oooo0_l00005ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`002?ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool0^_ooool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo0_l0000loooo
o`03o`000?oooooooooo0;Sooooo0ol00009ooooo`002?ooool01?l0003oooooooooooooool4o`00
00?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool000Oooooo0_l00003ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool000Sooooo00Co0000oooooooooooooooo1Ol00003
ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2joooo
o`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0^_ooool00ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0
^Oooool2o`0000Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0
000looooo`03o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`00
6oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool0
1oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2jooooo`03o`000?oo
oooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooooooo`07ooooo`006oooool2o`0003cooooo00?o0000ooooooooool0^Oooool2o`00
00Wooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`07ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;[ooooo
00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`006oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo0_l0000looooo`03
o`000?oooooooooo0;Wooooo0_l00009ooooo`006oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;[ooooo00?o0000ooooooooool01oooool001_ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Kooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`07ooooo`001_ooool5o`00
00?ooooo0_l00004ooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
0;[ooooo00?o0000ooooooooool01oooool000Oooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooooolo`0000Wooooo0009ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0?oo
oooo2?ooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000ooooool:ooooo`001_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooo`[ooooo
0007ooooo`?o00001?ooool2o`0000Cooooo0_l0003oooooo`_ooooo001Rooooo`?o00005_ooool3
o`0002Kooooo0ol0000dooooo`03o`000?oooooooooo04;ooooo001Sooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
047ooooo001Booooo`;o00000oooool3o`0000Cooooo0_l000000ooooooo0000ooooo`03o`0000;o
oooo1Ol000000ooooooo0000o`000003o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000o`000002o`0000Oooooo0ol00004ooooo`Co00000oooool2o`0000;ooooo1_l00007oooo
o`?o00000oooool4o`000004ooooool0003o0000o`0000Wooooo1?l00003ooooo`?o00001?ooool2
o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo043ooooo001Aooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0@?ooool0053ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00000_ooool3o`0000?ooooo00?o0000ooooooooool02Oooool3
o`0000;ooooo1Ol00002ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`10ooooo`00D?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`06ooooo`?o00000_ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00009ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00[ooooo0_l00005
ooooo`03o`000?oooooooooo043ooooo001@ooooo`03o`000?oooooooooo00Cooooo0ol00002oooo
o`;o000000Coooooo`000?l0003ooooo1?l00004ooooo`04o`000?ooooooooooooooo`?o00000ooo
ool4o`0000?ooooo1Ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0_l00003ooooo`Co0000
0oooool3o`0000Sooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000Sooooo
1?l00002ooooo`?o00000_ooool4o`0000cooooo00Go0000ooooooooooooooooo`000013ooooo`00
DOooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0@_ooool0
05;ooooo0ol0000Cooooo`?o00001Oooool00ol0003oooooooooo`0Cooooo`Co00002Oooool00ol0
003oooooooooo`02ooooo`;o0000;oooool00ol0003oooooooooo`09ooooo`?o0000B?ooool00?oo
oooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {251, 0}} -> {-143.27, -172.719, 1.5945, \
1.5945}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1680}, {0, 988}},
WindowSize->{967, 928},
WindowMargins->{{178, Automatic}, {Automatic, 3}},
DockedCells -> FEPrivate`FrontEndResource[ "FEExpressions", \
"CompatibilityToolbar"],
Magnification->1,
StyleDefinitions -> "Default.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 104, 3, 52, "Subtitle"],

Cell[CellGroupData[{
Cell[1905, 60, 63, 0, 38, "Subsection"],
Cell[1971, 62, 135, 4, 27, "Input"],

Cell[CellGroupData[{
Cell[2131, 70, 376, 9, 87, "Input"],
Cell[2510, 81, 96, 2, 44, "Output"],
Cell[2609, 85, 79, 1, 35, "Output"],
Cell[2691, 88, 158, 2, 50, "Output"],
Cell[2852, 92, 245, 5, 50, "Output"],
Cell[3100, 99, 245, 5, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3382, 109, 439, 10, 75, "Input"],
Cell[3824, 121, 209, 5, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4070, 131, 411, 12, 75, "Input"],
Cell[4484, 145, 160, 2, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4681, 152, 105, 2, 27, "Input"],
Cell[4789, 156, 92, 1, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4918, 162, 110, 2, 27, "Input"],
Cell[5031, 166, 102, 2, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5170, 173, 76, 1, 27, "Input"],
Cell[5249, 176, 67, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5353, 182, 178, 4, 27, "Input"],
Cell[5534, 188, 141, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5712, 196, 285, 6, 43, "Input"],
Cell[6000, 204, 120, 2, 27, "Output"],
Cell[6123, 208, 120, 2, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6292, 216, 136, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[6453, 221, 49, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[6527, 225, 296, 5, 27, "Input"],
Cell[6826, 232, 214, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7077, 240, 566, 10, 75, "Input"],
Cell[7646, 252, 60723, 1157, 259, 7660, 497, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[68418, 1415, 93, 3, 38, "Subsection"],

Cell[CellGroupData[{
Cell[68536, 1422, 41, 1, 27, "Input"],
Cell[68580, 1425, 214, 3, 27, "Output"]
}, Open  ]],
Cell[68809, 1431, 56, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[68890, 1436, 1218, 24, 219, "Input"],
Cell[70111, 1462, 25908, 1628, 103, 19993, 1550, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96056, 3095, 880, 25, 342, "Input"],

Cell[CellGroupData[{
Cell[96961, 3124, 66691, 2433, 260, 28045, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[163655, 5559, 66629, 2432, 260, 28048, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[230287, 7993, 66705, 2433, 260, 28047, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[296995, 10428, 66729, 2433, 260, 28047, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[363727, 12863, 66868, 2435, 260, 28044, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[430598, 15300, 66791, 2434, 260, 28044, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[497392, 17736, 66799, 2434, 260, 28048, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[564194, 20172, 67435, 2442, 260, 28044, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[631632, 22616, 67535, 2443, 260, 28043, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[699170, 25061, 67462, 2443, 260, 28046, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[766635, 27506, 67742, 2446, 260, 28047, 1950, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[834438, 29959, 50, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[834513, 29963, 314, 6, 27, "Input"],
Cell[834830, 29971, 233, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[835100, 29980, 563, 10, 75, "Input"],
Cell[835666, 29992, 42896, 970, 163, 8309, 539, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[878599, 30967, 112, 2, 27, "Input"],
Cell[878714, 30971, 51383, 1205, 186, 11036, 702, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[930146, 32182, 93, 3, 30, "Subsection"],

Cell[CellGroupData[{
Cell[930264, 32189, 42, 1, 27, "Input"],
Cell[930309, 32192, 233, 4, 27, "Output"]
}, Open  ]],
Cell[930557, 32199, 57, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[930639, 32204, 1218, 24, 219, "Input"],
Cell[931860, 32230, 25908, 1628, 103, 19993, 1550, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[957805, 33863, 861, 25, 342, "Input"],

Cell[CellGroupData[{
Cell[958691, 33892, 66859, 2435, 260, 28051, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1025553, 36329, 65643, 2420, 260, 28049, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1091199, 38751, 65458, 2418, 260, 28054, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1156660, 41171, 66142, 2426, 260, 28054, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1222805, 43599, 67083, 2438, 260, 28047, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1289891, 46039, 67357, 2441, 260, 28054, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1357251, 48482, 67139, 2439, 260, 28054, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1424393, 50923, 66525, 2431, 260, 28048, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1490921, 53356, 65838, 2422, 260, 28054, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1556762, 55780, 66688, 2433, 260, 28053, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1623453, 58215, 68377, 2454, 260, 28049, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1691833, 60671, 66743, 2434, 260, 28051, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1758579, 63107, 66861, 2435, 260, 28051, 1950, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1825501, 65549, 49, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[1825575, 65553, 331, 6, 27, "Input"],
Cell[1825909, 65561, 217, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1826163, 65569, 561, 10, 75, "Input"],
Cell[1826727, 65581, 43067, 978, 163, 8423, 546, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1869831, 66564, 120, 2, 27, "Input"],
Cell[1869954, 66568, 72812, 1638, 257, 14526, 914, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1942815, 68212, 140, 4, 38, "Subsection"],

Cell[CellGroupData[{
Cell[1942980, 68220, 42, 1, 27, "Input"],
Cell[1943025, 68223, 217, 3, 27, "Output"]
}, Open  ]],
Cell[1943257, 68229, 56, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1943338, 68234, 1218, 24, 219, "Input"],
Cell[1944559, 68260, 25908, 1628, 103, 19993, 1550, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1970504, 69893, 861, 25, 342, "Input"],

Cell[CellGroupData[{
Cell[1971390, 69922, 72709, 2507, 260, 28045, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2044102, 72431, 70683, 2482, 260, 28040, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2114788, 74915, 70223, 2477, 260, 28045, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2185014, 77394, 71162, 2488, 260, 28045, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2256179, 79884, 72048, 2499, 260, 28040, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2328230, 82385, 72300, 2502, 260, 28045, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2400533, 84889, 71361, 2491, 260, 28045, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2471897, 87382, 71635, 2494, 260, 28040, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2543535, 89878, 71860, 2497, 260, 28042, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2615398, 92377, 71822, 2496, 260, 28045, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2687223, 94875, 71530, 2493, 260, 28040, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2758756, 97370, 72871, 2509, 260, 28045, 1950, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2831630, 99881, 72709, 2507, 260, 28045, 1950, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

