(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     58543,       1267]*)
(*NotebookOutlinePosition[     59236,       1291]*)
(*  CellTagsIndexPosition[     59192,       1287]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["P3.01\tFind mechanism for list of fct values", "Section"],

Cell[CellGroupData[{

Cell["eccentric s.c. - basic functions", "Subsubsection"],

Cell[BoxData[
    \(\(Clear[r, l, e];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\  = \ 
      r\ Cos[phi]\  + \ Sqrt[l^2\  - \ \((e + r\ Sin[phi])\)^2]\)], "Input"],

Cell[BoxData[
    \(r\ Cos[phi] + \@\(l\^2 - \((e + r\ Sin[phi])\)\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s0 = 
      Sqrt[\((l + r)\)^2\  - e^2] - Sqrt[\((l - r)\)^2\  - e^2]\)], "Input"],

Cell[BoxData[
    \(\(-\@\(\(-e\^2\) + \((l - r)\)\^2\)\) + \@\(\(-e\^2\) + \((l + \
r)\)\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi0 = Pi - ArcSin[e/\((l - r)\)] + ArcSin[e/\((l + r)\)]\)], "Input"],

Cell[BoxData[
    \(\[Pi] - ArcSin[e\/\(l - r\)] + ArcSin[e\/\(l + r\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mymin = ArcCos[\((e + r)\)/l]\)], "Input"],

Cell[BoxData[
    \(ArcCos[\(e + r\)\/l]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Eq. of requirements for given data: e = -15, s1 = 80, , s2 = 55, s3 \
= 30, phi12 = + 60 Degrees, phi13 = + 120 Degrees\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(s1 = \(s /. phi \[Rule] phi1\) /. 
        e \[Rule] \(-15\)\), "\[IndentingNewLine]", 
    \(s2 = \(s /. phi \[Rule] phi1 + 60\ Degree\) /. 
        e \[Rule] \(-15\)\), "\[IndentingNewLine]", 
    \(s3 = \(s /. phi \[Rule] phi1 + 120\ Degree\) /. 
        e \[Rule] \(-15\)\)}], "Input"],

Cell[BoxData[
    \(r\ Cos[phi1] + \@\(l\^2 - \((\(-15\) + r\ Sin[phi1])\)\^2\)\)], "Output"],

Cell[BoxData[
    \(r\ Cos[
          60\ \[Degree] + 
            phi1] + \@\(l\^2 - \((\(-15\) + r\ Sin[60\ \[Degree] + \
phi1])\)\^2\)\)], "Output"],

Cell[BoxData[
    \(r\ Cos[
          120\ \[Degree] + 
            phi1] + \@\(l\^2 - \((\(-15\) + r\ Sin[120\ \[Degree] + \
phi1])\)\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["solution: find r, l, phi1", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg2 = 
      FindRoot[{s1 \[Equal] 80, s2 \[Equal] 55, s3 \[Equal] 30}, {r, 10}, {l, 
          30}, {phi1, 0}]\)], "Input"],

Cell[BoxData[
    \({r \[Rule] 29.115898094690856`, l \[Rule] 53.3348539966193`, 
      phi1 \[Rule] 0.40277744548541555`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi1erg = phi1/Degree /. erg2[\([3]\)]\)], "Input"],

Cell[BoxData[
    \(23.077447709374905`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["further results", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(phi = phiG\ Degree;\)\), "\[IndentingNewLine]", 
    \(\(Plot[\(s /. erg2\) /. e \[Rule] 15, \ {phiG, \(-40\), 
          400}, \[IndentingNewLine]GridLines \[Rule] Automatic, 
        AxesLabel \[Rule] {"\<phi(Degree)\>", None}, 
        PlotLabel \[Rule] "\<s (phi)\>", 
        PlotRange \[Rule] {{\(-40\), 400}, {0, 100}}];\)\), "\n", 
    \(\(Clear[phi];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.00227273 0 0.00618034 [
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 70 6 ]
[.07841 .12361 -12 -4.5 ]
[.07841 .12361 0 4.5 ]
[.07841 .24721 -12 -4.5 ]
[.07841 .24721 0 4.5 ]
[.07841 .37082 -12 -4.5 ]
[.07841 .37082 0 4.5 ]
[.07841 .49443 -12 -4.5 ]
[.07841 .49443 0 4.5 ]
[.07841 .61803 -18 -4.5 ]
[.07841 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .61803 L
s
.31818 0 m
.31818 .61803 L
s
.54545 0 m
.54545 .61803 L
s
.77273 0 m
.77273 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
s
0 .12361 m
1 .12361 L
s
0 .24721 m
1 .24721 L
s
0 .37082 m
1 .37082 L
s
0 .49443 m
1 .49443 L
s
0 .61803 m
1 .61803 L
s
0 g
.31818 0 m
.31818 .00625 L
s
[(100)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(200)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(300)] .77273 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(400)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(phi) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(H) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Degree) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(L) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09091 .12361 m
.09716 .12361 L
s
[(20)] .07841 .12361 1 0 Mshowa
.09091 .24721 m
.09716 .24721 L
s
[(40)] .07841 .24721 1 0 Mshowa
.09091 .37082 m
.09716 .37082 L
s
[(60)] .07841 .37082 1 0 Mshowa
.09091 .49443 m
.09716 .49443 L
s
[(80)] .07841 .49443 1 0 Mshowa
.09091 .61803 m
.09716 .61803 L
s
[(100)] .07841 .61803 1 0 Mshowa
.125 Mabswid
.09091 .0309 m
.09466 .0309 L
s
.09091 .0618 m
.09466 .0618 L
s
.09091 .09271 m
.09466 .09271 L
s
.09091 .15451 m
.09466 .15451 L
s
.09091 .18541 m
.09466 .18541 L
s
.09091 .21631 m
.09466 .21631 L
s
.09091 .27812 m
.09466 .27812 L
s
.09091 .30902 m
.09466 .30902 L
s
.09091 .33992 m
.09466 .33992 L
s
.09091 .40172 m
.09466 .40172 L
s
.09091 .43262 m
.09466 .43262 L
s
.09091 .46353 m
.09466 .46353 L
s
.09091 .52533 m
.09466 .52533 L
s
.09091 .55623 m
.09466 .55623 L
s
.09091 .58713 m
.09466 .58713 L
s
.25 Mabswid
.09091 0 m
.09091 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(phi) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(L) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .46667 m
.00942 .47523 L
.01975 .48337 L
.03065 .49042 L
.04057 .49535 L
.04626 .49752 L
.05163 .49911 L
.05458 .49978 L
.05731 .50028 L
.0603 .50069 L
.06181 .50084 L
.0626 .5009 L
.06347 .50096 L
.06421 .501 L
.06489 .50103 L
.06624 .50106 L
.06747 .50107 L
.06878 .50105 L
.06952 .50102 L
.07032 .50098 L
.07177 .50089 L
.07319 .50076 L
.07449 .50061 L
.07688 .50026 L
.07951 .49977 L
.08481 .49842 L
.09031 .49651 L
.09552 .49422 L
.10529 .48867 L
.11581 .48088 L
.12725 .47032 L
.14802 .44585 L
.17008 .41311 L
.20971 .34122 L
.25193 .25815 L
.29255 .18933 L
.31359 .1628 L
.3243 .15202 L
.33575 .14244 L
.34661 .13508 L
.35647 .12972 L
.36639 .12547 L
.37576 .12241 L
.38597 .11999 L
.39111 .11911 L
.39677 .11837 L
.4016 .11793 L
.40431 .11776 L
.40559 .11769 L
.40678 .11764 L
Mistroke
.40799 .1176 L
.40908 .11757 L
.4103 .11754 L
.41159 .11752 L
.41272 .11752 L
.41394 .11752 L
.41509 .11753 L
.41615 .11755 L
.41748 .11758 L
.41874 .11762 L
.4211 .11771 L
.42364 .11785 L
.4264 .11804 L
.43137 .11849 L
.43595 .11902 L
.44649 .12063 L
.45767 .12291 L
.47815 .1285 L
.49736 .13532 L
.53804 .15476 L
.58129 .18338 L
.62295 .21981 L
.66302 .2638 L
.70566 .31941 L
.74671 .37755 L
.79034 .43604 L
.81222 .46075 L
.83238 .47916 L
.84254 .48655 L
.85203 .49217 L
.86194 .49663 L
.86719 .49839 L
.86992 .49913 L
.87282 .49979 L
.87545 .50027 L
.87685 .50048 L
.87836 .50067 L
.87974 .50082 L
.881 .50092 L
.88221 .50099 L
.88348 .50104 L
.88487 .50107 L
.88565 .50107 L
.88635 .50106 L
.88773 .50102 L
.88903 .50095 L
.88976 .5009 L
.89054 .50084 L
.89194 .5007 L
.8951 .50026 L
Mistroke
.8976 .49979 L
.90029 .49917 L
.90515 .49773 L
.91093 .4955 L
.91621 .49295 L
.92656 .48658 L
.93616 .47905 L
.95793 .45639 L
.97949 .42688 L
.99904 .39494 L
1 .39326 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{411.938, 254.625},
  ImageMargins->{{43, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006K0000oR000`400?l00000o`00003ooooooonL
ooooo`00oooooonLooooo`00oooooonLooooo`00oooooonLooooo`00oooooonLooooo`00oooooonL
ooooo`00oooooonLooooo`00oooooonLooooo`00oooooonLooooo`00oooooonLooooo`00HOooool3
o`0000Cooooo0_l00004ooooo`;o0000??ooool5o`0000?ooooo0_l00004ooooo`;o0000?Oooool3
o`0000Cooooo0_l00004ooooo`;o0000?Oooool3o`0000?ooooo0_l00004ooooo`;o0000B?ooool0
06;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0003cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0003_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo0000?Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`15ooooo`00H_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000?Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
?oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0>?ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0017ooooo`00H_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000?_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0kooooo`;o00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0003[ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0004Oooooo001Rooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000kooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0003oo
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0004Oooooo001Qooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0003_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000>oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000looooo`;o00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0004Oooooo001Rooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o0000?Oooool3o`0000Cooooo0_l00004ooooo`;o0000?Oooool3
o`0000Cooooo0_l00004ooooo`;o0000?_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool2
o`0004Sooooo003ooooooicooooo003ooooooeOooooo0ol0000Cooooo`03o`000?oooooooooo00co
oooo0ol0000Eooooo`03o`000?oooooooooo00Gooooo003ooooooeSooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1?ooool00?ooooooF?ooool3o`0000;ooooo2ol00003ooooo`04o`000?ooooooooooooooo`Co0000
0oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00004ooooo`?o00000oooool3o`0000Go
oooo00?o0000ooooooooool00oooool00?ooooooF?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00?oo0000C_l0000:ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Go0000oooooooooooo0000ooooo`05o`000003ooooool0003ooooo00;ooooo00Co0000oooo
oooooooo00001?ooool5o`000003ooooool0003o000000?o00001?ooool00ol0003oooooooooo`03
ooooo`003oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool000oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool4o`00
00?ooooo0ol00002ooooo`?o00001_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00ol00003ooooo`Oo000000?oooooo`000?l000000_ooool3o`0000?ooooo0ol00004
ooooo`03o`000?oooooooooo00Cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001ooooo
ooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool03_ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`05ooooo`007_ooool00ol0003oooooooooo`18oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo00gooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo1?l0000Yoooo
o`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`00
0?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?oo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001ko
oooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool2o`0004Wooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Noooo
o`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?oo
ool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0
003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04So
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0C?ooool001kooooo0_l00019ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo
000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000
ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_oo
ool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooo
oooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04co
oooo000Nooooo`;o0000BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooooooo
o`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<oooo
o`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`00
0?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?oo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo04cooooo000>ooooo`Go00000oooool2o`0000Kooooo00?o0000ooooooooool0B?ooool00ol0
07ooooooooooo`0Looooo`?o0000:_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0C?ooool000oooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool04_ooool;
o`000003ooooool0003o000000So00008Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0C?ooool0013ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool03oooool3
o`0001Kooooo1ol0000Jooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`1<ooooo`004Ol007l01Ol0003o001oo`00Ool007oo000000;o001o00?o0000
o`00Ool007l00ol007l3o`0005Oo001o0ol0000Po`00O`?o0000[ol007m>ooooo`003_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`18ooooo`03o`00Oooooooooooo00_ooooo00?o0000ooooooooool09?ooool4o`0001?ooooo00?o
001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000>
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo04Sooooo00?o001oooooooooool02Oooool2o`0002_ooooo0ol0000@ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`003ooo
ool3o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool01_oo
ool3o`00033ooooo0_l0000>ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooo
oooo00Gooooo00?o0000ooooooooool0<oooool2o`0000cooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo
04Sooooo00?o001oooooooooool01?ooool00ol0003oooooooooo`0fooooo`;o00002_ooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001ko
oooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`02ooooo`;o0000>oooool2o`0000So
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04co
oooo000Nooooo`03o`000?oooooooooo04Sooooo00Go001oooooooooooooooooo`00000oooooo`03
o`000?oooooooooo00Gooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00Co001ooooooooooooo
0000@Oooool2o`0000Gooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooool00000
A?ooool2o`0000?ooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04cooooo000Nooooo`;o0000BOooool00ol007ooooooo`000016ooooo`;o000000?o
ooooo`00Ooooool0B_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000N
ooooo`03o`000?oooooooooo04Sooooo00?o001oo`000?ooool0B?ooool2o`0004_ooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo04Wooooo00?o001oo`000?ooool0BOooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Oooooo00?o0000o`00Oooo
ool0B_ooool01?l007ooooooo`000?l00018ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0C?ooool001kooooo00?o0000ooooooooool0Aoooool00ol0003o001oooooo`1:ooooo`04
o`00Ooooooooooooooooo`;o0000A_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo04Kooooo00?o0000ooooool007l0Boooool00ol007oo
ooooooooo`03ooooo`03o`000?oooooooooo04?ooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`00Od_o
oooo00?o001oooooooooool01?ooool2o`0004?ooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool0
07l0Boooool00ol007ooooooooooo`06ooooo`;o0000@Oooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
0_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo00Sooooo00?o0000ooooooooool0
?_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool00oooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo00Wooooo0_l0000nooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?oo
ool001kooooo0_l00012ooooo`03o`000?oooooooooo00Cooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
00Gooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0<ooooo`03o`000?oooooooooo
03[ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`0=ooooo`03o`000?oooooooooo03Wooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Kooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`0>ooooo`03o`000?oooooooooo03Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00Oooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`0?ooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`1<ooooo`007_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`0@ooooo`03o`000?oooooooooo03Kooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0Aoooo
o`03o`000?oooooooooo03Gooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<oooo
o`007_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Sooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`0Booooo`03o`000?oooooooooo03Cooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo00Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0Cooooo`03o`00
0?oooooooooo03?ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`0Dooooo`03o`000?oooooooooo03;ooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`1<ooooo`007_ooool2o`0003cooooo00?o0000ooooooooool02_ooool0
0ol007ooooooooooo`19ooooo`03o`00Oooooooooooo01Gooooo00?o0000ooooooooool0<Oooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool02oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
01Kooooo00?o0000ooooooooool0<?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02oooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo01Oooooo00?o0000ooooooooool0;oooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool03?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo01Oooooo
00?o0000ooooooooool0;oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo
000Nooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03Oooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo01Sooooo00?o0000ooooooooool0;_ooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool03Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo01Wooooo00?o0000
ooooooooool0;Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Noooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03_ooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo01[ooooo00?o0000ooooooooool0;?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool03_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo01_ooooo00?o0000oooooooo
ool0:oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000@ooooo`?o0000
0oooool2o`0000Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool07?ooool00ol0003oooooooooo`0Zooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool0017ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0@ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool07Oooool00ol0003ooooo
ooooo`0Yooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool000kooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0@ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool07_ooool00ol0003ooooo
ooooo`0Xooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool000ko001o00Co
0000o`00Ool007oo00000ol007l01?l0003o001oo`00Ool00005o`00O`?o0000=?l007l00ol0003o
001oo`00O`1oo`00O`03o`000?l007oo001o07?o001oC_ooool000oooooo00?o0000ooooool00000
0oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool04Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo023ooooo00?o0000oooooooo
ool09_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000@ooooo`;o0000
0oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool04_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo027ooooo00?o0000oooooooo
ool09Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Aooooo`03o`00
0?oooooooooo00;ooooo0_l00006ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
4oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo02;ooooo00?o0000ooooooooool0
9?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool04oooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo02?ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04cooooo000Nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05?ooool0
0ol007ooooooooooo`19ooooo`03o`00Oooooooooooo02Cooooo00?o0000ooooooooool08_ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool05?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
02Cooooo00?o0000ooooooooool08_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05Oooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo02Gooooo00?o0000ooooooooool08Oooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool05Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo02Kooooo
00?o0000ooooooooool08?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo
000Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05_ooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo02Oooooo00?o0000ooooooooool07oooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`;o0000<?ooool00ol0003oooooooooo`0F
ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool09oooool00ol0003oooooooooo`0O
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Gooooo`03o`00Oooooooooooo04Wooooo00?o001ooooo
ooooool0:?ooool00ol0003oooooooooo`0Nooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0C?ooool001kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Gooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0:Oooool00ol0003oooooooooo`0Mooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Hooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0
:_ooool00ol0003oooooooooo`0Looooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
C?ooool001kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03o`00Oooo
oooooooo04Wooooo00?o001oooooooooool0:_ooool00ol0003oooooooooo`0Looooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Iooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0:oooool0
0ol0003oooooooooo`0Kooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool0
01kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Iooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool0;?ooool00ol0003oooooooooo`0Jooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Jooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0;?ooool00ol0003o
ooooooooo`0Jooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Jooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0;Oooool00ol0003oooooooooo`0Iooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0Kooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0;_ooool00ol0003ooooooooo
o`0Hooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo0_l0000[
ooooo`03o`000?oooooooooo01_ooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0_
ooooo`03o`000?oooooooooo01Oooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<
ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01cooooo00?o001ooooo
ooooool0BOooool00ol007ooooooooooo`0_ooooo`03o`000?oooooooooo01Oooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01cooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0`ooooo`03
o`000?oooooooooo01Kooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`00
7_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool0
BOooool00ol007ooooooooooo`0aooooo`03o`000?oooooooooo01Gooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01gooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0booooo`03o`000?oo
oooooooo01Cooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`0booooo`03o`000?oooooooooo01Cooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01kooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0cooooo`03o`000?oooooooooo
01?ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01oooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`0dooooo`03o`000?oooooooooo01;ooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01oooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`0eooooo`03o`000?oooooooooo017ooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo023ooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`0eooooo`03o`000?oooooooooo017ooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`1<ooooo`007_ooool2o`0002Kooooo00?o0000ooooooooool08?ooool00ol007ooooooooooo`19
ooooo`03o`00Oooooooooooo03Kooooo00?o0000ooooooooool04?ooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool08Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo03Oooooo00?o0000oooo
ooooool03oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool08Oooool00ol007ooooooooooo`19ooooo`03
o`00Oooooooooooo03Sooooo00?o0000ooooooooool03_ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
8_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo03Sooooo00?o0000ooooooooool0
3_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool08_ooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo03Wooooo00?o0000ooooooooool03Oooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04cooooo000Nooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool0
0ol007ooooooooooo`19ooooo`03o`00Oooooooooooo03[ooooo00?o0000ooooooooool03?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool08oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
03[ooooo00?o0000ooooooooool03?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09?ooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo03_ooooo00?o0000ooooooooool02oooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000?ooooo`?o00001?ooool2o`0000Kooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Uooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0??ooool00ol0003oooooooooo`0:ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0C?ooool000kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Uooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0?Oooool00ol0003oooooooooo`09ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool000kooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Vooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0?Oooool00ol0
003oooooooooo`09ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool000ko
001o1?l00003o`00O`04o`000?l007oo001oo`0000Go001o0ol0000Oo`00O`03o`000?l007oo001o
0;?o001o00?o0000o`00Ool007l0E?l007m>ooooo`003_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Woooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0?oooool00ol0003oooooooooo`07oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool000oooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool09oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo043ooooo00?o0000oooo
ooooool01_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000@ooooo`;o
00001?ooool2o`0000Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Xooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0@?ooool00ol0003oooooooooo`06ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Xooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0
@Oooool00ol0003oooooooooo`05ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
C?ooool001kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Yooooo`03o`00Oooo
oooooooo04Wooooo00?o001oooooooooool0@_ooool00ol0003oooooooooo`04ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Yooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0@oooool0
0ol0003oooooooooo`03ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool0
01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Zooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool0@oooool00ol0003oooooooooo`03ooooo`03o`00Oooooooooooo
04Sooooo00?o0000ooooooooool0C?ooool001kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Zooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0A?ooool00ol0003o
ooooooooo`02ooooo`03o`00Oooooooooooo04Sooooo00?o0000ooooooooool0C?ooool001kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0[ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0AOooool01Ol0003ooooooooooooooooo001o04[ooooo00?o0000oooooooo
ool0C?ooool001kooooo0_l0000Jooooo`03o`000?oooooooooo02cooooo00?o001oooooooooool0
BOooool00ol007ooooooooooo`16ooooo`04o`000?ooooooooooo`00OdWooooo00?o0000o`00Oooo
ool0COooool001kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0/ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0A_ooool01?l0003oooooooooool007m8ooooo`03
o`000?oooooo001o04kooooo000Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
;Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Oooooo00?o0000ooooool007l0
B?ooool00ol0003oooooo`00O`1>ooooo`007_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02gooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`000?l0
07oooooo04Kooooo00Co0000oooooooooooo001oC_ooool001kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0^ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?oo
ool00ol0003o001oooooo`15ooooo`05o`000?ooooooooooooooool007l0C_ooool001kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0^ooooo`03o`00Oooooooooooo04Wooooo00?o
001oooooooooool0BOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00;ooooo00?o
001oooooooooool0C?ooool001kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_
ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oo0000ooooo`13
ooooo`03o`000?oooooooooo00;ooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0`ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooo
ooooool0BOooool00ol007ooooooo`000012ooooo`03o`000?oooooooooo00?ooooo00?o001ooooo
ooooool0C?ooool001kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0`ooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooo`000011ooooo`03
o`000?oooooooooo00Cooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0aooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0
BOooool01?l007ooooooooooool00010ooooo`03o`000?oooooooooo00Cooooo00?o001ooooooooo
ool0C?ooool001kooooo0_l0000Dooooo`03o`000?oooooooooo03;ooooo00?o001oooooooooool0
BOooool00ol007ooooooooooo`19ooooo`05o`00Ooooooooooooooooool00000?_ooool00ol0003o
ooooooooo`05ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0<_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool00_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo
00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0cooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`02ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01_ooool00ol007oooooooooo
o`1<ooooo`007_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03?ooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo00?ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`07ooooo`03o`00Oooooooooooo04cooooo000Noooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool01?ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0eooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool02Oooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03Gooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo00Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`03o`00
Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=_oo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool01ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[ooooo00?o001oooooooooool0C?oo
ool001kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`08ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool02oooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03Sooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo00Wooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0;ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0>Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool02_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00co
oooo00?o001oooooooooool0C?ooool001kooooo0_l0000<ooooo`03o`000?oooooooooo03[ooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo00_ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0=ooooo`03o`00Oooooooooooo04cooooo
0002o`0001cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0kooooo`03o`00Oooo
oooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0<ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool03_ooool00ol007ooooooooooo`1<ooooo`000_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0_l0000nooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0=ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool03oooool00ol007ooooooooooo`1<ooooo`000oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?_ooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool03_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo00?o001oooooooooool0C?ooool000Co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03oo
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo00oo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Aooooo`03o`00Oooooooooooo04co
oooo0005ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`10ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooo
ooooo`0@ooooo`;o00008?ooool2o`0001Cooooo00?o001oooooooooool0C?ooool000Kooooo0_l0
000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@Oooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool04_ooool2o`0001gooooo00?o
0000ooooooooool05?ooool00ol007ooooooooooo`1<ooooo`002?ooool00ol0003oooooooooo`04
ooooo`?o00001?ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12
ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0D
ooooo`;o00006Oooool2o`0001Oooooo00?o001oooooooooool0C?ooool000Wooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Ooo
ool01?l0003oooooooooooooool2o`0004Gooooo00?o001oooooooooool0BOooool00ol007oooooo
ooooo`19ooooo`03o`00Oooooooooooo01Kooooo00?o0000ooooooooool05?ooool2o`0001Wooooo
00?o001oooooooooool0C?ooool000[ooooo0ol000000ooooooo0000ooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0003oooooo`000?l00017ooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0Gooooo`;o
00004_ooool2o`0001_ooooo00?o001oooooooooool0C?ooool000go001o1Ol00003o`00O`04o`00
0?l007oo001oo`0000Go001o0ol0003lo`00O`03o`000?l007oo001o00ko001o00?o0000o`00Ool0
07l07?l007m>ooooo`003_ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool4o`0004[o
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo01[o
oooo1?l00009ooooo`?o00007_ooool00ol007ooooooooooo`1<ooooo`003_ooool01?l0003ooooo
ooooooooool9o`0000?ooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool07_ooool9o`00027ooooo00?o001ooooooooo
ool0C?ooool000oooooo0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`18ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?oo
ool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0
003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04So
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooo
ooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o
001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000N
ooooo`;o0000BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_oo
ool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooo
oooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04co
oooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007oooooo
ooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o
0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool2o`0004Wooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<oooo
o`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`00
0?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?oo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001ko
oooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooo
ooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o
001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19
ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<
ooooo`007_ooool2o`0004Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?oo
ool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0
003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04So
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0C?ooool000Wooooo0ol00004ooooo`;o00001?ooool2o`0000Kooooo
00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`002_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0C?ooool000[o001o00?o0000o`00Ool007l00_l007l01?l0003o
001oo`00Ool00002o`00O`04o`000?l007oo001oo`0000Go001o0ol0003oo`00Obgo001oC_ooool0
00[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`000?ooooooPoooool000Wooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000oooooon3ooooo`002_ooool00ol0003oooooooooo`03ooooo`;o00001?oo
ool2o`000?ooooooQ?ooool00?ooooooW?ooool00?ooooooW?ooool00:7ooooo00?o0000ooooool0
00000_l0000@ooooo`03o`000?oooooooooo0>;ooooo002Pooooo`05o`000?ooooooooooooooool0
00004_ooool00ol0003oooooooooo`3Qooooo`00TOooool4o`0000[ooooo00?o0000ooooooooool0
0_ooool3o`0000;ooooo2ol00004ooooo`03o`000?oooooooooo0>3ooooo002Eooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Pooooo`00
T_ooool3o`0000[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Poooo
o`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0h?ooool009;ooooo1?l0000:ooooo`03o`000?oooooooooo00Co00000oooool3o`00
00;ooooo0ol00005ooooo`03o`000?oooooooooo0>7ooooo002Qooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Rooooo`00ZOooool2o`0000Kooooo
00?o0000ooooooooool0ioooool00?ooooooW?ooool00?ooooooW?ooool00?ooooooW?ooool00?oo
ooooW?ooool00?ooooooW?ooool00?ooooooW?ooool00?ooooooW?ooool00?ooooooW?ooool00?oo
ooooW?ooool00?ooooooW?ooool00?ooooooW?ooool00001\
\>"],
  ImageRangeCache->{{{0, 410.938}, {253.625, 0}} -> {-40.0022, -10.959, \
1.32283, 0.486453}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s1 /. erg2\)], "Input"],

Cell[BoxData[
    \(80.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(phi0/Degree /. erg2\) /. e \[Rule] \(-15\) // N\)], "Input"],

Cell[BoxData[
    \(207.78664283916137`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(s0 /. erg2\) /. e \[Rule] \(-15\) // N\)], "Input"],

Cell[BoxData[
    \(62.060146569820844`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(mymin/Degree /. erg2\) /. e \[Rule] \(-15\) // N\)], "Input"],

Cell[BoxData[
    \(74.65291973765042`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(r + Abs[e] /. erg2\) /. r \[Rule] 30 // N\)], "Input"],

Cell[BoxData[
    \(\(\(29.115898094690856`\)\(\[InvisibleSpace]\)\) + Abs[e]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{767, 781},
WindowMargins->{{Automatic, 234}, {-43, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 63, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[1864, 57, 57, 0, 28, "Subsubsection"],
Cell[1924, 59, 52, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2001, 64, 105, 2, 27, "Input"],
Cell[2109, 68, 85, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2231, 74, 102, 2, 27, "Input"],
Cell[2336, 78, 108, 2, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2481, 85, 90, 1, 27, "Input"],
Cell[2574, 88, 85, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2696, 94, 62, 1, 27, "Input"],
Cell[2761, 97, 54, 1, 40, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2864, 104, 152, 3, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[3041, 111, 310, 6, 59, "Input"],
Cell[3354, 119, 93, 1, 35, "Output"],
Cell[3450, 122, 151, 4, 35, "Output"],
Cell[3604, 128, 153, 4, 35, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3806, 138, 50, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[3881, 142, 145, 3, 27, "Input"],
Cell[4029, 147, 136, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4202, 154, 71, 1, 27, "Input"],
Cell[4276, 157, 53, 1, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4378, 164, 40, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[4443, 168, 398, 7, 91, "Input"],
Cell[4844, 177, 52815, 1040, 265, 8619, 490, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57696, 1222, 43, 1, 27, "Input"],
Cell[57742, 1225, 38, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57817, 1231, 82, 1, 27, "Input"],
Cell[57902, 1234, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57992, 1240, 73, 1, 27, "Input"],
Cell[58068, 1243, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58158, 1249, 83, 1, 27, "Input"],
Cell[58244, 1252, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58333, 1258, 76, 1, 27, "Input"],
Cell[58412, 1261, 91, 1, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

