(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     57758,       1243]*)
(*NotebookOutlinePosition[     58448,       1267]*)
(*  CellTagsIndexPosition[     58404,       1263]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["P3.02\tFind mechanism for list of fct values", "Section"],

Cell[CellGroupData[{

Cell["eccentric s.c. find - basic functions", "Subsubsection"],

Cell[BoxData[
    \(\(Clear[r, l, e];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\  = \ 
      r\ Cos[phi]\  + \ Sqrt[l^2\  - \ \((e + r\ Sin[phi])\)^2]\)], "Input"],

Cell[BoxData[
    \(r\ Cos[phi] + \@\(l\^2 - \((e + r\ Sin[phi])\)\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s0 = 
      Sqrt[\((l + r)\)^2\  - e^2] - Sqrt[\((l - r)\)^2\  - e^2]\)], "Input"],

Cell[BoxData[
    \(\(-\@\(\(-e\^2\) + \((l - r)\)\^2\)\) + \@\(\(-e\^2\) + \((l + \
r)\)\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi0 = Pi - ArcSin[e/\((l - r)\)] + ArcSin[e/\((l + r)\)]\)], "Input"],

Cell[BoxData[
    \(\[Pi] - ArcSin[e\/\(l - r\)] + ArcSin[e\/\(l + r\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mymin = ArcCos[\((e + r)\)/l]\)], "Input"],

Cell[BoxData[
    \(ArcCos[\(e + r\)\/l]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Eq. of requirements  for given data: r = 30, phi1 = 30 Degrees, , \
s12 = -30, s13 = -57, phi12 = + 60 Degrees, phi13 = + 150 Degrees\
\>", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(s1 = \(s /. phi \[Rule] 30\ Degree\) /. 
        r \[Rule] 30\), "\[IndentingNewLine]", 
    \(s2 = \(s /. phi \[Rule] 90\ Degree\) /. 
        r \[Rule] 30\), "\[IndentingNewLine]", 
    \(s3 = \(s /. phi \[Rule] 180\ Degree\) /. r \[Rule] 30\)}], "Input"],

Cell[BoxData[
    \(15\ \@3 + \@\(\(-\((15 + e)\)\^2\) + l\^2\)\)], "Output"],

Cell[BoxData[
    \(\@\(\(-\((30 + e)\)\^2\) + l\^2\)\)], "Output"],

Cell[BoxData[
    \(\(-30\) + \@\(\(-e\^2\) + l\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["solution", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg2 = 
      FindRoot[{s1 \[Equal] s1erg, s2 \[Equal] s1erg - 30, 
          s3 == s1erg - 57}, {e, \(-5\)}, {l, 30}, {s1erg, 50}]\)], "Input"],

Cell[BoxData[
    \({e \[Rule] \(-10.615669293121007`\), l \[Rule] 46.56938834122138`, 
      s1erg \[Rule] 72.34330706878991`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(phi = phiG\ Degree;\)\), "\[IndentingNewLine]", 
    \(\(Plot[\(s /. erg2\) /. r \[Rule] 30, \ {phiG, \(-40\), 
          400}, \[IndentingNewLine]GridLines \[Rule] Automatic, 
        AxesLabel \[Rule] {"\<phi(Degree)\>", None}, 
        PlotLabel \[Rule] "\<s (phi)\>", 
        PlotRange \[Rule] {{\(-40\), 400}, {0, 100}}];\)\), "\n", 
    \(\(Clear[phi];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.00227273 0 0.00618034 [
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 70 6 ]
[.07841 .12361 -12 -4.5 ]
[.07841 .12361 0 4.5 ]
[.07841 .24721 -12 -4.5 ]
[.07841 .24721 0 4.5 ]
[.07841 .37082 -12 -4.5 ]
[.07841 .37082 0 4.5 ]
[.07841 .49443 -12 -4.5 ]
[.07841 .49443 0 4.5 ]
[.07841 .61803 -18 -4.5 ]
[.07841 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .61803 L
s
.31818 0 m
.31818 .61803 L
s
.54545 0 m
.54545 .61803 L
s
.77273 0 m
.77273 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
s
0 .12361 m
1 .12361 L
s
0 .24721 m
1 .24721 L
s
0 .37082 m
1 .37082 L
s
0 .49443 m
1 .49443 L
s
0 .61803 m
1 .61803 L
s
0 g
.31818 0 m
.31818 .00625 L
s
[(100)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(200)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(300)] .77273 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(400)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(phi) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(H) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Degree) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(L) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09091 .12361 m
.09716 .12361 L
s
[(20)] .07841 .12361 1 0 Mshowa
.09091 .24721 m
.09716 .24721 L
s
[(40)] .07841 .24721 1 0 Mshowa
.09091 .37082 m
.09716 .37082 L
s
[(60)] .07841 .37082 1 0 Mshowa
.09091 .49443 m
.09716 .49443 L
s
[(80)] .07841 .49443 1 0 Mshowa
.09091 .61803 m
.09716 .61803 L
s
[(100)] .07841 .61803 1 0 Mshowa
.125 Mabswid
.09091 .0309 m
.09466 .0309 L
s
.09091 .0618 m
.09466 .0618 L
s
.09091 .09271 m
.09466 .09271 L
s
.09091 .15451 m
.09466 .15451 L
s
.09091 .18541 m
.09466 .18541 L
s
.09091 .21631 m
.09466 .21631 L
s
.09091 .27812 m
.09466 .27812 L
s
.09091 .30902 m
.09466 .30902 L
s
.09091 .33992 m
.09466 .33992 L
s
.09091 .40172 m
.09466 .40172 L
s
.09091 .43262 m
.09466 .43262 L
s
.09091 .46353 m
.09466 .46353 L
s
.09091 .52533 m
.09466 .52533 L
s
.09091 .55623 m
.09466 .55623 L
s
.09091 .58713 m
.09466 .58713 L
s
.25 Mabswid
.09091 0 m
.09091 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(phi) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(L) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .36269 m
.01975 .39633 L
.04057 .42564 L
.06168 .448 L
.07365 .45713 L
.079 .46036 L
.08481 .46327 L
.09054 .46552 L
.09306 .46632 L
.09583 .46706 L
.09827 .4676 L
.10089 .46805 L
.10233 .46825 L
.10365 .46839 L
.10498 .46851 L
.10625 .46858 L
.10747 .46863 L
.10859 .46865 L
.10987 .46865 L
.11108 .46862 L
.11221 .46856 L
.11324 .46849 L
.11437 .4684 L
.11557 .46827 L
.11808 .46791 L
.12042 .46748 L
.12575 .46615 L
.13101 .46435 L
.13673 .46186 L
.14712 .45597 L
.16661 .44048 L
.18737 .41842 L
.20943 .39002 L
.24906 .33138 L
.29128 .26769 L
.3319 .21366 L
.3751 .16815 L
.4167 .13551 L
.45672 .11251 L
.47903 .10256 L
.4993 .09506 L
.52064 .08864 L
.5403 .08404 L
.54989 .08226 L
.56045 .08069 L
.56556 .08007 L
.57105 .07952 L
.57409 .07927 L
.57686 .07908 L
.5797 .07891 L
Mistroke
.58228 .07879 L
.58353 .07875 L
.58487 .07871 L
.58603 .07868 L
.5873 .07865 L
.58866 .07864 L
.5894 .07863 L
.59009 .07863 L
.59132 .07863 L
.59265 .07864 L
.59389 .07866 L
.59523 .07868 L
.5965 .07872 L
.59768 .07876 L
.5999 .07886 L
.60226 .07899 L
.6076 .07942 L
.61262 .07999 L
.61811 .08081 L
.62403 .08195 L
.63411 .08457 L
.64512 .08856 L
.65661 .09424 L
.66728 .10114 L
.67836 .11024 L
.68881 .12084 L
.70834 .14635 L
.74878 .22 L
.7918 .31097 L
.83323 .38879 L
.85406 .41964 L
.87306 .44165 L
.88357 .4511 L
.89353 .45821 L
.90403 .46372 L
.90998 .46593 L
.91284 .46677 L
.91548 .4674 L
.91779 .46785 L
.92033 .46822 L
.92165 .46837 L
.92288 .46848 L
.92418 .46857 L
.92557 .46863 L
.92679 .46865 L
.92812 .46865 L
.92938 .46861 L
.93053 .46855 L
.93158 .46848 L
.93273 .46838 L
Mistroke
.93505 .4681 L
.93786 .46763 L
.94043 .46708 L
.94622 .46543 L
.95158 .46338 L
.95667 .46098 L
.96675 .45501 L
.97748 .44693 L
.9968 .42835 L
1 .42482 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{412.375, 254.875},
  ImageMargins->{{43, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006L0000oR000`400?l00000o`00003ooooooonM
ooooo`00oooooonMooooo`00oooooonMooooo`00oooooonMooooo`00oooooonMooooo`00oooooonM
ooooo`00oooooonMooooo`00oooooonMooooo`00oooooonMooooo`00oooooonMooooo`00HOooool3
o`0000Cooooo0_l00004ooooo`;o0000??ooool5o`0000?ooooo0_l00004ooooo`;o0000?Oooool3
o`0000Cooooo0_l00004ooooo`;o0000?_ooool3o`0000?ooooo0_l00004ooooo`;o0000B?ooool0
06;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0003cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0003_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo0000?_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`15ooooo`00H_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000?Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
?oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0>Oooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0017ooooo`00H_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000?_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0kooooo`;o00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0003_ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0004Oooooo001Rooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000kooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0003oo
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0004Oooooo001Qooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0003_ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000>oooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000mooooo`;o00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0004Oooooo001Rooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o0000?Oooool3o`0000Cooooo0_l00004ooooo`;o0000?Oooool3
o`0000Cooooo0_l00004ooooo`;o0000?oooool00ol0003oooooooooo`02ooooo`;o00001?ooool2
o`0004Sooooo003ooooooigooooo003ooooooeSooooo0ol0000Cooooo`03o`000?oooooooooo00co
oooo0ol0000Eooooo`03o`000?oooooooooo00Gooooo003ooooooeWooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1?ooool00?ooooooFOooool3o`0000;ooooo2ol00003ooooo`04o`000?ooooooooooooooo`Co0000
0oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00004ooooo`?o00000oooool3o`0000Go
oooo00?o0000ooooooooool00oooool00?ooooooFOooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00?oo0000Col0000:ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Go0000oooooooooooo0000ooooo`05o`000003ooooool0003ooooo00;ooooo00Co0000oooo
oooooooo00001?ooool5o`000003ooooool0003o000000?o00001?ooool00ol0003oooooooooo`03
ooooo`003oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool001kooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`07ooooo`Co00000oooool3o`0000;ooooo0ol00006ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`03o`0000?ooooo1ol000000ooooooo0000o`000002
ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool01?ooool001kooooo00?o0000oooo
ooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooo
ooooool0BOooool00ol007ooooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo000Noooo
o`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool03Oooool2o`0000Kooooo00?o0000oooo
ooooool01oooool4o`0002Wooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_oo
ool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooo
oooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`1<ooooo`007_ooool2o`0004Wooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo
00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooooooo
o`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<oooo
o`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`00
0?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?oo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001ko
oooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool2o`0004Wooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Noooo
o`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool02?ooool:o`0003Oooooo00?o001oooooooooool0
BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooo
oooooooo04Wooooo00Co001ooooooooooooooooo1ol0000:ooooo`So0000;oooool00ol007oooooo
ooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o
001oooooooooool0A_ooool7o`0001Wooooo0ol0000/ooooo`03o`00Oooooooooooo04Wooooo00?o
001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`13
ooooo`?o00000oooool00ol007ooooooooooo`0Mooooo`03o`000?oooooooooo02Wooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18oooo
o`03o`00Oooooooooooo03oooooo1?l00006ooooo`03o`00Oooooooooooo01kooooo0_l0000Yoooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo0_l00019ooooo`03
o`00Oooooooooooo03cooooo0ol0000:ooooo`03o`00Oooooooooooo023ooooo0_l0000Wooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
B?ooool00ol007ooooooooooo`0hooooo`Co00003Oooool00ol007ooooooooooo`0Rooooo`;o0000
9Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo04Sooooo00?o001oooooooooool0=Oooool3o`00017ooooo00?o001oooooooooool09?oo
ool2o`0002?ooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool0
0ol0003oooooooooo`18ooooo`03o`00Oooooooooooo03;ooooo0ol0000Dooooo`03o`00Oooooooo
oooo02Kooooo00?o0000ooooooooool08?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0<?ooool2o`00
01Oooooo00?o001oooooooooool09oooool00ol0003oooooooooo`0Oooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oo
ooooooooo`0_ooooo`03o`000?oooooooooo01Oooooo00?o001oooooooooool0:?ooool00ol0003o
ooooooooo`0Nooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo
00?o0000ooooooooool0B?ooool00ol007ooooooooooo`0]ooooo`;o00006_ooool00ol007oooooo
ooooo`0Yooooo`;o00007_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo
000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0:oooool2o`0001cooooo00?o
001oooooooooool0:oooool00ol0003oooooooooo`0Kooooo`03o`00Oooooooooooo04Wooooo00?o
001oooooooooool0C?ooool000kooooo1Ol00003ooooo`;o00001_ooool00ol0003oooooooooo`18
ooooo`03o`00Oooooooooooo02Wooooo0_l0000Nooooo`03o`00Oooooooooooo02cooooo00?o0000
ooooooooool06_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000?oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`18ooooo`03o`00Oooooooooooo02Oooooo0_l0000Pooooo`03o`00Oooooooooooo02gooooo00?o
0000ooooooooool06Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000@
o`00O`03o`000?l007oo001o00;o001o00Co0000o`00Ool007oo00001Ol007l3o`00073o001o0_l0
001Bo`00O`03o`000?l007oo001o06Ko001oC_ooool0017ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B?ooool00ol007oooooooooo
o`0Sooooo`;o00009?ooool00ol007ooooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo00?o
001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`003_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`18ooooo`03o`00
Oooooooooooo027ooooo0_l0000Vooooo`03o`00Oooooooooooo02oooooo00?o0000ooooooooool0
5oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000>ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo04So
oooo00?o001oooooooooool07oooool2o`0002Sooooo00?o001oooooooooool0;oooool00ol0003o
ooooooooo`0Gooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool000oooooo
0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo01gooooo
0_l0000Zooooo`03o`00Oooooooooooo033ooooo00?o0000ooooooooool05_ooool00ol007oooooo
ooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o
001oooooooooool07?ooool00ol0003oooooooooo`0Zooooo`03o`00Oooooooooooo037ooooo00?o
0000ooooooooool05Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000N
ooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool06oooool00ol0003oooooooooo`0[
ooooo`03o`00Oooooooooooo037ooooo00?o0000ooooooooool05Oooool00ol007ooooooooooo`19
ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001ooooo
ooooool06_ooool00ol0003oooooooooo`0/ooooo`03o`00Oooooooooooo03;ooooo00?o0000oooo
ooooool05?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03
o`000?oooooooooo04Sooooo00?o001oooooooooool06?ooool2o`0002oooooo00?o001ooooooooo
ool0<oooool00ol0003oooooooooo`0Cooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`0Gooooo`03o`00
0?oooooooooo02oooooo00?o001oooooooooool0<oooool00ol0003oooooooooo`0Cooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?oo
ool00ol007ooooooooooo`0Fooooo`03o`000?oooooooooo033ooooo00?o001oooooooooool0=?oo
ool00ol0003oooooooooo`0Booooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?oo
ool001kooooo0_l00019ooooo`03o`00Oooooooooooo01Cooooo0_l0000cooooo`03o`00Oooooooo
oooo03Cooooo00?o0000ooooooooool04_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool04oooool00ol0
003oooooooooo`0cooooo`03o`00Oooooooooooo03Gooooo00?o0000ooooooooool04Oooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04So
oooo00?o001oooooooooool04_ooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo03Ko
oooo00?o0000ooooooooool04?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04co
oooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool04Oooool00ol0003ooooo
ooooo`0eooooo`03o`00Oooooooooooo03Kooooo00?o0000ooooooooool04?ooool00ol007oooooo
ooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o
001oooooooooool04?ooool00ol0003oooooooooo`0fooooo`03o`00Oooooooooooo03Oooooo00?o
0000ooooooooool03oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000N
ooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool04?ooool00ol0003oooooooooo`0f
ooooo`03o`00Oooooooooooo03Oooooo00?o0000ooooooooool03oooool00ol007ooooooooooo`19
ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001ooooo
ooooool03oooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo03Sooooo00?o0000oooo
ooooool03_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03
o`000?oooooooooo04Sooooo00?o001oooooooooool03_ooool00ol0003oooooooooo`0hooooo`03
o`00Oooooooooooo03Wooooo00?o0000ooooooooool03Oooool00ol007ooooooooooo`19ooooo`03
o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0
3Oooool00ol0003oooooooooo`0iooooo`03o`00Oooooooooooo03Wooooo00?o0000ooooooooool0
3Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo04Sooooo00?o001oooooooooool03?ooool00ol0003oooooooooo`0jooooo`03o`00Oooo
oooooooo03[ooooo00?o0000ooooooooool03?ooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo04cooooo000Nooooo`;o0000BOooool00ol007ooooooooooo`0;ooooo`03o`000?oooooo
oooo03_ooooo00?o001oooooooooool0>_ooool00ol0003oooooooooo`0<ooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol0
07ooooooooooo`0:ooooo`03o`000?oooooooooo03cooooo00?o001oooooooooool0>oooool00ol0
003oooooooooo`0;ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001ko
oooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`09ooooo`03o`000?oooooooooo03go
oooo00?o001oooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooo
ooooo`08ooooo`03o`000?oooooooooo03kooooo00?o001oooooooooool0??ooool00ol0003ooooo
ooooo`0:ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o
0000ooooooooool0B?ooool00ol007ooooooooooo`07ooooo`03o`000?oooooooooo03oooooo00?o
001oooooooooool0?Oooool00ol0003oooooooooo`09ooooo`03o`00Oooooooooooo04Wooooo00?o
001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`06
ooooo`03o`000?oooooooooo043ooooo00?o001oooooooooool0?Oooool00ol0003oooooooooo`09
ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooo
ooooool0B?ooool00ol007ooooooooooo`05ooooo`03o`000?oooooooooo047ooooo00?o001ooooo
ooooool0?_ooool00ol0003oooooooooo`08ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooo
ooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`04ooooo`03
o`000?oooooooooo04;ooooo00?o001oooooooooool0?_ooool00ol0003oooooooooo`08ooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
B?ooool00ol007ooooooooooo`03ooooo`03o`000?oooooooooo04?ooooo00?o001oooooooooool0
?oooool00ol0003oooooooooo`07ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0
C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`02ooooo`03o`000?oo
oooooooo04Cooooo00?o001oooooooooool0@?ooool00ol0003oooooooooo`06ooooo`03o`00Oooo
oooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo0_l00019ooooo`03o`00Oooooooo
oooo00;ooooo00?o0000ooooooooool0A?ooool00ol007ooooooooooo`10ooooo`03o`000?oooooo
oooo00Kooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0
003oooooooooo`18ooooo`05o`00Ooooooooooooooooool00000Aoooool00ol007ooooooooooo`11
ooooo`03o`000?oooooooooo00Gooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<
ooooo`007_ooool00ol0003oooooooooo`18ooooo`04o`00Ooooooooooooo`0004Sooooo00?o001o
ooooooooool0@Oooool00ol0003oooooooooo`05ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooo`000019oooo
o`03o`00Oooooooooooo04;ooooo00?o0000ooooooooool01?ooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooool0
0000BOooool00ol007ooooooooooo`12ooooo`03o`000?oooooooooo00Cooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00
Ool0003ooooo04Wooooo00?o001oooooooooool0@oooool00ol0003oooooooooo`03ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`19ooooo`03o`00Oooooooooooo04?ooooo00?o0000ooooooooool00ooo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0BOooool00ol007ooooooooooo`13ooooo`03o`000?oooooo
oooo00?ooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`004?ooool3o`00
00?ooooo0_l00006ooooo`03o`000?oooooooooo04Oooooo00?o0000o`00Ooooool0B_ooool00ol0
07ooooooooooo`14ooooo`03o`000?oooooooooo00;ooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`1<ooooo`004Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo001o04_ooooo00?o001ooooo
ooooool0A?ooool00ol0003oooooooooo`02ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooo
ooooool0C?ooool000ko001o1Ol00002o`00O`04o`000?l007oo001oo`0000Go001o0ol00015o`00
O`03o`000?l007oo001o09Co001o00?o0000o`00Ool007l0C_l007m>ooooo`003_ooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0AOooool0
1?l0003oooooooooool007m;ooooo`03o`00Oooooooooooo04Gooooo00Go0000oooooooooooooooo
o`00O`1;ooooo`03o`00Oooooooooooo04cooooo000?ooooo`03o`000?oooooo000000?ooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool0
07l0Boooool00ol007ooooooooooo`16ooooo`04o`000?ooooooooooo`00Od_ooooo00?o001ooooo
ooooool0C?ooool0013ooooo0_l00003ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`02ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooo
ooooool0A_ooool01?l0003oooooooooool007m;ooooo`03o`00Oooooooooooo04cooooo000Aoooo
o`03o`000?oooooooooo00;ooooo0_l00006ooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool00_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Oooooo00?o0000oooo
ool007l0Boooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo00?ooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`17ooooo`03
o`000?oooooo001o04_ooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`04ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0
B?ooool00ol0003o001oooooo`1:ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool01Oooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo04Sooooo00?o0000o`00Ooooool0B_ooool00ol007ooooooooooo`1<ooooo`007_ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`18ooooo`03o`000?l007oooooo04[ooooo00?o001oooooooooool0C?ooool0
01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`06ooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool0BOooool00ol0003oooooooooo`19ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01oooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o0000ooooooooool0BOooool00ol007oo
ooooooooo`1<ooooo`007_ooool2o`0003oooooo00?o0000ooooooooool01oooool00ol007oooooo
ooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oo`000?ooool0BOooool00ol007oooooo
ooooo`1<ooooo`007_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Sooooo00?o
001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Ool0003ooooo04Wooooo00?o
001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`09
ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooo`000019
ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool02Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooo
ool00000BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00[ooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`04
o`00Ooooooooooooo`0004Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0;ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool01?l007ooooooooooool00018ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool02oooool00ol007ooooooooooo`19ooooo`03
o`00Oooooooooooo04Wooooo00Go001oooooooooooooooooo`000017ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03?ooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00Go001oooooooooooooooooo`000017oooo
o`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool03Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00Go001ooooooooo
ooooooooo`000017ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool03_ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool00_ooool00ol0003oooooooooo`14ooooo`03o`00Oooooooooooo04co
oooo000Nooooo`;o0000>?ooool00ol0003oooooooooo`0>ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`02ooooo`03o`000?oooooooooo04Cooooo
00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0?ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`03ooooo`03o`000?oooooooooo04?ooooo00?o001oooooooooool0C?ooool001kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`03ooooo`03o`000?oooooooooo04?ooooo00?o001o
ooooooooool0C?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`04oooo
o`03o`000?oooooooooo04;ooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Aooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`04ooooo`03o`000?oooooooooo04;ooooo00?o001ooooooooo
ool0C?ooool001kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Booooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`05ooooo`03o`00
0?oooooooooo047ooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Booooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`05ooooo`03o`000?oooooooooo047ooooo00?o001oooooooooool0C?oo
ool001kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`06ooooo`03o`000?oooooo
oooo043ooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Dooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`07ooooo`03o`000?oooooooooo03oooooo00?o001oooooooooool0C?ooool001ko
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`07ooooo`03o`000?oooooooooo03oo
oooo00?o001oooooooooool0C?ooool001kooooo0_l0000aooooo`03o`000?oooooooooo01Gooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo00Sooooo
00?o0000ooooooooool0?_ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo01Kooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo00Sooooo00?o0000ooooooooool0?_ooool00ol007oooooooooo
o`1<ooooo`007_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Kooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo00Wooooo00?o0000
ooooooooool0?Oooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo01Oooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo00Wooooo00?o0000ooooooooool0?Oooool00ol007ooooooooooo`1<oooo
o`007_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo00[ooooo00?o0000oooooooo
ool0??ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo01Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo00[ooooo00?o0000ooooooooool0??ooool00ol007ooooooooooo`1<ooooo`007_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Wooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo00_ooooo00?o0000ooooooooool0>ooo
ool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo01[ooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo00_ooooo00?o0000ooooooooool0>oooool00ol007ooooooooooo`1<ooooo`0000?o0000oooo
ooooool03?ooool3o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool06oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooo
ooooool03?ooool00ol0003oooooooooo`0jooooo`03o`00Oooooooooooo04cooooo00000ol0003o
ooooooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06oooool00ol007ooooooooooo`19
ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool03?ooool00ol0003oooooooooo`0j
ooooo`03o`00Oooooooooooo04cooooo00000ooooooo0000ooooo`0;ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool07?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o
001oooooooooool03Oooool00ol0003oooooooooo`0iooooo`03o`00Oooooooooooo04cooooo0000
0ol007oo0000o`00O`0;o`00O`Co00000ol007l01?l0003o001oo`00Ool00005o`00O`?o0000:?l0
07l00ol0003o001oo`00O`36o`00O`03o`000?l007oo001o03Wo001oC_ooool000;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Mooooo`03o`00Oooooooooooo04Wooooo00?o
001oooooooooool0BOooool00ol007ooooooooooo`0>ooooo`03o`000?oooooooooo03Sooooo00?o
001oooooooooool0C?ooool000;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Nooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`0?ooooo`03o`000?oooooooooo03Oooooo00?o001oooooooooool0C?ooool000?ooooo00?o0000
ooooooooool02_ooool2o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool07oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool03oooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo04cooooo0004oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Ooooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0@oooo
o`03o`000?oooooooooo03Kooooo00?o001oooooooooool0C?ooool000Cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo023ooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo013ooooo00?o0000oooooooo
ool0=_ooool00ol007ooooooooooo`1<ooooo`001Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool08Oooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo04Wooooo00?o001oooooooooool04Oooool00ol0003oooooooooo`0eooooo`03o`00
Oooooooooooo04cooooo0005ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Qooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`0Aooooo`03o`000?oooooooooo03Gooooo00?o001oooooooooool0C?oo
ool000Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo02;ooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooo
oooo01;ooooo00?o0000ooooooooool0=?ooool00ol007ooooooooooo`1<ooooo`001_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08oooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool04oooool00ol0
003oooooooooo`0cooooo`03o`00Oooooooooooo04cooooo0007ooooo`03o`000?oooooooooo01Co
oooo0_l0000Rooooo`03o`000?oooooooooo02Cooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo01?ooooo00?o0000ooooooooool0<oooool00ol007oo
ooooooooo`1<ooooo`002?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool09Oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool05?ooool00ol0003oooooooooo`0booooo`03o`00Oooooooooooo04cooooo
0008ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Uooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`0Eooooo`03o`000?oooooooooo037ooooo00?o001oooooooooool0C?ooool000Wooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo01Kooooo00?o0000
ooooooooool0<?ooool00ol007ooooooooooo`1<ooooo`002_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool09oooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool05_ooool00ol0003oooooooooo`0`oooo
o`03o`00Oooooooooooo04cooooo000;ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Xooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`0Gooooo`03o`000?oooooooooo02oooooo00?o001ooooooooo
ool0C?ooool000_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00
Oooooooooooo01Sooooo00?o0000ooooooooool0;_ooool00ol007ooooooooooo`1<ooooo`003?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:Ooo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool06?oo
ool00ol0003oooooooooo`0^ooooo`03o`00Oooooooooooo04cooooo000=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Zooooo`03o`00Oooooooo
oooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0Iooooo`03o`000?oooooo
oooo02cooooo0_l0001>ooooo`003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:oooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool06_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo001o
04kooooo000?ooooo`03o`000?oooooooooo00cooooo0_l0000Jooooo`03o`000?oooooooooo02co
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo01_o
oooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool007m>ooooo`004?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;Oooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool07?ooool00ol0003o
ooooooooo`0Vooooo`05o`000?ooooooooooooooool007l0C_ooool0017ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02kooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo01gooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`02ooooo`03o`00Oooooooooooo04cooooo000Booooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool05Oooool2o`00037ooooo00?o001oooooooooool0
BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo01kooooo0_l0000Sooooo`03o`00
0?oooooooooo00?ooooo00?o001oooooooooool0C?ooool001?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo037ooooo00?o001oooooooooool0BOoo
ool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo023ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`04ooooo`03o`00Oooooooooooo04cooooo000Dooooo`;o00002?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03;ooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`19ooooo`03o`00Oooooooooooo027ooooo00?o0000ooooooooool07?ooool2
o`0000Oooooo00?o001oooooooooool0C?ooool001Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo02;ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`07ooooo`03o`00Oooooooooooo04cooooo000Gooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo04Wo
oooo00?o001oooooooooool0BOooool00ol007ooooooooooo`0Sooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool02?ooool00ol007ooooooooooo`1<ooooo`006?ooool2o`0000Cooooo
00?o0000ooooooooool03oooool2o`0003Oooooo00?o001oooooooooool0BOooool00ol007oooooo
ooooo`19ooooo`03o`00Oooooooooooo02Cooooo00?o0000ooooooooool05Oooool2o`0000_ooooo
00?o001oooooooooool0C?ooool001[ooooo0_l00002ooooo`03o`000?oooooooooo00gooooo0_l0
000iooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`0Uooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`03o`00Oooooooooooo04cooooo000L
ooooo`?o00003Oooool2o`0003_ooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19
ooooo`03o`00Oooooooooooo02Oooooo0_l0000?ooooo`?o00003_ooool00ol007ooooooooooo`1<
ooooo`007_ooool2o`0000Wooooo0ol0000mooooo`03o`00Oooooooooooo04Wooooo00?o001ooooo
ooooool0BOooool00ol007ooooooooooo`0Yooooo`?o00002_ooool2o`00017ooooo00?o001ooooo
ooooool0C?ooool001kooooo2ol00010ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`0/ooooo`[o00004oooool00ol007ooooooooooo`1<ooooo`00
7_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0
BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool0
0ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool000oooooo
0ol00004ooooo`;o00001_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo
000>ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool000kooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0B?ooool00ol0
07ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol0
07ooooooooooo`1<ooooo`003ol007l3o`0000?o001o00Co0000o`00Ool007oo00001Ol007l3o`00
0?oo001o;_l007m>ooooo`003_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000>oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo04Wooooo00?o001oooooooooool0C?ooool000oooooo0ol00004ooooo`;o00001_ooool0
0ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo
04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo
000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000
ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04cooooo000Nooooo`;o0000BOooool00ol007ooooooooooo`19ooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`00
7_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0
BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool0
0ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo
00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooooooo
o`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<oooo
o`007_ooool2o`0004Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03
o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0
BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooo
oooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool0
01kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003o
ooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001o
ooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Noooo
o`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19oooo
o`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001ooooooooo
ool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool2o`0004Wooooo00?o001oooooooooool0
BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0
C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19ooooo`03o`00Oooo
oooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<ooooo`007_ooool0
0ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool0
0ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo
04Sooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo
04Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oo
ooooooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007oo
ooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo
00?o001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo
000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007oooooooooo
o`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool000Wooooo0ol00004
ooooo`;o00001?ooool2o`0000Kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`19
ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0BOooool00ol007ooooooooooo`1<
ooooo`002_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Wooooo00?o
001oooooooooool0BOooool00ol007ooooooooooo`19ooooo`03o`00Oooooooooooo04cooooo000:
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0BOooool00ol007oooooo
ooooo`19ooooo`03o`00Oooooooooooo04Wooooo00?o001oooooooooool0C?ooool000[o001o00?o
0000o`00Ool007l00_l007l01?l0003o001oo`00Ool00002o`00O`04o`000?l007oo001oo`0000Go
001o0ol0003oo`00Obko001oC_ooool000[ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`000?ooooooQ?ooool000Wooooo0_l00004ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000oooooon4ooooo`002_ooool00ol0
003oooooooooo`03ooooo`;o00001?ooool2o`000?ooooooQOooool00?ooooooWOooool00?oooooo
WOooool00:7ooooo00?o0000ooooool000000_l0000@ooooo`03o`000?oooooooooo0>?ooooo002P
ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`3Rooooo`00TOooool4
o`0000[ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo2ol00004ooooo`03o`000?oooooo
oooo0>7ooooo002Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3Qooooo`00T_ooool3o`0000[ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3Qooooo`00TOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0hOooool009;ooooo1?l0000:ooooo`03o`00
0?oooooooooo00Co00000oooool3o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo0>;ooooo
002Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`3Sooooo`00ZOooool2o`0000Kooooo00?o0000ooooooooool0j?ooool00?ooooooWOooool00?oo
ooooWOooool00?ooooooWOooool00?ooooooWOooool00?ooooooWOooool00?ooooooWOooool00?oo
ooooWOooool00?ooooooWOooool00?ooooooWOooool00?ooooooWOooool00?ooooooWOooool00001
\
\>"],
  ImageRangeCache->{{{0, 411.375}, {253.875, 0}} -> {-40.0022, -10.9416, \
1.32114, 0.48583}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s2 /. erg2\)], "Input"],

Cell[BoxData[
    \(42.34330706878991`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(phi0/Degree /. erg2\) /. r \[Rule] 30 // N\)], "Input"],

Cell[BoxData[
    \(211.87329111721434`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(s0 /. erg2\) /. r \[Rule] 30 // N\)], "Input"],

Cell[BoxData[
    \(63.10781895422434`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(mymin/Degree /. erg2\) /. r \[Rule] 30 // N\)], "Input"],

Cell[BoxData[
    \(65.4021801288831`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(r + Abs[e] /. erg2\) /. r \[Rule] 30 // N\)], "Input"],

Cell[BoxData[
    \(40.61566929312101`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{767, 781},
WindowMargins->{{83, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 63, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[1864, 57, 62, 0, 28, "Subsubsection"],
Cell[1929, 59, 52, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2006, 64, 105, 2, 27, "Input"],
Cell[2114, 68, 85, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2236, 74, 102, 2, 27, "Input"],
Cell[2341, 78, 108, 2, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2486, 85, 90, 1, 27, "Input"],
Cell[2579, 88, 85, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2701, 94, 62, 1, 27, "Input"],
Cell[2766, 97, 54, 1, 40, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2869, 104, 168, 4, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[3062, 112, 278, 5, 59, "Input"],
Cell[3343, 119, 77, 1, 35, "Output"],
Cell[3423, 122, 67, 1, 35, "Output"],
Cell[3493, 125, 66, 1, 35, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3608, 132, 33, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[3666, 136, 164, 3, 43, "Input"],
Cell[3833, 141, 141, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4011, 148, 398, 7, 91, "Input"],
Cell[4412, 157, 52504, 1036, 265, 8599, 489, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56953, 1198, 43, 1, 27, "Input"],
Cell[56999, 1201, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57088, 1207, 77, 1, 27, "Input"],
Cell[57168, 1210, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57258, 1216, 68, 1, 27, "Input"],
Cell[57329, 1219, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57418, 1225, 78, 1, 27, "Input"],
Cell[57499, 1228, 51, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57587, 1234, 76, 1, 27, "Input"],
Cell[57666, 1237, 52, 1, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

