(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     59571,       1293]*)
(*NotebookOutlinePosition[     60262,       1317]*)
(*  CellTagsIndexPosition[     60218,       1313]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["P3.03\tDead point construction via ALT", "Section"],

Cell[CellGroupData[{

Cell["\<\
1. Find r, l, e of an eccentric  sider-crank mechanism (VDI 2130)\
\
\>", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(Clear[phi0, s0, s, r, l, e];\)\)], "Input"],

Cell[CellGroupData[{

Cell["data = {phi0->130 Degree, s0->75, auxbeta->78 Degree}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({phi0 \[Rule] 130\ \[Degree], s0 \[Rule] 75, 
      auxbeta \[Rule] 78\ \[Degree]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["gam = 1/2 phi0", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(phi0\/2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rA  = s0 / (4 Sin[gam])", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(1\/4\ s0\ Csc[phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rB  = rA / Cos[gam]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(1\/4\ s0\ Csc[phi0\/2]\ Sec[phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["theta = 180 Degree - auxbeta - phi0/2", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(-auxbeta\) + 180\ \[Degree] - phi0\/2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["r = 2 rA Cos[theta]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ s0\ Cos[auxbeta + phi0\/2]\ Csc[phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["l = 2 rB Cos[theta - gam] - r", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(1\/2\ s0\ Cos[auxbeta + phi0\/2]\ Csc[phi0\/2] - 
      1\/2\ s0\ Cos[auxbeta + phi0]\ Csc[phi0\/2]\ Sec[phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["e  = (r+l) Cos[auxbeta]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ s0\ Cos[auxbeta]\ Cos[auxbeta + phi0]\ Csc[phi0\/2]\ Sec[
        phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(data\)], "Input"],

Cell[BoxData[
    \({phi0 \[Rule] 130\ \[Degree], s0 \[Rule] 75, 
      auxbeta \[Rule] 78\ \[Degree]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
r = r/.data//N
l = l/.data//N
e = e/.data//N\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(33.04487951570738`\)], "Output"],

Cell[BoxData[
    \(53.40058727052502`\)], "Output"],

Cell[BoxData[
    \(17.973023163056048`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["further results", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(r + Abs[e] // N\)], "Input"],

Cell[BoxData[
    \(51.01790267876343`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s0 = 
      Sqrt[\((l + r)\)^2\  - e^2] - Sqrt[\((l - r)\)^2\  - e^2]\)], "Input"],

Cell[BoxData[
    \(75.00000000000001`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi0 = \((Pi - ArcSin[e/\((l - r)\)] + ArcSin[e/\((l + r)\)])\)/Degree // 
        N\)], "Input"],

Cell[BoxData[
    \(129.99999999999991`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mymin = ArcCos[\((e + r)\)/l]/Degree\)], "Input"],

Cell[BoxData[
    \(17.180115696081355`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\  = \ 
      r\ Cos[phi]\  + \ Sqrt[l^2\  - \ \((e + r\ Sin[phi])\)^2]\)], "Input"],

Cell[BoxData[
    \(33.04487951570738`\ Cos[
          phi] + \@\(\(\(2851.622720836959`\)\(\[InvisibleSpace]\)\) - \
\((\(\(17.973023163056048`\)\(\[InvisibleSpace]\)\) + 33.04487951570738`\ \
Sin[phi])\)\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(phi = phiG*Degree;\)\), "\[IndentingNewLine]", 
    \(Plot[s, {phiG, \(-40\), 400}, GridLines \[Rule] Automatic, 
      AxesLabel \[Rule] {"\<phi(Degree)\>", None}, 
      PlotLabel \[Rule] "\<s (phi)\>", 
      PlotRange \[Rule] {{\(-40\), 400}, {0, 100}}]; Clear[phi];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.00227273 0 0.00618034 [
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 70 6 ]
[.07841 .12361 -12 -4.5 ]
[.07841 .12361 0 4.5 ]
[.07841 .24721 -12 -4.5 ]
[.07841 .24721 0 4.5 ]
[.07841 .37082 -12 -4.5 ]
[.07841 .37082 0 4.5 ]
[.07841 .49443 -12 -4.5 ]
[.07841 .49443 0 4.5 ]
[.07841 .61803 -18 -4.5 ]
[.07841 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .61803 L
s
.31818 0 m
.31818 .61803 L
s
.54545 0 m
.54545 .61803 L
s
.77273 0 m
.77273 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
s
0 .12361 m
1 .12361 L
s
0 .24721 m
1 .24721 L
s
0 .37082 m
1 .37082 L
s
0 .49443 m
1 .49443 L
s
0 .61803 m
1 .61803 L
s
0 g
.31818 0 m
.31818 .00625 L
s
[(100)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(200)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(300)] .77273 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(400)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(phi) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(H) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Degree) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(L) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09091 .12361 m
.09716 .12361 L
s
[(20)] .07841 .12361 1 0 Mshowa
.09091 .24721 m
.09716 .24721 L
s
[(40)] .07841 .24721 1 0 Mshowa
.09091 .37082 m
.09716 .37082 L
s
[(60)] .07841 .37082 1 0 Mshowa
.09091 .49443 m
.09716 .49443 L
s
[(80)] .07841 .49443 1 0 Mshowa
.09091 .61803 m
.09716 .61803 L
s
[(100)] .07841 .61803 1 0 Mshowa
.125 Mabswid
.09091 .0309 m
.09466 .0309 L
s
.09091 .0618 m
.09466 .0618 L
s
.09091 .09271 m
.09466 .09271 L
s
.09091 .15451 m
.09466 .15451 L
s
.09091 .18541 m
.09466 .18541 L
s
.09091 .21631 m
.09466 .21631 L
s
.09091 .27812 m
.09466 .27812 L
s
.09091 .30902 m
.09466 .30902 L
s
.09091 .33992 m
.09466 .33992 L
s
.09091 .40172 m
.09466 .40172 L
s
.09091 .43262 m
.09466 .43262 L
s
.09091 .46353 m
.09466 .46353 L
s
.09091 .52533 m
.09466 .52533 L
s
.09091 .55623 m
.09466 .55623 L
s
.09091 .58713 m
.09466 .58713 L
s
.25 Mabswid
.09091 0 m
.09091 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(phi) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(L) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .48586 m
.00942 .49546 L
.01975 .50448 L
.03065 .51218 L
.04057 .51743 L
.04626 .51964 L
.05163 .52117 L
.05458 .52178 L
.05731 .52219 L
.05873 .52235 L
.0603 .52248 L
.06109 .52252 L
.06194 .52256 L
.06274 .52258 L
.06347 .52259 L
.06478 .52257 L
.06552 .52255 L
.06618 .52252 L
.06748 .52244 L
.0687 .52233 L
.07013 .52216 L
.07144 .52198 L
.07441 .52142 L
.07682 .52083 L
.07947 .52005 L
.08481 .51804 L
.09031 .51534 L
.09552 .5122 L
.10529 .50477 L
.11581 .49453 L
.12725 .48079 L
.14802 .44909 L
.17008 .40651 L
.20971 .31099 L
.25193 .19547 L
.27133 .14577 L
.28232 .12134 L
.29255 .10221 L
.30272 .08711 L
.31359 .07531 L
.31956 .07053 L
.3252 .06698 L
.33026 .06448 L
.33575 .06241 L
.34088 .06099 L
.34568 .06006 L
.34844 .05967 L
.35095 .05941 L
.35234 .0593 L
.35386 .0592 L
Mistroke
.35455 .05917 L
.35529 .05914 L
.35662 .05909 L
.35734 .05908 L
.35811 .05907 L
.35949 .05906 L
.36025 .05907 L
.36097 .05908 L
.36175 .0591 L
.36259 .05912 L
.3641 .05918 L
.36553 .05925 L
.36821 .05944 L
.37083 .05967 L
.37324 .05993 L
.37871 .06066 L
.38885 .06249 L
.39835 .06466 L
.41999 .07096 L
.46067 .08679 L
.50392 .10877 L
.54558 .13563 L
.58565 .16813 L
.6283 .21182 L
.66935 .26417 L
.71298 .32995 L
.75501 .39787 L
.79546 .45818 L
.81596 .48342 L
.82682 .4947 L
.83848 .50491 L
.84967 .51269 L
.85989 .51792 L
.86481 .51976 L
.86741 .52055 L
.87016 .52125 L
.87257 .52174 L
.87384 .52196 L
.87522 .52216 L
.87648 .52231 L
.87764 .52241 L
.87874 .52249 L
.8799 .52255 L
.8812 .52258 L
.88192 .52259 L
.8826 .52258 L
.88383 .52255 L
.88514 .52248 L
.88631 .52239 L
.88741 .52227 L
Mistroke
.88991 .52193 L
.8926 .52142 L
.89506 .52082 L
.90061 .51901 L
.90533 .51697 L
.91049 .5142 L
.91988 .50773 L
.93073 .49796 L
.94056 .48698 L
.96258 .45522 L
1 .38047 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{410.125, 253.5},
  ImageMargins->{{43, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006J0000oB000`400?l00000o`00003ooooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00HOooool3
o`0000Cooooo0_l00004ooooo`;o0000>oooool5o`0000?ooooo0_l00004ooooo`;o0000??ooool3
o`0000Cooooo0_l00004ooooo`;o0000?Oooool3o`0000?ooooo0_l00004ooooo`;o0000BOooool0
06;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0003_ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0003[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo0000?Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`16ooooo`00H_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000??ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
?_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0>?ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0018ooooo`00H_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000?Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0jooooo`;o00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0003[ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0004Sooooo001Rooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000jooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0003ko
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0004Sooooo001Qooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0003[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000>_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000looooo`;o00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0004Sooooo001Rooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o0000??ooool3o`0000Cooooo0_l00004ooooo`;o0000??ooool3
o`0000Cooooo0_l00004ooooo`;o0000?_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool2
o`0004Wooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooeKooooo0ol0000Cooooo`03o`00
0?oooooooooo00cooooo0ol0000Eooooo`03o`000?oooooooooo00Gooooo003ooooooeOooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01?ooool00?ooooooEoooool3o`0000;ooooo2ol00003ooooo`04o`000?oooooo
ooooooooo`Co00000oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00004ooooo`?o0000
0oooool3o`0000Gooooo00?o0000ooooooooool00oooool00?ooooooEoooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00?oo0000C?l0000;ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000oooooooooooo0000ooooo`05o`000003ooooool0003ooooo00;o
oooo00Co0000oooooooooooo00001?ooool5o`000003ooooool0003o000000?o00001?ooool00ol0
003oooooooooo`03ooooo`003oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool00_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool001kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`08ooooo`Co00000oooool3o`0000;ooooo0ol00006ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03o`0000?ooooo1ol000000ooo
oooo0000o`000002ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool01?ooool001ko
oooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0?ooooo`03o`000?oooooooooo00co
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Gooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool03_ooool2o`0000Ko
oooo00?o0000ooooooooool01oooool4o`0002Wooooo000Nooooo`03o`000?oooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`1=ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Noooo
o`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000oooooooo
ool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool2o`0004Wooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
COooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool0
0ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo
04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo
000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001ooooooooo
ool01Oooool<o`0003Oooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04gooooo000Nooooo`;o0000BOooool00ol007ooooooooooo`02ooooo`?o0000
3?ooool6o`00037ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool00_l0
000Eooooo`?o0000;_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0COooool001kooooo00?o0000ooooooooool0B?ooool00ol007oo0000o`00000J
ooooo`?o0000:oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0COooool001kooooo00?o0000ooooooooool0Aoooool2o`0001oooooo0ol0000Xoooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=oooo
o`007_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo001o02;ooooo0ol0000Uooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`00
7_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo001o02Gooooo0ol0000Rooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_oo
ool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`00ObSooooo0ol0000Oooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_oo
ool00ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool007l0:oooool3o`0001cooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo
000Nooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool00_ooool00ol007oooooooooo
o`0/ooooo`;o00006_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0COooool001kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`02
ooooo`03o`00Oooooooooooo02kooooo0_l0000Hooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool2o`0004?ooooo00?o0000oooo
ooooool00oooool00ol007ooooooooooo`0`ooooo`;o00005_ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`04ooooo`03o`00Oooooooooooo03;ooooo0_l0000Dooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`00
7_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Gooooo00?o001oooooooooool0
=?ooool2o`0001;ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01_oo
ool00ol007ooooooooooo`0fooooo`;o00004?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`06ooooo`03o`00Oooooooooooo03Sooooo0_l0000>ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o001oooooooooool0>_ooool2o`00
00cooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04gooooo000Nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01oooool00ol007oo
ooooooooo`0looooo`03o`000?oooooooooo00Wooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool02?ooool00ol007ooooooooooo`0mooooo`;o00002Oooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool000gooooo1Ol0
0003ooooo`;o00001oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Sooooo00?o
001oooooooooool0?oooool00ol0003oooooooooo`06ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`003_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`08ooooo`03o`00Oooooooooooo043ooooo0_l00006ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`003ol007l00ol0003o001oo`00
O`02o`00O`04o`000?l007oo001oo`0000Ko001o0ol0000lo`00O`03o`000?l007oo001o04ko001o
0_l0002Ko`00Odoooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02Oooool00ol007oooooo
ooooo`14ooooo`05o`000?ooooooooooooooool007l0B_ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04gooooo000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0
07ooooooooooo`15ooooo`;o000000?oooooo`00Ooooool0BOooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04gooooo000=ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool0
0ol007ooooooooooo`17ooooo`03o`000?l007oooooo04Wooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`1=ooooo`003_ooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool02oooool00ol007ooooooooooo`18ooooo`;o0000BOooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool02oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo000004So
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo00cooooo00?o001oooooooooool0B?ooool01?l007oooooo
ooooool00017ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`03o`00Oooooooooooo04Sooooo
00Go001oooooooooooooooooo`000016ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0COooool001kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0=ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool00_ooool00ol0003oooooooooo`13ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0=ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool00ooo
ool2o`0004?ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00kooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`05ooooo`03o`000?oooooooooo043ooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`1=ooooo`007_ooool2o`0003Sooooo00?o0000ooooooooool03_ooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo00Kooooo00?o0000ooooooooool0?oooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool03_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00Oo
oooo00?o0000ooooooooool0?_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04go
oooo000Nooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03oooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo00Sooooo00?o0000ooooooooool0?Oooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool03oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00Wooooo00?o
0000ooooooooool0??ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000N
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03oooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo00[ooooo00?o0000ooooooooool0>oooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool04?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00[ooooo00?o0000oooo
ooooool0>oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04?ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
4Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00cooooo00?o0000ooooooooool0
>Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool04Oooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo00gooooo00?o0000ooooooooool0>?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04gooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04Oooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00kooooo00?o0000ooooooooool0=oooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`;o0000=?ooool00ol0
003oooooooooo`0Booooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool03oooool00ol0
003oooooooooo`0fooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001ko
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Booooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool04?ooool00ol0003oooooooooo`0eooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Booooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool04Oooool00ol0003ooooo
ooooo`0dooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool04_ooool00ol0003oooooooooo`0cooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0COooool001kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0C
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool04oooool00ol0003oooooooooo`0b
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool05?ooool00ol0003oooooooooo`0aooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0COooool001kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Dooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool05Oooool00ol0003oooooooooo`0`ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
5_ooool00ol0003oooooooooo`0_ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
COooool001kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Eooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool05oooool00ol0003oooooooooo`0^ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Eooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool06?ooool0
0ol0003oooooooooo`0]ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool0
01kooooo0_l0000aooooo`03o`000?oooooooooo01Gooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`0Hooooo`03o`000?oooooooooo02gooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Ko
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0Iooooo`03o`000?oooooooooo02co
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01Kooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`0Jooooo`03o`000?oooooooooo02_ooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`1=ooooo`007_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Oooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`0Kooooo`03o`000?oooooooooo02[ooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01Oooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0L
ooooo`03o`000?oooooooooo02Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=
ooooo`007_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Oooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0Mooooo`03
o`000?oooooooooo02Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`00
7_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`0Nooooo`03o`000?oooooooooo02Oooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`1=ooooo`003oooool3o`0000?ooooo0_l00007ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool06?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo01oooooo00?o0000ooooooooool09_ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04gooooo000@ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool06Oooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo023ooooo00?o0000ooooooooool09Oooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04gooooo000=o`00O`Go00000_l007l01?l0003o001oo`00Ool0
0006o`00O`?o0000;?l007l00ol0003o001oo`00O`28o`00O`03o`000?l007oo001o073o001oCooo
ool000gooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool06Oooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo027ooooo00?o0000ooooooooool09?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04gooooo000>ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01[ooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`0Rooooo`03o`000?oooooooooo02?ooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`1=ooooo`003oooool2o`0000?ooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01[ooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`1=ooooo`004?ooool00ol0003oooooooooo`02ooooo`;o00001ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01_ooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`0Tooooo`03o`000?oooooooooo027ooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01_ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0Uooooo`03o`000?oooooo
oooo023ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01_ooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`0Vooooo`03o`000?oooooooooo01oooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01co
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0Vooooo`03o`000?oooooooooo01oo
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo01cooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`0Wooooo`03o`000?oooooooooo01kooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`1=ooooo`007_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01cooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`0Xooooo`03o`000?oooooooooo01gooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0X
ooooo`03o`000?oooooooooo01gooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=
ooooo`007_ooool2o`0002Wooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo02Wooooo00?o0000ooooooooool07?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool07_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo02[ooooo00?o0000oooooooo
ool06oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo02[ooooo00?o0000ooooooooool06oooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool07_oo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo02_ooooo00?o0000ooooooooool06_oo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool07oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo02_ooooo00?o0000ooooooooool06_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo04gooooo000Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07oooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo02cooooo00?o0000ooooooooool06Oooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool07oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo02go
oooo00?o0000ooooooooool06?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04go
oooo000Nooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08?ooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo02gooooo00?o0000ooooooooool06?ooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool08?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo02kooooo00?o
0000ooooooooool05oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000N
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08?ooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo02oooooo00?o0000ooooooooool05_ooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo04gooooo000Nooooo`;o00009Oooool00ol0003oooooooooo`0Qoooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0;oooool00ol0003oooooooooo`0Foooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Qooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0<?ooool00ol0003oooooooooo`0Eooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0COooool001kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0<Oooool00ol0003oooooooooo`0Dooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Rooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0<Ooo
ool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COoo
ool001kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Sooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0<_ooool00ol0
003oooooooooo`0Cooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001ko
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0<oooool00ol0003oooooooooo`0Booooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Tooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0=?ooool00ol0003ooooo
ooooo`0Aooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Tooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0=?ooool00ol0003oooooooooo`0Aooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0COooool001kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0T
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0=Oooool00ol0003oooooooooo`0@
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo0_l0000Qoooo
o`03o`000?oooooooooo02Gooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0foooo
o`03o`000?oooooooooo00oooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=oooo
o`007_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Gooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`0fooooo`03o`000?oooooooooo00oooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo02Kooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0gooooo`03o`00
0?oooooooooo00kooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`0hooooo`03o`000?oooooooooo00gooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo02Kooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0hooooo`03o`000?oooooo
oooo00gooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Oooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`0iooooo`03o`000?oooooooooo00cooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Oo
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0iooooo`03o`000?oooooooooo00co
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02Sooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`0jooooo`03o`000?oooooooooo00_ooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`1=ooooo`003_ooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0:?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo03_ooooo00?o
0000ooooooooool02_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000=
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0:Oooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04gooooo000=o`00O`05o`000?l007oo001oo`00Ool000000_l007l01?l0003o001o
o`00Ool00006o`00O`?o00007?l007l00ol0003o001oo`00O`2co`00O`03o`000?l007oo001o05Go
001oCoooool000gooooo1?l00003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Yooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0?Oooool00ol0003oooooooooo`08ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0COooool000gooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0:_ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo03gooooo00?o0000ooooooooool02?ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04gooooo000>ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02[ooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o001ooooooooo
ool0B?ooool00ol0003oooooooooo`1=ooooo`003oooool2o`0000Cooooo0_l00007ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:oooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo03oooooo00?o0000ooooooooool01_ooool00ol007ooooooooooo`18ooooo`03o`00
0?oooooooooo04gooooo000Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:ooo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo03oooooo00?o0000ooooooooool01_oo
ool00ol007ooooooooooo`17ooooo`03o`000?l007oooooo04kooooo000Nooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0:oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo043ooooo00?o0000ooooooooool01Oooool00ol007ooooooooooo`17ooooo`03o`000?l007oo
oooo04kooooo000Nooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0;?ooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo043ooooo00?o0000ooooooooool01Oooool00ol0
07ooooooooooo`16ooooo`03o`000?oooooo001o04oooooo000Nooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0;?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo047o
oooo00?o0000ooooooooool01?ooool00ol007ooooooooooo`16ooooo`03o`000?oooooo001o04oo
oooo000Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;Oooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04;ooooo00?o0000ooooooooool00oooool00ol007oooooo
ooooo`15ooooo`04o`000?ooooooooooo`00Odoooooo000Nooooo`;o00006Oooool00ol0003ooooo
ooooo`0]ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0@_ooool00ol0003ooooo
ooooo`03ooooo`03o`00Oooooooooooo04Gooooo00Co0000oooooooooooo001oCoooool001kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0]ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0@oooool00ol0003oooooooooo`02ooooo`03o`00Oooooooooooo04Cooooo
00Go0000ooooooooooooooooo`00O`1?ooooo`007_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02kooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`14ooooo`05o`00
0?ooooooooooooooool007l0A_ooool01Ol0003ooooooooooooooooo001o04oooooo000Nooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0;_ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04Cooooo00Go0000ooooooooooooooooo`00O`15ooooo`03o`000?oooooooooo
00;ooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0_ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0AOooool01?l0003o
ooooooooool007m5ooooo`03o`000?oooooooooo00;ooooo00?o001oooooooooool0COooool001ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0A_ooool00ol0003oooooo`00O`14ooooo`03o`000?oooooooooo00?o
oooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0`ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0Aoooool00ol0003o001o
ooooo`13ooooo`03o`000?oooooooooo00?ooooo00?o001oooooooooool0COooool001kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0aooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0Aoooool00ol0003o001oooooo`13ooooo`03o`000?oooooooooo00?ooooo00?o
001oooooooooool0COooool001kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0a
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo00Cooooo00?o001oooooooooool0COooool001kooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0booooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0B?ooool00ol007oo0000ooooo`11ooooo`03o`000?oooooooooo00Cooooo00?o001ooooo
ooooool0COooool001kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0booooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo0000ooooo`10ooooo`03
o`000?oooooooooo00Gooooo00?o001oooooooooool0COooool001kooooo0_l0000Cooooo`03o`00
0?oooooooooo03?ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooo0000043ooooo00?o0000ooooooooool01Oooool00ol007ooooooooooo`1=ooooo`007_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03?ooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`18ooooo`04o`00Ooooooooooooo`0003kooooo00?o0000ooooooooool0
1_ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo03Cooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`04o`00Oooo
ooooooooo`0003kooooo00?o0000ooooooooool01_ooool00ol007ooooooooooo`1=ooooo`007_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Gooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`18ooooo`05o`00Ooooooooooooooooool00000??ooool00ol0003ooooo
ooooo`07ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0=Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool00_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00Oooooo00?o
001oooooooooool0COooool001kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0f
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`03
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol007ooooooooooo`1=
ooooo`007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Kooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00?ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`08ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool01?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00Wooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`05ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
2Oooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo03Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo00Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0:ooooo`03o`00Oooo
oooooooo04gooooo000Nooooo`;o00003_ooool00ol0003oooooooooo`0hooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`06ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool02oooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03Wooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0;ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0>_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool02?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00co
oooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0jooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`08ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool00ol007oooooo
ooooo`1=ooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00Wooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0=ooooo`03o`00Oooooooooooo04gooooo000N
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>oooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool02_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00kooooo00?o001oooooooooool0COooool001kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0looooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool03_ooool00ol007ooooooooooo`1=ooooo`0000?o0000ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03gooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo00cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0?ooooo`03o`00Oooooooooooo04gooooo00000ooooooo0000ooooo`0;ooooo`?o0000
1?ooool2o`0000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0nooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0=ooooo`03o`00
0?oooooooooo02Cooooo0_l0000Booooo`03o`00Oooooooooooo04gooooo0002ooooo`03o`000?oo
oooooooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0oooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0>ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool04_ooool00ol007ooooooooooo`1=ooooo`000ol007l00ol0003o001o
o`00O`07o`00O`05o`000?l007oo001oo`00Ool000000_l007l01?l0003o001oo`00Ool00006o`00
O`?o00001Ol007l00ol0003o001oo`00O`3Xo`00O`03o`000?l007oo001o023o001o00?o0000o`00
Ool007l05?l007m?ooooo`001?ooool00ol0003oooooooooo`07ooooo`?o00000oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@Oooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool04?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo00?o001oooooooooool0COooool000Go
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo017ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`03o`00Oooooooooooo04gooooo0006oooo
o`;o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo01;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Fooooo`03o`00Oooooooooooo04gooooo0008ooooo`03o`000?oooooo
oooo00?ooooo0ol00004ooooo`;o00001oooool00ol0003oooooooooo`02o`0004Kooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo01?ooooo0_l0000I
ooooo`03o`000?oooooooooo01Oooooo00?o001oooooooooool0COooool000Wooooo00?o0000oooo
ooooool04_ooool00ol0003oooooo`000018ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`0Eooooo`;o00005_ooool00ol0003oooooooooo`0Hoooo
o`03o`00Oooooooooooo04gooooo000:ooooo`;o00004_ooool2o`0004Wooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo01Oooooo0_l0000Cooooo`03
o`000?oooooooooo01Wooooo00?o001oooooooooool0COooool000cooooo00?o0000ooooooooool0
3_ooool2o`0004[ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo01Wooooo00?o0000ooooooooool03_ooool2o`0001cooooo00?o001oooooooooool0
COooool000gooooo1?l0000:ooooo`;o000000?oooooo`000?ooool0BOooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool06_ooool3o`0000[ooooo0ol0
000Nooooo`03o`00Oooooooooooo04gooooo000Aooooo`[o00000oooool00ol0003oooooooooo`18
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0L
ooooo`_o00008Oooool00ol007ooooooooooo`1=ooooo`007_ooool2o`0004Wooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0COooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`00
7_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oo
oooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0B?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04gooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo
00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003ooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0COooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=oooo
o`007_ooool2o`0004Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0
B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04gooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool0
01kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool00ol0003o
ooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`1=ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Noooo
o`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0COooool001kooooo0_l00019ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
COooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1=ooooo`007_ooool0
0ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo000Nooooo`03o`000?oooooooooo
04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0COooool001kooooo00?o0000ooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1=ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04gooooo
0008ooooo`?o00001?ooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo04Sooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0COooool000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0B?ooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`1=ooooo`002Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04go
oooo0009o`00O`03o`000?l007oo001o00;o001o00Co0000o`00Ool007oo00000_l007l01?l0003o
001oo`00Ool00006o`00O`?o0000ool007l[o`00Odoooooo0009ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003ooooooh?ooooo0008oooo
o`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?ooooooPooo
ool000Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l0003oooooohCooooo003ooooo
oi_ooooo003ooooooi_ooooo002Pooooo`03o`000?oooooo000000;o00004?ooool00ol0003ooooo
ooooo`3Rooooo`00Woooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool0
hOooool0093ooooo1?l0000:ooooo`03o`000?oooooooooo00;ooooo0ol00002ooooo`_o00001?oo
ool00ol0003oooooooooo`3Pooooo`00U?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0h?ooool0097ooooo0ol0000:ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0h?ooool0093ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>3ooooo002Aooooo`Co
00002_ooool00ol0003oooooooooo`04o`0000?ooooo0ol00002ooooo`?o00001Oooool00ol0003o
ooooooooo`3Qooooo`00X?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0h_ooool00:Sooooo0_l00006ooooo`03o`000?oooooooooo0>Oooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003ooooooi_ooooo003o
oooooi_ooooo0000\
\>"],
  ImageRangeCache->{{{0, 409.125}, {252.5, 0}} -> {-40.0022, -11.0097, \
1.3299, 0.489053}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{878, 802},
WindowMargins->{{39, Automatic}, {-5, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[1858, 57, 130, 4, 38, "Subsection"],
Cell[1991, 63, 65, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2081, 68, 103, 1, 27, "Input"],
Cell[2187, 71, 116, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2340, 78, 64, 1, 27, "Input"],
Cell[2407, 81, 41, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2485, 87, 73, 1, 27, "Input"],
Cell[2561, 90, 56, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2654, 96, 69, 1, 27, "Input"],
Cell[2726, 99, 70, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2833, 105, 87, 1, 27, "Input"],
Cell[2923, 108, 73, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3033, 114, 69, 1, 27, "Input"],
Cell[3105, 117, 89, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3231, 123, 79, 1, 27, "Input"],
Cell[3313, 126, 147, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3497, 133, 73, 1, 27, "Input"],
Cell[3573, 136, 123, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3733, 143, 37, 1, 27, "Input"],
Cell[3773, 146, 116, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3926, 153, 102, 5, 57, "Input"],
Cell[4031, 160, 52, 1, 27, "Output"],
Cell[4086, 163, 52, 1, 27, "Output"],
Cell[4141, 166, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4231, 172, 40, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[4296, 176, 48, 1, 27, "Input"],
Cell[4347, 179, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4436, 185, 102, 2, 27, "Input"],
Cell[4541, 189, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4630, 195, 117, 2, 27, "Input"],
Cell[4750, 199, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4840, 205, 69, 1, 27, "Input"],
Cell[4912, 208, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5002, 214, 105, 2, 27, "Input"],
Cell[5110, 218, 224, 4, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5371, 227, 307, 5, 75, "Input"],
Cell[5681, 234, 53838, 1053, 264, 8625, 490, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

