(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     57635,       1270]*)
(*NotebookOutlinePosition[     58326,       1294]*)
(*  CellTagsIndexPosition[     58282,       1290]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["P3.04\tDead point construction via ALT", "Section"],

Cell[CellGroupData[{

Cell["\<\
1. Find r, l, e of an eccentric  sider-crank mechanism (VDI 2130)\
\
\>", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(Clear[phi0, s0, s, r, l, e];\)\)], "Input"],

Cell[CellGroupData[{

Cell["data = {phi0->158 Degree, s0->60, auxbeta->75 Degree}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({phi0 \[Rule] 158\ \[Degree], s0 \[Rule] 60, 
      auxbeta \[Rule] 75\ \[Degree]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["gam = 1/2 phi0", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(phi0\/2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rA  = s0 / (4 Sin[gam])", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(1\/4\ s0\ Csc[phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rB  = rA / Cos[gam]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(1\/4\ s0\ Csc[phi0\/2]\ Sec[phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["theta = 180 Degree - auxbeta - phi0/2", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(-auxbeta\) + 180\ \[Degree] - phi0\/2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["r = 2 rA Cos[theta]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ s0\ Cos[auxbeta + phi0\/2]\ Csc[phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["l = 2 rB Cos[theta - gam] - r", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(1\/2\ s0\ Cos[auxbeta + phi0\/2]\ Csc[phi0\/2] - 
      1\/2\ s0\ Cos[auxbeta + phi0]\ Csc[phi0\/2]\ Sec[phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["e  = (r+l) Cos[auxbeta]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ s0\ Cos[auxbeta]\ Cos[auxbeta + phi0]\ Csc[phi0\/2]\ Sec[
        phi0\/2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(data\)], "Input"],

Cell[BoxData[
    \({phi0 \[Rule] 158\ \[Degree], s0 \[Rule] 60, 
      auxbeta \[Rule] 75\ \[Degree]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
r = r/.data//N
l = l/.data//N
e = e/.data//N\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(27.468495008739335`\)], "Output"],

Cell[BoxData[
    \(68.92303152542522`\)], "Output"],

Cell[BoxData[
    \(24.94796285354676`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["further results", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(r + Abs[e] // N\)], "Input"],

Cell[BoxData[
    \(52.416457862286094`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s0 = 
      Sqrt[\((l + r)\)^2\  - e^2] - Sqrt[\((l - r)\)^2\  - e^2]\)], "Input"],

Cell[BoxData[
    \(60.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi0 = \((Pi - ArcSin[e/\((l - r)\)] + ArcSin[e/\((l + r)\)])\)/Degree // 
        N\)], "Input"],

Cell[BoxData[
    \(157.99999999999997`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mymin = ArcCos[\((e + r)\)/l]/Degree\)], "Input"],

Cell[BoxData[
    \(40.4910729964717`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(s\  = \ 
      r\ Cos[phi]\  + \ Sqrt[l^2\  - \ \((e + r\ Sin[phi])\)^2]\)], "Input"],

Cell[BoxData[
    \(27.468495008739335`\ Cos[
          phi] + \@\(\(\(4750.384274654758`\)\(\[InvisibleSpace]\)\) - \
\((\(\(24.94796285354676`\)\(\[InvisibleSpace]\)\) + 27.468495008739335`\ \
Sin[phi])\)\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(phi = phiG*Degree;\)\), "\[IndentingNewLine]", 
    \(Plot[s, {phiG, \(-40\), 400}, GridLines \[Rule] Automatic, 
      AxesLabel \[Rule] {"\<phi(Degree)\>", None}, 
      PlotLabel \[Rule] "\<s (phi)\>", 
      PlotRange \[Rule] {{\(-40\), 400}, {0, 100}}]; Clear[phi];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.00227273 0 0.00618034 [
[.31818 -0.0125 -9 -9 ]
[.31818 -0.0125 9 0 ]
[.54545 -0.0125 -9 -9 ]
[.54545 -0.0125 9 0 ]
[.77273 -0.0125 -9 -9 ]
[.77273 -0.0125 9 0 ]
[1 -0.0125 -9 -9 ]
[1 -0.0125 9 0 ]
[1.025 0 0 -6 ]
[1.025 0 70 6 ]
[.07841 .12361 -12 -4.5 ]
[.07841 .12361 0 4.5 ]
[.07841 .24721 -12 -4.5 ]
[.07841 .24721 0 4.5 ]
[.07841 .37082 -12 -4.5 ]
[.07841 .37082 0 4.5 ]
[.07841 .49443 -12 -4.5 ]
[.07841 .49443 0 4.5 ]
[.07841 .61803 -18 -4.5 ]
[.07841 .61803 0 4.5 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.09091 0 m
.09091 .61803 L
s
.31818 0 m
.31818 .61803 L
s
.54545 0 m
.54545 .61803 L
s
.77273 0 m
.77273 .61803 L
s
1 0 m
1 .61803 L
s
0 0 m
1 0 L
s
0 .12361 m
1 .12361 L
s
0 .24721 m
1 .24721 L
s
0 .37082 m
1 .37082 L
s
0 .49443 m
1 .49443 L
s
0 .61803 m
1 .61803 L
s
0 g
.31818 0 m
.31818 .00625 L
s
[(100)] .31818 -0.0125 0 1 Mshowa
.54545 0 m
.54545 .00625 L
s
[(200)] .54545 -0.0125 0 1 Mshowa
.77273 0 m
.77273 .00625 L
s
[(300)] .77273 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(400)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.13636 0 m
.13636 .00375 L
s
.18182 0 m
.18182 .00375 L
s
.22727 0 m
.22727 .00375 L
s
.27273 0 m
.27273 .00375 L
s
.36364 0 m
.36364 .00375 L
s
.40909 0 m
.40909 .00375 L
s
.45455 0 m
.45455 .00375 L
s
.5 0 m
.5 .00375 L
s
.59091 0 m
.59091 .00375 L
s
.63636 0 m
.63636 .00375 L
s
.68182 0 m
.68182 .00375 L
s
.72727 0 m
.72727 .00375 L
s
.81818 0 m
.81818 .00375 L
s
.86364 0 m
.86364 .00375 L
s
.90909 0 m
.90909 .00375 L
s
.95455 0 m
.95455 .00375 L
s
.04545 0 m
.04545 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(phi) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(H) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Degree) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(L) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.09091 .12361 m
.09716 .12361 L
s
[(20)] .07841 .12361 1 0 Mshowa
.09091 .24721 m
.09716 .24721 L
s
[(40)] .07841 .24721 1 0 Mshowa
.09091 .37082 m
.09716 .37082 L
s
[(60)] .07841 .37082 1 0 Mshowa
.09091 .49443 m
.09716 .49443 L
s
[(80)] .07841 .49443 1 0 Mshowa
.09091 .61803 m
.09716 .61803 L
s
[(100)] .07841 .61803 1 0 Mshowa
.125 Mabswid
.09091 .0309 m
.09466 .0309 L
s
.09091 .0618 m
.09466 .0618 L
s
.09091 .09271 m
.09466 .09271 L
s
.09091 .15451 m
.09466 .15451 L
s
.09091 .18541 m
.09466 .18541 L
s
.09091 .21631 m
.09466 .21631 L
s
.09091 .27812 m
.09466 .27812 L
s
.09091 .30902 m
.09466 .30902 L
s
.09091 .33992 m
.09466 .33992 L
s
.09091 .40172 m
.09466 .40172 L
s
.09091 .43262 m
.09466 .43262 L
s
.09091 .46353 m
.09466 .46353 L
s
.09091 .52533 m
.09466 .52533 L
s
.09091 .55623 m
.09466 .55623 L
s
.09091 .58713 m
.09466 .58713 L
s
.25 Mabswid
.09091 0 m
.09091 .61803 L
s
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(phi) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(L) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .55362 m
.00942 .56003 L
.01975 .56587 L
.02496 .56832 L
.03053 .57056 L
.03575 .57228 L
.04057 .57355 L
.04328 .57412 L
.04628 .57464 L
.04929 .57502 L
.05093 .57518 L
.05248 .5753 L
.05317 .57534 L
.05393 .57537 L
.05531 .57542 L
.05665 .57543 L
.0579 .57542 L
.05866 .57541 L
.05938 .57539 L
.06072 .57532 L
.06148 .57528 L
.06217 .57522 L
.06373 .57508 L
.06626 .57478 L
.06862 .57442 L
.07398 .57327 L
.07921 .57175 L
.08481 .56966 L
.09549 .56437 L
.10711 .5567 L
.12824 .53776 L
.149 .51332 L
.17106 .48189 L
.2107 .41557 L
.25291 .34126 L
.29353 .27912 L
.31457 .25388 L
.33673 .23329 L
.34675 .22598 L
.35746 .21948 L
.36749 .21456 L
.37674 .21097 L
.3875 .20787 L
.39316 .20667 L
.39605 .20617 L
.39916 .20571 L
.40188 .20538 L
.40436 .20513 L
.40686 .20493 L
.40923 .20478 L
Mistroke
.41056 .20472 L
.4113 .20469 L
.41198 .20467 L
.41332 .20464 L
.41454 .20462 L
.41524 .20461 L
.41598 .20461 L
.41731 .20462 L
.41805 .20463 L
.41875 .20464 L
.4195 .20466 L
.42032 .20469 L
.4216 .20473 L
.42302 .2048 L
.42588 .20498 L
.42854 .2052 L
.43103 .20545 L
.43663 .20616 L
.44266 .20716 L
.4537 .20958 L
.4638 .21244 L
.48371 .21976 L
.50546 .23016 L
.5481 .2574 L
.58916 .29188 L
.63278 .33697 L
.67482 .3874 L
.71526 .43966 L
.75828 .49405 L
.7797 .51843 L
.79971 .53838 L
.82016 .55505 L
.83023 .56163 L
.83955 .56667 L
.84977 .57093 L
.85516 .57263 L
.85792 .57335 L
.86089 .57401 L
.86338 .57446 L
.86566 .57481 L
.86785 .57506 L
.87015 .57526 L
.87137 .57534 L
.87267 .57539 L
.8739 .57542 L
.87503 .57543 L
.87634 .57542 L
.87709 .5754 L
.87777 .57538 L
.87903 .57532 L
Mistroke
.88037 .57522 L
.88163 .57511 L
.88302 .57496 L
.88553 .57462 L
.89026 .57373 L
.89578 .57226 L
.90089 .57049 L
.9102 .56628 L
.92012 .56036 L
.94261 .54163 L
.9638 .51767 L
1 .46489 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{409.938, 253.375},
  ImageMargins->{{43, 0}, {0, 2}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006I0000oB000`400?l00000o`00003ooooooonJ
ooooo`00oooooonJooooo`00oooooonJooooo`00oooooonJooooo`00oooooonJooooo`00oooooonJ
ooooo`00oooooonJooooo`00oooooonJooooo`00oooooonJooooo`00oooooonJooooo`00HOooool3
o`0000Cooooo0_l00004ooooo`;o0000>oooool5o`0000?ooooo0_l00004ooooo`;o0000??ooool3
o`0000Cooooo0_l00004ooooo`;o0000?Oooool3o`0000?ooooo0_l00004ooooo`;o0000B?ooool0
06;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0003_ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0003[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo0000?Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`15ooooo`00H_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000??ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
?_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool0>?ooool5o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0017ooooo`00H_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000?Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0jooooo`;o00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0003[ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0004Oooooo001Rooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000jooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0003ko
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0004Oooooo001Qooooo`;o00001?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0003[ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000>_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000looooo`;o00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0004Oooooo001Rooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`;o0000??ooool3o`0000Cooooo0_l00004ooooo`;o0000??ooool3
o`0000Cooooo0_l00004ooooo`;o0000?_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool2
o`0004Sooooo003ooooooi[ooooo003ooooooi[ooooo003ooooooeGooooo0ol0000Cooooo`03o`00
0?oooooooooo00cooooo0ol0000Eooooo`03o`000?oooooooooo00Gooooo003ooooooeKooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01?ooool00?ooooooE_ooool3o`0000;ooooo2ol00003ooooo`04o`000?oooooo
ooooooooo`Co00000oooool3o`0000?ooooo1?l000001?oooooo0000o`000?l00004ooooo`?o0000
0oooool3o`0000Gooooo00?o0000ooooooooool00oooool00?ooooooE_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00?oo0000C?l0000:ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000oooooooooooo0000ooooo`05o`000003ooooool0003ooooo00;o
oooo00Co0000oooooooooooo00001?ooool5o`000003ooooool0003o000000?o00001?ooool00ol0
003oooooooooo`03ooooo`003oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool00_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`000003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool001kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`07ooooo`Co00000oooool3o`0000;ooooo0ol00006ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03o`0000?ooooo1ol000000ooo
oooo0000o`000002ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool01?ooool001ko
oooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0>ooooo`03o`000?oooooooooo00co
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Gooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool03Oooool2o`0000Ko
oooo00?o0000ooooooooool01oooool4o`0002Wooooo000Nooooo`03o`000?oooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Noooo
o`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool2o`0004Wooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool0
0ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo
04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo
000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0C?ooool001kooooo0_l00019ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo
00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<oooo
o`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`;o0000
BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool0
01kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003o
ooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000=oooo
o`Go00000oooool2o`0000Oooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<oooo
o`003_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`003oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<
ooooo`004?l007l01Ol0003o001oo`00Ool007oo000000;o001o00?o0000o`00Ool007l01?l007l3
o`000?oo001o:ol007m>ooooo`003Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000=
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool000kooooo0ol00004ooooo`;o00001ooo
ool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooo
oooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04co
oooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o
0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo04cooooo000Nooooo`;o0000BOooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<oooo
o`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`00
0?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?oo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001ko
oooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooo
ooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<
ooooo`007_ooool2o`0004Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?oo
ool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0
003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04So
oooo00?o001oooooooooool06Oooool9o`0002Kooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo
00?o001oooooooooool04_ooool7o`0000Wooooo1ol0000Oooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003ooooooooo
o`18ooooo`03o`00Oooooooooooo00oooooo0ol0000Gooooo`Co00006oooool00ol007oooooooooo
o`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000
ooooooooool0B?ooool00ol007ooooooooooo`0>ooooo`03o`000?oooooooooo01cooooo0ol0000H
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<
ooooo`007_ooool2o`0004Wooooo00?o001oooooooooool03?ooool2o`0002;ooooo0ol0000Eoooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<oooo
o`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo00Wooooo0ol0000Wooooo`;o
00004oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`07ooooo`;o0000
;?ooool2o`00017ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool01_oo
ool00ol0003oooooooooo`0^ooooo`;o00003oooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool0
0ol007ooooooooooo`05ooooo`03o`000?oooooooooo037ooooo0_l0000=ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0
003oooooooooo`18ooooo`03o`00Oooooooooooo00Cooooo00?o0000ooooooooool0=?ooool2o`00
00_ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool00oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo00Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo
00?o001oooooooooool00_ooool00ol0003oooooooooo`0iooooo`;o00002?ooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool000oooooo0ol0
0003ooooo`;o00001oooool00ol0003oooooooooo`18ooooo`05o`00Ooooooooooooooooool00000
?_ooool00ol0003oooooooooo`05ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`1<ooooo`004?ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`18ooooo`04o`00Ooooooooooooo`00043o
oooo0_l00005ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1<ooooo`003Ol007l5o`0000;o001o00Co0000o`00Ool007oo00001_l007l3o`0004[o
001o00?o0000o`00Ool007l0@Ol007l2o`0009[o001oC_ooool000gooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo04Sooooo00?o001oo`00
0?ooool0AOooool01?l0003oooooooooool007m:ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0C?ooool000kooooo00?o0000ooooool000000oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0A_ooool2o`000003o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`003oooool2o`00
00?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`17ooooo`03o`000?l007oo
oooo04Wooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooo
oooo04cooooo000@ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`03o`000?oooooooooo
04Oooooo00?o0000o`00Ooooool0BOooool00ol007oo0000o`000018ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooo`00O`1:ooooo`04o`00Ooooooooooooo`0004Oooooo00?o001oooooooooool0B?ooool00ol0
07ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`00
Od[ooooo00Go001oooooooooooooooooo`000016ooooo`03o`00Oooooooooooo04Sooooo00?o001o
ooooooooool0C?ooool001kooooo00?o0000ooooooooool0A?ooool01Ol0003ooooooooooooooooo
001o04[ooooo00?o001oooooooooool00_ooool00ol0003oooooooooo`13ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`02ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool00oooool00ol0
003oooooooooo`12ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001ko
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`03ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool01?ooool2o`0004;ooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`06ooooo`03o`000?oooooooooo03oooooo
00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool2o`00047ooooo00?o
0000ooooooooool01Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00Oooooo00?o
0000ooooooooool0?_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000N
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01Oooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo00Sooooo00?o0000ooooooooool0?Oooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool01_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00Wooooo00?o0000oooo
ooooool0??ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool01oooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo00[ooooo00?o0000ooooooooool0>oooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
1oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00_ooooo00?o0000ooooooooool0
>_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool02?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo00cooooo00?o0000ooooooooool0>Oooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04cooooo000Nooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02Oooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00gooooo00?o0000ooooooooool0>?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
00kooooo00?o0000ooooooooool0=oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo00oooooo00?o0000ooooooooool0=_ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool02oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo013ooooo
00?o0000ooooooooool0=Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo
000Nooooo`;o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool04Oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0<
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool04_ooool00ol0003oooooooooo`0c
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0=ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool04oooool00ol0003oooooooooo`0booooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0C?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0>ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool05?ooool00ol0003oooooooooo`0aooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0>ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
5Oooool00ol0003oooooooooo`0`ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
C?ooool001kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0@ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool05oooool0
0ol0003oooooooooo`0^ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool0
01kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Aooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool06?ooool00ol0003oooooooooo`0]ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0Aooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool06Oooool00ol0003o
ooooooooo`0/ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Booooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool06_ooool00ol0003oooooooooo`0[ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool0C?ooool001kooooo0_l0000cooooo`03o`000?oooooooooo01?ooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`0Jooooo`03o`000?oooooooooo02_ooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01?ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0K
ooooo`03o`000?oooooooooo02[ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<
ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Cooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`0Looooo`03o`000?oooooooooo02Wooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01Cooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0Mooooo`03
o`000?oooooooooo02Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`00
7_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Gooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`0Nooooo`03o`000?oooooooooo02Oooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Kooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0Oooooo`03o`000?oo
oooooooo02Kooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Kooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01Oooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0Pooooo`03o`000?oooooooooo
02Gooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`003_ooool3o`0000Co
oooo0_l00007ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool05oooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo027ooooo00?o0000ooooooooool09?ooool00ol007oo
ooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000=ooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool06?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo02;ooooo00?o0000oooo
ooooool08oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000=o`00O`05
o`000?l007oo001oo`00Ool000000_l007l01?l0003o001oo`00Ool00006o`00O`?o0000;Ol007l0
0ol0003o001oo`00O`29o`00O`03o`000?l007oo001o06ko001oC_ooool000gooooo1?l00003oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0I
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool08oooool00ol0003oooooooooo`0R
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool000gooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool06Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo02Cooooo00?o0000
ooooooooool08Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000>oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo01[ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0U
ooooo`03o`000?oooooooooo023ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<
ooooo`003oooool2o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool06oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo02Kooooo00?o0000oooo
ooooool07oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool06oooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo02Oooooo00?o0000ooooooooool07_ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
7?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo02Sooooo00?o0000ooooooooool0
7Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool07?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo02Sooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04cooooo000Nooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07Oooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo02Wooooo00?o0000ooooooooool07?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool07Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
02[ooooo00?o0000ooooooooool06oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04cooooo000Nooooo`;o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0:oooool00ol0003oooooooooo`0Jooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Nooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0:oooool00ol0003ooooo
ooooo`0Jooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Oooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0;?ooool00ol0003oooooooooo`0Iooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0C?ooool001kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0P
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0;Oooool00ol0003oooooooooo`0H
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Pooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0;_ooool00ol0003oooooooooo`0Gooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0C?ooool001kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Qooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0;oooool00ol0003oooooooooo`0Fooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Qooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
;oooool00ol0003oooooooooo`0Fooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
C?ooool001kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0<?ooool00ol0003oooooooooo`0Eooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Rooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0<Oooool0
0ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool0
01kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Sooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Tooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0<_ooool00ol0003o
ooooooooo`0Cooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo
0_l0000Rooooo`03o`000?oooooooooo02Cooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`0cooooo`03o`000?oooooooooo01;ooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`1<ooooo`007_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Gooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`0dooooo`03o`000?oooooooooo017ooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo02Gooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0e
ooooo`03o`000?oooooooooo013ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<
ooooo`007_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Kooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`0eooooo`03o`000?oooooooooo013ooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Oooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0fooooo`03
o`000?oooooooooo00oooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`00
7_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Oooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`0gooooo`03o`000?oooooooooo00kooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo02Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0hooooo`03o`000?oo
oooooooo00gooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`0iooooo`03o`000?oooooooooo00cooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
02Wooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0iooooo`03o`000?oooooooooo
00cooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02[ooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`0jooooo`03o`000?oooooooooo00_ooooo00?o001oooooooooool0B?ooool00ol007oo
ooooooooo`1<ooooo`007_ooool2o`0001cooooo00?o0000ooooooooool0:_ooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol007oooooo
ooooo`18ooooo`03o`000?oooooooooo04cooooo000Nooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0:oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo03cooooo00?o
0000ooooooooool02Oooool00ol007ooooooooooo`18ooooo`03o`000?oooooooooo04cooooo000N
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:oooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo03cooooo00?o0000ooooooooool02Oooool00ol007ooooooooooo`17
ooooo`03o`000?l007oooooo04gooooo000Nooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0;?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo03gooooo00?o0000oooo
ooooool02?ooool00ol007ooooooooooo`16ooooo`03o`000?oooooo001o04kooooo000Nooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0;Oooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo03kooooo00?o0000ooooooooool01oooool00ol007ooooooooooo`16ooooo`03
o`000?oooooo001o04kooooo000Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
;Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo03oooooo00?o0000ooooooooool0
1_ooool00ol007ooooooooooo`15ooooo`04o`000?ooooooooooo`00Odkooooo000Nooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0;_ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo043ooooo00?o0000ooooooooool01Oooool00ol007ooooooooooo`14ooooo`05o`00
0?ooooooooooooooool007l0C_ooool001kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0^ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0@?ooool00ol0003ooooo
ooooo`05ooooo`03o`00Oooooooooooo04Cooooo00Go0000ooooooooooooooooo`00O`1>ooooo`00
3_ooool3o`0000Cooooo0_l00007ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo047ooooo00?o0000ooooooooool0
1?ooool00ol007ooooooooooo`13ooooo`03o`000?oooooooooo00;ooooo00?o001oooooooooool0
C?ooool000gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0`ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0@_ooool00ol0003oooooooooo`03ooooo`03o`00Oooooooooooo04;o
oooo00?o0000ooooooooool00oooool00ol007ooooooooooo`1<ooooo`003Ol007l01Ol0003o001o
o`00Ool007oo000000;o001o00Co0000o`00Ool007oo00001_l007l3o`0001Go001o00?o0000o`00
Ool007l0`Ol007l00ol0003o001oo`00O`17o`00O`03o`000?l007oo001o00Co001oC_ooool000ko
oooo0ol00003ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0aooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0@oooool00ol0
003oooooooooo`02ooooo`03o`00Oooooooooooo047ooooo00?o0000ooooooooool01?ooool00ol0
07ooooooooooo`1<ooooo`003Oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03;ooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`14ooooo`05o`000?ooooooooooooooool007l0@_oo
ool00ol0003oooooooooo`05ooooo`03o`00Oooooooooooo04cooooo000=ooooo`05o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0<oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Gooooo
00Co0000oooooooooooo001o@_ooool00ol0003oooooooooo`05ooooo`03o`00Oooooooooooo04co
oooo000>ooooo`?o00001?ooool2o`0000Oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0cooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0A_ooool00ol0003ooooo
o`00O`11ooooo`03o`000?oooooooooo00Kooooo00?o001oooooooooool0C?ooool001kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0dooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0Aoooool00ol0003o001oooooo`0oooooo`03o`000?oooooooooo00Oooooo00?o
001oooooooooool0C?ooool001kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0e
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00Oooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0eooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0B?ooool00ol007oo0000ooooo`0mooooo`03o`000?oooooooooo00Sooooo00?o001ooooo
ooooool0C?ooool001kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0fooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooo`00000looooo`03
o`000?oooooooooo00Wooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0gooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
B?ooool01?l007ooooooooooool0000kooooo`03o`000?oooooooooo00Wooooo00?o001ooooooooo
ool0C?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo03Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`18ooooo`05o`00Ooooooooooooooooool00000>Oooool00ol0003o
ooooooooo`0:ooooo`03o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0>Oooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo
00?o001oooooooooool00_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo
00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0jooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooooooo
o`03ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool03?ooool00ol007oooooooooo
o`1<ooooo`007_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o001o
ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0=ooooo`03o`00Oooooooooooo04cooooo000Noooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0??ooool00ol007ooooooooooo`18oooo
o`03o`00Oooooooooooo04Sooooo00?o001oooooooooool01Oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00kooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0mooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`06ooooo`;o0000;_ooool00ol0003oooooooooo`0?ooooo`03
o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
?_ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
2?ooool00ol0003oooooooooo`0Yooooo`;o00004_ooool00ol007ooooooooooo`1<ooooo`007_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03oooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo00Wooooo0_l0000Xooooo`03o`000?oo
oooooooo01;ooooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`10ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool04oooool0
0ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
047ooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
00cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`00Oooooooooooo
04cooooo0002o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`12ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0=ooooo`;o
00008Oooool00ol0003oooooooooo`0Eooooo`03o`00Oooooooooooo04cooooo0002ooooo`03o`00
0?oooooooooo01Wooooo0_l00002ooooo`;o0000AOooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01Kooooo00?o001oooooooooool0C?ooool000?ooooo0_l0000Iooooo`04o`000?oo
oooo0000o`0004Oooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo013ooooo0_l0000Kooooo`;o00006Oooool00ol007ooooooooooo`1<ooooo`001Ooo
ool00ol0003oooooooooo`0Fooooo`;o0000BOooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool04_ooool00ol0003oooooooooo`0Fooooo`;o00006ooo
ool00ol007ooooooooooo`1<ooooo`001_ooool2o`0001Gooooo0_l0001:ooooo`03o`00Oooooooo
oooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0Cooooo`?o00004oooool2
o`0001gooooo00?o001oooooooooool0C?ooool000Sooooo0ol0000@ooooo`;o000000?oooooo`00
0?ooool0BOooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool05_ooool2o`0000oooooo0_l0000Oooooo`03o`00Oooooooooooo04cooooo000;ooooo`Co
00002?ooool4o`0000?ooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool06?ooool3o`0000Sooooo1?l0000Qooooo`03
o`00Oooooooooooo04cooooo000?ooooo`So00001oooool00ol0003oooooooooo`18ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`0Kooooo`So0000
9Oooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooo
oooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooo
oooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool0
0ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool0
01kooooo00?o0000ooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo
04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool2o`0004Wo
oooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04So
oooo00?o001oooooooooool0C?ooool001kooooo00?o0000ooooooooool0B?ooool00ol007oooooo
ooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007oooooo
ooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o
001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04cooooo000N
ooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18
ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0C?ooool001kooooo00?o0000oooo
ooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooo
ooooool0B?ooool00ol007ooooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`18ooooo`03
o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03
o`00Oooooooooooo04cooooo000Nooooo`03o`000?oooooooooo04Sooooo00?o001oooooooooool0
B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0
C?ooool000Sooooo0ol00004ooooo`;o00001?ooool2o`0000Oooooo00?o0000ooooooooool0B?oo
ool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001oooooooooool0B?oo
ool00ol007ooooooooooo`1<ooooo`002Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`18ooooo`03o`00
Oooooooooooo04Sooooo00?o001oooooooooool0B?ooool00ol007ooooooooooo`18ooooo`03o`00
Oooooooooooo04cooooo0009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo04Sooooo00?o001ooooooooo
ool0B?ooool00ol007ooooooooooo`18ooooo`03o`00Oooooooooooo04Sooooo00?o001ooooooooo
ool0C?ooool000Wo001o00?o0000o`00Ool007l00_l007l01?l0003o001oo`00Ool00002o`00O`04
o`000?l007oo001oo`0000Ko001o0ol0003oo`00Ob_o001oC_ooool000Wooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?ooooooP_ooool0
00Sooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000oooo
oon2ooooo`002Oooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`000?ooooooPoooool0
0?ooooooV_ooool00?ooooooV_ooool00:3ooooo00?o0000ooooool000000_l0000@ooooo`03o`00
0?oooooooooo0>7ooooo002Oooooo`05o`000?ooooooooooooooool000004_ooool00ol0003ooooo
ooooo`3Pooooo`00T?ooool4o`0000[ooooo00?o0000ooooooooool00_ooool3o`0000;ooooo2ol0
0004ooooo`03o`000?oooooooooo0=oooooo002Dooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Oooooo`00TOooool3o`0000[ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Oooooo`00T?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0goooool0097o
oooo1?l0000:ooooo`03o`000?oooooooooo00Co00000oooool3o`0000;ooooo0ol00005ooooo`03
o`000?oooooooooo0>3ooooo002Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`3Qooooo`00Z?ooool2o`0000Kooooo00?o0000ooooooooool0i_oo
ool00?ooooooV_ooool00?ooooooV_ooool00?ooooooV_ooool00?ooooooV_ooool00?ooooooV_oo
ool00?ooooooV_ooool00?ooooooV_ooool00?ooooooV_ooool00?ooooooV_ooool00?ooooooV_oo
ool00?ooooooV_ooool00001\
\>"],
  ImageRangeCache->{{{0, 408.938}, {252.375, 0}} -> {-40.0022, -11.0129, \
1.33064, 0.489324}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
WindowSize->{878, 802},
WindowMargins->{{39, Automatic}, {-5, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[1858, 57, 130, 4, 38, "Subsection"],
Cell[1991, 63, 65, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2081, 68, 103, 1, 27, "Input"],
Cell[2187, 71, 116, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2340, 78, 64, 1, 27, "Input"],
Cell[2407, 81, 41, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2485, 87, 73, 1, 27, "Input"],
Cell[2561, 90, 56, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2654, 96, 69, 1, 27, "Input"],
Cell[2726, 99, 70, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2833, 105, 87, 1, 27, "Input"],
Cell[2923, 108, 73, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3033, 114, 69, 1, 27, "Input"],
Cell[3105, 117, 89, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3231, 123, 79, 1, 27, "Input"],
Cell[3313, 126, 147, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3497, 133, 73, 1, 27, "Input"],
Cell[3573, 136, 123, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3733, 143, 37, 1, 27, "Input"],
Cell[3773, 146, 116, 2, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3926, 153, 102, 5, 57, "Input"],
Cell[4031, 160, 53, 1, 27, "Output"],
Cell[4087, 163, 52, 1, 27, "Output"],
Cell[4142, 166, 52, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4231, 172, 40, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[4296, 176, 48, 1, 27, "Input"],
Cell[4347, 179, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4437, 185, 102, 2, 27, "Input"],
Cell[4542, 189, 38, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4617, 195, 117, 2, 27, "Input"],
Cell[4737, 199, 53, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4827, 205, 69, 1, 27, "Input"],
Cell[4899, 208, 51, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4987, 214, 105, 2, 27, "Input"],
Cell[5095, 218, 225, 4, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5357, 227, 307, 5, 75, "Input"],
Cell[5667, 234, 51916, 1030, 264, 8634, 491, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

