(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13272,        514]*)
(*NotebookOutlinePosition[     14841,        561]*)
(*  CellTagsIndexPosition[     14797,        557]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Aufgabe 4.05: Kinematik einer Antenne.", "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["daten = {gam->6 Pi/9, l->3, u->0.3, dgam->6}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({gam \[Rule] \(2\ \[Pi]\)\/3, l \[Rule] 3, u \[Rule] 0.3`, 
      dgam \[Rule] 6}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Drehmatrizen", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Clear[phix, phiy, phiz];", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
\t\tMatAx = {{ 1, 0,           0 \t\t },
\t\t\t\t{ 0, Cos [phix], -Sin [phix] },
\t\t\t\t{ 0, Sin [phix],  Cos [phix] }};
\t\tMatAy = {{ Cos [phiy],  0, Sin [phiy] },
\t\t\t\t{ 0         ,  1, 0 \t\t },
\t\t\t\t{-Sin [phiy],  0, Cos [phiy] }};
\t\tMatAz = {{ Cos [phiz], -Sin [phiz], 0 },
\t\t\t\t{ Sin [phiz],  Cos [phiz], 0 },
\t\t\t\t{ 0         ,  0         , 1 }};
MatA = MatAx . MatAy . MatAz; MatrixForm[MatA]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[phiy]\ Cos[phiz]\), \(\(-Cos[phiy]\)\ Sin[phiz]\), \(Sin[
                phiy]\)},
            {\(Cos[phiz]\ Sin[phix]\ Sin[phiy] + 
                Cos[phix]\ Sin[phiz]\), \(Cos[phix]\ Cos[phiz] - 
                Sin[phix]\ Sin[phiy]\ Sin[phiz]\), \(\(-Cos[phiy]\)\ Sin[
                  phix]\)},
            {\(\(-Cos[phix]\)\ Cos[phiz]\ Sin[phiy] + 
                Sin[phix]\ Sin[phiz]\), \(Cos[phiz]\ Sin[phix] + 
                Cos[phix]\ Sin[phiy]\ Sin[phiz]\), \(Cos[phix]\ Cos[phiy]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MatH = {{ Cos[phiy] Cos[phiz], Sin[phiz], 0},
        {-Cos[phiy] Sin[phiz], Cos[phiz], 0},
        { Sin[phiy],           0        , 1}}; MatrixForm[MatH]\
\>", "Input",\

  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[phiy]\ Cos[phiz]\), \(Sin[phiz]\), "0"},
            {\(\(-Cos[phiy]\)\ Sin[phiz]\), \(Cos[phiz]\), "0"},
            {\(Sin[phiy]\), "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
InvH = Inverse[MatH];
Simplify[InvH]//MatrixForm\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[phiz]\ Sec[phiy]\), \(\(-Sec[phiy]\)\ Sin[phiz]\), "0"},
            {\(Sin[phiz]\), \(Cos[phiz]\), "0"},
            {\(\(-Cos[phiz]\)\ Tan[phiy]\), \(Sin[phiz]\ Tan[phiy]\), "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrix AIB", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
AIB = MatA/.{phix -> 0, phiy -> 0, phiz -> gam}; \
MatrixForm[AIB]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[gam]\), \(-Sin[gam]\), "0"},
            {\(Sin[gam]\), \(Cos[gam]\), "0"},
            {"0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AIBd = AIB/.daten; MatrixForm[AIBd//N]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-0.5`\), \(-0.8660254037844386`\), "0.`"},
            {"0.8660254037844386`", \(-0.5`\), "0.`"},
            {"0.`", "0.`", "1.`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Position, Gescwindigkeiten, Beschleunigungen", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Position", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["rFB = {l, -u, 0}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({l, \(-u\), 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rFB /.daten", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({3, \(-0.3`\), 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rB = {0, 0, 0}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rF = rB + AIB.rFB; MatrixForm[rF]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(l\ Cos[gam] + u\ Sin[gam]\)},
            {\(\(-u\)\ Cos[gam] + l\ Sin[gam]\)},
            {"0"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Plus[ 
          Times[ l, 
            Cos[ gam]], 
          Times[ u, 
            Sin[ gam]]], 
        Plus[ 
          Times[ -1, u, 
            Cos[ gam]], 
          Times[ l, 
            Sin[ gam]]], 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rF/.daten//MatrixForm//N", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-1.2401923788646685`\)},
            {"2.748076211353316`"},
            {"0.`"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {-1.2401923788646685, 2.7480762113533159, 0.0}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Winkelgeschw., u. Winkelbeschl", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["omeB = MatH . {0, 0, dgam}", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({0, 0, dgam}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["omeB /.daten", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({0, 0, 6}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["alphaB = D[omeB,t]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lineargeschwindigkeit", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["vF = D[rF,gam] * dgam; MatrixForm[vF]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(dgam\ \((u\ Cos[gam] - l\ Sin[gam])\)\)},
            {\(dgam\ \((l\ Cos[gam] + u\ Sin[gam])\)\)},
            {"0"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Times[ dgam, 
          Plus[ 
            Times[ u, 
              Cos[ gam]], 
            Times[ -1, l, 
              Sin[ gam]]]], 
        Times[ dgam, 
          Plus[ 
            Times[ l, 
              Cos[ gam]], 
            Times[ u, 
              Sin[ gam]]]], 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["vF/.daten//N//MatrixForm", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-16.488457268119895`\)},
            {\(-7.441154273188011`\)},
            {"0.`"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {-16.488457268119895, -7.4411542731880109, 0.0}]]], "Output"]
}, Open  ]],

Cell["oder", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Tilde[v1_?ListQ]:=
\t\t{{0,-v1[[3]],v1[[2]]},
\t     {v1[[3]],0,-v1[[1]]},
\t     {-v1[[2]],v1[[1]],0}} /; Length[v1]==3
omeBTilde = Tilde[omeB]; MatrixForm[omeBTilde]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", \(-dgam\), "0"},
            {"dgam", "0", "0"},
            {"0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
vF = D[rB,t] + AIB . omeBTilde . rFB + D[rFB,t]; \
MatrixForm[vF]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(dgam\ u\ Cos[gam] - dgam\ l\ Sin[gam]\)},
            {\(dgam\ l\ Cos[gam] + dgam\ u\ Sin[gam]\)},
            {"0"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Plus[ 
          Times[ dgam, u, 
            Cos[ gam]], 
          Times[ -1, dgam, l, 
            Sin[ gam]]], 
        Plus[ 
          Times[ dgam, l, 
            Cos[ gam]], 
          Times[ dgam, u, 
            Sin[ gam]]], 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["vF/.daten//N//TableForm", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(-16.488457268119895`\)},
          {\(-7.441154273188011`\)},
          {"0.`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {-16.488457268119895, -7.4411542731880109, 0.0}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Linearbeschleunigung", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["aF = Simplify[D[vF,gam] * dgam]; MatrixForm[aF]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-dgam\^2\)\ \((l\ Cos[gam] + u\ Sin[gam])\)\)},
            {\(dgam\^2\ \((u\ Cos[gam] - l\ Sin[gam])\)\)},
            {"0"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Times[ -1, 
          Power[ dgam, 2], 
          Plus[ 
            Times[ l, 
              Cos[ gam]], 
            Times[ u, 
              Sin[ gam]]]], 
        Times[ 
          Power[ dgam, 2], 
          Plus[ 
            Times[ u, 
              Cos[ gam]], 
            Times[ -1, l, 
              Sin[ gam]]]], 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["aF/.daten//N//MatrixForm", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"44.646925639128064`"},
            {\(-98.93074360871937`\)},
            {"0.`"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {44.646925639128064, -98.930743608719368, 0.0}]]], "Output"]
}, Open  ]],

Cell["oder", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
aF = D[rB,{t,2}] + AIB . (omeBTilde.omeBTilde.rFB + 2 \
omeBTilde.D[rFB,t] + D[rFB,{t,2}]); 
MatrixForm[aF]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-dgam\^2\)\ l\ Cos[gam] - dgam\^2\ u\ Sin[gam]\)},
            {\(dgam\^2\ u\ Cos[gam] - dgam\^2\ l\ Sin[gam]\)},
            {"0"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Plus[ 
          Times[ -1, 
            Power[ dgam, 2], l, 
            Cos[ gam]], 
          Times[ -1, 
            Power[ dgam, 2], u, 
            Sin[ gam]]], 
        Plus[ 
          Times[ 
            Power[ dgam, 2], u, 
            Cos[ gam]], 
          Times[ -1, 
            Power[ dgam, 2], l, 
            Sin[ gam]]], 0}]]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["aF/.daten//N//MatrixForm", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"44.646925639128064`"},
            {\(-98.93074360871937`\)},
            {"0.`"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {44.646925639128064, -98.930743608719368, 0.0}]]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
WindowSize->{926, 816},
WindowMargins->{{Automatic, 66}, {Automatic, 0}},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
      "Prof.Dr. O. Wallrapp, FHM FB06"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {36, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000004Xh=2ommoi/C4@e`0fL5N`?P0080004/0B`000000]P2:001
0000AP0000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 91, 1, 61, "Subtitle"],

Cell[CellGroupData[{
Cell[1855, 56, 94, 1, 27, "Input"],
Cell[1952, 59, 115, 2, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2104, 66, 67, 1, 44, "Subsection"],
Cell[2174, 69, 74, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2273, 74, 474, 12, 162, "Input"],
Cell[2750, 88, 661, 13, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3448, 106, 215, 6, 57, "Input"],
Cell[3666, 114, 305, 7, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4008, 126, 106, 4, 42, "Input"],
Cell[4117, 132, 342, 7, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4496, 144, 68, 1, 41, "Subsubsection"],

Cell[CellGroupData[{
Cell[4589, 149, 124, 4, 27, "Input"],
Cell[4716, 155, 265, 7, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5018, 167, 88, 1, 27, "Input"],
Cell[5109, 170, 289, 7, 55, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5459, 184, 99, 1, 44, "Subsection"],

Cell[CellGroupData[{
Cell[5583, 189, 66, 1, 41, "Subsubsection"],

Cell[CellGroupData[{
Cell[5674, 194, 66, 1, 27, "Input"],
Cell[5743, 197, 48, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5828, 203, 61, 1, 27, "Input"],
Cell[5892, 206, 51, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5980, 212, 64, 1, 27, "Input"],
Cell[6047, 215, 43, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6127, 221, 83, 1, 27, "Input"],
Cell[6213, 224, 485, 17, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6735, 246, 74, 1, 27, "Input"],
Cell[6812, 249, 291, 7, 55, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7152, 262, 88, 1, 41, "Subsubsection"],

Cell[CellGroupData[{
Cell[7265, 267, 76, 1, 27, "Input"],
Cell[7344, 270, 46, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7427, 276, 62, 1, 27, "Input"],
Cell[7492, 279, 43, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7572, 285, 68, 1, 27, "Input"],
Cell[7643, 288, 43, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7735, 295, 79, 1, 41, "Subsubsection"],

Cell[CellGroupData[{
Cell[7839, 300, 87, 1, 27, "Input"],
Cell[7929, 303, 570, 19, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8536, 327, 74, 1, 27, "Input"],
Cell[8613, 330, 295, 7, 55, "Output"]
}, Open  ]],
Cell[8923, 340, 53, 1, 22, "Text"],

Cell[CellGroupData[{
Cell[9001, 345, 225, 7, 87, "Input"],
Cell[9229, 354, 237, 7, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9503, 366, 123, 4, 27, "Input"],
Cell[9629, 372, 528, 17, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10194, 394, 73, 1, 27, "Input"],
Cell[10270, 397, 349, 10, 55, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10668, 413, 78, 1, 41, "Subsubsection"],

Cell[CellGroupData[{
Cell[10771, 418, 97, 1, 27, "Input"],
Cell[10871, 421, 629, 21, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11537, 447, 74, 1, 27, "Input"],
Cell[11614, 450, 291, 7, 55, "Output"]
}, Open  ]],
Cell[11920, 460, 53, 1, 22, "Text"],

Cell[CellGroupData[{
Cell[11998, 465, 165, 5, 42, "Input"],
Cell[12166, 472, 649, 21, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12852, 498, 74, 1, 27, "Input"],
Cell[12929, 501, 291, 7, 55, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

