(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13140,        494]*)
(*NotebookOutlinePosition[     14733,        542]*)
(*  CellTagsIndexPosition[     14689,        538]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Zur Aufgabe 5.01: Kinematik von Robotern", "Subtitle",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Drehmatrizen", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["Vorbelegungen", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Clear[phix, phiy, phiz];", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
\t\tMatAx = {{ 1, 0,           0 \t\t },
\t\t\t\t{ 0, Cos [phix], -Sin [phix] },
\t\t\t\t{ 0, Sin [phix],  Cos [phix] }};
\t\tMatAy = {{ Cos [phiy],  0, Sin [phiy] },
\t\t\t\t{ 0         ,  1, 0 \t\t },
\t\t\t\t{-Sin [phiy],  0, Cos [phiy] }};
\t\tMatAz = {{ Cos [phiz], -Sin [phiz], 0 },
\t\t\t\t{ Sin [phiz],  Cos [phiz], 0 },
\t\t\t\t{ 0         ,  0         , 1 }};
MatA = MatAx . MatAy . MatAz; MatrixForm[MatA]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[phiy]\ Cos[phiz]\), \(\(-Cos[phiy]\)\ Sin[phiz]\), \(Sin[
                phiy]\)},
            {\(Cos[phiz]\ Sin[phix]\ Sin[phiy] + 
                Cos[phix]\ Sin[phiz]\), \(Cos[phix]\ Cos[phiz] - 
                Sin[phix]\ Sin[phiy]\ Sin[phiz]\), \(\(-Cos[phiy]\)\ Sin[
                  phix]\)},
            {\(\(-Cos[phix]\)\ Cos[phiz]\ Sin[phiy] + 
                Sin[phix]\ Sin[phiz]\), \(Cos[phiz]\ Sin[phix] + 
                Cos[phix]\ Sin[phiy]\ Sin[phiz]\), \(Cos[phix]\ Cos[phiy]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
MatH = {{ Cos[phiy] Cos[phiz], Sin[phiz], 0},
        {-Cos[phiy] Sin[phiz], Cos[phiz], 0},
        { Sin[phiy],           0        , 1}}; MatrixForm[MatH]\
\>", "Input",\

  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[phiy]\ Cos[phiz]\), \(Sin[phiz]\), "0"},
            {\(\(-Cos[phiy]\)\ Sin[phiz]\), \(Cos[phiz]\), "0"},
            {\(Sin[phiy]\), "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
InvH = Inverse[MatH];
Simplify[InvH]//MatrixForm\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[phiz]\ Sec[phiy]\), \(\(-Sec[phiy]\)\ Sin[phiz]\), "0"},
            {\(Sin[phiz]\), \(Cos[phiz]\), "0"},
            {\(\(-Cos[phiz]\)\ Tan[phiy]\), \(Sin[phiz]\ Tan[phiy]\), "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrix AOG", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
AOG = Chop[MatA/.{phix -> 90 Degree, phiy -> 0 Degree, phiz -> 0 \
Degree}//N]; 
MatrixForm[AOG]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0", "0"},
            {"0", "0", \(-1.`\)},
            {"0", "1.`", "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrix AGE", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
AGE = MatA/.{phix -> 0 Degree, phiy -> 45 Degree, phiz -> 0 \
Degree}//N; 
MatrixForm[AGE]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.7071067811865475`", "0.`", "0.7071067811865475`"},
            {"0.`", "1.`", "0.`"},
            {\(-0.7071067811865475`\), "0.`", "0.7071067811865475`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Matrix AOE", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["AOE = AOG . AGE; \tMatrixForm[AOE]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.7071067811865475`", "0.`", "0.7071067811865475`"},
            {"0.7071067811865475`", "0.`", \(-0.7071067811865475`\)},
            {"0.`", "1.`", "0.`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Berechnung von rE = rG + AOG . rEG", "Subsection",
  CellMargins->{{13, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(\(rG\  = \ {80, \ 40, \ 
        125}\)\(;\)\(\ \)\(rEG\  = \ {20, \ \(-10\), \ \(-20\)}\)\(;\)\(\ \
\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rE\  = \ rG\  + \ AOG\  . \ rEG; \ MatrixForm[rE]\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"100.`"},
            {"60.`"},
            {"115.`"}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {100.0, 60.0, 115.0}]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Aufloesung nach den Winkeln!", "Subsection",
  CellMargins->{{13, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Aerg = AOE;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
betaerg = ArcSin[Aerg[[1,3]]]/Degree//N
betaerg = ArcTan[Aerg[[1,3]] / Sqrt[ Aerg[[2,3]]^2 + Aerg[[3,3]]^2 \
]]/Degree//N\
\>", "Input",
  CellMargins->{{13, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(45.`\)], "Output"],

Cell[BoxData[
    \(45.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
alphaerg = ArcSin[- Aerg[[2,3]]/Cos[betaerg*Degree] ]/Degree//N
alphaerg = ArcCos[  Aerg[[3,3]]/Cos[betaerg*Degree] ]/Degree//N
alphaerg = ArcTan[Aerg[[3,3]], - Aerg[[2,3]] ]/Degree//N\
\>", "Input",
  CellMargins->{{13, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(90.`\)], "Output"],

Cell[BoxData[
    \(90.`\)], "Output"],

Cell[BoxData[
    \(90.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
gammaerg = ArcSin[- Aerg[[1,2]]/Cos[betaerg*Degree] ]/Degree//N
gammaerg = ArcCos[  Aerg[[1,1]]/Cos[betaerg*Degree] ]/Degree//N
gammaerg = ArcTan[Aerg[[1,1]], - Aerg[[1,2]] ]/Degree//N\
\>", "Input",
  CellMargins->{{13, Inherited}, {Inherited, Inherited}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(0.`\)], "Output"],

Cell[BoxData[
    \(0.`\)], "Output"],

Cell[BoxData[
    \(0.`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transformationsmatizen", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
TOG = Table[0, {4}, {4}]; 
TOG[[4,4]] = 1;
Do [ Do [TOG[[i,j]] = AOG[[i,j]];
     ,{j,3}];
,{i,3}];     
TOG[[1,4]] = 80; TOG[[2,4]] = 40; TOG[[3,4]] = 125;
MatrixForm[TOG]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1.`", "0", "0", "80"},
            {"0", "0", \(-1.`\), "40"},
            {"0", "1.`", "0", "125"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TGE = Table[0, {4}, {4}]; 
TGE[[4,4]] = 1;
Do [ Do [TGE[[i,j]] = AGE[[i,j]];
     ,{j,3}];
,{i,3}];     
TGE[[1,4]] = 20; TGE[[2,4]] = -10; TGE[[3,4]] = -20;
MatrixForm[TGE]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.7071067811865475`", "0.`", "0.7071067811865475`", "20"},
            {"0.`", "1.`", "0.`", \(-10\)},
            {\(-0.7071067811865475`\), "0.`", 
              "0.7071067811865475`", \(-20\)},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TOE = TOG . TGE; MatrixForm[TOE]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.7071067811865475`", "0.`", "0.7071067811865475`", "100.`"},
            {"0.7071067811865475`", "0.`", \(-0.7071067811865475`\), "60.`"},
            {"0.`", "1.`", "0.`", "115.`"},
            {"0.`", "0.`", "0.`", "1.`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DH-Parameter finden", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["die Parameter", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Terg = TOE;", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["thetaj = ArcTan[Terg[[1,1]], Terg[[2,1]] ]/Degree//N", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(45.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["lengthdj     = Terg[[3,4]]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(115.`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["lengthlj     = Sqrt[ Terg[[1,4]]^2 + Terg[[2,4]]^2 ]", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(116.61903789690601`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["lambdaj = ArcTan[Terg[[3,3]], Terg[[3,2]] ]/Degree//N", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(90.`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Einsetzen in DH-Matrix:", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Clear[DMat]; DMat  = Array [HD,{4,4}];
DMat[[1,1]] =                Cos[thej];
DMat[[1,2]] =    - Cos[lamj] Sin[thej];
DMat[[1,3]] =      Sin[lamj] Sin[thej];
DMat[[1,4]] =            lj  Cos[thej];
DMat[[2,1]] =                Sin[thej];
DMat[[2,2]] =      Cos[lamj] Cos[thej];
DMat[[2,3]] =    - Sin[lamj] Cos[thej];
DMat[[2,4]] =            lj  Sin[thej];
DMat[[3,1]] =              0;
DMat[[3,2]] =      Sin[lamj];
DMat[[3,3]] =      Cos[lamj];
DMat[[3,4]] =             dj;
DMat[[4,1]] =              0;
DMat[[4,2]] =              0;
DMat[[4,3]] =              0;
DMat[[4,4]] =              1;
MatrixForm[DMat]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[
                thej]\), \(\(-Cos[lamj]\)\ Sin[thej]\), \(Sin[lamj]\ Sin[
                  thej]\), \(lj\ Cos[thej]\)},
            {\(Sin[
                thej]\), \(Cos[lamj]\ Cos[thej]\), \(\(-Cos[thej]\)\ Sin[
                  lamj]\), \(lj\ Sin[thej]\)},
            {"0", \(Sin[lamj]\), \(Cos[lamj]\), "dj"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["DMat01 = DMat /. {thej -> thetaj Degree, lamj -> \
lambdaj Degree, lj -> lengthlj, dj -> lengthdj}//N;\n\
MatrixForm[Chop[DMat01]]//N",
  FontWeight->"Bold"]], "Input",
  ImageRegion->{{0, 1}, {0, 1}},
  FontWeight->"Plain"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.7071067811865475`", "0.`", "0.7071067811865476`", 
              "82.4621125123532`"},
            {"0.7071067811865476`", "0.`", \(-0.7071067811865475`\), 
              "82.46211251235322`"},
            {"0.`", "1.`", "0.`", "115.`"},
            {"0.`", "0.`", "0.`", "1.`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
ShowPageBreaks->True,
WindowToolbars->{},
WindowSize->{910, 783},
WindowMargins->{{49, Automatic}, {17, Automatic}},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
      "Prof. Dr. O. Wallrapp, FHM FB06"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000004o/>3?mcoi<DR0ii0fL5N`?P0080004/0B`000000]P2:001
0000@@0000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 93, 1, 39, "Subtitle"],

Cell[CellGroupData[{
Cell[1857, 56, 67, 1, 42, "Subsection"],

Cell[CellGroupData[{
Cell[1949, 61, 71, 1, 33, "Subsubsection"],
Cell[2023, 64, 74, 1, 22, "Input"],

Cell[CellGroupData[{
Cell[2122, 69, 474, 12, 110, "Input"],
Cell[2599, 83, 661, 13, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3297, 101, 215, 6, 40, "Input"],
Cell[3515, 109, 305, 7, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3857, 121, 106, 4, 30, "Input"],
Cell[3966, 127, 342, 7, 44, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4357, 140, 68, 1, 33, "Subsubsection"],

Cell[CellGroupData[{
Cell[4450, 145, 154, 5, 30, "Input"],
Cell[4607, 152, 237, 7, 44, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4893, 165, 68, 1, 33, "Subsubsection"],

Cell[CellGroupData[{
Cell[4986, 170, 148, 5, 30, "Input"],
Cell[5137, 177, 313, 7, 44, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5499, 190, 68, 1, 33, "Subsubsection"],

Cell[CellGroupData[{
Cell[5592, 195, 84, 1, 22, "Input"],
Cell[5679, 198, 313, 7, 44, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6053, 212, 147, 2, 42, "Subsection"],
Cell[6203, 216, 140, 3, 22, "Input"],

Cell[CellGroupData[{
Cell[6368, 223, 82, 1, 22, "Input"],
Cell[6453, 226, 236, 7, 44, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6738, 239, 141, 2, 42, "Subsection"],
Cell[6882, 243, 61, 1, 22, "Input"],

Cell[CellGroupData[{
Cell[6968, 248, 237, 6, 30, "Input"],
Cell[7208, 256, 38, 1, 22, "Output"],
Cell[7249, 259, 38, 1, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7324, 265, 300, 6, 40, "Input"],
Cell[7627, 273, 38, 1, 22, "Output"],
Cell[7668, 276, 38, 1, 22, "Output"],
Cell[7709, 279, 38, 1, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7784, 285, 300, 6, 40, "Input"],
Cell[8087, 293, 37, 1, 22, "Output"],
Cell[8127, 296, 37, 1, 22, "Output"],
Cell[8167, 299, 37, 1, 22, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8253, 306, 77, 1, 42, "Subsection"],

Cell[CellGroupData[{
Cell[8355, 311, 230, 9, 80, "Input"],
Cell[8588, 322, 290, 8, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8915, 335, 231, 9, 80, "Input"],
Cell[9149, 346, 386, 9, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9572, 360, 82, 1, 22, "Input"],
Cell[9657, 363, 381, 8, 56, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10087, 377, 74, 1, 42, "Subsection"],

Cell[CellGroupData[{
Cell[10186, 382, 71, 1, 33, "Subsubsection"],
Cell[10260, 385, 61, 1, 22, "Input"],

Cell[CellGroupData[{
Cell[10346, 390, 102, 1, 22, "Input"],
Cell[10451, 393, 38, 1, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10526, 399, 76, 1, 22, "Input"],
Cell[10605, 402, 39, 1, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10681, 408, 102, 1, 22, "Input"],
Cell[10786, 411, 53, 1, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10876, 417, 103, 1, 22, "Input"],
Cell[10982, 420, 38, 1, 22, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11069, 427, 81, 1, 33, "Subsubsection"],

Cell[CellGroupData[{
Cell[11175, 432, 673, 20, 190, "Input"],
Cell[11851, 454, 512, 12, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12400, 471, 248, 5, 30, "Input"],
Cell[12651, 478, 437, 10, 56, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

