(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14943,        389]*)
(*NotebookOutlinePosition[     16448,        436]*)
(*  CellTagsIndexPosition[     16404,        432]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Zur Aufgabe 5.02: 
DH-Parameter und DH-Matrizen des 6-achsigen Knickarm-Roboters\
\>", "Subtitle",\

  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["DH-Parameter und DH-Matrix", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
\ttheatj \t= Drehwinkel bei Drehung von xi in xj um Achse zj \
(Vorzeichen)
\tdj     \t= Abstand zwischen xi und xj Achse, gemessen in zi (Vorzeichen)
\tli\t = Kreuzungsabstand der zi und zj Achse, gemessen in xj 
\t\t   (stets positiv, wenn xj von zi nach zj gerichtet ist.)
\tlambdaj = Kreuzungswinkel der zi und zj Achse, gemessen um xj \
(Vorzeichen)\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell["\<\
Clear[DMat,HD];
DMat  = Array [HD,{4,4}];MatrixForm[DMat]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(HD[1, 1]\), \(HD[1, 2]\), \(HD[1, 3]\), \(HD[1, 4]\)},
            {\(HD[2, 1]\), \(HD[2, 2]\), \(HD[2, 3]\), \(HD[2, 4]\)},
            {\(HD[3, 1]\), \(HD[3, 2]\), \(HD[3, 3]\), \(HD[3, 4]\)},
            {\(HD[4, 1]\), \(HD[4, 2]\), \(HD[4, 3]\), \(HD[4, 4]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
DMat[[1,1]] =                Cos[thej];
DMat[[1,2]] =    - Cos[lamj] Sin[thej];
DMat[[1,3]] =      Sin[lamj] Sin[thej];
DMat[[1,4]] =            lj  Cos[thej];
DMat[[2,1]] =                Sin[thej];
DMat[[2,2]] =      Cos[lamj] Cos[thej];
DMat[[2,3]] =    - Sin[lamj] Cos[thej];
DMat[[2,4]] =            lj  Sin[thej];
DMat[[3,1]] =              0;
DMat[[3,2]] =      Sin[lamj];
DMat[[3,3]] =      Cos[lamj];
DMat[[3,4]] =             dj;
DMat[[4,1]] =              0;
DMat[[4,2]] =              0;
DMat[[4,3]] =              0;
DMat[[4,4]] =              1;
MatrixForm[DMat]\
\>", "Input",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[
                thej]\), \(\(-Cos[lamj]\)\ Sin[thej]\), \(Sin[lamj]\ Sin[
                  thej]\), \(lj\ Cos[thej]\)},
            {\(Sin[
                thej]\), \(Cos[lamj]\ Cos[thej]\), \(\(-Cos[thej]\)\ Sin[
                  lamj]\), \(lj\ Sin[thej]\)},
            {"0", \(Sin[lamj]\), \(Cos[lamj]\), "dj"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DH-Matrizen der 6 Achsen:", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DHPar1\  = \ {thej\ \  \[Rule] \ theta1, dj \[Rule] d1, \ 
        lj \[Rule] 
          0, \ \ lamj \[Rule] \(-90\)\ Degree}\), "\[IndentingNewLine]", 
    \(DH01\  = \ DMat /. DHPar1; \ MatrixForm[DH01]\)}], "Input"],

Cell[BoxData[
    \({thej \[Rule] theta1, dj \[Rule] d1, lj \[Rule] 0, 
      lamj \[Rule] \(-90\)\ \[Degree]}\)], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[theta1]\), "0", \(-Sin[theta1]\), "0"},
            {\(Sin[theta1]\), "0", \(Cos[theta1]\), "0"},
            {"0", \(-1\), "0", "d1"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DHPar2\  = \ {thej\ \  \[Rule] \ theta2, dj \[Rule] d2, \ 
        lj \[Rule] l2, \ \ lamj \[Rule] 0}\), "\[IndentingNewLine]", 
    \(DH12\  = \ DMat /. DHPar2; \ MatrixForm[DH12]\)}], "Input"],

Cell[BoxData[
    \({thej \[Rule] theta2, dj \[Rule] d2, lj \[Rule] l2, 
      lamj \[Rule] 0}\)], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[theta2]\), \(-Sin[theta2]\), "0", \(l2\ Cos[theta2]\)},
            {\(Sin[theta2]\), \(Cos[theta2]\), "0", \(l2\ Sin[theta2]\)},
            {"0", "0", "1", "d2"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DHPar3\  = \ {thej\ \  \[Rule] \ theta3, dj \[Rule] 0, \ 
        lj \[Rule] 0, \ \ lamj \[Rule] 90\ Degree}\), "\[IndentingNewLine]", 
    \(DH23\  = \ DMat /. DHPar3; \ MatrixForm[DH23]\)}], "Input"],

Cell[BoxData[
    \({thej \[Rule] theta3, dj \[Rule] 0, lj \[Rule] 0, 
      lamj \[Rule] 90\ \[Degree]}\)], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[theta3]\), "0", \(Sin[theta3]\), "0"},
            {\(Sin[theta3]\), "0", \(-Cos[theta3]\), "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DHPar4\  = \ {thej\ \  \[Rule] \ theta4, dj \[Rule] d4, \ 
        lj \[Rule] 
          0, \ \ lamj \[Rule] \(-90\)\ Degree}\), "\[IndentingNewLine]", 
    \(DH34\  = \ DMat /. DHPar4; \ MatrixForm[DH34]\)}], "Input"],

Cell[BoxData[
    \({thej \[Rule] theta4, dj \[Rule] d4, lj \[Rule] 0, 
      lamj \[Rule] \(-90\)\ \[Degree]}\)], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[theta4]\), "0", \(-Sin[theta4]\), "0"},
            {\(Sin[theta4]\), "0", \(Cos[theta4]\), "0"},
            {"0", \(-1\), "0", "d4"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DHPar5\  = \ {thej\ \  \[Rule] \ theta5, dj \[Rule] 0, \ 
        lj \[Rule] 0, \ \ lamj \[Rule] 90\ Degree}\), "\[IndentingNewLine]", 
    \(DH45\  = \ DMat /. DHPar5; \ MatrixForm[DH45]\)}], "Input"],

Cell[BoxData[
    \({thej \[Rule] theta5, dj \[Rule] 0, lj \[Rule] 0, 
      lamj \[Rule] 90\ \[Degree]}\)], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[theta5]\), "0", \(Sin[theta5]\), "0"},
            {\(Sin[theta5]\), "0", \(-Cos[theta5]\), "0"},
            {"0", "1", "0", "0"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DHPar6\  = \ {thej\ \  \[Rule] \ theta6, dj \[Rule] d6, \ 
        lj \[Rule] 0, \ \ lamj \[Rule] 0}\), "\[IndentingNewLine]", 
    \(\(DH5E\  = \ DMat /. DHPar6;\)\), "\[IndentingNewLine]", 
    \(MatrixForm[DH5E]\)}], "Input"],

Cell[BoxData[
    \({thej \[Rule] theta6, dj \[Rule] d6, lj \[Rule] 0, 
      lamj \[Rule] 0}\)], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(Cos[theta6]\), \(-Sin[theta6]\), "0", "0"},
            {\(Sin[theta6]\), \(Cos[theta6]\), "0", "0"},
            {"0", "0", "1", "d6"},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["DH-Matriz DH0E", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(DH0E\  = \ DH01 . DH12 . DH23 . DH34 . DH45 . DH5E\)], "Input"],

Cell[BoxData[
    \({{Cos[
              theta6]\ \((Cos[
                    theta5]\ \((Cos[
                          theta4]\ \((Cos[theta1]\ Cos[theta2]\ Cos[theta3] - 
                            Cos[theta1]\ Sin[theta2]\ Sin[theta3])\) - 
                      Sin[theta1]\ Sin[theta4])\) + \((\(-Cos[theta1]\)\ Cos[
                          theta3]\ Sin[theta2] - 
                      Cos[theta1]\ Cos[theta2]\ Sin[theta3])\)\ Sin[
                    theta5])\) + \((\(-Cos[theta4]\)\ Sin[
                    theta1] - \((Cos[theta1]\ Cos[theta2]\ Cos[theta3] - 
                      Cos[theta1]\ Sin[theta2]\ Sin[theta3])\)\ Sin[
                    theta4])\)\ Sin[theta6], 
        Cos[theta6]\ \((\(-Cos[theta4]\)\ Sin[
                    theta1] - \((Cos[theta1]\ Cos[theta2]\ Cos[theta3] - 
                      Cos[theta1]\ Sin[theta2]\ Sin[theta3])\)\ Sin[
                    theta4])\) - \((Cos[
                    theta5]\ \((Cos[
                          theta4]\ \((Cos[theta1]\ Cos[theta2]\ Cos[theta3] - 
                            Cos[theta1]\ Sin[theta2]\ Sin[theta3])\) - 
                      Sin[theta1]\ Sin[theta4])\) + \((\(-Cos[theta1]\)\ Cos[
                          theta3]\ Sin[theta2] - 
                      Cos[theta1]\ Cos[theta2]\ Sin[theta3])\)\ Sin[
                    theta5])\)\ Sin[
              theta6], \(-Cos[
                theta5]\)\ \((\(-Cos[theta1]\)\ Cos[theta3]\ Sin[theta2] - 
                Cos[theta1]\ Cos[theta2]\ Sin[theta3])\) + \((Cos[
                    theta4]\ \((Cos[theta1]\ Cos[theta2]\ Cos[theta3] - 
                      Cos[theta1]\ Sin[theta2]\ Sin[theta3])\) - 
                Sin[theta1]\ Sin[theta4])\)\ Sin[theta5], 
        l2\ Cos[theta1]\ Cos[theta2] - d2\ Sin[theta1] + 
          d4\ \((Cos[theta1]\ Cos[theta3]\ Sin[theta2] + 
                Cos[theta1]\ Cos[theta2]\ Sin[theta3])\) + 
          d6\ \((\(-Cos[
                      theta5]\)\ \((\(-Cos[theta1]\)\ Cos[theta3]\ Sin[
                          theta2] - 
                      Cos[theta1]\ Cos[theta2]\ Sin[theta3])\) + \((Cos[
                          theta4]\ \((Cos[theta1]\ Cos[theta2]\ Cos[theta3] - 
                            Cos[theta1]\ Sin[theta2]\ Sin[theta3])\) - 
                      Sin[theta1]\ Sin[theta4])\)\ Sin[theta5])\)}, {Cos[
              theta6]\ \((Cos[
                    theta5]\ \((Cos[
                          theta4]\ \((Cos[theta2]\ Cos[theta3]\ Sin[theta1] - 
                            Sin[theta1]\ Sin[theta2]\ Sin[theta3])\) + 
                      Cos[theta1]\ Sin[theta4])\) + \((\(-Cos[theta3]\)\ Sin[
                          theta1]\ Sin[theta2] - 
                      Cos[theta2]\ Sin[theta1]\ Sin[theta3])\)\ Sin[
                    theta5])\) + \((Cos[theta1]\ Cos[
                    theta4] - \((Cos[theta2]\ Cos[theta3]\ Sin[theta1] - 
                      Sin[theta1]\ Sin[theta2]\ Sin[theta3])\)\ Sin[
                    theta4])\)\ Sin[theta6], 
        Cos[theta6]\ \((Cos[theta1]\ Cos[
                    theta4] - \((Cos[theta2]\ Cos[theta3]\ Sin[theta1] - 
                      Sin[theta1]\ Sin[theta2]\ Sin[theta3])\)\ Sin[
                    theta4])\) - \((Cos[
                    theta5]\ \((Cos[
                          theta4]\ \((Cos[theta2]\ Cos[theta3]\ Sin[theta1] - 
                            Sin[theta1]\ Sin[theta2]\ Sin[theta3])\) + 
                      Cos[theta1]\ Sin[theta4])\) + \((\(-Cos[theta3]\)\ Sin[
                          theta1]\ Sin[theta2] - 
                      Cos[theta2]\ Sin[theta1]\ Sin[theta3])\)\ Sin[
                    theta5])\)\ Sin[
              theta6], \(-Cos[
                theta5]\)\ \((\(-Cos[theta3]\)\ Sin[theta1]\ Sin[theta2] - 
                Cos[theta2]\ Sin[theta1]\ Sin[theta3])\) + \((Cos[
                    theta4]\ \((Cos[theta2]\ Cos[theta3]\ Sin[theta1] - 
                      Sin[theta1]\ Sin[theta2]\ Sin[theta3])\) + 
                Cos[theta1]\ Sin[theta4])\)\ Sin[theta5], 
        d2\ Cos[theta1] + l2\ Cos[theta2]\ Sin[theta1] + 
          d4\ \((Cos[theta3]\ Sin[theta1]\ Sin[theta2] + 
                Cos[theta2]\ Sin[theta1]\ Sin[theta3])\) + 
          d6\ \((\(-Cos[
                      theta5]\)\ \((\(-Cos[theta3]\)\ Sin[theta1]\ Sin[
                          theta2] - 
                      Cos[theta2]\ Sin[theta1]\ Sin[theta3])\) + \((Cos[
                          theta4]\ \((Cos[theta2]\ Cos[theta3]\ Sin[theta1] - 
                            Sin[theta1]\ Sin[theta2]\ Sin[theta3])\) + 
                      Cos[theta1]\ Sin[theta4])\)\ Sin[theta5])\)}, {Cos[
              theta6]\ \((Cos[theta4]\ Cos[
                    theta5]\ \((\(-Cos[theta3]\)\ Sin[theta2] - 
                      Cos[theta2]\ Sin[theta3])\) + \((\(-Cos[theta2]\)\ Cos[
                          theta3] + Sin[theta2]\ Sin[theta3])\)\ Sin[
                    theta5])\) - \((\(-Cos[theta3]\)\ Sin[theta2] - 
                Cos[theta2]\ Sin[theta3])\)\ Sin[theta4]\ Sin[
              theta6], \(-Cos[theta6]\)\ \((\(-Cos[theta3]\)\ Sin[theta2] - 
                Cos[theta2]\ Sin[theta3])\)\ Sin[
              theta4] - \((Cos[theta4]\ Cos[
                    theta5]\ \((\(-Cos[theta3]\)\ Sin[theta2] - 
                      Cos[theta2]\ Sin[theta3])\) + \((\(-Cos[theta2]\)\ Cos[
                          theta3] + Sin[theta2]\ Sin[theta3])\)\ Sin[
                    theta5])\)\ Sin[
              theta6], \(-Cos[theta5]\)\ \((\(-Cos[theta2]\)\ Cos[theta3] + 
                Sin[theta2]\ Sin[theta3])\) + 
          Cos[theta4]\ \((\(-Cos[theta3]\)\ Sin[theta2] - 
                Cos[theta2]\ Sin[theta3])\)\ Sin[theta5], 
        d1 - l2\ Sin[theta2] + 
          d4\ \((Cos[theta2]\ Cos[theta3] - Sin[theta2]\ Sin[theta3])\) + 
          d6\ \((\(-Cos[theta5]\)\ \((\(-Cos[theta2]\)\ Cos[theta3] + 
                      Sin[theta2]\ Sin[theta3])\) + 
                Cos[theta4]\ \((\(-Cos[theta3]\)\ Sin[theta2] - 
                      Cos[theta2]\ Sin[theta3])\)\ Sin[theta5])\)}, {0, 0, 0, 
        1}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
ShowPageBreaks->True,
WindowToolbars->{},
WindowSize->{910, 783},
WindowMargins->{{Automatic, 38}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Cell[ 
      "Prof. Dr. O. Wallrapp, FHM FB06"]}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1,
MacintoshSystemPageSetup->"\<\
00<0004/0B`000004Xh=2ommoi/C4@e`0fL5N`?P0080004/0B`000000]P2:001
0000AP0000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 143, 5, 58, "Subtitle"],

Cell[CellGroupData[{
Cell[1907, 60, 81, 1, 42, "Subsection"],
Cell[1991, 63, 411, 9, 77, "Text"],

Cell[CellGroupData[{
Cell[2427, 76, 115, 4, 30, "Input"],
Cell[2545, 82, 421, 8, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3003, 95, 634, 19, 180, "Input"],
Cell[3640, 116, 512, 12, 56, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4201, 134, 80, 1, 42, "Subsection"],

Cell[CellGroupData[{
Cell[4306, 139, 239, 4, 32, "Input"],
Cell[4548, 145, 124, 2, 22, "Output"],
Cell[4675, 149, 330, 8, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5042, 162, 215, 3, 32, "Input"],
Cell[5260, 167, 108, 2, 22, "Output"],
Cell[5371, 171, 359, 8, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5767, 184, 222, 3, 32, "Input"],
Cell[5992, 189, 118, 2, 22, "Output"],
Cell[6113, 193, 326, 8, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6476, 206, 239, 4, 32, "Input"],
Cell[6718, 212, 124, 2, 22, "Output"],
Cell[6845, 216, 330, 8, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7212, 229, 222, 3, 32, "Input"],
Cell[7437, 234, 118, 2, 22, "Output"],
Cell[7558, 238, 326, 8, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7921, 251, 249, 4, 43, "Input"],
Cell[8173, 257, 107, 2, 22, "Output"],
Cell[8283, 261, 327, 8, 56, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8659, 275, 69, 1, 42, "Subsection"],

Cell[CellGroupData[{
Cell[8753, 280, 83, 1, 22, "Input"],
Cell[8839, 283, 6064, 101, 392, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

