(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     78180,       1596]*)
(*NotebookOutlinePosition[     79037,       1623]*)
(*  CellTagsIndexPosition[     78993,       1619]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(mass\  = \ r^2*Pi*rho*bK\)], "Input"],

Cell[BoxData[
    \(bK\ \[Pi]\ r\^2\ rho\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(par\  = {r \[Rule] 0.03, rho \[Rule] 9000, bK \[Rule] 0.03}\)], "Input"],

Cell[BoxData[
    \({r \[Rule] 0.03`, rho \[Rule] 9000, bK \[Rule] 0.03`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mass /. par\)], "Input"],

Cell[BoxData[
    \(0.7634070148223198`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(mK = 0.8\ kg\)], "Input"],

Cell[BoxData[
    \(0.8`\ kg\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IK\  = \ m/4 \((r^2 + bK^2/3)\)\)], "Input"],

Cell[BoxData[
    \(1\/4\ m\ \((bK\^2\/3 + r\^2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(IK /. par\) /. m \[Rule] mK\)], "Input"],

Cell[BoxData[
    \(0.00023999999999999998`\ kg\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mP\  = \ 0.1\ kg\)], "Input"],

Cell[BoxData[
    \(0.1`\ kg\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lP\  = \ 0.09\)], "Input"],

Cell[BoxData[
    \(0.09`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IP\  = mP\ \(\(lP^2\)\(/\)\(12\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(0.0000675`\ kg\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(mKo\  = \ 0.2\ kg\)], "Input"],

Cell[BoxData[
    \(0.2`\ kg\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IKo\  = \ 0.00005\ kg\)], "Input"],

Cell[BoxData[
    \(0.00005`\ kg\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(par\  = \ {r \[Rule] 0.03, l \[Rule] 0.09, mK \[Rule] 0.2, 
        mP \[Rule] 0.1, mW \[Rule] 0.8, JSW \[Rule] 2.4*^-4, JSK = 5*^-5, 
        JSP \[Rule] mP*l^2/12}\)], "Input"],

Cell[BoxData[
    \({r \[Rule] 0.03`, l \[Rule] 0.09`, mK \[Rule] 0.2`, mP \[Rule] 0.1`, 
      mW \[Rule] 0.8`, JSW \[Rule] 0.00024`, 0.0000675`, 
      JSP \[Rule] \(l\^2\ mP\)\/12}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Pi/180 // N\)], "Input"],

Cell[BoxData[
    \(0.017453292519943295`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(phi - \((Floor[phi/\((2  Pi)\)]*2  Pi)\) /. 
      phi\  \[Rule] 120.5\)], "Input"],

Cell[BoxData[
    \(1.1194791635878687`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Pi/2 + 5\ *Pi/180 // N\)], "Input"],

Cell[BoxData[
    \(1.6580627893946132`\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Force[phi_, F0_, phi0_] := 
        If[phi - \((Floor[phi/\((2  Pi)\)]*2  Pi)\) < \((Pi/2 + phi0)\) && 
            phi - \((Floor[phi/\((2  Pi)\)]*2  Pi)\) >= \((phi0)\), 
          F0*Sin[\((phi - \((Floor[phi/\((2  Pi)\)]*2  Pi)\) - phi0)\)*2], 
          0];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Force[phi, 1, 0], {phi, 0, 4  Pi}, GridLines \[Rule] Automatic, 
        Frame \[Rule] True, AxesLabel \[Rule] {"\<phi [rad]\>", "\<Force\>"}, 
        PlotLabel \[Rule] "\<Force on phi\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0757881 0.0147151 0.588605 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17539 -0.0125 -3 -9 ]
[.17539 -0.0125 3 0 ]
[.32696 -0.0125 -3 -9 ]
[.32696 -0.0125 3 0 ]
[.47854 -0.0125 -3 -9 ]
[.47854 -0.0125 3 0 ]
[.63011 -0.0125 -3 -9 ]
[.63011 -0.0125 3 0 ]
[.78169 -0.0125 -6 -9 ]
[.78169 -0.0125 6 0 ]
[.93327 -0.0125 -6 -9 ]
[.93327 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13244 -18 -4.5 ]
[-0.0125 .13244 0 4.5 ]
[-0.0125 .25016 -18 -4.5 ]
[-0.0125 .25016 0 4.5 ]
[-0.0125 .36788 -18 -4.5 ]
[-0.0125 .36788 0 4.5 ]
[-0.0125 .4856 -18 -4.5 ]
[-0.0125 .4856 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.17539 0 m
.17539 .61803 L
s
.32696 0 m
.32696 .61803 L
s
.47854 0 m
.47854 .61803 L
s
.63011 0 m
.63011 .61803 L
s
.78169 0 m
.78169 .61803 L
s
.93327 0 m
.93327 .61803 L
s
0 .13244 m
1 .13244 L
s
0 .25016 m
1 .25016 L
s
0 .36788 m
1 .36788 L
s
0 .4856 m
1 .4856 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17539 0 m
.17539 .00625 L
s
[(2)] .17539 -0.0125 0 1 Mshowa
.32696 0 m
.32696 .00625 L
s
[(4)] .32696 -0.0125 0 1 Mshowa
.47854 0 m
.47854 .00625 L
s
[(6)] .47854 -0.0125 0 1 Mshowa
.63011 0 m
.63011 .00625 L
s
[(8)] .63011 -0.0125 0 1 Mshowa
.78169 0 m
.78169 .00625 L
s
[(10)] .78169 -0.0125 0 1 Mshowa
.93327 0 m
.93327 .00625 L
s
[(12)] .93327 -0.0125 0 1 Mshowa
.125 Mabswid
.0617 0 m
.0617 .00375 L
s
.0996 0 m
.0996 .00375 L
s
.13749 0 m
.13749 .00375 L
s
.21328 0 m
.21328 .00375 L
s
.25117 0 m
.25117 .00375 L
s
.28907 0 m
.28907 .00375 L
s
.36486 0 m
.36486 .00375 L
s
.40275 0 m
.40275 .00375 L
s
.44064 0 m
.44064 .00375 L
s
.51643 0 m
.51643 .00375 L
s
.55433 0 m
.55433 .00375 L
s
.59222 0 m
.59222 .00375 L
s
.66801 0 m
.66801 .00375 L
s
.7059 0 m
.7059 .00375 L
s
.7438 0 m
.7438 .00375 L
s
.81958 0 m
.81958 .00375 L
s
.85748 0 m
.85748 .00375 L
s
.89537 0 m
.89537 .00375 L
s
.97116 0 m
.97116 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13244 m
.00625 .13244 L
s
[(0.2)] -0.0125 .13244 1 0 Mshowa
0 .25016 m
.00625 .25016 L
s
[(0.4)] -0.0125 .25016 1 0 Mshowa
0 .36788 m
.00625 .36788 L
s
[(0.6)] -0.0125 .36788 1 0 Mshowa
0 .4856 m
.00625 .4856 L
s
[(0.8)] -0.0125 .4856 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04415 m
.00375 .04415 L
s
0 .07358 m
.00375 .07358 L
s
0 .10301 m
.00375 .10301 L
s
0 .16187 m
.00375 .16187 L
s
0 .1913 m
.00375 .1913 L
s
0 .22073 m
.00375 .22073 L
s
0 .27959 m
.00375 .27959 L
s
0 .30902 m
.00375 .30902 L
s
0 .33845 m
.00375 .33845 L
s
0 .39731 m
.00375 .39731 L
s
0 .42674 m
.00375 .42674 L
s
0 .45617 m
.00375 .45617 L
s
0 .51503 m
.00375 .51503 L
s
0 .54446 m
.00375 .54446 L
s
0 .57389 m
.00375 .57389 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.17539 .61178 m
.17539 .61803 L
s
.32696 .61178 m
.32696 .61803 L
s
.47854 .61178 m
.47854 .61803 L
s
.63011 .61178 m
.63011 .61803 L
s
.78169 .61178 m
.78169 .61803 L
s
.93327 .61178 m
.93327 .61803 L
s
.125 Mabswid
.0617 .61428 m
.0617 .61803 L
s
.0996 .61428 m
.0996 .61803 L
s
.13749 .61428 m
.13749 .61803 L
s
.21328 .61428 m
.21328 .61803 L
s
.25117 .61428 m
.25117 .61803 L
s
.28907 .61428 m
.28907 .61803 L
s
.36486 .61428 m
.36486 .61803 L
s
.40275 .61428 m
.40275 .61803 L
s
.44064 .61428 m
.44064 .61803 L
s
.51643 .61428 m
.51643 .61803 L
s
.55433 .61428 m
.55433 .61803 L
s
.59222 .61428 m
.59222 .61803 L
s
.66801 .61428 m
.66801 .61803 L
s
.7059 .61428 m
.7059 .61803 L
s
.7438 .61428 m
.7438 .61803 L
s
.81958 .61428 m
.81958 .61803 L
s
.85748 .61428 m
.85748 .61803 L
s
.89537 .61428 m
.89537 .61803 L
s
.97116 .61428 m
.97116 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .13244 m
1 .13244 L
s
.99375 .25016 m
1 .25016 L
s
.99375 .36788 m
1 .36788 L
s
.99375 .4856 m
1 .4856 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04415 m
1 .04415 L
s
.99625 .07358 m
1 .07358 L
s
.99625 .10301 m
1 .10301 L
s
.99625 .16187 m
1 .16187 L
s
.99625 .1913 m
1 .1913 L
s
.99625 .22073 m
1 .22073 L
s
.99625 .27959 m
1 .27959 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33845 m
1 .33845 L
s
.99625 .39731 m
1 .39731 L
s
.99625 .42674 m
1 .42674 L
s
.99625 .45617 m
1 .45617 L
s
.99625 .51503 m
1 .51503 L
s
.99625 .54446 m
1 .54446 L
s
.99625 .57389 m
1 .57389 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Force) show
99.000 13.000 moveto
(on) show
117.000 13.000 moveto
(phi) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04262 .29501 L
.0522 .41556 L
.06244 .51613 L
.0679 .55515 L
.07286 .58096 L
.07525 .58997 L
.07651 .59379 L
.07784 .59715 L
.07901 .59949 L
.08029 .60142 L
.08146 .6026 L
.08255 .6032 L
.08326 .60332 L
.08391 .60325 L
.08463 .60298 L
.08539 .60245 L
.08612 .60172 L
.08681 .60084 L
.0881 .59868 L
.08936 .59588 L
.09053 .59274 L
.09317 .58362 L
.09581 .5717 L
.09872 .55549 L
.10458 .5132 L
.11478 .41196 L
.12409 .29446 L
.13495 .1366 L
.13973 .06322 L
.14104 .04294 L
.14173 .03227 L
.14245 .02103 L
.14309 .01472 L
.14378 .01472 L
.145 .01472 L
.15426 .01472 L
.16409 .01472 L
.18485 .01472 L
.22541 .01472 L
.26446 .01472 L
.30595 .01472 L
.34594 .01472 L
.3844 .01472 L
.42532 .01472 L
.44568 .01472 L
.46472 .01472 L
.48299 .01472 L
.48825 .01472 L
.49324 .01472 L
Mistroke
.49541 .01472 L
.49772 .01472 L
.49841 .01472 L
.49905 .01472 L
.50026 .01875 L
.50139 .0363 L
.50261 .05523 L
.5222 .34011 L
.53331 .46798 L
.53863 .51609 L
.54367 .55253 L
.54846 .57839 L
.55116 .58905 L
.55245 .5931 L
.55366 .59629 L
.55476 .59867 L
.55576 .60042 L
.55688 .60188 L
.55808 .60289 L
.55917 .60329 L
.56036 .60318 L
.56161 .60243 L
.56276 .60117 L
.56404 .59914 L
.56543 .59618 L
.56795 .58884 L
.5704 .57925 L
.57265 .56834 L
.57778 .53631 L
.58321 .49207 L
.59267 .39217 L
.60282 .25915 L
.61233 .11844 L
.61652 .05394 L
.61767 .03614 L
.61891 .01693 L
.62007 .01472 L
.62115 .01472 L
.62607 .01472 L
.6313 .01472 L
.64236 .01472 L
.66247 .01472 L
.70207 .01472 L
.74014 .01472 L
.78067 .01472 L
.81968 .01472 L
.86115 .01472 L
.9011 .01472 L
.93953 .01472 L
.97619 .01472 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{348.688, 215.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005L0000eb000`400?l00000o`00003oo`3ooomM
0?ooo`00:03oool2000002T0oooo1@00000[0?ooo`<00000:P3oool3000002X0oooo0`00000X0?oo
o`<00000103oool2000002D0oooo0`0000020?ooo`D00000703oool002L0oooo00@000000?ooo`3o
ool00000:@3oool010000000oooo0?ooo`00000/0?ooo`030000003oool0oooo02P0oooo00D00000
0?ooo`3oool0oooo0000000X0?ooo`050000003oool0oooo0?ooo`000000:03oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`00000L0?ooo`009`3oool010000000oooo0?ooo`00000Z0?ooo`030000003oool0oooo
02T0oooo1@00000Y0?ooo`050000003oool0oooo0?ooo`000000:03oool01@000000oooo0?ooo`3o
ool0000002P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0703oool002L0oooo00@000000?ooo`3oool00000
:`3oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo000002X0oooo1000000Z0?ooo`<0
0000:@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000002D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0K0?ooo`009`3oool010000000oooo0?ooo`00000X0?oo
o`050000003oool0oooo0?ooo`000000:P3oool00`000000oooo0000000Z0?ooo`030000003oool0
oooo02X0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000009@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool06P3oool002L0oooo00@000000?ooo`3oool00000:03oool01@000000oooo0?ooo`3oool00000
02/0oooo0P00000[0?ooo`030000003oool0oooo02T0oooo00D000000?ooo`3oool0oooo0000000W
0?ooo`800000103oool010000000oooo0?ooo`00000T0?ooo`8000000`3oool01@000000oooo0?oo
o`3oool0000001`0oooo000X0?ooo`800000:P3oool3000002d0oooo00<000000?ooo`3oool0:P3o
ool2000002X0oooo0`00000Y0?ooo`030000003oool0oooo00<0oooo0P00000V0?ooo`030000003o
ool0oooo0080oooo0`00000M0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00o`3ooomM0?ooo`00
o`3ooomM0?ooo`00o`3ooomM0?ooo`008P3ooooo000002l00000303oool00280oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02P3oool001X0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo0340oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02X0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool001T0oooo00@000000?ooo`3oool0
00001@3oool3000000@0oooo00<000000?ooo`3oool08@3ooom/000002<0ooooK00000050?ooo`<0
0000303oool001T0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool00`3oool00`000000oooo0?ooo`0Q0?ooo`04
0000003oool0oooo0000Obd0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?oo
o`030000003oool0oooo00X0oooo000I0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00<0oooo00<000000?oo
o`3oool08@3oool010000000oooo0?ooo`0007l]0?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`006@3oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`06
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`03
0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool0001o;@3oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool001X0oooo0P000006
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`03
0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool0001o;@3oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00@0oooo00<00000
0?ooo`3oool0803oool010000000oooo0?ooo`0007l]0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0P
0?ooo`040000003oool0oooo0000Obd0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?oo
o`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo0200oooo00@00000
0?ooo`3oool0001o;@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<0
00000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool0803oool010000000oooo0?ooo`00
07l]0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`008P3oool2000000H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`07
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`04
0?ooo`030000003oool0oooo0200oooo00@000000?ooo`3oool0001o;@3oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo00l0oooo0`00000<0?ooo`008P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0O
0?ooo`050000003oool0oooo0?ooo`0007l0;@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool07`3oool0
1@000000oooo0?ooo`3oool0001o02d0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?oo
o`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo00D00000
0?ooo`3oool0oooo0000O`0]0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3o
ool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`050000003oool0
oooo0?ooo`0007l0;@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<0
00000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3o
ool0001o02d0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003o
ool0oooo00X0oooo000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo00D000000?ooo`3oool0oooo0000
O`0]0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`0007l0;@3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3o
ool00280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00L0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo00@0oooo00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0001o02d0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R
0?ooo`8000001P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00@0oooo00<00000
0?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0001o02d0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0?0?ooo`<00000303oool00280oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool07`3oool0
1@000000oooo0?ooo`3oool0001o02d0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?oo
o`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0oooo01h0oooo00D00000
0?ooo`3oool0oooo0000O`0]0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3o
ool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool01@3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0
oooo0?ooo`0007l0;@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<0
00000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`02
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A
0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0080oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0
:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0
:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`080?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`050?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool2
000000L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool03`3oool3000000`0oooo000R0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`050?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool00`0007l0
oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool01@3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool0:`3oool00`0007l0
oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00D0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo
000R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`080?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?oo
o`050?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`008P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool02@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<00000
0?ooo`3oool02P3oool000h0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D000001@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02@3oool0
0`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool01@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool0
00d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`090?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`060?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`003@3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000=0?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool0103oool3000000L0001o00<000000000O`0007l06`00
07l00`000000001o0000O`1^0000O`030000000007l0001o01`0001o00<000000000O`0007l0L000
07l3000000`0oooo000=0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`090?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo
0?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo
0?ooo`0:0?ooo`003@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool02@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3o
ool01P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3o
ool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3o
ool02P3oool000h0oooo0P0000090?ooo`<000001P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00<0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00H0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`060?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02@3oool00`00
07l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool01P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool0:`3oool00`00
07l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00T0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00H0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0
oooo000R0?ooo`800000203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00H0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0?0?ooo`<00000303oool00280oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00H0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`06
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:
0?ooo`008P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool02P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?oo
o`3oool02P3oool00280oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00X0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo00H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`03
0000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0
:`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
0`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0
4@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00<0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00L0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`030?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool2000000T0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool03`3oool3000000`0oooo000R0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00L0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?oo
o`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`070?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`0[0?oo
o`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?oo
o`008P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool02P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3o
ool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3o
ool02P3oool00280oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00X0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000
003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3o
ool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00@0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo0P0000090?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00@0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
00l0oooo0`00000<0?ooo`008P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00@0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140
oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo00P0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`040?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo
0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`080?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0103oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00@0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00P0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`040?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`080?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`00
3P3oool2000000@0oooo00<000000?ooo`3oool00`3oool3000000D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool0
:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00P0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`050?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0
:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000=0?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool000d0oooo00@000000?ooo`3oool00000
1`3oool5000000D0oooo0`0000090000O`030000000007l0001o01L0001o00<000000000O`0007l0
LP0007l00`000000001o0000O`0G0000O`030000000007l0001o07<0001o0`00000<0?ooo`003@3o
ool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3o
ool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`050?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3o
ool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000=0?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00D0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool000d0oooo00@000000?ooo`3oool0
00002@3oool2000000H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`03
0000003oool0oooo00X0oooo000>0?ooo`8000002`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`080?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0203o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3o
ool00280oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00`0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0
oooo00X0oooo000R0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0<0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`00
07l0oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00`00
07l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`00
0000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140
oooo00<000000?ooo`3oool02P3oool00280oooo0P00000;0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00l0oooo
0`00000<0?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0303oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<0
00000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`06
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A
0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00H0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0
:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00T0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0
:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`090?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool0
0`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool0
0280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00`0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
00T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo
00X0oooo000R0?ooo`8000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00T0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0?0?ooo`<00000303oool00280oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00T0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo
000R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0=0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?oo
o`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool03@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<00000
0?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?oo
o`030000O`3oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`060?oo
o`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?oo
o`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3o
ool0:`3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3o
ool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00L0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00X0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool20000
00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool03`3oool3000000`0oooo000R0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool02P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00X0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0:
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:
0?ooo`008P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool03P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool02P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?oo
o`3oool02P3oool000h0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000060?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0:0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`00
3@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`00
07l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool02`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0:`3oool00`00
07l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool000d0
oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000D0oooo0`00000;
0000O`030000000007l0001o0180001o00<000000000O`0007l0N00007l00`000000001o0000O`0B
0000O`030000000007l0001o07D0001o0`00000<0?ooo`003@3oool010000000oooo0?ooo`000007
0?ooo`@000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool03P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<00000
0?ooo`3oool02P3oool000d0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0;
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:
0?ooo`003@3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00/0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000>0?oo
o`8000002P3oool2000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?oo
o`030000O`3oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?oo
o`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?oo
o`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3o
ool0:`3oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0203oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3o
ool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00P0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00/0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool20000
00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool03`3oool3000000`0oooo000R0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0;0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool02`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00`0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0<
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:
0?ooo`008P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?oo
o`3oool02P3oool00280oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00l0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`03
0000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0
:`3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
2@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0
4@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00T0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo0P00000=0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00T0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo00l0oooo0`00000<0?ooo`008P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00T0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<0001o0?ooo`3oool0:`3oool00`0007l0
oooo0?ooo`0[0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`090?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0
oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0303oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00T0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00`0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?oo
o`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0<0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0[0?oo
o`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?oo
o`008P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0403oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo00<0001o0?ooo`3o
ool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3o
ool02P3oool00280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0100oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000
003oool0oooo00X0oooo000R0?ooo`8000003P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0100oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0?0?ooo`<00000303o
ool00280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0100oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0
oooo00X0oooo000R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0@0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`00
07l0oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`00
07l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`00
0000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140
oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo
0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`003P3oool2000000@0oooo00<00000
0?ooo`3oool00P3oool3000000H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A
0?ooo`030000003oool0oooo00X0oooo000=0?ooo`040000003oool0oooo000000L0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0A0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3o
ool00`000000oooo0?ooo`0:0?ooo`003@3oool010000000oooo0?ooo`0000070?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo
00<000000?ooo`3oool02P3oool000d0oooo00@000000?ooo`3oool00000203oool3000000H0oooo
0`00000>0000O`030000000007l0001o00`0001o00<000000000O`0007l0OP0007l00`000000001o
0000O`0;0000O`030000000007l0001o07T0001o0`00000<0?ooo`003@3oool010000000oooo0?oo
o`0000070?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool000d0oooo00@000000?ooo`3oool0
00001`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool0:`3oool00`00
07l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`00
07l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000>0?ooo`8000002@3oool3000000H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00h0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0
oooo000R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0B0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo
0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo
0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool04P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<0
00000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A
0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo0P00000@0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00`0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo00l0oooo0`00000<0?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00`0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00l0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo
02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool00`0007l0
oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool03`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0
oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00l0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo02/0oooo
00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo
000R0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0C0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?oo
o`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`008P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<00000
0?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01<0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?oo
o`030000O`3oool0oooo0100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?oo
o`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?oo
o`030000003oool0oooo00X0oooo000R0?ooo`8000004@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01<0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0?0?ooo`<0
0000303oool00280oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01@0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000
O`3oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000
O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000
003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3o
ool00`0007l0oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3o
ool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3o
ool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo02/0oooo00<0001o0?ooo`3oool0403oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0
oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<0001o0?ooo`3oool0:`3oool00`00
07l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`00
07l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0
oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00h0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo
0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool02P3oool00280oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R
0?ooo`8000004`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0?0?ooo`<00000303oool00280oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0180oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000R0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0[0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`00
8P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
5@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0
4P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<0001o0?ooo`3oool0
:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3oool0
2P3oool00280oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01D0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`030000O`3o
ool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003o
ool0oooo00X0oooo000R0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool0
0`000000oooo0?ooo`0:0?ooo`008P3oool00`000000oooo0?ooo`0D0?ooo`050000003oool0oooo
0?ooo`000000603oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o
0?ooo`3oool04`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<00000
0?ooo`3oool02P3oool001T0oooo0`0000060?ooo`030000003oool0oooo01@0oooo00D000000?oo
o`3oool0oooo0000000H0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool0
0`0007l0oooo0?ooo`0C0?ooo`050000003oool0oooo0?ooo`0000004P3oool00`0007l0oooo0?oo
o`0[0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool04@3oool00`000000oooo0?oo
o`0:0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01@0oooo00@00000
0?ooo`3oool000006@3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool0503oool00`000000oooo0000000C0?ooo`030000O`3oool0oooo02/0oooo00<0
001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo000J
0?ooo`030000003oool0oooo00D0oooo0`00000E0?ooo`<000006@3oool00`0007l0oooo0?ooo`0[
0?ooo`030000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0503oool3000001<0oooo00<0001o
0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo00l0oooo0`00000<
0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0340oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo02X0oooo00<0001o0?oo
o`3oool0:`3oool00`0007l0oooo0?ooo`0[0?ooo`030000O`3oool0oooo0140oooo00<000000?oo
o`3oool02P3oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0a0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0Z0?ooo`03
0000O`3oool0oooo02/0oooo00<0001o0?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0A0?ooo`03
0000003oool0oooo00X0oooo000I0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool02P3oool001X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0:0?ooo`008P3ooooo000002l00000303oool00?l0ooooG@3oool00?l0
ooooG@3oool00?l0ooooG@3oool00?l0ooooG@3oool00<X0oooo0`00002?0?ooo`00b`3oool00`00
0000oooo0?ooo`2>0?ooo`00U03oool3000000@0oooo0`0000020?ooo`<00000103oool3000000<0
oooo0`0000090?ooo`<000000P3oool3000000030?ooo`000000000000L0oooo0`0000020?ooo`/0
0000P@3oool009D0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000002`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0P@3oool009D0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`D000001`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0P@3oool009D0oooo0`0000020?ooo`050000
003oool0oooo0?ooo`0000000P3oool2000000<0oooo00L000000?ooo`3oool0oooo0000003oool0
000000<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000080oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0P@3oool009D0oooo00<000000?ooo`3oool00`3oool300000080
oooo0P0000000`3oool00000000000020?ooo`<000000`3oool3000000T0oooo0`0000020?ooo`@0
0000203oool4000000<0oooo0`0000020?ooo`<00000P`3oool009D0oooo00@000000?ooo`3oool0
0000>03oool00`000000oooo0?ooo`280?ooo`00U03oool5000003L0oooo0P0000060?ooo`030000
003oool0oooo0840oooo003o0?oooed0oooo003o0?oooed0oooo0000\
\>"],
  ImageRangeCache->{{{0, 347.688}, {214.5, 0}} -> {-1.81395, -0.0970549, \
0.0438484, 0.00564587}}]
}, Open  ]]
}, Open  ]],

Cell[" ", "Subsubsection"]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowSize->{743, 517},
WindowMargins->{{Automatic, 107}, {Automatic, 2}},
ShowCellLabel->False,
MacintoshSystemPageSetup->"\<\
00<0001804P00000=?HTO_ggoPPg42IQ0dL5N`?P0080001804P000000]X2:001
0000I00000400@410?l00BL?00400@0000000000000006P801T1T0000000@000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 57, 1, 27, "Input"],
Cell[1787, 55, 54, 1, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1878, 61, 92, 1, 27, "Input"],
Cell[1973, 64, 87, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2097, 70, 44, 1, 27, "Input"],
Cell[2144, 73, 53, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2234, 79, 45, 1, 27, "Input"],
Cell[2282, 82, 42, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2361, 88, 64, 1, 27, "Input"],
Cell[2428, 91, 64, 1, 45, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2529, 97, 62, 1, 27, "Input"],
Cell[2594, 100, 61, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2692, 106, 26, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[2743, 110, 49, 1, 27, "Input"],
Cell[2795, 113, 42, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2874, 119, 46, 1, 27, "Input"],
Cell[2923, 122, 39, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2999, 128, 73, 1, 27, "Input"],
Cell[3075, 131, 48, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3172, 138, 26, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[3223, 142, 50, 1, 27, "Input"],
Cell[3276, 145, 42, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3355, 151, 54, 1, 27, "Input"],
Cell[3412, 154, 46, 1, 26, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3507, 161, 26, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[3558, 165, 198, 3, 43, "Input"],
Cell[3759, 170, 197, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4005, 179, 26, 0, 42, "Subsubsection"],

Cell[CellGroupData[{
Cell[4056, 183, 44, 1, 27, "Input"],
Cell[4103, 186, 55, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4195, 192, 103, 2, 27, "Input"],
Cell[4301, 196, 53, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4391, 202, 55, 1, 27, "Input"],
Cell[4449, 205, 53, 1, 26, "Output"]
}, Open  ]],
Cell[4517, 209, 299, 5, 75, "Input"],

Cell[CellGroupData[{
Cell[4841, 218, 232, 3, 43, "Input"],
Cell[5076, 223, 73047, 1367, 224, 7456, 553, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[78150, 1594, 26, 0, 42, "Subsubsection"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

